#!/bin/bash

# environment variables common to this version/user (=clancy james here! Change this to your own directory!)
KM3USER=cjames
KM3_V=v5r0
KM3DIR=/sps/km3net/users/${USER}/km3

if [ ! -d ${KM3DIR} ]
then
	echo "Directory $KM3DIR does not exist - have you specified the correct user (= ${USER} ) and directory ( = ${KM3DIR} )?"
	exit
fi

OUTPUTDIR=${KM3DIR}/scripts
PLATFORM=Linux
KM3DAT=${KM3DIR}/dat

# sets the gen executable
GENEXE=$KM3DIR/${PLATFORM}/gen${KM3_V}.exe
if [ ! -f "$GENEXE" ]
then
   echo "Error: gen executable ${GENEXE} not readable"
   exit
fi

##### environment variable common to all five gen files #####
export WLENFILE=${KM3DAT}/gen-water-optical-partic-0.0075.dat
export RADFILE=temp-gen-radii.dat
export WATMODEL='partic'
######## Muon table #########

# gets random number seeds from the computer time
set tempseed1=`date +%s`
set SEED1=${tempseed1:5:5}
set SEED2=${tempseed1:4:1}${tempseed1:6:4}
set SEED3=${tempseed1:3:1}${tempseed1:6:4}

# environment variables specific to this run of gen
export PTYP=5
export FILEROOT=muon-100gev_${KM3_V}
export HBOOKFILE=${OUTPUTDIR}/${FILEROOT}.gen
export DESCFILE=${OUTPUTDIR}/${FILEROOT}.desc

# specifies user inputs used by km3
ORIG_RAD_FILE=${KM3DIR}/dat/gen-write_mu_0.1.dat

# gen water radii applicable for km3 v4r3
cp ${ORIG_RAD_FILE} temp-gen-radii.dat

${GENEXE} <<EOF
# number of events to run
NEVT      4000
# particle type (5 = muon, 3 = electron)
PTYP      ${PTYP}
# particle energy in gev
LAMB      100.
# first random number seed
SEED      ${SEED1}
# water model id
WMOD     '${WATMODEL}'
# lambda abs from input (if 0 from Geasim)
IABS      1
# second rndm number group
RNDM      ${SEED2} ${SEED3}
# muon-nucleus interactions 
MUNU      0
# hadr. interactions
HADR      4
# photon induced nuclear fission
PFIS      1
# delta ray production
DRAY      1
# continuous energy loss
LOSS      1
# emin emax nbins for cross-section tables
ERAN  1.e-5 1.e7 120
# tracking cut for gammas, electrons, neutral hadr, charg hadr, muons, bremmss, ......
CUTS  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002 0.0002
END
EOF

######## 100GeV electron table #########

# use this for all electron tables
export ORIG_RAD_FILE=${KM3DIR}/dat/gen-write_0.01.dat

# gets random number seeds from the computer time
set tempseed1=`date +%s`
set SEED1=${tempseed1:5:5}
set SEED2=${tempseed1:4:1}${tempseed1:6:4}
set SEED3=${tempseed1:3:1}${tempseed1:6:4}

# environment variables specific to this run of gen
export PTYP=3
export FILEROOT=elec-100gev_${KM3_V}
export HBOOKFILE=${OUTPUTDIR}/${FILEROOT}.gen
export DESCFILE=${OUTPUTDIR}/${FILEROOT}.desc

cp ${ORIG_RAD_FILE} temp-gen-radii.dat

${GENEXE} <<EOF
# number of events to run
NEVT      100
# particle type (5 = muon, 3 = electron)
PTYP      ${PTYP}
# particle energy in gev
LAMB      100.
# first random number seed
SEED      ${SEED1}
# water model id
WMOD     '${WATMODEL}'
# lambda abs from input (if 0 from Geasim)
IABS      1
# second rndm number group
RNDM      ${SEED2} ${SEED3}
# muon-nucleus interactions 
MUNU      0
# hadr. interactions
HADR      4
# photon induced nuclear fission
PFIS      1
# delta ray production
DRAY      1
# continuous energy loss
LOSS      1
# emin emax nbins for cross-section tables
ERAN  1.e-5 1.e7 120
# tracking cut for gammas, electrons, neutral hadr, charg hadr, muons, bremmss, ......
CUTS  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002 0.0002
END
EOF


#####  10 GeV electron table ######

export ORIG_RAD_FILE=${KM3DIR}/dat/gen-write_0.01.dat

# gets random number seeds from the computer time
set tempseed1=`date +%s`
set SEED1=${tempseed1:5:5}
set SEED2=${tempseed1:4:1}${tempseed1:6:4}
set SEED3=${tempseed1:3:1}${tempseed1:6:4}

# environment variables specific to this run of gen
export PTYP=3
export FILEROOT=elec-10gev_${KM3_V}
export HBOOKFILE=${OUTPUTDIR}/${FILEROOT}.gen
export DESCFILE=${OUTPUTDIR}/${FILEROOT}.desc

cp ${ORIG_RAD_FILE} temp-gen-radii.dat

${GENEXE} <<EOF
# number of events to run
NEVT      1000
# particle type (5 = muon, 3 = electron)
PTYP      ${PTYP}
# particle energy in gev
LAMB      10.
# first random number seed
SEED      ${SEED1}
# water model id
WMOD     '${WATMODEL}'
# lambda abs from input (if 0 from Geasim)
IABS      1
# second rndm number group
RNDM      ${SEED2} ${SEED3}
# muon-nucleus interactions 
MUNU      0
# hadr. interactions
HADR      4
# photon induced nuclear fission
PFIS      1
# delta ray production
DRAY      1
# continuous energy loss
LOSS      1
# emin emax nbins for cross-section tables
ERAN  1.e-5 1.e7 120
# tracking cut for gammas, electrons, neutral hadr, charg hadr, muons, bremmss, ......
CUTS  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002 0.0002
END
EOF

#####  10 GeV electron table ######

export ORIG_RAD_FILE=${KM3DIR}/dat/gen-write_0.1.dat

# gets random number seeds from the computer time
set tempseed1=`date +%s`
set SEED1=${tempseed1:5:5}
set SEED2=${tempseed1:4:1}${tempseed1:6:4}
set SEED3=${tempseed1:3:1}${tempseed1:6:4}

# environment variables specific to this run of gen
export PTYP=3
export FILEROOT=elec-1gev_${KM3_V}
export HBOOKFILE=${OUTPUTDIR}/${FILEROOT}.gen
export DESCFILE=${OUTPUTDIR}/${FILEROOT}.desc

cp ${ORIG_RAD_FILE} temp-gen-radii.dat

${GENEXE} <<EOF
# number of events to run
NEVT      1000
# particle type (5 = muon, 3 = electron)
PTYP      ${PTYP}
# particle energy in gev
LAMB      1.
# first random number seed
SEED      ${SEED1}
# water model id
WMOD     '${WATMODEL}'
# lambda abs from input (if 0 from Geasim)
IABS      1
# second rndm number group
RNDM      ${SEED2} ${SEED3}
# muon-nucleus interactions 
MUNU      0
# hadr. interactions
HADR      4
# photon induced nuclear fission
PFIS      1
# delta ray production
DRAY      1
# continuous energy loss
LOSS      1
# emin emax nbins for cross-section tables
ERAN  1.e-5 1.e7 120
# tracking cut for gammas, electrons, neutral hadr, charg hadr, muons, bremmss, ......
CUTS  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002 0.0002
END
EOF

#####  10 GeV electron table ######

export ORIG_RAD_FILE=${KM3DIR}/dat/gen-write_0.1.dat

# gets random number seeds from the computer time
set tempseed1=`date +%s`
set SEED1=${tempseed1:5:5}
set SEED2=${tempseed1:4:1}${tempseed1:6:4}
set SEED3=${tempseed1:3:1}${tempseed1:6:4}

# environment variables specific to this run of gen
export PTYP=3
export FILEROOT=elec-100mev_${KM3_V}
export HBOOKFILE=${OUTPUTDIR}/${FILEROOT}.gen
export DESCFILE=${OUTPUTDIR}/${FILEROOT}.desc
export RADFILE=temp-gen-radii.dat

cp ${ORIG_RAD_FILE} temp-gen-radii.dat

${GENEXE} <<EOF
# number of events to run
NEVT      10000
# particle type (5 = muon, 3 = electron)
PTYP      ${PTYP}
# particle energy in gev
LAMB      0.1
# first random number seed
SEED      ${SEED1}
# water model id
WMOD     '${WATMODEL}'
# lambda abs from input (if 0 from Geasim)
IABS      1
# second rndm number group
RNDM      ${SEED2} ${SEED3}
# muon-nucleus interactions 
MUNU      0
# hadr. interactions
HADR      4
# photon induced nuclear fission
PFIS      1
# delta ray production
DRAY      1
# continuous energy loss
LOSS      1
# emin emax nbins for cross-section tables
ERAN  1.e-5 1.e7 120
# tracking cut for gammas, electrons, neutral hadr, charg hadr, muons, bremmss, ......
CUTS  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002  0.0002 0.0002
END
EOF


