#!/bin/bash

########## README ############
# This script runs km3mc in a local shell in Lyon. Both hit and gen must have previously been run to generate a set of tables - see run-gen-batchlyon.sh and run-hit-batchlyon.sh for examples.

######### Local parameters - you ought to check these! ########
# You are probably not me. Change user!
USER=cjames

# local km3 directory - i.e. here
KM3_DIR=/sps/km3net/users/${USER}/km3

# It is also possible that for a personalised version of km3, the following variables will need to be modified:
PLATFORM=Linux

# name for the km3 version - names the executable
KM3_V=v5r0

# tag for the hit files and hit directory - this is the same variable as would be used in 'run-hit-batchlyon.sh'
HITTAG=''

# directory containing the km3 tables
TABLE_DIR=${KM3_DIR}/scripts/${HITTAG}hit_tables

# defines km3 executable
KM3_EXEC=${KM3_DIR}/${PLATFORM}/km3mc${KM3_V}.exe

# km3 data directory
KM3_DAT=${KM3_DIR}/dat

######### Defines input and output files ##########

# input file (assumed from genhen) - must be in standard ANTARES format. An example is included in the 'dat' directory
export EVIFIL=${KM3_DAT}/km3-genhen_example_output.evt

# output file - will be in standard ANTARES format
export EVOFIL=km3-genhen_example_output.km3${KM3_V}.evt

# specifies the detector geometry (here, for the ANTARES detector)
export GEOFIL=$ANTRS_ROOT/DETECTOR/l12_c00_s01.det

####### Runs km3mc with default parameters #########

# required variable - do not trap floating point errors
export TRAPKM3FPE=0

##### NOTE: for ANTARES and KM3NeT, the electrons have different energies ####
# hit output tables - in binary format
export hbmuon=${TABLE_DIR}/km3-muon-${TAG}100gev_${KM3_V}.hit
export hbele1=${TABLE_DIR}/km3-elec-${TAG}100mev_${KM3_V}.hit
export hbele2=${TABLE_DIR}/km3-elec-${TAG}1gev_${KM3_V}.hit
export hbele3=${TABLE_DIR}/km3-elec-${TAG}10gev_${KM3_V}.hit
export hbele4=${TABLE_DIR}/km3-elec-${TAG}100gev_${KM3_V}.hit

# descriptor files - these are in plain text
export demuon=${TABLE_DIR}/km3-muon-${TAG}100gev_${KM3_V}.desc
export deele1=${TABLE_DIR}/km3-elec-${TAG}100mev_${KM3_V}.desc
export deele2=${TABLE_DIR}/km3-elec-${TAG}1gev_${KM3_V}.desc
export deele3=${TABLE_DIR}/km3-elec-${TAG}10gev_${KM3_V}.desc
export deele4=${TABLE_DIR}/km3-elec-${TAG}100gev_${KM3_V}.desc

# music data files
export hbdisp=${KM3_DAT}/km3-dispersion.hbook
export Meloss=${KM3_DAT}/km3-music-eloss.dat
export Mddxsections=${KM3_DAT}/km3-music-double-diff.dat
export Mxsections=${KM3_DAT}/km3-music-cross-sections.dat

# Run KM3 with minimal inputs

${KM3_EXEC} << EOF
# random number initialiser
IRAND 3 1000 0 0
# max number of events to process
INEVT 19000000
# do not write empty events
IEMPT 0
END
EOF

# the version below shows a list of commonly used km3 cards set to their default values
# running this as is will produce exactly the same output as the above call
# see the file ${KM3DIR}/inc/km3-cards.inc for a full list of defaults

#${KM3_EXEC} << EOF
#IRAND 3 1000 0 0
#INEVT 1000		only do 1000 events maximum
#INGRP 2		group velocity includes dispersion (i.e. wavelength-dependence)
#IEMPT 1		write (1) or do not (0) events with no hits
#RECHO 0		do (1) or not (0) record the hit origin (which particle)
#ELREC 0		do not record muon energy loss (0) or record it every N metres (N)
#DIVTK 1.0		distance for grouping muon track segments multiplied by 1.0 (no effect)
#INOPA 1		Use the OPA (1), turn it off (0), or use the MPA (2)
#INPOL 0		use linear interpolation between bins
#IPT40 0, 500		Controls K40 hits - IPT40 0 X turns it off
#XRAWH	0 25 250	If (xrawh(1) .eq. 0) do nothing; if > 0. then do something with 'hit_raw' tag...
#END
#EOF

