C* Original author: Martin Moorhead<BR>
C* Original date: 21 March 1996<BR>
C*
C* Find the distance from a point in a given direction to a sphere of a 
C* given radius centered on the origin. It assumes that the sphere is
C* centred at the origin.
C* 
C* @param pos Input. The REAL(3) co-ordinates of the photon
C* @param dir Input. The REAL(3) direction cosines of the photon
C* @param rad Input. The radius of the sphere
C* @param dist Output. The distance to the sphere
C* @param flag Output. Returns 0 if the photon misses the sphere. 1 otherwise
C*
C* @warning UNVERIFIED
C*/

      SUBROUTINE distance_to_sphere( pos, dir, rad, dist, flag )
 
      IMPLICIT NONE

      INTEGER*4 flag
      REAL*8    pos(3), dir(3), rad, dist, dot, root
      REAL*8    dist1, dist2, pos2 

      flag = 0
      dot  = pos(1)*dir(1) + pos(2)*dir(2) + pos(3)*dir(3)
      pos2 = pos(1)*pos(1) + pos(2)*pos(2) + pos(3)*pos(3) 
      root = dot*dot - pos2 + rad*rad

      if ( root .gt. 0.0d0 ) then
C
C--- there are two real solutions to the quadratic equation for the 
C--- intersection of this line with this sphere. dist1 and dist2 are the 
C--- distances to either of these intersection points (N.B. either or both 
C--- distances can be negative)
C
         dist1 = - dot + sqrt( root )
         dist2 = - dot - sqrt( root )

         if ( dist1 .gt. 0.0d0 ) then
C
C--- dist1 is in the forward direction. We have at least one good solution
C
            flag = 1

            if ( dist2 .gt. 0.0d0 ) then
C           
C--- then we have two good solutions and we find the closest one
C
               if ( dist1 .lt. dist2 ) then
                  dist = dist1
               else
                  dist = dist2
               endif

            else
C
C--- only dist1 is a good solution
C
               dist = dist1

            endif

         elseif ( dist2 .gt. 0.0d0 ) then
C
C--- only dist2 is a good solution
C
            flag = 1
            dist = dist2 

         endif
      endif
      end
