C* Original author: Clancy W James
C* Original date: 20 March 2012
C*
C*  In :   xlambda = photon wave-length (in nanometers)                  
C*  Out:   fraction of Rayleigh scattering at this wavelength               
C*
C* Use the tabulated values of eta calculated in 'mobley' to
C* determine the scattering fraction from particles and water
C* molecules. This treats the scattering off pure seawater as
C* 'known' and hence the remaining component must come from
C* particles.          
C* (see C.D.Mobley 'Light and Water' ISBN 0-12-502750-8 pag.119)         
C* 
C*

      REAL FUNCTION ETA_FROM_DATA(xlambda)
      include 'gen.inc'
      REAL   Vs, Vl, pure_sea, small_par, large_par
      REAL*8 xlambda
      REAL eta

      if ( P_wlbin .eq. 0) then
C
C--- extrapolate below first bin 
C
         slope = (TAB_ETA(2)-TAB_ETA(1)) / (in_wlen(2)-in_wlen(1))
         eta = TAB_ETA(1) + (xlambda - in_wlen(1)) * slope

      elseif ( P_wlbin .eq. in_nwavelens) then
C
C--- extrapolate above last bin 
C
         slope = (TAB_ETA(in_nwavelens)-TAB_ETA(in_nwavelens-1)) / 
     1           (in_wlen(in_nwavelens) - in_wlen(in_nwavelens-1))
         eta = TAB_ETA(in_nwavelens) + (xlambda - 
     1           in_wlen(in_nwavelens)) * slope

      else
C
C--- interpolate 
C
         slope = (TAB_ETA(P_wlbin+1)-TAB_ETA(P_wlbin)) / 
     1           (in_wlen(P_wlbin+1) - in_wlen(P_wlbin))
         eta = TAB_ETA(P_wlbin)+(xlambda-in_wlen(P_wlbin))*slope

      endif
C
C--- check for unphysical extrapolations
C
      if ( eta .le. 0.0 ) then
      	 eta = 0.0
      else if (eta .ge. 1.0) then
      	 eta = 1.0
      endif

      eta_from_data=eta
      
 999  CONTINUE
      END
