C* Original author: Sergio Navas Concha<BR>
C* Original date: 10 June 1999<BR>
C*
C*  In :   xlambda = photon wave-length (in nanometers)                  
C*  Out:   scatlength = scattering length (in meters)                    
C*
C* Use the Kopelevich model for spectral volume scattering functions     
C* The model separates the contributions by:                             
C* - pure_sea: pure sea water                                            
C* - small_par: 'small' particles (size < 1 micro meter)                 
C* - large_par: 'large' particles (size > 1 micro meter)                 
C* (see C.D.Mobley 'Light and Water' ISBN 0-12-502750-8 pag.119)         
C* 
C* <PRE>                                                                    
C*   Vs    Vl   lambda  scatlength                                       
C*  ----------  ------  ----------                                       
C*  0.01  0.01   532     51.83321                                 
C*               466     40.80480                                        
C*               355     23.29228                                        
C* </PRE>
C*
C* The two parameters specifying the model are:
C* - Vs is the volume concentration of small particles with units of cm3 of 
C* particles per m3 of water
C* - Vl is the analogous volume concentration of large particles
C*
C* @param xlambda Input. Photon wavelength in nm
C* @param scatlength Output. The scattering length in m
C*
C* @warning UNVERIFIED
C*/

      SUBROUTINE KOPELEVICH(xlambda,scatlength)

      REAL   Vs, Vl, pure_sea, small_par, large_par
      REAL*8 xlambda,scatlength

      Vs= 0.01
      Vl= 0.01
      pure_sea  = 0.0017*      (550./xlambda)**4.3
      small_par = 1.340 * Vs * (550./xlambda)**1.7
      large_par = 0.312 * Vl * (550./xlambda)**0.3
      scatlength = (pure_sea + small_par + large_par)
      if (scatlength .ne. 0.)  scatlength = 1.0/scatlength

 999  CONTINUE
      END
