C*/
      real*4 function eff_area_pmt(xlambda,cos_th)
* -----------------------------------------------------------------------
*
* This function computes the "PMT Effective Area" as the product of:
*
*  1.  PM geometrical area        ( 10" )
*  2.  PM collection efficiency   ( 90% )
*  3.  PM quantum efficiency      ( Ham. sheet )
*  4.  PMT transmitivity          ( measured by Herve Lafoux at Saclay )
*  5.  Angular dependence         (     idem                           )
* 
*==> This function works in the range: 300 nm .le. lambda .le. 610 nm <==
*==>                                    angle( photon-PMT ) < 110 deg <==
* Inputs:
* -------
* energy = photon energy (eV)
* cos_th = cosinus photon reverse direction and the OM direction vector
* 
* Description:
* -----------
* pm_diam       = PM diameter in inches ( 1" = 0.0254m )
* area          = PM area (m^2).
* eff_col       = PM collection efficiency.
* effang(cost) = angular dependence.
*
* Created  16-November-1998   Sergio Navas Concha
* -----------------------------------------------------------------------
*
      include 'hit.inc'
      REAL*4   cos_th, qe, effang, transmit
      REAL*4   pm_diam, xlambda, ev
      INTEGER*4 ilambda, iflamb
*
* 10" PMs are really 9.3" PMs
c      PARAMETER ( pm_diam =  9.3 )
c      PARAMETER ( eff_col =  0.9 )
*
      eff_area_pmt = 0.
*
      IF (xlambda.gt.PMT_max_lam .or. xlambda.lt.PMT_min_lam) THEN
         GOTO 999
      ENDIF
*
* Compute "PMT Effective Area" : area now inside fqe
      ev = con_wlen_to_energy/xlambda
      ilambda=IFLAMB(xlambda)
      eff_area_pmt = qe(xlambda,ilambda) *
     &               effang(cos_th,ev) *
     &               transmit(xlambda,ilambda)
*
 999  continue
      end
