C*/
      SUBROUTINE find_om_direction( hit_pos, om_dir, k,l)

*     Created:  1-July-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
c     given a photon hit position. Find the OM direction for the
c     (k,l)th matrix of OM orientations

*     In/Out Variables:-
*     ==========
c     hit_pos(3)  in      position vector of hit
c     om_dir      out     directions 
 
*     Common Block Access:-
*     ===================
c     /hit/  	in 		holds structures for HIT program

*     Assumptions:-
*     ===========
c     The direction vectors of the OM axis are calculated relative to the
c     vector from the origin to the location of the hit (hit_pos). 
c     om_theta is the the angle between the OM axis and the vector hit_pos.
c     om_phi is the azimuthal orientation of the om axis relative to hit_pos
c     with the convention that om_phi = 180 corresponds to the azimuthal
c     orientation of the z-axis about hit_pos.

c     Direct hits:  there is only one bin in OM_PHI which is set to OM_PHI = 0. 
c     OM_THETA is sampled uniformly in cos(om_theta) from 1 to -1.
  
*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine
c     V5        C. James      	 Modified routine

      include 'hit.inc'

      integer*4 l, j, k
      real*4    hit_pos(3), cos_theta_step, theta, cosarg 
      real*4    om_dir(3)
      real*4    sin_phi_hit, theta_hit, r_polar 
      real*4    cos_theta_hit, sin_theta_hit, cos_phi_hit
      real*4    avec(3), bvec(3), cvec(3)
      real*4    th_e, ph_e

c find the theta, phi spherical polar angles for this hit position
*
* Protection against divided by zero
*
      cos_theta_hit = MAX(-1.0 , MIN( 1.0 , hit_pos(3)/r_rad(h_i_r) ))

      IF ( cos_theta_hit .EQ. 1.0 ) THEN
* Photon through the z axis
        theta_hit     = 0.0
        sin_theta_hit = 0.0
        r_polar       = 0.0
        cos_phi_hit   = 1.0
        sin_phi_hit   = 0.0
      ELSE
        theta_hit     = acos( cos_theta_hit )
        sin_theta_hit = sqrt( 1.0 - cos_theta_hit**2.0 )
        r_polar       = sin_theta_hit * r_rad(h_i_r)
        cos_phi_hit   = MAX(-1.0 , MIN( 1.0 , hit_pos(1)/r_polar ))
        sin_phi_hit   = MAX(-1.0 , MIN( 1.0 , hit_pos(2)/r_polar ))
      ENDIF

c if direct and from a muon, the photon has been forced to come
c from the cherenkov direction, regardless of origin     
      if ( h_part_id .eq. id_muon .and. h_scat .eq. 0) then
      	 cos_theta_hit=h_theta_ch
	 sin_theta_hit = sqrt( 1.0 - cos_theta_hit**2.0 )
      endif
      
c defines basis vectors for the rotations:
c a is theta=phi=0, points away from the origin, and is the phi-rotation basis
c c points out of the z-a plane, and is the theta-rotation base
c b is defined such that axb=c, and corresponds to theta=90, phi=0
      avec(1) = sin_theta_hit*cos_phi_hit
      avec(2) = sin_theta_hit*sin_phi_hit
      avec(3) = cos_theta_hit
      
c c is out of the z-avec plane; z x a = 
      if (sin_theta_hit .ne. 0.0) then
      	 cvec(1) = -avec(2)/sin_theta_hit
      	 cvec(2) = avec(1)/sin_theta_hit
      	 cvec(3) = 0.0
      else
      	 cvec(1) = 0.0
	 cvec(2) = 1.0
	 cvec(3) = 0.0
      endif
c defining b-vector as c x a: normalised by construction
      bvec(1) = cvec(2)*avec(3) - cvec(3)*avec(2)
      bvec(2) = cvec(3)*avec(1) - cvec(1)*avec(3)
      bvec(3) = cvec(1)*avec(2) - cvec(2)*avec(1)
            
c      begin with the vector (1,0,0) in the a-b-c basis

      do j=1,3
      	 om_dir(j) = B_om_matrix(h_scat,k,l,1)*avec(j)
     &	             	+ B_om_matrix(h_scat,k,l,2)*bvec(j)
     &	             	+ B_om_matrix(h_scat,k,l,3)*cvec(j)
      enddo


      end
