C*/
      SUBROUTINE Process_shell

*     Created:  1-July-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
*     For each band (direct or scattered), read in the photons hits on 
c     the given shell and place them into the hit buffer, according to the
c     the angular extent of the band, and call process_band.

*     In/Out Variables:-
*     ==========
 
*     Common Block Access:-
*     ===================
c     /hit/  	in 		holds structures for HIT program

*     Assumptions:-
*     ===========
c     direct photons are defined as having no scatters.
c     This routine is sensitive to the structure of gen i/o.
c     please ensure that they get mutually updated accordingly

*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine

      include 'hit.inc'
      include 'gen-hit-ntuple.inc'

      integer*4 i, j,k, ierror, dir_hits, scat_hits, correct_flag
      real*4    cos_hit
      integer*4 istat
c      logical   hit_used(max_hits*max_band)
 
      write (*,*) 'processing shell number =', h_i_r

      write (*,*) ' No. of entries in Ntuple for this shell =',
     & counts_tot(h_i_r)
     
      OPEN(UNIT=lun_in_rz,FILE=GENFILES(h_i_r),ACCESS='DIRECT',
     &	 STATUS='unknown',FORM='UNFORMATTED',RECL=reclen,
     &	 IOSTAT=istat)
     
      write(*,*) 'opened file ',GENFILES(h_i_r),' with status ',istat
c set the hit_used logical flag for all hits in the current shell

      IF (h_nhits.gt.MAX_HITS*MAX_BAND) THEN
        WRITE(*,123) h_nhits
      ENDIF
 123  FORMAT(/,'Process_shell warning - nhits=',I8,' out of bounds',/)
 
c    i.e if it is a muon, do direct hits
      n_dir_to_scat=0
      next_dir_to_scat=1
      
      if ( h_part_id.eq.5 .or. h_part_id.eq.6 ) then
c do the direct hit bands

         write (*,*) 'doing direct hits'

         h_scat = 0 ! set to direct hits

c loop over the direct hit bands
      	 if (ALL_SCAT .eq. 1 .OR. counts_dir(h_i_r) .eq. 0) GO TO 445
         
      	 do i = 1, b_nbins(h_scat)
      	    write(*,*) '   in band ',i, 'of shell ',h_i_r
            h_i_band  = i
c count for the band
            p_nhits = 0

c read in the appropriate hits- very inefficient because of disorder!
      	    do j = 1,counts_tot(h_i_r)
	       READ(lun_in_rz,REC=j) (xtup(k),k=1,ntuplen), xtupscat
      	       if (xtupscat .eq. 0) then
c this hit is unscattered

* xtup(4) = j-photon z_position when reaching the cell
                  cos_hit =  MAX(-1.,MIN(1.,xtup(4) / r_rad(h_i_r)))

c cosine of polar angle for hit location on shell
c checks that the direct hit band includes everything
                  if (  
     1   ( cos_hit .gt. b_cos_min(h_scat,h_i_r,h_i_band) ) .and. 
     2   ( cos_hit .le. b_cos_max(h_scat,h_i_r,h_i_band) ) ) then
c this hit is in the current band, so we plug it into the hit buffer
      	             
		     
c                     hit_used(j)           = .true.
                     p_nhits = p_nhits + 1
                     IF (p_nhits.GT.MAX_HITS) THEN
                     	WRITE(*,*) '*** WARNING! DIR p_nhits',
     &		p_nhits, '>',MAX_HITS, '\n THIS IS SERIOUS!',
     &          ' (got to ',j,' out of ', counts_tot(h_i_r),')'
      	             	WRITE(*,*) 'this happened for bin ',i
			
                     	GOTO 444
                     ENDIF
c This line is critical to xtup structure: modding xtup is therefore dangerous!
		     counts_udir(h_i_r) = counts_udir(h_i_r)+1
		     p_time(p_nhits)   = xtup(1)
                     p_pos(p_nhits,1)  = xtup(2)
                     p_pos(p_nhits,2)  = xtup(3)
                     p_pos(p_nhits,3)  = xtup(4)
                     p_dir(p_nhits,1)  = xtup(5)
                     p_dir(p_nhits,2)  = xtup(6)
                     p_dir(p_nhits,3)  = xtup(7)
                     p_wlen(p_nhits)   = xtup(8)
c                     p_nscat(p_nhits)  = 0
		     p_wgt(p_nhits)  = exp(xtup(9))    ! xtup(9) is the log weight)
		     if (xtupscat .eq. 0 .and. ALL_SCAT .ne. 1 .and.
     *      ( h_part_id .eq. 5 .or. h_part_id .eq. 6 ) ) then
			call correct_photon()
		     endif
		  else
c we put this photon number in a list which tells us to treat it as scattered
      	             if (n_dir_to_scat .eq. max_dir_to_scat) then
		     	write(*,*) 'dir to scat buffer full!'
		     else
		     	n_dir_to_scat = n_dir_to_scat+1
		     	dir_to_scat_ids(n_dir_to_scat)=j
		     endif
c		     write(*,*) 'direct photon ',j,
c     & ' rejected on cosine grounds in shell ',h_i_r,''
c		     xtupscat=1
c		     counts_dir(h_i_r) = counts_dir(h_i_r)-1
c		     counts_sca(h_i_r) = counts_sca(h_i_r)+1
c		     WRITE(lun_in_rz,rec=j) (xtup(k),k=1,ntuplen)
		  endif
               endif
            enddo

 444        CONTINUE

            write (*,*) 'band #', h_i_band, ' nhits =', p_nhits

            call process_band

         enddo

      endif

c sets the next one to zero, so it never matches
      dir_to_scat_ids(n_dir_to_scat+1)=0
      
c now deal with the scattered hit bands

445      h_scat = 1 ! set to scattered hits

c loop over the scattered hit bands

      write (*,*) 'shell ', h_i_r,': doing scattered hits; b_nbins =',
     &                b_nbins(h_scat),h_scat,' h_nhits =',h_nhits

      do i = 1, b_nbins(h_scat)

         h_i_band  = i
         p_nhits = 0

c read in the appropriate hits
      	    do j = 1,counts_tot(h_i_r)
      	       
	       READ(lun_in_rz,rec=j) (xtup(k),k=1,ntuplen),xtupscat
	       
c	       write(*,*) '\n\nj = ',j, 'info= ', (xtup(k), k=1,ntuplen), xtupscat
c        check to see if this photon is being forced to be scattered
c     	 if so, we might have to correct its properties
      	       if (j .eq. dir_to_scat_ids(next_dir_to_scat)) then
	          xtupscat = 1
		  correct_flag=1
		  next_dir_to_scat=next_dir_to_scat+1
c		  write(*,*) 'photon ',j,' scattered'
	       else
	          correct_flag=0
	       endif
	       
c Must not be direct (xtupscat=0), must be less than max_scat (testing cut),
c allowing for EM_SCAT_ID meaning 0 for 2nd test but not for 1st
               if ( xtup(9).gt.-14..and.(xtupscat .lt. MAX_SCAT .or. 
     & xtupscat .eq. EM_SCAT_ID ) .and. xtupscat .gt. 0) then  
c this hit is not from a `cut-out' event and has not been scattered too often
                  cos_hit =  MAX(-1.,MIN(1.,xtup(4) / r_rad(h_i_r)))

c cosine of polar angle for hit location on shell

                  if (
     1   ( cos_hit .gt. b_cos_min(h_scat,h_i_r,h_i_band) ) .and. 
     2   ( cos_hit .le. b_cos_max(h_scat,h_i_r,h_i_band) ) ) then

c this hit is in the current band so we plug it into the hit buffer
 
                     p_nhits = p_nhits + 1
                     IF (p_nhits.GT.MAX_HITS) THEN
                     	WRITE(*,*) '*** WARNING! SCA p_nhits',p_nhits,
     &                      '>',MAX_HITS
                     	GOTO 333
                     ENDIF
                     counts_usca(h_i_r) = counts_usca(h_i_r)+1
		     p_time(p_nhits)   = xtup(1)
                     p_pos(p_nhits,1)  = xtup(2)
                     p_pos(p_nhits,2)  = xtup(3)
                     p_pos(p_nhits,3)  = xtup(4)
                     p_dir(p_nhits,1)  = xtup(5)
                     p_dir(p_nhits,2)  = xtup(6)
                     p_dir(p_nhits,3)  = xtup(7)
                     p_wlen(p_nhits)   = xtup(8)
		     p_wgt(p_nhits)  = exp(xtup(9))
		     if (correct_flag .eq. 1) then
c     	             	adjusts weight to mimic a scattered event
			p_wgt(p_nhits) = p_wgt(p_nhits)*
     & r_prescale(1,h_i_r)/r_prescale(0,h_i_r)
		     	if (ALL_SCAT .ne. 1 .and.
     *      ( h_part_id .eq. 5 .or. h_part_id .eq. 6 ) ) then
      	                   call correct_photon()
		     	endif
		     endif
                  endif
               endif
         enddo

 333     CONTINUE

         write (*,*) 'band #', h_i_band, ' nhits =', p_nhits
            
         call process_band

      enddo
      counts_utot(h_i_r) = counts_usca(h_i_r)+counts_udir(h_i_r)
      CLOSE(lun_in_rz)
      
      end
