C*/
      SUBROUTINE read_desc_file(i_ret)

*     Created:  12-June-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
*     get the inputs from the desc file which is output by generate-photons:
c     shell radii and scalefactors, n_ref, photon wavelength bins, 
c     particle ID (of geant primary), # of events (geant primaries),
c     shower/muon track length.
*     
*     Common Block Access:-
*     ===================
c     /hit/  	in 		holds structures for HIT program

*     Assumptions:-
*     ===========

*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine

      include 'hit.inc'

      integer*4    j, i, i_ret, ierror, itemp
      integer*4 orig_ngen
      character*60  dummy_char
      real*4 temp_zstart

      write(*,*) ' Input .DESC file:'
      write(6,*) H_file_in_desc

c get input information from the description file output by generate-photons

*
      open(unit=lun_in_desc,file=H_file_in_desc,status='unknown',
     1     form='formatted',IOSTAT=ierror)
      write(*,*) ' %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%'
      write(*,*) ' '

      IF(ierror.NE.0) THEN
        WRITE(*,*) ' Error opening file_in_desc file ',ierror
        RETURN
      END IF
*
      read (lun_in_desc, 333) dummy_char
333   format(a60)
      read (lun_in_desc, *) h_i_medium ! medium ID (1=ice, 2=water)
      read (lun_in_desc, *) h_n_ref  ! refractive index of medium
      read (lun_in_desc, *) h_dens_medium ! density of medium 
      write(*,*) 'h_n_ref is ', h_n_ref
      read (lun_in_desc, *)  watmod   ! Water model name
      read (lun_in_desc,334) labs,dummy_char,luz     ! absorption length
      read (lun_in_desc, *)  lscat    ! scattering length
      read (lun_in_desc, *)  alpha    ! Two H-G method: 
      read (lun_in_desc, *)  cosme1   ! alpha*cosme1 + (1-alpha)*cosme2
      read (lun_in_desc, *)  cosme2   ! 
      read (lun_in_desc, *)  eta      ! Rayleigh*eta + Partic*(1-eta)
 334  format(2X,F8.3,A24,F8.3)
      
      read (lun_in_desc, *) EM_SCAT_ID ! ID fo scattered photons from electrons
      read (lun_in_desc,*) ALL_SCAT    ! treat all photons as scattered yes/no?
      
      read (lun_in_desc, 333) dummy_char
      read (lun_in_desc, 333) dummy_char
      read (lun_in_desc, *) r_nbins   ! number of shells
      read (lun_in_desc, 333) dummy_char

c check to see if there are too many shells in the input file
      if ( r_nbins .gt. max_r ) then
c there are too many shells and the MAX_R parameter in the file
c hit.inc needs to be changed. Abort run until change is made and
c code re-compiled with new array sizes
         i_ret = 1
         write (*,*) 'FATAL ERROR: too many shells in input file'
         write (*,*) 'Change value of MAX_R in hit.inc and recompile'
         return
      endif   
      do i = 1, r_nbins
c input radii and scale factors for each shell
         read (lun_in_desc, *) j, r_rad(i), r_prescale(0,i), 
     1                         r_prescale(1,i) 
c         write(*, *) j, r_rad(i), r_prescale(0,i),r_prescale(1,i) 

      enddo
      read (lun_in_desc, *) r_power    ! rad power for linear inter_ 
      read (lun_in_desc, *) h_part_id  ! Geant id # for initial particles
      read (lun_in_desc, * ) h_part_energy  ! energy of primary particles
      read (lun_in_desc, * ) orig_ngen  ! # of primary particles generated
      read (lun_in_desc, * ) h_seg_length ! is the length
c of the muon track or the average length of the shower_ This program
c assumes that start of the muon or shower is at - seg_length / 2.0
      read(lun_in_desc,*) temp_zstart  ! temporary variable to read in zstart
      read(lun_in_desc,*) h_e_thresh  ! threshold energy loss
      read(lun_in_desc,*) h_nevents ! number of events written
      read(lun_in_desc,*) h_min_ion_eloss  ! mean muon energy-loss
      h_good_events = h_nevents
      if (h_part_id .eq. 5 .or. h_part_id .eq. 6) then
         h_dodir=1
	 write(*,*) 'including direct hits'
	 write(*,*) h_nevents, ' of type ', h_part_id,
     &	    'written above threshold ',h_e_thresh,
     &	    ' GeV, with mean eloss ',h_min_ion_eloss, ' GeV'
      else
         h_dodir=0
	 write(*,*) 'excluding direct hits'
	 write(*,*) h_nevents, ' of type ', h_part_id,
     &	    'written, with mean eloss ',h_min_ion_eloss, ' GeV'
      endif
      read(lun_in_desc,*) total_counts ! all photons in all files
      read(lun_in_desc,*) dummy_char ! the headers
      do i=1,r_nbins 	! photons per radial bin
      	 read(lun_in_desc,353) itemp, counts_dir(i),
     & counts_sca(i), counts_tot(i), genfiles(i)
      	 write(*,*)  itemp, counts_dir(i),
     & counts_sca(i), counts_tot(i),genfiles(i)
      enddo

353   format(I3,3(1x,I8,1x),a120)
      close ( unit = lun_in_desc )

      end
