C*/
      PROGRAM hit

*     Created:  15-JUNE-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
*     Create OM hit distributions for muons track segments and for electron
*     showers. Uses the photon fields created by the GENERATE-PHOTON program.
*     For each case (muon or showers of given energy) 4 OM hit distributions
*     are produced: 
*     i) probability of direct (unscattered) hit 
*     ii) inverse cumulative time distribution of direct hits,
*     iii) probability of scattered hit 
*     ii) inverse cumulative time distribution of scattered hits,

*     Modified slightly to include values of OM polar theta and phi in the
*     output ntuples.
*     D. Lowder    4/7/97
* 
*     Common Block Access:-
*     ===================
c     /hit/  	in 		holds structures for HIT program

*     Assumptions:-
*     ===========
*     see documentation.
 
*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine

      INCLUDE 'hit.inc'

      INTEGER*4 I, i_ret
      CHARACTER*60 FNAME_EVENT_LIST

c-------------------------------------------------------------
c  Input Structure constants
c-------------------------------------------------------------
c Constants
        con_pi         = 3.1415926535
        con_root_two     = 1.4142135623731
        con_wlen_to_energy = 1239.84 

c Particle ids
        id_laser    = -1
        id_photon   =  1
        id_electron =  3
        id_muon     =  5
        id_tau      = 99

*  End input constants
*------------------------------------------------------------------

C      CALL GETENV('FNAME_EVENT_LIST',FNAME_EVENT_LIST)
C      OPEN(UNIT=60, FILE=FNAME_EVENT_LIST, STATUS='UNKNOWN')

      i_ret = 0

      write(*,*) ' '
      write(*,*) ' ******************************** '
      write(*,*) ' **       Running  HIT         ** '
      write(*,*) ' **                            ** '
      write(*,*) ' **       July 25, 2000        ** '
      write(*,*) ' ******************************** '
      write(*,*) ' '
* Initialize optical properties of PMs, Gel, Glass, etc. to compute the
* "PMT Effective Area" and Printout the values for some (energy,theta) points.
c  call read_pmt_files   ! input OM eff. area vs angle + wavelength OBSOLETE!!
CWJ Note that the value 55. slightly renormalises from 54.94
c      call ini_optic(0,1,55.)
c      Gets the environment variables - quickly, before they might change
      CALL GETENV('GENDESC',H_file_in_desc)
      CALL GETENV('HITDESC',H_file_out_desc)
      
      call ini_optic(1)
c      call PRINT_PMT_EFF
      WRITE(*,*) ' out from PRINT_PMT_EFF '

      write(*,*) ' Calling read_desc_file '
      call read_desc_file(i_ret)   ! input shell radii, scalefactors, wavelths.
      if (i_ret .ne. 0) stop   
      write(*,*) ' Calling read_user_inputs '
      call read_user_inputs ! band angles + nbins, OM angles + nbins 
c      write(*,*) ' Calling read_rz_file '
c      call read_rz_file     ! open rz file with photon field ntuple

c makes the probability values in time
      h_scat=0
      call make_t_values()
      h_scat=1
      call make_t_values()
      
c loop through the shells, calling process shell to read in the photons for 
c each shell and sort into bands of direct and scattered photons.
      
      do i = 1, r_nbins
         counts_udir(i)=0
	 counts_usca(i)=0
         h_i_r       = i   ! define current shell number

         call process_shell
         
	 write(*,*) 'Shell ',i,'; HIT used ', counts_udir(i), 'of',
     &  counts_dir(i), ' direct and', counts_usca(i), 'of',
     &  counts_sca(i), 'scattered photons; thus ',
     &  counts_tot(i)-counts_utot(i),' photons were missed'
      enddo

c call make outputs to output the ntuples with the OM distributions

      call write_rz_file   ! ouput the HIT distribution in an ntuple
      call write_desc_file ! ouput the accompanying description file

 999  continue
      stop

      end
