      SUBROUTINE ADDRAW(NARS,ITINTER,ITDEAD,IERR)
C     -------------------------------------------
C--- create hit_raw tag based on
C--- NARS : number of ARS per OM
C--- ITINTER : integration time (nsec)
C--- ITDEAD  : deadtime (nsec)
C
c      IMPLICIT NONE
C
c      INCLUDE 'km3-phomul.inc'
      INCLUDE 'km3.inc'
C
      CHARACTER*255 CHLINE
C
      INTEGER NARS     ! number of ARS per OM
      INTEGER ITINTER  ! integration time (nsec)
      INTEGER ITDEAD   ! deadtime (nsec)
      INTEGER IERR     ! error code (0 - o.k., IPM - too many hits)
C
      INTEGER MAXOMHIT ! max number of hits per OM in time ordered list
      PARAMETER (MAXOMHIT=1000)       
      REAL AMP(MAXOMHIT) ! list of time ordered amplitudes
      REAL TIM(MAXOMHIT) ! list of ordered times
      INTEGER NOMHIT   ! actual number of hits per OM
C
      INTEGER MAXRWHIT ! max number of raw hits per OM in time ordered list
      PARAMETER (MAXRWHIT=1000)       
      REAL ARW(MAXRWHIT) ! list of time ordered raw amplitudes
      REAL TRW(MAXRWHIT) ! list of ordered raw times
      INTEGER NRWHIT   ! actual number of raw hits per OM
C
      INTEGER IPM   ! OM counter
      INTEGER IDRAW ! global hit id
      INTEGER I
C
      IERR  = 0
      IDRAW = 0
      DO IPM=1,NPHOMU     ! loop over all OMs
       CALL SORTHIT(IDPM(IPM),MAXOMHIT,AMP,TIM,NOMHIT,IERR)
       IF (NOMHIT.GT.0) THEN
                  CALL HITRAW(NOMHIT,AMP,TIM,
     +    NARS,ITINTER,ITDEAD,NRWHIT,ARW,TRW,IERR)
         DO I=1,NRWHIT
          IDRAW = IDRAW + 1
          WRITE(CHLINE,'(2I6,2F12.2)') IDRAW,IDPM(IPM),ARW(I),TRW(I)
          CALL EVTAGA('hit_raw',CHLINE,IERR)
          IF (IERR.NE.0) GOTO 99
         ENDDO
       ENDIF
      ENDDO               ! end loop over OMs
 99   CONTINUE
      END
      SUBROUTINE HITRAW
     +  (NOMHIT,AMP,TIM,NARS,ITINTER,ITDEAD,NRWHIT,ARW,TRW,IERR)
C     --------------------------------------------------------------
C--- creates event-tag hit_raw from time sorted hit lists AMP,TIM
C--- further input : NARS    : number of ARS
C---                 ITINTER : integration time
C---                 ITDEAD  : dead time
C--- output : ARW,TRW time sorted raw hit lists
C--- output : NRWHIT : number of raw hits
C--- output : IERR : 0 - o.k. , 1 - event buffer full
C
      IMPLICIT NONE
C
      INTEGER NARS     ! number of ARS per OM
      INTEGER ITINTER  ! integration time (nsec)
      INTEGER ITDEAD   ! deadtime (nsec)
      INTEGER IERR     ! error code (0 - o.k., 1 - event buffer full)
C
      INTEGER NOMHIT   ! number of hits per OM in time ordered list
      REAL AMP(NOMHIT) ! list of time ordered amplitudes
      REAL TIM(NOMHIT) ! list of ordered times
C
      INTEGER NRWHIT   ! number of raw hits per OM in time ordered list
      REAL ARW(*)      ! list of time ordered raw amplitudes
      REAL TRW(*)      ! list of ordered raw times
C
      INTEGER MAXARS    ! max number of ARS allowed per OM
      PARAMETER (MAXARS=10)
      REAL TST(MAXARS) ! start time of dead time
      INTEGER ISTAT(MAXARS) ! status of each ARS
               ! 0 - idle, 1 - deadtime, 2 - integration
      INTEGER INTARS ! identifier of ARS which is integrating
      REAL AMPINT    ! integrated amplitude 
      REAL TSTART    ! integration start time
C
      INTEGER I,IARS
C
      NARS = MIN(NARS,MAXARS)  ! limit number of ARS
      INTARS = 0               ! no integration
      AMPINT = 0.
      TSTART = 0.
      NRWHIT = 0
      CALL VZERO(ISTAT,MAXARS) ! all ARS idle
      DO I=1,NOMHIT
C---              update status of 'dead' ARSs
       DO IARS=1,NARS
        IF (ISTAT(IARS).EQ.1) THEN
         IF (TIM(I).GT.TST(IARS)+FLOAT(ITDEAD)) ISTAT(IARS) = 0
        ENDIF
       ENDDO
C---              one ARS is already integrating
       IF (INTARS.GT.0) THEN
C---              add hit if it is in the integration window
        IF(TIM(I).LE.TSTART+FLOAT(ITINTER)) THEN
         AMPINT = AMPINT + AMP(I)
        ELSE
C--- otherwise close integration and write out hit
         NRWHIT = NRWHIT + 1
         ARW(NRWHIT) = AMPINT
         TRW(NRWHIT) = TSTART
C-- put ARS into idle or dead state depending on hit time
         IF(TIM(I).LE.TSTART+FLOAT(ITINTER+ITDEAD)) THEN
          ISTAT(INTARS) = 1
          TST(INTARS) = TSTART+FLOAT(ITINTER)
         ELSE
          ISTAT(INTARS) = 0      
         ENDIF
         INTARS = 0   
        ENDIF
       ENDIF
C--- find new ARS to start integration
       IF (INTARS.EQ.0) THEN
        DO IARS=1,NARS
         IF (ISTAT(IARS).EQ.0) THEN
          TSTART = TIM(I)
          AMPINT = AMP(I)
          INTARS = IARS 
          ISTAT(IARS) = 2
          GOTO 10
         ENDIF
        ENDDO
       ENDIF
 10    CONTINUE
      ENDDO
C
C--- close integration for last hit and write it out
      IF (INTARS.GT.0) THEN
         NRWHIT = NRWHIT + 1
         ARW(NRWHIT) = AMPINT
         TRW(NRWHIT) = TSTART
      ENDIF
C
 99   CONTINUE
      END
      SUBROUTINE SORTHIT(IPM,MAXOMHIT,AMP,TIM,NOMHIT,IERR)
C     ----------------------------------------------------
C--- fills into arrays AMP, TIM time sorted hit lists for
C--- OM with ID IPM
C--- NMAX : max. allowed number of hits in list
C--- output: NOMHIT - number of hits in list AMP,HIT
C---         IERR : 0 - o.k., IPM - list truncated too many hits
C
      IMPLICIT NONE
C
      INCLUDE 'km3-hits.inc'
C
      REAL EPS
      PARAMETER (EPS=0.01) ! cut amplitude for hits
C
      INTEGER IPM      ! OM identifier
      INTEGER MAXOMHIT   ! max number of hits per OM in time ordered list
      REAL AMP(MAXOMHIT) ! list of time ordered amplitudes
      REAL TIM(MAXOMHIT) ! list of ordered times
      INTEGER NOMHIT   ! actual number of hits per OM
C
      INTEGER IERR ! error code
      INTEGER IHIT ! global hit counter
      INTEGER I,J
C
C
      IERR  = 0
      NOMHIT = 0         ! number of hits for this OM
      DO IHIT=1,NHIT     ! loop over hits
       IF (IHPM(IHIT).EQ.IPM.AND.RPE(IHIT).GT.EPS) THEN
        DO I=1,NOMHIT    ! find slot for new hit into ordered list
         IF (TIM(I).GT.THIT(IHIT)) GOTO 10
        ENDDO
        I = NOMHIT + 1    ! add hit at the end of list
 10     CONTINUE          ! 'I' is correctly defined now
        IF (NOMHIT.GE.MAXOMHIT) THEN
         IERR = IPM ! keep in mind OM id for error message
         GOTO 99
        ENDIF
        DO J=NOMHIT,I,-1  ! shift rest of the list
         AMP(J+1) = AMP(J)
         TIM(J+1) = TIM(J) 
        ENDDO
        NOMHIT = NOMHIT + 1 ! update global counter
        AMP(I) = RPE(IHIT)  ! include new hit
        TIM(I) = THIT(IHIT)
       ENDIF             ! end if OM-id of hit is identical to current OM-id
      ENDDO              ! end loop over hits
C
 99   CONTINUE
      END
