C*/
      SUBROUTINE cut_muon( part_num, flag_cut )

*     Created:  2-FEB-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
c     Cut a muon if its distance of closest approach to the detector is
c     greater than h_muon_cut_distance. 
c     The algorithm used has been adapted from work by J. Jacobsen for the 
c     Wisconsin Amanda MC.

*     In/Out Variables:-
*     ==========
c     in	part_num	particle number for use in P array
c     out       flag_cut        0=do not cut, 1=cut muon
 
*     Common Block Access:-
*     ===================
c     /km3/  	in 		holds structures for KM3

*     Assumptions:-
*     ===========
c     The particle must be a muon, but this is checked. The muon maximum
c     range is found by assuming that the energy loss processes are only 
c     minimum ionising (see range_muon.for). 
c     The routine checks that the muon's distance of closest
c     approach is .lt. h_muon_cut_distance + g.str.cls.rad_sph
c     for at least one cluster. i.e. It must get within striking distance
c     of at least one cluster.

*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine

      INCLUDE 'km3.inc'

      INTEGER*4  part_num, flag_cut, i, j, idum
      REAL*4     muon_range, closest 
      REAL*4     track(3), track_end(3), dummy_vec1(3), dummy_vec2(3)
      REAL*4     dummy_vec3(3)

c check to see if particle is really a muon

      if ( p_part_id(part_num) .ne. p_id_muon 
     & .and. p_part_id(part_num) .ne. p_id_tau ) then
         print *, 'ERROR: non-muon particle sent to muon_cut'
         flag_cut = 0
         return
      endif

      flag_cut = 1

c find the maximum muon range by assuming minimum ion energy losses

      muon_range = p_e0(part_num) / 0.19    ! 0.19 Gev/m

c find the coordinates of the muon track endpoint

      DO idum=1,3
        track(idum) = p_v0(idum,part_num) * muon_range
        track_end(idum) = p_x0(idum,part_num) + track(idum)
      END DO

c check distance of closest approach to the whole detector volume

      DO idum=1,3
        dummy_vec1(idum) = p_x0(idum,part_num)
        dummy_vec2(idum) = p_v0(idum,part_num)
      END DO
      call distance_to_track(dummy_vec1,dummy_vec2, 
     1     muon_range, track_end, g_origin, closest )

      if ( closest .gt. h_muon_cut_distance + g_rad_sph) return  

c the muon has `missed' the detector and we return with flag_cut = 1
 		
c now check distance of closest approach to the strings

      do i=1, g_num_str  ! loop over strings

        DO idum=1,3
          dummy_vec1(idum) = p_x0(idum,part_num) 
          dummy_vec2(idum) = p_v0(idum,part_num)
          dummy_vec3(idum) = g_str_x(idum,i)
        END DO
        call distance_to_track(dummy_vec1, dummy_vec2, 
     1       muon_range, track_end, dummy_vec3, closest )

        if ( closest .lt. h_muon_cut_distance + 
     1                    g_str_rad_sph(i) ) then  
c the muon has `hit' one of the strings and we check the distance of 
c closest approach to the clusters in this string

          do j=1, g_str_num_cls(i)  ! loop over clusters

            DO idum=1,3
              dummy_vec1(idum) = p_x0(idum,part_num)
              dummy_vec2(idum) = p_v0(idum,part_num)
              dummy_vec3(idum) = g_str_cls_x(idum,j,i)
            END DO
            call distance_to_track( dummy_vec1, 
     1           dummy_vec2, muon_range, track_end, 
     2           dummy_vec3, closest )

            if ( closest .lt. h_muon_cut_distance + 
     1                        g_str_cls_rad_sph(j,i) ) then  
c the muon has `hit' one of the clusters and we consider this an interesting
c muon (may produce OM hits) and so we return with flag_cut = 0

              flag_cut = 0
              return

            endif
          enddo
        endif
      enddo

c if the muon has not `hit' any of the clusters then we return with
c flag_cut = 1, since the muon is very unlikely to produce any OM hits

      end
