C*/
      SUBROUTINE distance_to_track( track_start, track_dir, 
     1           track_length, track_end, point, closest )	

*     Created:  1-FEB-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
c     find the closest distance between a track (with end points) and a point. 

*     In/Out Variables:-
*     ==========
c     in	track_start	xyz coordinates of the track start	
c     in	track_dir	xyz direction cosines along track (from
c                               track_start to the other end)	
c     in	track_length	length of track 
c     in	track_end	xyz coordinates of the track end	
c     in	point        	xyz coordinates of the point	
c     out       closest         distance of closest approach
 
*     Common Block Access:-
*     ===================
c     none

*     Assumptions:-
*     ===========
c     track_dir should be a unit vector, but this is checked just to be sure. 
c     All quantities are in the same coordinate system! 

*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine

      IMPLICIT NONE

      REAL*4  track_start(3), track_dir(3), track_length, point(3)
      REAL*4  diff(3), lambda, track_end(3)
      REAL*4  vec_dot, vec_norm, vec_norm2, squ, closest, closest_sqr
      REAL*4  vec_diff

      call sub_vec( point, track_start, diff) 

c diff is the vector from track_start to the point

      lambda =  vec_dot( diff, track_dir)
c lambda is the distance along the track (from track_start in the direction
c given by track_dir) to the point of closest approach

      if ( lambda .lt. 0. ) then
c track_start is the closest point along the track

        closest = vec_norm( diff ) 

      else

        if ( lambda .lt. track_length ) then
c the closest point occurs between the two end-points of the track

           closest_sqr = vec_norm2( diff ) - squ( lambda )

           if ( closest_sqr .gt. 0. ) then

              closest = sqrt( closest_sqr )

           else

              closest = 0.

           endif

        else
c the closest point occurs at the opposite end of the track (not track_start)

          closest = vec_diff( track_end, point )

        endif
      endif

      end
