C*/
	real function eloss_mu(e_mu,r)

! Simulates the energy loss of a high energy muon in 1 m of water, using
! interpolated lookup tables.  The table used has deltaE versus P(>deltaE)
! for 10, 100, 1000, and 10000 GeV.

! Created: 		25 Feb 1997
! Author:  		D. Lowder
! Files required:	km3_eloss_mu.inc,large-eloss-table.dat
! Inputs:		r = uniform random deviate between 0 and 1
! 			e_mu = energy of primary muon being propagated, in GeV
! Outputs:		eloss_mu = energy loss of the primary muon in 1 m.w.e.,
!				   distributed with full physics accounted for
! Limitations:		Not reliable for primary energy greater than 10 TeV.

	include 'km3-muon-eloss.inc'
	real r,e_mu

! Two possibilities: we are in the small "ionization" eloss regime, or the
! large "radiative" eloss regime.  Empirically, it turns out that the dividing
! line occurs when the random deviate (i.e. the probability that the energy loss
! is larger than some value) = 0.2.  If r is greater than this, we use the
! fit for small elosses; otherwise, use the lookup tables for large elosses.
! 
	rlog = log10(r)
	i1 = 0
	i2 = 0
! Find out where we are in the large eloss table:
! Where we are in list of entries -- between i1 and i2:
	if(rlog.lt.p_log_table(1)) then
		i1=1
		i2=2
	else if(rlog.ge.p_log_table(n_in_table)) then
		i1=n_in_table-1
		i2=n_in_table
	else
		do i=1,n_in_table
			if(rlog.ge.p_log_table(i).and.
	1		rlog.lt.p_log_table(i+1)) then
			   i1=i
			   i2=i+1
			else
			   write (6,*) 'ERROR cannot find right ',
	1			   'Eloss table entry. rlog=',rlog
			   stop
			end if
		end do
	end if
! Where we are in energy -- between j1 and j2
	elog=log10(e_mu)
	if(elog.lt.1.0) then		! Less than 10 GeV
		j1=1
		j2=2
	else if(elog.ge.4.0) then 	! Greater than 10 TeV
		j1=3
		j2=4
	else
		j1=int(elog)
		j2=j1+1
	end if
! Now interpolate.  First interpolate on the entries, then on the primary
! energy.
	e1 = e_log_table(j1,i1) +
	1		(rlog - p_log_table(i1))
	1		*(e_log_table(j1,i2) - e_log_table(j1,i1))
	1		/(p_log_table(i2) - p_log_table(i1))
	e2 = e_log_table(j2,i1) +
	1		(rlog - p_log_table(i1))
	1		*(e_log_table(j2,i2) - e_log_table(j2,i1))
	1		/(p_log_table(i2) - p_log_table(i1))

	eloss_log = e1 + (elog - j1)*(e2 - e1) ! /(j2 - j1)
	eloss_mu = 10.0**(eloss_log)

! Finally, check for stupid stuff before returning.
	if(eloss_mu.lt.0.0) eloss_mu=0.0
	if(eloss_mu.gt.e_mu) eloss_mu=e_mu

	return

	end
