C*/
      SUBROUTINE find_oms_near_point( point, rho_max, rho_min,
     &                                oms_in_range, num_oms_in_range)

*     Created:  23-FEB-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
c     find all OMS less than a distance rho_max away from a given point
c     by searching through the nested geometry structure

*     In/Out Variables:-
*     ==========
c     in	point   	 point from which to look for OMS in range
c     in	rho_max    	 max distance in meters to decide if in range 
c     in	rho_min    	 min distance in meters to decide if in range 
c     out       oms_in_range     array of OM id's which are in range
c     out       num_oms_in_range number of OMs which are in range (returns 0
c                                if no OMs in range).
 
*     Common Block Access:-
*     ===================
c     /km3/  	in 		holds structures for KM3

*     Assumptions:-
*     ===========

*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine
*
*------------------------------------------------------------------------
* 24-Nov-1998  Sergio Navas Concha
*
* New input variable "rho_min"
* Do not process a string (= consider that the string is not in rage)
* if the distance between the point and the string is smaller than rho_min.
* The idea is to 'switch off' the string where the LASER is located on. 
* This should have null effect on 'muon' and 'electron' events.
*
* rho_min        should be equal to zero for muons and electrons and
*                something like 30. for a LASER flash_
*------------------------------------------------------------------------
*
      INCLUDE 'km3.inc'

      INTEGER*4  num_oms_in_range, oms_in_range(max_num_oms_det)
      INTEGER*4  i, j, k, idum
      REAL*4     point(3), rho_max, rho_min, closest, vec_diff, rho 
      REAL*4     dummy_vec1(3)

      num_oms_in_range = 0

c check to see that the KM3 detector itself is within range of the point

      if ( g_rad_cyl .eq. 0.) then  ! KM3 is just a string
        call distance_to_string( point, g_origin, g_hht, closest )
      else                    ! KM3 is a cylinder
        call distance_to_cylinder( point, g_origin, g_hht, 
     1       g_rad_cyl, closest )
      endif

      if ( closest .lt. rho_max ) then   ! KM3 is in range

c now loop over strings, checking to see if any are in range          

        do i=1, g_num_str
          if ( g_str_rad_cyl(i) .eq. 0.) then  ! string is string-shaped
            DO idum=1,3
              dummy_vec1(idum) = g_str_x(idum,i)
            END DO
            call distance_to_string( point, dummy_vec1, 
     1      g_str_hht(i), closest )
          else                    ! string is cylinder-shaped
            DO idum=1,3
              dummy_vec1(idum) = g_str_x(idum,i)
            END DO
            call distance_to_cylinder( point, dummy_vec1, 
     1      g_str_hht(i), g_str_rad_cyl(i), closest )
          endif
*
          if ( closest .lt. rho_max .and.
     &         closest .ge. rho_min       ) then   ! string is in range

c now loop over clusters, checking to see if any are in range          

            do j=1, g_str_num_cls(i)

              if ( g_str_cls_rad_cyl(j,i) .eq. 0.) then 
c               cluster is string-shaped

                DO idum=1,3
                  dummy_vec1(idum) = g_str_cls_x(idum,j,i)
                END DO
                call distance_to_string( point, dummy_vec1, 
     1          g_str_cls_hht(j,i), closest )
              else                    ! cluster is cylinder-shaped

                DO idum=1,3
                  dummy_vec1(idum) = g_str_cls_x(idum,j,i)
                END DO
                call distance_to_cylinder( point, dummy_vec1, 
     1        g_str_cls_hht(j,i), g_str_cls_rad_cyl(j,i), closest )
              endif

              if ( closest .lt. rho_max ) then   ! cluster is in range

c now loop over OMs within cluster to see which OMs are in range

                do k=1, g_str_cls_num_oms(j,i)

                  DO idum=1,3
                    dummy_vec1(idum) = g_str_cls_om_x(idum,k,j,i)
                  END DO
                  rho = vec_diff( point, dummy_vec1 )

                  if ( rho .lt. rho_max ) then
c the OM is within range and we update array and number of OMs in range

                    num_oms_in_range = num_oms_in_range + 1
                    oms_in_range(num_oms_in_range) = 
     1              g_str_cls_om_id_km3(k,j,i)

                  endif
                enddo
              endif
            enddo
          endif
        enddo
      endif
      end
