C*/
      SUBROUTINE find_point_params( point, point_dir, om_point, 
     1           om_dir, rho_vec, rho, cos_band, theta_om, phi_om )	

*     Created:  16-FEB-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
c     calculate the values of the parameters which describe the geometrical
c     relationship between a point (+ direction) and a given OM. 
c     The algorithm used has been taken from work by J. Jacobsen for the 
c     Wisconsin Amanda MC.

*     In/Out Variables:-
*     ==========
c     in	point           xyz coordinates of the point 
c     in	point_dir       xyz direction cosines of the point
c     in	om_point        xyz coordinates of the OM 
c     in	om_dir          xyz direction cosines of the OM
c     out       rho_vec         vector from point to om_point
c     out       rho             magnitude of rho_vec
c     out       cos_band        cos(angle between point_dir and rho_vec) 
c     out       theta_om        angle between om_dir and rho_vec
c     out       phi_om 	        azimuthal orientation of om_dir about rho_vec

*     Common Block Access:-
*     ===================
c     /km3/ holds structures for KM3      

*     Assumptions:-
*     ===========
c     All quantities are in the same coordinate system! 
c     All angles are calculated in radians.
c     phi_om is restricted to the range 0-PI because of symmetry in the 
c     OM_HIT distributions which makes phi_om = -x equivalent to phi_om = x.
c     The zero for phi_om is defined as the azimuthal direction about rho_vec
c     which is OPPOSITE to the azimuthal direction of point_dir about rho_vec.
c     The translation from km3_mc variables to wisconsin amanda variables
c     as is follows:
c     rho         = rho
c     cos_band    = cos(psi)
c     theta_om    = theta 
c     phi_om      = phi

*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine

      INCLUDE 'km3.inc'

      REAL*4  point(3), point_dir(3), om_point(3), om_dir(3)
      REAL*4  rho, rho_vec(3), cos_band, theta_om, phi_om
      REAL*4  anglediff, vec_norm, om_cross(3), point_cross(3)
      REAL*4  vec_dot

      call sub_vec( om_point, point, rho_vec )
      rho = vec_norm( rho_vec )

      cos_band = vec_dot( rho_vec, point_dir )
      cos_band = cos_band / rho
      theta_om = anglediff( rho_vec, om_dir )

      if ( (cos_band .le. -1.0) .or. (theta_om .le. 0.) .or.  
     1     (cos_band .ge.  1.0) .or. (theta_om .ge. c_pi) ) then 

         phi_om = 0.   ! avoids singularities 

      else

         call cross_vec( rho_vec, point_dir, point_cross )
         call cross_vec( om_dir,  rho_vec, om_cross  )

         phi_om = anglediff( point_cross, om_cross )

      endif
      end
