C*/
      SUBROUTINE make_tau_track( part_num, ier)

*     Created:  27-FEB-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
c     create a tau track and treat it as a minimum-ionising muon track

      INCLUDE 'km3.inc'
      INCLUDE 'km3-mass.inc'
      
c don't need all of these now - these variables are inherited from muon tracking
      INTEGER*4 ier, muon_flag, part_num, nseg, idum
      REAL*4 track_dir(3), eloss_mu, random_dist 
      REAL*4 seg_step_half(3), seg_rad, ran1
      REAL*4 vec_norm, vec_dot, fraction, random_num
      REAL*4 seg_step_full(3), vec_diff, dummy_vec(3)
      REAL*4 dummy_vec2(3), dummy_vec3(3)
      REAL shower_E, hlength_elec
      INTEGER*4 status
      EXTERNAL eloss_mu

c check to see if particle is really a muon

      if ( p_part_id(part_num) .ne. p_id_tau ) then
         print *, 'ERROR: non-tau particle sent to make_tau_track'
         ier = 1
         return
      endif

      ier = 0

c input muon start conditions into the first segment
      DO idum = 1,3
        dummy_vec(idum) = p_v0(idum,part_num)
      END DO
      call renorm_vec(dummy_vec)    ! just to be sure
      DO idum = 1,3
        p_v0(idum,part_num) = dummy_vec(idum)
        seg_pos_start(idum,1) = p_x0(idum,part_num)
        seg_dir_start(idum,1) = p_v0(idum,part_num)
	seg_dir_center(idum,1) = p_v0(idum,part_num)
      END DO
      
      seg_e_start(1) = p_e0(part_num)
      seg_t_start(1) = p_t0(part_num)
      
c     default is a muon stopping in the detector 
      muon_flag      = 1
      fraction       = 1.0
      seg_length(1)  = h_seg_length_km3
      nseg           = 0

c calculates travel distance from its resting lifetime
      TAU_gamma=p_e0(part_num)/AMASSS(p_id_tau)
      TAU_sealife=TAU_restlife(part_num)*TAU_gamma
      TAU_distance=TAU_sealife*c_c_mpns
c check to test whole or partial segments
      TAU_NSEG=int(TAU_DISTANCE/h_seg_length_km3)+1
      TAU_RSEG=TAU_DISTANCE-(TAU_NSEG-1)*h_seg_length_km3
c loop over number of complete tracks
      
      do while (nseg .lt. TAU_NSEG)		

         nseg = nseg + 1
c segment length - knows how much is left
	 if (nseg .lt. TAU_NSEG) then
	     seg_length(nseg)=h_seg_length_km3
	 else
	     seg_length(nseg)=TAU_RSEG
	 endif
	 seg_total_e_loss(nseg) = TAU_ELOSS*seg_length(nseg)
	 
         DO idum=1,3
            seg_dir_start(idum,nseg+1) = seg_dir_start(idum,nseg)
            seg_dir_center(idum,nseg+1) = seg_dir_center(idum,nseg)
         END DO
	 
         DO idum = 1,3 
           seg_step_full(idum) = p_v0(idum,part_num)*seg_length(nseg)
	   seg_step_half(idum) = seg_step_full(idum)/2.
	   seg_pos_center(idum,nseg) = seg_pos_start(idum,nseg) +
     &                                    seg_step_half(idum)
           seg_pos_start(idum,nseg+1) = seg_pos_start(idum,nseg) + 
     &           seg_step_full(idum)
         END DO
         seg_t_center(nseg) = seg_t_start(nseg) + seg_length(nseg) 
     1                         * 0.5 / c_c_mpns
         seg_t_start(nseg+1) = seg_t_start(nseg) + seg_length(nseg)
     1                         / c_c_mpns
         seg_e_start(nseg+1) = seg_e_start(nseg) - 
     1                         seg_total_e_loss(nseg)

c we always lose only ionisation energy
         seg_ion_e_loss(nseg) = seg_total_e_loss(nseg)
         
         if ( mod( nseg, 3 ) .eq. 0 ) then
c we calculate the running average ion_e_loss over the last three segments

            seg_ion_e_loss_3(nseg-1) = seg_ion_e_loss(nseg-2) +
     1      seg_ion_e_loss(nseg-1) + seg_ion_e_loss(nseg)

         endif

         if ( mod( nseg, 9 ) .eq. 0 ) then
c we calculate the running average ion_e_loss over the last nine segments

            seg_ion_e_loss_9(nseg-4) = seg_ion_e_loss_3(nseg-7) +
     1      seg_ion_e_loss_3(nseg-4) + seg_ion_e_loss_3(nseg-1)

         endif

         if ( mod( nseg, 27 ) .eq. 0 ) then
c we calculate the runningz average ion_e_loss over the last 27 segments

            seg_ion_e_loss_27(nseg-13) = seg_ion_e_loss_9(nseg-22) +
     1      seg_ion_e_loss_9(nseg-13) + seg_ion_e_loss_9(nseg-4)

         endif
         
	 
	 DO idum=1,3
           dummy_vec(idum) = seg_pos_start(idum,nseg+1)
           dummy_vec2(idum) = seg_dir_start(idum,nseg+1)
         END DO
 
         seg_rad = vec_norm(dummy_vec)

         if ( ( seg_rad .gt. h_muon_cut_distance + g_rad_sph ) .and. 
     1        ( vec_dot(dummy_vec,dummy_vec2) .gt. 0. ) ) then 

c the muon is moving away from KM3 AND it is more than h_muon_cut_distance
c away from KM3 - so it is LEAVING the detector.

            muon_flag = 2  ! muon leaving detector
	    exit
         endif
	 
	 
      END DO
      
      
c write outcome of muon into the particle record.

      nseg = nseg + 1

      DO idum=1,3
        p_x_end(idum,part_num) = seg_pos_start(idum,nseg)
        p_v_end(idum,part_num) = seg_dir_start(idum,nseg)
      END DO

      p_e_end(part_num) = seg_e_start(nseg)
      p_t_end(part_num) = seg_t_start(nseg)
      p_outcome(part_num) = muon_flag
      p_nsegs(part_num)   = nseg - 1

      DO idum=1,3
        dummy_vec(idum) = p_x_end(idum,part_num)
        dummy_vec2(idum) = p_x0(idum,part_num)
      END DO

      call sub_vec(dummy_vec, dummy_vec2, track_dir )
      p_length(part_num) = vec_norm( track_dir )
      IF (p_length(part_num).NE.0) THEN 
        call renorm_vec( track_dir )
      ENDIF
      DO idum=1,3
        p_dir(idum,part_num) = track_dir(idum)
      END DO
      
      end
