
      SUBROUTINE muon_direct_hits( part_num, om_num )

*     Created:  9-OCT-97
*     Contact:  M. Moorhead, OXFORD.
*     Verified:

*     Purpose and Method:-
*     ====================
c     Calculate the number of direct (unscattered) hits for a given OM and 
c     A given muon track. First find the segment of the muon track from which
c     the `cone' of direct light at the cherenkov angle hits this OM.
c     Then (if such a segment exists) find the average poisson 
c     probability of a hit by sampling the mu_dir_prob array by linear 
c     interpolation in the rho and cos_theta_om dimensions. 
c     The hit time of each hit (if any)
c     is then found by sampling the mu_dir_time array (in 3 dimensions ). 
c     The OM hits (if any) are then placed into the hit structure record.

*     In/Out Variables:-
*     ==========
c     in        part_num        number of particle to which segment belongs
c     in	om_num   	number of current OM
 
*     Common Block Access:-
*     ===================
c     /km3/  	in 		holds structures for KM3

*     Assumptions:-
*     ===========
c     the `cone' of direct light is defined with repsect to the segment center
c     and direction of muon at segment center.
 
*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine

      INCLUDE 'km3.inc'
      INCLUDE 'km3-interpol.inc'
*
      INTEGER*4  num_hits, part_num, seg_num, ran_poisson, bin(3,2)
      INTEGER*4  idum, i_hit, i, j, k, om_num
      REAL*4     rho, point(3), weight(3,2), l, y, x
      REAL*4     avg_num_hits, rho_vec(3), vec_dot, l_ch, rho_ch
      REAL*4     ran1, hit_time, vec_norm, r1,r2
      REAL*4     dummy_vec1(3), dummy_vec2(3)

      integer    itbin
      real       vnhits(40000), vthits(40000), vxhits(40000), tempo
      real       time_min, this_time
      integer*4  i_p, locatr
*
* -- Ntuple inputs :
c      NSCAT = 0
c      ID_OM    = g_om_id_ant_om(om_num)
c      TYPE_HIT = 5

c first find the muon segment from which the `cone' of direct light projected 
c out at the cherenkov angle hits this OM.

      DO idum=1,3
        dummy_vec1(idum) = g_om_x(idum,om_num)
        dummy_vec2(idum) = p_x0(idum,part_num)
      END DO
      call sub_vec(dummy_vec1,dummy_vec2, rho_vec )   

c rho_vec is the vector from the track start to the OM
      rho = vec_norm( rho_vec )

      DO idum=1,3
        dummy_vec1(idum) = p_dir(idum,part_num)
      END DO
      l = vec_dot( rho_vec, dummy_vec1 )

* SN 17-Jan-2000   Protection against negative values:
      y =  ( rho*rho - l*l )
      if (y.gt.0) then
        y = sqrt( y )
      else
        y = 0.
      endif

      x = y / h_tan_ch
      l_ch   = l - x 

c l_ch is the distance along the muon track from the track_start to the 
c point at which the muon would have emitted light at the cherenkov cone angle
c to reach the OM

      seg_num = int( l_ch / h_seg_length_km3 )  ! first guess at correct seg. 

      if ( seg_num .lt. 1 ) seg_num = 1  
      if ( seg_num .gt. p_nsegs(part_num) ) seg_num =  
     1                  p_nsegs(part_num)

c now refine the guess to the segment which illuminates the OM

      DO idum=1,3
        dummy_vec1(idum) = g_om_x(idum,om_num)
        dummy_vec2(idum) = seg_pos_center(idum,seg_num)
      END DO
      call sub_vec(dummy_vec1,dummy_vec2, rho_vec )   
      rho = vec_norm( rho_vec )

      DO idum=1,3
        dummy_vec1(idum) = seg_dir_center(idum,seg_num)
      END DO
      l = vec_dot( rho_vec, dummy_vec1 )

* SN 17-Jan-2000   Protection against negative values:
      y =  ( rho*rho - l*l )
      if (y.gt.0) then
        y = sqrt( y )
      else
        y = 0.
      endif

      x = y / h_tan_ch
      l_ch   = l - x 
c l_ch is the distance along the muon track from the first guess segment center 
c to the point at which the muon would have emitted light at the cherenkov 
c cone angle to reach the OM

      if ( abs(l_ch) .gt. seg_length(seg_num) * 0.5 ) then
c the point of cherenkov emission is outside the first guess segment and 
c so we try a second guess segment based on extrapolating from the first 
c segment

        seg_num = seg_num + nint( l_ch / h_seg_length_km3 )  

c if this second guess is outside the allowed range we return with no hits

        if ( seg_num .lt. 1 ) return
        if ( seg_num .gt. p_nsegs(part_num) ) return
        
        DO idum=1,3
          dummy_vec1(idum) = g_om_x(idum,om_num)
          dummy_vec2(idum) = seg_pos_center(idum,seg_num)
        END DO
        call sub_vec(dummy_vec1,dummy_vec2, rho_vec )   
        rho = vec_norm( rho_vec )

        DO idum=1,3
          dummy_vec1(idum) = seg_dir_center(idum,seg_num)
        END DO
        l = vec_dot( rho_vec, dummy_vec1 )

* SN 17-Jan-2000   Protection against negative values:
        y =  ( rho*rho - l*l )
        if (y.gt.0) then
          y = sqrt( y )
        else
          y = 0.
        endif

        x = y / h_tan_ch
        l_ch   = l - x 
c l_ch is the distance along the muon track from the second segment center 
c to the point at which the muon would have emitted light at the cherenkov 
c cone angle to reach the OM
      endif
      
c now we find the bin values which straddle the current point 
c in the mu_dir_prob array. There are two dimensions to consider, rho
c and cos(theta_om)= cosine of angle between rho_vec and om.dir. 
c the first dimension must be adjusted to the correct power

      point(1) = rho**mu_dir_power(1)

      DO idum=1,3
        dummy_vec1(idum) = g_om_dir(idum,om_num)
      END DO
      point(2) = vec_dot( rho_vec, dummy_vec1 ) / rho
      
c This correction seems never to have been implemented - why?
c      rho_ch = sqrt( x*x + y*y ) ! rho_ch is the distance light traveled  
c      if (rho_ch .lt. 0.21) then ! track traverses glass sphere assume full angular acceptance
c	point(2) = 1.
c      endif

      do i = 1,2    ! loop over two dimensions
         if ( point(i).le. mu_dir_min(i) ) then
c we use the first two bins
            bin(i,1) = 1 
            bin(i,2) = 2
         else if ( point(i) .ge. mu_dir_max(i) ) then
c we use the last two bins
            bin(i,1) = mu_dir_nbins(i) - 1 
            bin(i,2) = mu_dir_nbins(i) 
         else
c we are inside the linearly spaced array 
            bin(i,1) = 1 + int( (point(i) - mu_dir_min(i) ) / 
     1                 mu_dir_step(i) ) 
            bin(i,2) = bin(i,1) + 1
         endif
      enddo


c now we find the weights for each of these bins, depending on how
c far they are from the point in question. This is the linear 
c interpolation

      do i = 1, 2  ! loop over dimensions
         weight(i,2) = point(i) - ( mu_dir_min(i) + 
     1                 ( bin(i,1) - 1 ) * mu_dir_step(i) ) 
         weight(i,1) = mu_dir_min(i) + ( bin(i,2) - 1 ) * 
     1                 mu_dir_step(i) - point(i) 
      enddo 

c now we do the weighted sum of all the relevant bins in the mu_dir_prob
c array which surround the point. There are a 2**n points to consider
c where n=2 is the number of dimensions

      avg_num_hits = 0.0

      do i = 1, 2  ! loop over straddling bins in the first dimension
         do j = 1,2 ! loop over straddling bins in the second dimension
            avg_num_hits = avg_num_hits + 
     1      mu_dir_prob( bin(1,i) , bin(2,j) ) * weight(1,i) *
     2      weight(2,j)  
         enddo
      enddo

c normalise the weighted average correctly

      avg_num_hits = avg_num_hits / mu_dir_step_prod

c remember that mu_dir_prob is the log(prob) so we take an exponential
c to get the prob itself

      avg_num_hits = exp( avg_num_hits )
      
c now we adjust for small fluctuations in average Nhits according to the
c energy loss in this particular segment. We scale to the average e_loss
c in the segments used to generate the HIT distributions
c Note that the use of h_ave_e_loss_KM3, as opposed to h_ave_e_loss_HIT
c (used in km3-muon_scattered_hits.f), is because avg_num_hits is
c independent of the track length: the distribution comes pre-normalised
c out of hit. Hence, h_ave_e_loss_km3 must take into account the actual
c eloss and scale by it, so that the ratio seg_ion.../h_ave_... is on
c average 1

c Note that this gives artificially large variation, since the muon itself
c is the only thing [as of v4r2] giving 'direct' hits. Hence, this gets
c commented out.

c      avg_num_hits = avg_num_hits * seg_ion_e_loss(seg_num) /
c     1               h_ave_e_loss_km3

c now get the poisson distributed number of hits by sampling a poisson
c distribution

      num_hits = ran_poisson( avg_num_hits )

      if (num_hits.gt.5000) num_hits = 5000

      if ( num_hits .lt. 1) then
c there are no hits and we return
         return
      endif

*
* ----------------------------------------------------------------------
*
* Define the time window = 4000.  ns  \__ time_max = time_min + 4000.*10.
* Define the time bin    =    0.1 ns  /
*
      if (num_hits .eq. 1) then
        vnhits(1) = 0.
        vthits(1) = 0.
      else
        do i=1,40000
          vnhits(i) = 0.
          vthits(i) = 0.
        enddo
      endif
* The min. time should be at the begining of the segment.
* sometimes the hit_time is negative -> safety window of 10ns ... 
*        time_min = om_time - 10. 
      time_min = p_t0(part_num) - 10. 
* -------------------------------------------------------------------------

c Implements first-order timing correction: assuming t ~ r
      r1=(bin(1,1)-1)*mu_dir_step(1)+mu_dir_min(1)
      r2=(bin(1,2)-1)*mu_dir_step(1)+mu_dir_min(1)
      r1=r1**(1./mu_dir_power(1))
      r2=r2**(1./mu_dir_power(1))
      weight(1,1)=weight(1,1)*rho/r1
      weight(1,2)=weight(1,2)*rho/r2

c now loop over hits, determining each hit time by sampling the mu_dir_time
c distributions

      do i_hit = 1, num_hits

c find the bins and weights in the time dimension (3) by sampling randomly
c between the mu_dir_nbins(3) time bins


        point(3) =  ran1(idum) * mu_dir_nbins(3)

*  Random intervals in inverse cumulative distribution are not 
*  equally space so we need a different approach to know weights
*  and bins in linear interpolation
      
      	 if (H_CHEB .eq. 1) then
      	    i_p = locatr(x_cheb,mu_dir_nbins(3)+1,point(3))-1
      	 else if (H_CHEB .eq. 0) then
	    i_p = int(point(3))
	 else if (point(3) .lt. 0.5) then
	    i_p = int(mu_dir_tc*(point(3)**mu_dir_itp))
	 else
	    i_p = int(mu_dir_nbins(3) - mu_dir_tc*
     &        ((mu_dir_nbins(3)-point(3))**mu_dir_itp))
	 endif
	    
        bin(3,1) =  abs(i_p)
        bin(3,2) =  bin(3,1) + 1
      	 if (H_CHEB .eq. 1) then
	    weight(3,2) = point(3) - x_cheb(bin(3,1)) 
            weight(3,1) = x_cheb(bin(3,2)) - point(3)
	 else if (H_CHEB .eq. 0) then
	    weight(3,2) = point(3)-i_p
	    weight(3,1) = 1.-weight(3,2)
	 else
	    weight(3,2) = point(3) - mu_dir_tx(bin(3,1))
	    weight(3,1) = mu_dir_tx(bin(3,2))-point(3)
	 endif
      

c now we do the weighted sum of all the relevant bins in the mu_dir_time
c array which surrounds the point. There are a 3**n points to consider
c where n=3 is the number of dimensions

         hit_time = 0.0
         do i = 1, 2  ! loop over straddling bins in the first dimension (radius)
            do j = 1,2 ! loop over straddling bins in the second dimension (OM theta)
               do k = 1,2 ! loop over straddling bins in the time dimension
                  hit_time = hit_time + mu_dir_time( bin(1,i) , 
     1                       bin(2,j), bin(3,k) ) * weight(1,i) *
     2                       weight(2,j) * weight(3,k)  
               enddo
            enddo
         enddo
c normalise the weighted average correctly
         hit_time = hit_time / mu_dir_step_prod
*
         hit_time = hit_time / (weight(3,2)+weight(3,1))
c place the hit info in the hit buffer

         gen_nhits = gen_nhits + 1
*
* -------------------------------------------------------
*
c muon propagation time from origin to the segment center
c + correction for the emission point from the segment center 
c + photon propagation time from track to OM
        this_time = seg_t_center(seg_num) + hit_time
	
        if (num_hits .eq. 1) then
          vnhits(1) = 1.0
          vthits(1) = this_time
        else
c-          itbin = (nint(this_time*10.) - int(time_min*10.) + 1)
           itbin =
     &     ((nint(this_time*10.) - int(time_min*10.))*1./(tmerg*10.))
     &     + 1

          if (itbin.gt.40000 .or. itbin.le.0) then
* Write the hit parameters inmediatly if the hit time is too large
            nlines = nlines + 1
            write(50,110)
     &           nlines,
     &           g_om_id_ant_om(om_num),
     &           1.0,
     &           this_time,
     &           p_part_id(part_num),
     &           p_track_id(part_num),
     &           p_iparent(part_num)
          else
            vnhits(itbin) = vnhits(itbin) + 1.0
	    vxhits(itbin) = this_time
c-            vthits(itbin) = (int(time_min*10.) + itbin - 1 )*0.1
	    vthits(itbin) = int(time_min) + real(itbin)*tmerg
     &                      - tmerg/2.
          endif
        endif
* find the earliest and latest
         if (this_time.gt.tmaxh) tmaxh = this_time
         if (this_time.lt.tminh) tminh = this_time
*
* -------------------------------------------------------
*
       enddo
*
       if (num_hits .eq. 1) then
         nlines = nlines + 1
         if (H_REC_HIT_ORIGIN .eq. 1) then
	    write(50,111)
     &            nlines,
     &            g_om_id_ant_om(om_num),
     &            vnhits(1),
     &            vthits(1),
     &            p_part_id(part_num),
     &            p_track_id(part_num),
     &            p_iparent(part_num),
     &	          seg_num
	 else
	    write(50,110)
     &             nlines,
     &             g_om_id_ant_om(om_num),
     &             vnhits(1),
     &             vthits(1),
     &             p_part_id(part_num),
     &             p_track_id(part_num),
     &             p_iparent(part_num)
         endif
       else
*
         do i = 1, 40000
           if (vnhits(i) .gt. 0.) then
             nlines = nlines + 1

	     if (vnhits(i).eq.1) tempo = vxhits(i)
	     if (vnhits(i).gt.1) tempo = vthits(i)
      	     if (H_REC_HIT_ORIGIN .eq. 1) then
               write(50,111)
     &            nlines,
     &            g_om_id_ant_om(om_num),
     &            vnhits(i),
     &            tempo,
     &            p_part_id(part_num),
     &            p_track_id(part_num),
     &            p_iparent(part_num),
     &	          seg_num
	     else
               write(50,110)
     &            nlines,
     &            g_om_id_ant_om(om_num),
     &            vnhits(i),
     &            tempo,
     &            p_part_id(part_num),
     &            p_track_id(part_num),
     &            p_iparent(part_num)
             endif
	   endif
         enddo
       endif
*
c 110  FORMAT('hit:',1X,I7,1X,I5,1X,F6.1,1X,F10.2,3(1X,I6))
 110  FORMAT('hit:',1X,I7,1X,I7,1X,F6.1,1X,F11.2,3(1X,I6))
 111  FORMAT('hit:',1X,I7,1X,I7,1X,F6.1,1X,F11.2,4(1X,I6))
 100  FORMAT(5X,'* WARNING !! MUON_DIR_HITS routine, gen_nhits 
     &      out of range')
*
 777   CONTINUE
*
**
*
 999  CONTINUE
      end
