C*/
      subroutine muon_inter_ini( rho, cos_band, theta_om, phi_om )
*************************************************************************
*     Name           :  muon_inter_ini                                  *
*     Called by      :                                                  *
*     Author         :  Sergio Navas, based on "inter_ini"              *
*     Date           :  14-Dec-1999                                     *
*     Task           :  For a given muon,                               *
*                       Compute inverse cumulative function values for  *
*                       time interpolation scattered photons, once the  *
*                       optical module coordinates are known.           *
*                                                                       *
*  In/Out Variables:                                                    *
*  -----------------                                                    *
*   in     rho         magnitude of rho_vec                             *
*   in     cos_band    cos(angle between seg_dir and rho_vec)           *
*   in     theta_om    angle between om_dir and rho_vec                 *
*   in     phi_om      phi orientation of optical module                *
*                                                                       *
*************************************************************************
      include 'km3.inc'
      include 'km3-interpol.inc'

      real*4 rho, cos_band, theta_om, phi_om, point(5), weight(5,2) 
      integer*4 bin(5,2),i_b
      integer*4 i_time,i,j,k,l

c------------------------------------------------------------------------
c  Compute f values for interpolation (inverse acumulative function)
c------------------------------------------------------------------------
      if ( cos_band .lt. h_cos_ch ) then
c we are in the low bands
        i_b = 1
        point(2) = (h_cos_ch - cos_band)**mu_sca_power(i_b,2)
      else 
c we are in the high bands
        i_b = 2
        point(2) = (cos_band - h_cos_ch)**mu_sca_power(i_b,2)
      endif
      point(1) = rho**mu_sca_power(i_b,1)
      point(3) = theta_om
      point(4) = phi_om

      do i = 1,  mu_sca_nbins(i_b,5)+1
        a_time(i) = x_cheb(i-1)
      enddo

c------------------------------------------------------------------------
c now we find the bin values which straddle the current point where we are
c in the mu_sca_prob array.
c------------------------------------------------------------------------
      do i = 1,4    ! loop over four geometrical dimensions
         if ( point(i).le. mu_sca_min(i_b,i) ) then
c we use the first two bins
            bin(i,1) = 1 
            bin(i,2) = 2
         else if ( point(i) .ge. mu_sca_max(i_b,i) ) then
c we use the last two bins
            bin(i,1) = mu_sca_nbins(i_b,i) - 1 
            bin(i,2) = mu_sca_nbins(i_b,i) 
         else
c we are inside the linearly spaced array 
            bin(i,1) = 1 + int( (point(i) - mu_sca_min(i_b,i) ) / 
     1                 mu_sca_step(i_b,i) ) 
            bin(i,2) = bin(i,1) + 1
         endif
      enddo
c------------------------------------------------------------------------
c now we find the weights for each of these bins, depending on how
c far they are from the point in question. This is the linear 
c interpolation
c------------------------------------------------------------------------
      do i = 1, 4  ! loop over four geometrical dimensions
         weight(i,2) = point(i) - ( mu_sca_min(i_b,i) + 
     1                 ( bin(i,1) - 1 ) * mu_sca_step(i_b,i) )
         weight(i,1) = mu_sca_min(i_b,i) + ( bin(i,2) - 1 ) * 
     1                 mu_sca_step(i_b,i) - point(i) 

      enddo 

*-------------------------------------------------------------------------
* Build the time distribution for the point in question
*-------------------------------------------------------------------------

      do i_time = 0, mu_sca_nbins(i_b,5)
        f_time(i_time+1) = 0.0
        do i = 1, 2  ! loop over straddling  bins in the 1st geom dimension
           do j = 1,2 ! loop over straddling bins in the 2nd geom dimension
              do k = 1,2 ! loop over stradd. bins in the 3rd geom dimension
                 do l = 1,2 ! loop over straddl. bins in 4th geom. dimension
                    f_time(i_time+1) = f_time(i_time+1)+
     &              mu_sca_time(i_b,bin(1,i),bin(2,j),
     &                   bin(3,k),bin(4,l),i_time)
     &                   *weight(1,i)*weight(2,j)
     &                   *weight(3,k)*weight(4,l)
                  enddo 
              enddo
           enddo
        enddo

c normalise the weighted average correctly

        f_time(i_time+1) = f_time(i_time+1) / mu_sca_step_prod(i_b)

      enddo

      return
      end
