      SUBROUTINE mu_scatt(jp,E,v,theta,phi)
      IMPLICIT NONE
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* Input:
      INTEGER*4 jp
!               * jp = 1 : bremsstrahlung
!               * jp = 2 : pair-production
!               * jp = 3 : nuclear
      REAL*8 E    !initial energy of the muon
      REAL*8 v        !fractional energy loss of muon
* Output:
      REAL*8 theta,phi
* theta respect to parent muon direction,always positive!!!
* phi orthogonal to plane defined by parent muon direction
* theta phi in deg
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      REAL*8 mmu,pi,n_z,n_a,n_rho,n_lambda,mel,conv
      PARAMETER (pi=3.141592654)
      PARAMETER (conv=57.29577951)
      PARAMETER (mmu=105.658e-3)
      PARAMETER (mel=0.511e-3)

      real*4 ee,vv,yfl

      REAL*8 eoutmu,p2q
      COMMON/rock2/n_a,n_z,n_rho,n_lambda

* Bremsstrahlung declarations
      REAL*8 ak1,ak2,ak3,ak4,ak5,an,the1,the2,the3,the_mean,at


* Pair prod. declarations
      REAL*4 a_min

      the_mean = 0
* Bremsstrahlung: following Van Ginneken
      IF (jp.EQ.1) THEN
        ak1=0.092*E**(-1./3.)
        ak3=0.22*E**(-0.92)
        ak4=0.26*E**(-0.91)
        an=0.81*dsqrt(E)/(dsqrt(E)+1.8)
        ak2=0.052/E*n_z**(-0.25)
        at=min(ak1*sqrt(v),ak2)
        the1=max(at,ak3*v)
        the2=ak4*v**(1.+an)*(1.-v)**(-an)
        ak5=ak4*0.5**(1.+an)*0.5**(-an)/0.5**(-0.5)
        the3=ak5/dsqrt(1.-v)
        IF(v.LE.0.5) the_mean=the1
        IF(v.GT.0.5.AND.the2.LT.0.2) the_mean=the2
        IF(v.GT.0.5.AND.the2.GE.0.2) the_mean=the3
        the_mean=the_mean*the_mean
   10   call ranlux(yfl,1)
        theta=-the_mean*alog(yfl)
        theta=dsqrt(theta)
        IF(theta.GT.pi) go to 10
        call ranlux(yfl,1)
        phi=(2.*pi)*(yfl)                   !uniform between 0 and 2*pi
c        theta=theta*(conv)              !from rad to deg
c        phi=(phi)*(conv)

*     pair production (Van Ginneken)

      ELSE IF (jp.EQ.2) THEN
         ee=E
         vv=v
        a_min=min(8.9e-4*sqrt(sqrt(vv))*(1.+1.5e-5*ee)+0.032*vv/
     *    (vv+1.),0.1)
        the_mean=(2.3+dlog(E))/E/(1.-v)*(v-2.*mel/E)**2/v/v*a_min
        the_mean=the_mean*the_mean
   11   call ranlux(yfl,1)
        theta=-the_mean*alog(yfl)
        theta=dsqrt(theta)
        IF(theta.GT.pi) go to 11
        call ranlux(yfl,1)
        phi=(2.*pi)*(yfl)                   !uniform between 0 and 2*pi
c        theta=theta*(conv)              !from rad to deg
c        phi=(phi)*(conv)

* Inelastic scattering

      ELSE IF (jp.EQ.3) THEN
        CALL defl(E,jp,v,theta,phi)

      ELSE
        PRINT *,'Invalid jp argument on mu_scat',jp
        STOP
      ENDIF
      RETURN
      END
