      SUBROUTINE multiple
     *(x0,einmu,eoutmu,alpha,beta,theta,phi,deltax,deltay,deltar,err)
      IMPLICIT NONE
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* Multiple scattering: following
* P.Lipari and T. Stanev, Phys. Rev. D, 44, 3543 (1991) and
* L. Highland, Nucl. Instr. and Methods, 129, 497 (1975)
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* Input:
      REAL*8 x0        !in g/cm^2
      REAL*8 einmu     !initial energy of the muon
      REAL*8 eoutmu    !final energy of the muon
      REAL*8 alpha     !ionization energy loss of muon
      REAL*8 beta      !relative (continuous) energy losses of muon
                       !due to other processes
* Output:
      REAL*8 theta
      REAL*8 phi
      REAL*8 deltax,deltay
      REAL*8 deltar             !approximate increase of a muon path
      INTEGER*4 err             !error flag (err=1) indicates that
                                !einmu or eoutmu is less than mmu
                                !error flag (err=2) indicates that
                                !integral along path is LE.0

* theta respect to parent muon direction
* phi orthogonal to plane defined by parent muon direction
* theta phi in deg
* deltax,deltay    lateral displacement of the muon in g/cm^2
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* Multiple scattering declarations
      REAL*8 mmu,pi,mel,conv
      PARAMETER (pi=3.141592654)
      PARAMETER (conv=57.29577951)
      PARAMETER (mmu=105.658e-3)
      PARAMETER (mel=0.511e-3)

      REAL*8 ems,sigma,sigt,xx,yy,ro
      REAL*8 sigmat,sigmax,thetax,thetay,zz,sz,step,sz1
      REAL*8 p1,g1,bet1,p2,g2,bet2
      REAL*8 n_a,n_z,n_rho,n_lambda
      REAL*4 sigmatt,sigmaxx,roo,thetaxx,thetayy,xxx,yyy
      REAL*4 vv(2,2),cc(2,2),vcx(2)

C      PARAMETER (ems=0.0124)                 !in Gev (cfr Highland)
C      PARAMETER (ems=0.014)                  !in Gev (cfr Lipari)
      PARAMETER (ems=0.015)                  !in Gev (060697)

      COMMON/rock2/n_a,n_z,n_rho,n_lambda

      err=0
      IF(einmu.LE.mmu) THEN
         einmu=mmu
         err=1

         RETURN
      END IF
      IF(eoutmu.LE.mmu) THEN     
         eoutmu=mmu
      END IF
      p1=dsqrt(einmu*einmu-mmu*mmu)
      g1=einmu/mmu
      bet1=dsqrt(g1*g1-1.)/g1
      p2=dsqrt(eoutmu*eoutmu-mmu*mmu)
      g2=eoutmu/mmu
      bet2=dsqrt(g2*g2-1.)/g2
      sigt = 0
      sz1 = 0
*      print *,'ok',p1,p2,g1,g2,bet1,bet2

      IF(beta.GT.0..AND.bet2.GT.0.) THEN
        sigt=1./alpha*(1./p2/bet2-1./p1/bet1)+beta/alpha/alpha*
     *    (dlog(dabs(1.+alpha/beta/p1/bet1))-
     *    dlog(dabs(1.+alpha/beta/p2/bet2)))
      END IF
      IF(beta.EQ.0..AND.bet2.GT.0.) THEN
        sigt=1./alpha*(1./p2/bet2-1./p1/bet1)
      END IF
      IF(sigt.LE.0.) THEN
        sigt=1./p1/bet1/p1/bet1
      END IF
      IF(bet2.LE.0.) THEN
        sigt=1./p1/bet1/p1/bet1*16.
      END IF
      sigma=sigt*ems*ems/n_lambda
      sigmat=dsqrt(sigma)              !sigma(theta_x)=sigma(theta_y)
      IF(einmu.EQ.eoutmu) THEN                        !for test programs
        sigmat=dsqrt(ems*ems*x0/einmu/einmu/n_lambda)    !
      END IF                                          !
      IF((einmu-eoutmu)/eoutmu.gt.0.5.or.eoutmu.le.10..or.x0.gt.1.e4) 
     *THEN
      sz=0.
      step=x0/100.
      zz=0.
    1 zz=zz+step/2.
      IF(beta*zz.GT.1.e-6) THEN
        sz1=p1*bet1*dexp(-beta*zz)-alpha/beta*(1.-dexp(-beta*zz))
      END IF
      IF(beta*zz.le.1.e-6) THEN
        sz1=p1*bet1-alpha*zz
      END IF
      IF(sz1.LE.mmu) THEN
        sz=0.
        go to 3
      END IF
      sz=sz+zz*zz*step/sz1/sz1
      zz=zz+step/2.
      IF(zz.LT.x0) go to 1
    3 CONTINUE
      IF(sz.LE.0.) THEN
         sz=x0*x0*x0/3./(p1+p2)/(p1+p2)/(bet1+bet2)/(bet1+bet2)*16.
      END IF

      ELSE
         sz=x0*x0*x0/3./(p1+p2)/(p1+p2)/(bet1+bet2)/(bet1+bet2)*16.
      END IF

      IF(sz.LE.0.) THEN
        err=2
        RETURN
      END IF
      sigmax=dsqrt(sz*ems*ems/n_lambda)        !sigma(x)=sigma(y)
      ro=sqrt(3.)/2.                  !correlation coefficient
    2 CONTINUE
      sigmatt=sigmat
      sigmaxx=sigmax
      roo=ro
c      CALL normco(thetaxx,xxx,0.,0.,sigmatt,sigmaxx,roo) !simulation of thetax,
c      CALL normco(thetayy,yyy,0.,0.,sigmatt,sigmaxx,roo) !thetay,xx,yy
	vv(1,1)=sigmatt*sigmatt
	vv(2,2)=sigmaxx*sigmaxx
	vv(1,2)=roo*sigmatt*sigmaxx
	vv(2,1)=roo*sigmatt*sigmaxx
	call corset(vv,cc,2)
	call corgen(cc,vcx,2)
	thetaxx=vcx(1)
	xxx=vcx(2)
	call corgen(cc,vcx,2)
	thetayy=vcx(1)
	yyy=vcx(2)
c      thetax=conv*thetaxx
c      thetay=conv*thetayy
       thetax=thetaxx
       thetay=thetayy
cc      IF(dabs(thetax).GE.pi/2..OR.dabs(thetay).GE.pi/2.) go to 2
      theta=datan(dsqrt(dtan(thetax)*dtan(thetax)+     !evaluation of theta
     *  dtan(thetay)*dtan(thetay)))                     !using thetax,thetay
      IF(dsin(thetax).NE.0.) THEN
        phi=datan(dtan(thetay)/dtan(thetax))            !evaluation of phi
        IF(dtan(thetax).LT.0.) phi=pi+phi             !using thetax,thetay
      END IF
      IF(dsin(thetax).EQ.0.) THEN
        phi=pi/2.
        IF(dtan(thetay).LT.0.) phi=pi*3./2.
      END IF
      IF(phi.GT.pi*2.) phi=-pi*2.+phi
      IF(phi.LT.0.) phi=phi+pi*2.
      deltax=xxx
      deltay=yyy
      deltar=sigmat*sigmat*x0   !very approximately (according to GEANT)

      RETURN
      END
