      SUBROUTINE MUONDECAY(muid,xmu,ymu,zmu,cxmu,cymu,czmu,emu,
     *     tmu,eid,xe,ye,ze,cxe,cye,cze,ee,te)
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

c     Subroutine to simulate electron spectrum and angular distribution
c     from muon decay in water
c     Pure water is considered; any change for sea water - tdecay and 
c     fdecay for mu-?
c     Based on Kamiokande II results: Phys. Rev. D44 (1991) 617 
c     (see also references therein for muon decay and polarisation parameters)

      implicit none
      integer*4 muid,eid,id,i
      real*8 theta00,phi00,theta1,phi1
      real*4 xmu,ymu,zmu,cxmu,cymu,czmu,emu,tmu,mmu,asim,cs,c0,temp
      real*4 xe,ye,ze,cxe,cye,cze,ee,te,theta0,phi0,theta,phi,xxe
      real*4 tdecay(2),polar(2),polar0,fdecay(2),polar1,pi,cthe,erange
      real*8 xe1,ye1,ze1,xe2,ye2,ze2
      data tdecay/2.197e3,1.795e3/      ! decay constants for mu+ and mu-
      data polar/0.72,0.051/            ! remaining fractional polarization 
                                        ! in water
      data fdecay/1.,0.816/             ! fraction of mu- that decay
      parameter (polar0=0.29)           ! initial polarisation of muons in atm.
      parameter (mmu=0.105658)
      parameter (pi=3.141592654e0)
      real*4 yfl,yfl1,yfl2,yfl3
      real*4 een(15),range(15)
      data een/0.5,1.0,1.5,2.0,3.,4.,5.,7.,10.,15.,20.,30.,40.,50.,55./
      data range/0.1766,0.4367,0.7075,0.9785,1.514,2.037,2.550,3.545,
     *     4.975,7.219,9.320,13.17,16.65,19.83,21.32/

c      czmu=1.
c      cxmu=0.
c      cymu=0.

      xe=0.
      ye=0.
      ze=0.
      ee=0.
      cxe=0.
      cye=0.
      cze=0.
      te=0.
      eid=0
      id = 0
      phi0 = 0

      IF(muid.eq.5) THEN
         eid=2
         id=1
      END IF
      IF(muid.eq.6) THEN
         eid=3
         id=2
         call ranlux(yfl,1)
         IF(yfl.GT.fdecay(2)) RETURN
      END IF

 1    call ranlux(yfl,1)
      call ranlux(yfl1,1)
      IF(yfl1.LT.yfl**2*(3.-yfl*2.)) THEN
         xxe=yfl
         ee=mmu*xxe/2.
c         print *,'decay-ee',ee
         IF(ee.GT.mmu/2.) GO TO 1
      ELSE
         GO TO 1
      END IF

      asim=(1.-2.*xxe)/(3.-2.*xxe)
      polar1=(3-2.*id)*polar0*polar(id)
      asim=asim*polar1
c      print *,'id,muid,eid,xxe,asim,polar1',
c     *id,muid,eid,xxe,asim,polar1
      call ranlux(yfl,1)
      c0=2.*yfl-1.
      temp=asim*asim+1.+2.*asim*c0
      IF(temp.GE.0.) THEN
         cthe=(sqrt(temp)-1.)/asim
      ELSE
c         print *,asim,c0,temp
         cthe=c0
      END IF
      call ranlux(yfl,1)
      phi=2.*pi*yfl
      theta=acos(cthe)
c      print *,'decay-costheta,phi',cthe,phi

      i=1
 2    i=i+1
      if(alog10(ee*1000.).GE.alog10(een(i))) GO TO 2
      erange=10.**((alog10(range(i))-alog10(range(i-1)))/
     *     (alog10(een(i))-alog10(een(i-1)))*
     *     (alog10(ee*1000.)-alog10(een(i-1)))+alog10(range(i-1)))
c      print *,erange
      ze1=erange*cthe
      xe1=erange*sin(theta)*cos(phi)
      ye1=erange*sin(theta)*sin(phi)

      theta0=acos(czmu)
      IF(cxmu.NE.0.) THEN
         phi0=atan(cymu/cxmu)
	IF(cxmu.LT.0.) phi0=pi+phi0
      END IF
      IF(cxmu.EQ.0.) THEN
         phi0=pi/2.
         IF(cymu.LT.0.) phi0=1.5*pi
      END IF
      IF(phi0.GT.2.*pi) phi0=-2.*pi+phi0
      IF(phi0.LT.0.) phi0=phi0+2.*pi
      theta1=1.d0*theta
      phi1=1.d0*phi
      theta00=1.d0*theta0
      phi00=1.d0*phi0
      CALL coord_transform(xe2,ye2,ze2,xe1,ye1,ze1,theta00,phi00)
      xe=xmu+xe2/100./1.03
      ye=ymu+ye2/100./1.03
      ze=zmu+ze2/100./1.03
      IF(theta.NE.0.) THEN
         call angle_transform(theta00,phi00,theta1,phi1)
      END IF
      theta0=theta00
      phi0=phi00
cc      theta0=theta
cc      phi0=phi
      cze=cos(theta0)
      cxe=sin(theta0)*cos(phi0)
      cye=sin(theta0)*sin(phi0)

      call ranlux(yfl,1)
      te=-tdecay(id)*alog(yfl)
      te=te+tmu

      RETURN
      END
