c Routine to return the half-length of a cascade in metres

      REAL FUNCTION OPA_HLENGTH(IPART,EKIN)
      
      IMPLICIT NONE
      REAL EKIN
      INTEGER IPART
      REAL hlength_part,hlength_elec
      REAL hlength_pion, hlength_klong, hlength_kshort
      REAL hlength_kaon, hlength_neutron, hlength_proton
      
c 100% energy to EM showers if electron, positron, pi0, or gamma
      if (ipart .eq. 1 .or. ipart .eq. 2
     &	 .or. ipart .eq. 3 .or. ipart .eq. 7) then
	 hlength_part = hlength_elec(ekin)
      else if (ipart .eq. 8 .or. ipart .eq. 9) then
      	 hlength_part=hlength_pion(ekin)
      else if (ipart .eq. 10) then
      	 hlength_part=hlength_klong(ekin)
      else if (ipart .eq. 16) then
      	 hlength_part=hlength_kshort(ekin)
      else if (ipart .eq. 11 .or. ipart .eq. 12) then
      	 hlength_part=hlength_kaon(ekin)
      else if (ipart .eq. 13) then
      	 hlength_part=hlength_neutron(ekin)
      else if (ipart .eq. 14) then
      	 hlength_part=hlength_proton(ekin)
      else
c     	 when in doubt, treat it as a pion
      	 hlength_part=hlength_pion(ekin)
      endif
      if (hlength_part .lt. 0.) then
      	 hlength_part = 0.
      endif
      opa_hlength=hlength_part      
      return
      end

c **** calculates the expected half-length of a cascade in m
      REAL FUNCTION HLENGTH_ELEC(EKIN)
      implicit none
      REAL eleca,elecd,ekin
      
      eleca          = 0.802659
      elecd          = 1.09616
      hlength_elec = eleca*log10(ekin)+elecd
      return
      end
	    
c **** calculates the expected half-length of a cascade in m
      REAL FUNCTION HLENGTH_PROTON(EKIN)
      implicit none
      REAL pa,pd,ekin
      
      pa           = 1.40561
      pd           = 1.01171
      hlength_proton = pa*log10(ekin)+pd
      return
      end
    
c **** calculates the expected half-length of a cascade in m
      REAL FUNCTION HLENGTH_PION(EKIN)
      implicit none
      REAL pia,pib,pid, ekin
      
      pia           = 1.46659
      pib           = 0.119678
      pid           = 1.07648
      hlength_pion = pia*log10(ekin+pib)+pid
      return
      end

c **** calculates the expected half-length of a cascade in m
      REAL FUNCTION HLENGTH_NEUTRON(EKIN)
      implicit none
      REAL na,nb,nc,nd,neuca,neucb,neucd,ekin
      
      neuca           = 1.48695
      neucb           = 6.14255
      neucd           = 0.710296
      na              = 0.409666
      nb              = -0.18489
      nc              = 0.552911
      nd              = -0.603341

      hlength_neutron = neuca*log10(ekin+neucb)+neucd +
     &      10.*exp(-ekin/na)*(nb+nc*ekin+nd*ekin**2)
      return
      end

c **** calculates the expected half-length of a cascade in m
      REAL FUNCTION HLENGTH_KAON(EKIN)
      implicit none
      REAL ka,kb,kd,ekin
      
      ka           = 1.52988
      kb           = 0.0508188
      kd           = 1.31544

      hlength_kaon = ka*log10(ekin+kb) + kd
      
      return
      end
      
c **** calculates the expected half-length of a cascade in m
      REAL FUNCTION HLENGTH_KSHORT(EKIN)
      implicit none
      REAL k0sa,k0sb,k0sd,ekin
      
      k0sa           = 1.50825
      k0sb           = 0.362939
      k0sd           = 0.903518

      hlength_kshort=k0sa*log10(ekin+k0sb)+k0sd
      
      return
      end

c **** calculates the expected number of photons for K0-short as a function of energy
      REAL FUNCTION HLENGTH_KLONG(EKIN)
      implicit none
      REAL k0la,k0lb,k0ld,ekin
      
      k0la           = 1.08424
      k0lb           = 0.195756
      k0ld           = 1.88574

      hlength_klong= k0la*log10(ekin+k0lb)+k0ld
      
      return
      end

