C*/
      SUBROUTINE process_em_shower( part_num, ier, eff_seg_num )

*     Created:  24-Mar-98
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
c     Process an electromagnetic shower into OM hits

*     In/Out Variables:-
*     ==========
c     in        part_num         number of particle to which segment belongs
c     in	ier      	 error code
*     Common Block Access:-
*     ===================
c     /km3/  	in 		holds structures for KM3

*     Assumptions:-
*     ===========
c     first we move the defining point of the shower along to the shower 
c     maximum. This shower max is used to reference all the Om hits and
c     is calculated by a simple formula provided by D. Lowder
c     The rest is very similar to process_segment (cwj: i.e. process_muon?)
 
*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine

      INCLUDE 'km3.inc'

      INTEGER*4  num_oms_in_range, oms_in_range(max_num_oms_det)
      INTEGER*4  part_num, ier, i, idum, eff_seg_num
      REAL*4     rho_vec(3), rho, cos_band, theta_om, phi_om
      REAL*4     shower_step(3), shower_max, max_dist
      REAL*4     dummy_vec1(3), dummy_vec2(3), dummy_vec3(3)
      REAL*4     dummy_vec4(3)

c The movement of the shower point along by a distance given by D. lowder's
c formula for shower maximum is now performed in previous routines
c hence this part is commented out
c      shower_max=0.9*(1.0+log10(p_e0(part_num)))/h_dens_medium
c      showers are already offset by now - must be due to MPA
c      shower_max=0.
c      DO idum=1,3
c        dummy_vec1(idum) = p_v0(idum,part_num)
c      END DO
c
c      call scale_vec( shower_max,dummy_vec1,shower_step )
c      DO idum=1,3
c        p_x0(idum,part_num) = p_x0(idum,part_num) + shower_step(idum)
c      END DO
c      p_t0(part_num) = p_t0(part_num) + shower_max / c_c_mpns

c Adjust the maximum distance over which one should look for nearby OMs
c which might get hits from this shower, according to the shower's energy 
c      max_dist = h_rho_max + 50.0 * ( log10( p_e0(part_num) ) - 1.0)
* "max_dist" should not be biger than the radius of the more external
* simulated shell in order to avoid extrapolations which generate
* negative hit_time values. At 100 GeV (log10-2 = 0) we get the min value

      max_dist = h_rho_elec_cut_base + h_rho_elec_cut_del*
     & 	 max(( log10( p_e0(part_num) ) - 2.0),0.)
      max_dist = min(max_dist, el_sca_max(1,2)**(1./el_sca_power(1,2)))

c find the OMs which are within this distance from the shower max

      DO idum=1,3
        dummy_vec1(idum) = p_x0(idum,part_num)
      END DO
      call find_oms_near_point(dummy_vec1, max_dist, 0.0,
     1     oms_in_range, num_oms_in_range )
      if ( num_oms_in_range .eq. 0) return
c there are no OMs in range and we simply return

c loop over the OMs which are in range
      do i = 1, num_oms_in_range
c find the values of the 4 geometrical parameters which describe the 
c geometrical relationship between the shower and an OM 
c (rho,cos_band,theta_om,phi_om)
         
         DO idum=1,3
           dummy_vec1(idum) = p_x0(idum,part_num)
           dummy_vec2(idum) = p_v0(idum,part_num)
           dummy_vec3(idum) = g_om_x(idum,oms_in_range(i))
           dummy_vec4(idum) = g_om_dir(idum,oms_in_range(i))
         END DO
	 
         call find_point_params(dummy_vec1,dummy_vec2,dummy_vec3,
     &   dummy_vec4, rho_vec, rho, cos_band, theta_om, phi_om )	

c there should be no direct electron hits - but if there were, this would be the place to put them, e.g. as below:
c      	 if (H_do_dir_ph .gt. 1.5) then
c	       write(*,*) 'Sorry - no direct electron hits allowed'
cc            call elec_direct_hits( part_num, oms_in_range(i), 
c     1                          rho, cos_band, theta_om )
c      	 endif

c find the scattered hits for this OM (from this shower), including 
c the hit times for each hit
         call elec_scattered_hits( part_num,  oms_in_range(i), 
     1                             rho, cos_band, theta_om, phi_om )

      enddo
      end
