C*/
      SUBROUTINE PROCESS_PHOTON_BOMB( part_num, ier )
*************************************************************************
*     Name           :  PROCESS_PHOTON_BOMB                             *
*     Called by      :                                                  *
*     Author         :  Sergio Navas                                    *
*     Date           :  21-Sep-1998                                     *
*     Task           :  Process a LASER-flash into OM hits              *
*                                                                       *
*  In/Out Variables:                                                    *
*  -----------------                                                    *
*     in        part_num   number of particle to which segment belongs  *
*     in	ier        error code                                   *
*                                                                       *
*  Assumptions:                                                         *
*  ------------                                                         *
*                                                                       *
*************************************************************************
*
      INCLUDE 'km3.inc'
*
      INTEGER*4  num_oms_in_range, oms_in_range(max_num_oms_det)
      INTEGER*4  part_num, ier, i, idum
      REAL*4     rho_vec(3), rho, cos_band, theta_om, phi_om
      REAL*4     max_dist, min_dist
      REAL*4     dummy_vec1(3), dummy_vec2(3), dummy_vec3(3)
      REAL*4     dummy_vec4(3)

c Adjust the maximum distance over which one should look for nearby OMs
c which might get hits from this shower, according to the shower's energy 
      max_dist = h_rho_elec_cut_base + h_rho_elec_cut_del*
     & 	 max(( log10( p_e0(part_num) ) - 2.0),0.)
      max_dist = min(max_dist, el_sca_max(1,2)**(1./el_sca_power(1,2)))

* maximum radius bin
      IF ( p_part_id(part_num) .eq. p_id_laser )  then
        max_dist = 300.0
        min_dist =  30.0
      ENDIF
* <<<<<<<<

c find the OMs which are within this distance from the shower max

C D. Bailey: 23/11/00
C Copy to dummy vectors for the subroutines call in F77
  
      DO idum=1,3
        dummy_vec1(idum) = p_x0(idum,part_num)
      END DO 

      call find_oms_near_point( dummy_vec1, max_dist, min_dist,
     1     oms_in_range, num_oms_in_range )

      if ( num_oms_in_range .eq. 0) return
c there are no OMs in range and we simply return

c loop over the OMs which are in range
      do i = 1, num_oms_in_range

c find the values of the 4 geometrical parameters which describe the 
c geometrical relationship between the shower and an OM 
c (rho,cos_band,theta_om,phi_om)

C D. Bailey: 23/11/00
C Copy to dummy vectors for the subroutine call in F77

        DO idum=1,3
          dummy_vec1(idum) = p_x0(idum,part_num)
          dummy_vec2(idum) = p_v0(idum,part_num)
          dummy_vec3(idum) = g_om_x(idum,oms_in_range(i))
          dummy_vec4(idum) = g_om_dir(idum,oms_in_range(i))
        END DO 

        call find_point_params(dummy_vec1,dummy_vec2, 
     1       dummy_vec3, dummy_vec4,
     &       rho_vec,rho, cos_band, theta_om, phi_om )	

C D. Bailey: 23/11/00
C find_point_params takes the positions and directions as inputs only so
C there is no need to copy back...

c find the direct hits for this OM (from this shower), including 
c the hit times for each hit

        IF (PHDIR) THEN
          call phot_direct_hits( part_num, oms_in_range(i), 
     1         rho, cos_band, theta_om )
        ENDIF
c find the scattered hits for this OM (from this shower), including 
c the hit times for each hit

        IF (PHSCA) THEN
* Initialize Interpolation: Compute Inverse cumulative values for this point
          call inter_ini( rho, cos_band, theta_om, phi_om )

          call phot_scattered_hits( part_num,  oms_in_range(i), 
     1         rho, cos_band, theta_om, phi_om )
        ENDIF
*
      enddo
*
**
*
 999  CONTINUE
      END
