C*/
	SUBROUTINE READ_ANTARES_GEOM(i_err)
	INCLUDE 'km3.inc'
c
c  Read geometry file with the => OLD <= ANTARES format, and fill the
c  the geometry structures

        INTEGER*4 I, i_err, om_id_km3, j, k, l        
        INTEGER*4 n_clusters, n_strings
        REAL*4    squ
        REAL*4    dummy_vec(3)
        CHARACTER*6 TAG
c
c--- open geometry file
c
	OPEN(UNIT=IO_UNGEO,FILE=io_geom_file,STATUS='OLD',
     1       IOSTAT=i_err)
        write(*,*) 'Open file ',IO_GEOM_FILE,' Unit=',IO_UNGEO
	IF(i_err.NE.0) THEN
	  WRITE(*,*) ' Error opening geometry file',i_err
	  RETURN
	END IF
c
c--- read the detector global geometry specification
c
        READ (IO_UNGEO, 222) tag 
 222	FORMAT(a6)
        if ( tag .ne. 'det:' ) then
	  WRITE(*,*) ' Error reading geometry file: det tag'
	  i_err = 1
	  RETURN
	END IF
*
        READ (IO_UNGEO, *) g_num_str, g_num_cls, g_num_oms, 
	1    g_latitude, g_longitude, g_z_surface, g_z_bottom,
	2    g_rad_cyl, g_hht  

c calculate radius of detector enclosing sphere
        g_rad_sph = sqrt( squ(g_rad_cyl) + squ(g_hht) )

c check if # of OMs is too many for the g.om array size
	if ( g_num_oms .gt. max_num_oms_det) then
	  WRITE(*,*) ' Error reading geom file: Too many OMs in det'
	  WRITE(*,*) ' Change max_num_oms_det in file km3.inc to',
	1      g_num_oms   
	  i_err = 1
	  RETURN
        END IF

c check if # of Strings is too many for the nested geometry array size
	if ( g_num_str .gt. max_num_str) then
	  WRITE(*,*) ' Error reading geom file: Too many strings'
	  WRITE(*,*) ' Change max_num_str in file km3.inc to',
	1      g_num_str   
	  i_err = 1
	  RETURN
        END IF
	
        om_id_km3  = 0
        n_strings  = 0
        n_clusters = 0
	
c now continue reading the data file, looping over strings
	do i = 1, g_num_str

	  n_strings = n_strings + 1

	  READ (IO_UNGEO, 222) tag 
	  if ( tag .ne. 'str:' ) then
	    WRITE(*,*) ' Error reading geometry file: str tag'
	    i_err = 1
	    RETURN
	  END IF
          
	  READ (IO_UNGEO, *) g_str_id_ant_str(i),
	1      g_str_x(1,i), g_str_x(2,i),
	2      g_str_x(3,i), g_str_rad_cyl(i),
	3      g_str_hht(i), g_str_num_cls(i)
	  
c calculate radius of string enclosing sphere
	  g_str_rad_sph(i) = sqrt( squ(g_str_rad_cyl(i)) + 
	1      squ(g_str_hht(i)) )

c check if # of clusters is too many for the nested geometry array size
	  if ( g_str_num_cls(i) .gt. max_num_cls) then
	    WRITE(*,*) ' Error reading geom file: Too many clusters'
	    WRITE(*,*) ' Change max_num_cls in file km3.inc to',
	1	 g_str_num_cls(i)
	    i_err = 1
	    RETURN
	  END IF
	  
c now continue reading the data file, looping over clusters 

	  do j = 1, g_str_num_cls(i)

c update the cumulative cluster count
	    n_clusters = n_clusters + 1
	    
	    READ (IO_UNGEO, 222) tag 
	    if ( tag .ne. 'cls:' ) then
	      WRITE(*,*) ' Error reading geometry file: cls tag'
	      i_err = 1
	      RETURN
	    END IF
	    
	    READ (IO_UNGEO, *) g_str_cls_id_ant_cls(j,i), 
	1	 g_str_cls_id_ant_str(j,i), g_str_cls_x(1,j,i), 
	2	 g_str_cls_x(2,j,i),
	3	 g_str_cls_x(3,j,i), 
	4	 g_str_cls_rad_cyl(j,i),
	5	 g_str_cls_hht(j,i), 
	6	 g_str_cls_num_oms(j,i)
	    
c calculate radius of cluster enclosing sphere
	    g_str_cls_rad_sph(j,i) = sqrt( 
	1	 squ(g_str_cls_rad_cyl(j,i)) + 
	2	 squ(g_str_cls_hht(j,i)) )
	    
c check if # of OMs is too many for the nested geometry array size
	    if ( g_str_cls_num_oms(j,i) .gt. max_num_oms_cls) then
	      WRITE(*,*) ' Error read geom file: Too many OMs in CLS'
	      WRITE(*,*) ' Change max_num_oms_cls in file km3.inc to',
	1	   g_str_cls_num_oms(j,i)
	      i_err = 1
	      RETURN
	    END IF
	    
c now continue reading the data file, looping over OMs
	    
	    do k = 1, g_str_cls_num_oms(j,i)
	      
	      READ (IO_UNGEO, 222) tag 
	      if ( tag .ne. 'pm:' ) then
		WRITE(*,*) ' Error reading geometry file: pm tag'
		i_err = 1
		RETURN
	      END IF
	      
c update the value of the KM3 internal OM identifier that is used in the
c g.om detector array of OMs
	      om_id_km3 = om_id_km3 + 1
	      
	      READ (IO_UNGEO, *) 
	1	   g_om_id_ant_om(om_id_km3), 
	2	   g_om_id_ant_cls(om_id_km3), 
	3	   g_om_id_ant_str(om_id_km3),
	4	   g_str_cls_om_x(1,k,j,i), 
	5	   g_str_cls_om_x(2,k,j,i),
	6	   g_str_cls_om_x(3,k,j,i), 
	7	   g_om_dir(1,om_id_km3),
	8	   g_om_dir(2,om_id_km3), 
	9	   g_om_dir(3,om_id_km3)
	      
c renormalise OM direction vector
C D. Bailey: 22/11/00
C Copy to dummy vector first for F77 call
              DO l=1,3
                dummy_vec(l) = g_om_dir(l,om_id_km3)
              END DO
       	      call renorm_vec(dummy_vec)
              DO l=1,3
                g_om_dir(l,om_id_km3) = dummy_vec(l)
              END DO     
	   
c copy the remaining information into the g.om detector array 
	      
	      g_str_cls_om_id_km3(k,j,i) = om_id_km3
	      do l = 1, 3
		g_om_x(l,om_id_km3) = 
	1	     g_str_cls_om_x(l,k,j,i)
	      enddo
	    enddo
	  enddo 
        enddo 
	
c check # of OMs read-in is correct
	if ( om_id_km3 .ne. g_num_oms ) then
	  WRITE(*,*) ' Error reading geometry file: # OMs wrong'
	  i_err = 1
	  RETURN
        END IF
	
c check # of clusters read-in is correct
	if ( n_clusters .ne. g_num_cls ) then
	  WRITE(*,*) ' Error reading geometry file: # CLs wrong'
	  i_err = 1
	  RETURN
        END IF
	
c check # of strings read-in is correct
	if ( n_strings .ne. g_num_str ) then
	  WRITE(*,*) ' Error reading geometry file: # STRs wrong'
	  i_err = 1
	  RETURN
        END IF
	
c Read is successful, write summary to log file
	
	WRITE(*,*) ' Geometry file read succesfully'
        Write(*,*) ' # strings = ', n_strings, ' # clusters = ',
	1    n_clusters, ' # oms = ', g_num_oms 
*
        END
