C*/
	SUBROUTINE READ_ELEC_DESC_FILES(ierror)
	INCLUDE 'km3.inc'
	INCLUDE 'km3-interpol.inc'
c
c This routine reads in the decscritpion files which contain all the 
c relevant information with respect to
c the hit distributions from electron showers

c
c  Local variables

        INTEGER*4 part_id, i, ierror, j, i_dum
        REAL*4    elec_energy, min_hold, r_dum

	ierror = 0
c first we open the first elec description file which contains gloabl 
c quantities relevant to all the electron hit distributions
	OPEN(UNIT=IO_UN_ELEC_DESC,FILE=IO_ELEC_DESC_FILE(1),
     1       STATUS='OLD', IOSTAT=ierror)
	IF(ierror.NE.0) THEN
	  WRITE(*,*) ' Error opening elec_desc file',ierror
	  WRITE(*,*) ' file name= ',IO_ELEC_DESC_FILE(1)
	  RETURN
	END IF
c  read inputs from control file
c  start with global variables

	READ(IO_UN_ELEC_DESC,*)            ! skip line
	READ(IO_UN_ELEC_DESC,*) part_id    ! should be electron
        IF (part_id .ne. p_id_electron) then
           write(*,*) 'ERROR: non-electron found in electron desc file' 
           ierror = 1
           return
        endif
	READ(IO_UN_ELEC_DESC,*) elec_energy  ! electron minimum energy
        write(*,*) 'first elec energy in desc file = ', elec_energy
c copy minimum energy into the other el_dir and the el_sca arrays
c        el_dir_min(1,1) =  log10(elec_energy)
c        el_dir_min(2,1) =  el_dir_min(1,1)
        el_sca_min(1,1) =  log10(elec_energy)
        el_sca_min(2,1) =  el_sca_min(1,1)

c copy default energy power (1) into el_dir and el_sca arrays
c        el_dir_power(1,1) = 1.0
c        el_dir_power(2,1) = 1.0
        el_sca_power(1,1) = 1.0
        el_sca_power(2,1) = 1.0

      	READ(IO_UN_ELEC_DESC,*) i_dum ! 1=ice, 2=water, 3=seawater
        if (i_dum .ne. h_media_id ) then
c the electron and muon files are incompatible
           ierror = 1
           write (*,*) 'FATAL ERROR: incompatible muon and elec files'
        endif
	READ(IO_UN_ELEC_DESC,*) r_dum ! refractive index of water/ice

	READ(IO_UN_ELEC_DESC,*) r_dum ! density of water/ice
        if (r_dum .ne. h_dens_medium ) then
c the electron and muon files are incompatible
           ierror = 1
           write (*,*) 'FATAL ERROR: incompatible muon and elec files'
        endif
	READ(IO_UN_ELEC_DESC,*) r_dum ! segment lengths
	READ(IO_UN_ELEC_DESC,*) r_dum ! average mu eloss <e_thresh
	READ(IO_UN_ELEC_DESC,*) r_dum ! threshold for muon showers

c now read parameters for the radii dependence of hit distributions
      
	READ(IO_UN_ELEC_DESC,*) el_sca_nbins(1,2) ! number of radii bins
	READ(IO_UN_ELEC_DESC,*) el_sca_min(1,2)   ! minimum radius bin
	READ(IO_UN_ELEC_DESC,*) el_sca_max(1,2)   ! maximum radius bin
	READ(IO_UN_ELEC_DESC,*) el_sca_power(1,2) ! exponent for radii bins

c the min and max radii must be adjusted to the correct power

        el_sca_min(1,2) = el_sca_min(1,2)**el_sca_power(1,2)
        el_sca_max(1,2) = el_sca_max(1,2)**el_sca_power(1,2)
	
c the variables must be copied into the second electron band

        el_sca_nbins(2,2) = el_sca_nbins(1,2)
        el_sca_min(2,2)   = el_sca_min(1,2)
        el_sca_max(2,2)   = el_sca_max(1,2)
        el_sca_power(2,2) = el_sca_power(1,2)
        
c now read band info for scattered hit distributions starting with
c low bands (i=1) and then doing high bands
        
        do i = 1,2  ! loop over low and high bands
	   READ(IO_UN_ELEC_DESC,*) el_sca_nbins(i,3)  ! # of bands
	   READ(IO_UN_ELEC_DESC,*) el_sca_power(i,3)  ! power for bands
	   READ(IO_UN_ELEC_DESC,*) el_sca_step(i,3)   ! step between bins
	   READ(IO_UN_ELEC_DESC,*) el_sca_min(i,3)    ! minimum band
	   READ(IO_UN_ELEC_DESC,*) el_sca_max(i,3)    ! maximum band
        enddo

c adjust min and max bands by taking the absolute value of the difference
c between the cos angle and cos cherenkov angle and then taking this value
c to the appropriate power. Note that we also switch max and min for the
c lo bands so that min is always less than max

        min_hold         = el_sca_min(1,3)
        el_sca_min(1,3) = (h_cos_ch - el_sca_max(1,3))**
     1                     el_sca_power(1,3)
        el_sca_max(1,3) = (h_cos_ch - min_hold)**
     1                     el_sca_power(1,3)

        el_sca_min(2,3) = (el_sca_min(2,3) - h_cos_ch)**
     1                     el_sca_power(2,3)
        el_sca_max(2,3) = (el_sca_max(2,3) - h_cos_ch)**
     1                     el_sca_power(2,3)

c this is no longer hard-wired, and rather is read from the desc file!
      
      READ(IO_UN_ELEC_DESC,*) el_sca_nbins(1,4)
      el_sca_nbins(2,4) = el_sca_nbins(1,4)
      
      do i = 1,2  ! loop over low and high bands
c           el_sca_nbins(i,4) = 5      ! now this is variable!
      	 el_sca_power(i,4) = 1.0  
      	 el_sca_min(i,4)   = 0.0     ! minimum theta_OM
      	 el_sca_max(i,4)   = c_pi    ! maximum theta_OM
      enddo

c input the hardwired default values for phi_OM variables
c for the scattered distributions
      READ(IO_UN_ELEC_DESC,*) el_sca_nbins(1,5)
      el_sca_nbins(2,5) = el_sca_nbins(1,5) 	
       
      do i = 1,2   ! loop over low and high bands
c           el_sca_nbins(i,5) = 3
      	 el_sca_power(i,5) = 1.0  
      	 el_sca_min(i,5)   = 0.0     ! minimum phi_OM
      	 el_sca_max(i,5)   = c_pi    ! maximum phi_OM
      enddo

c read in the number of time bins for direct and scattered photons

      READ(IO_UN_ELEC_DESC,*) el_sca_nbins(1,6)  ! # of time bins
      READ(IO_UN_ELEC_DESC,*) i_dum         ! chebychev binning
      if (i_dum .ne. H_CHEB) then
      	 write(*,*) 'WARNING!!! mismatched time binning! Here ',
     &	    i_dum,' vs ',H_CHEB
      endif
      el_sca_nbins(2,6) = el_sca_nbins(1,6)
      do i=0,el_sca_nbins(1,6)
      	 READ(IO_UN_ELEC_DESC,*) el_sca_tx(i)
      enddo
      
c generates short-cuts if applicable	
      if (H_CHEB .ge. 2) then
      	 el_sca_itp=1./float(H_CHEB)
      	 el_sca_tc=(0.5*el_sca_nbins(1,6))**(1.-el_sca_itp)
      endif
	    

C Close the first electron desc file
	CLOSE(UNIT=IO_UN_ELEC_DESC)

c open the last electron desc file to get the maximum energy

	OPEN(UNIT=IO_UN_ELEC_DESC,FILE=IO_ELEC_DESC_FILE(
     1       el_sca_nbins(1,1)), STATUS='OLD', IOSTAT=ierror)
	IF(ierror.NE.0) THEN
	  WRITE(*,*) ' Error opening elec_desc file',ierror
	  WRITE(*,*) ' file name=',IO_ELEC_DESC_FILE(el_sca_nbins(1,1))
	  RETURN
	END IF
c
	READ(IO_UN_ELEC_DESC,*)            ! skip line
	READ(IO_UN_ELEC_DESC,*) part_id    ! should be electron
        IF (part_id .ne. p_id_electron) then
           write(*,*) 'ERROR: non-electron found in electron desc file' 
           ierror = 1
           return
        endif
	READ(IO_UN_ELEC_DESC,*) elec_energy  ! electron maximum energy
        write(*,*) 'maximum elec energy in desc file = ', elec_energy
c copy maximum energy into the other el_dir and the el_sca arrays
c        el_dir_max(1,1) =  log10(elec_energy)
c        el_dir_max(2,1) =  el_dir_max(1,1)
        el_sca_max(1,1) =  log10(elec_energy)
        el_sca_max(2,1) =  el_sca_max(1,1)

C Close the last electron desc file
	CLOSE(UNIT=IO_UN_ELEC_DESC)

c calculate the step sizes and step prod factor for direct distributions

c ### NO DIRECT ELECTRON PHOTONS!!! ####
c	write(*,*) ' -------  direct showers bins  -------'
c	write(*,*) ' 4dim band   max    min   nbins  step'
c        el_dir_step_prod(1) = 1.0
c        el_dir_step_prod(2) = 1.0
c        do i = 1,4  ! loop over 4 (energy + geometrical) dimensions
c           do j = 1,2 ! loop over low and high bands
c              el_dir_step(j,i)  = (el_dir_max(j,i) - 
c     1        el_dir_min(j,i) ) / float(el_dir_nbins(j,i) - 1) 
c              el_dir_step_prod(j) = el_dir_step_prod(j) * 
c     1        el_dir_step(j,i)
c
c	      write(*,200) i,j,
c     & el_dir_max(j,i), el_dir_min(j,i), el_dir_nbins(j,i),
c     & el_dir_step_prod(j)
c           enddo
c        enddo
      
c calculate the step sizes and step prod factors for scattered distributions

	write(*,*) ' ----  scattered showers bins  ------'
	write(*,*) ' 5dim band   max    min   nbins  step'
        el_sca_step_prod(1) = 1.0
        el_sca_step_prod(2) = 1.0
        do i = 1,5 ! loop over 5 (energy+geometrical) dimensions
           do j = 1,2 ! loop over low and high bands
              el_sca_step(j,i)  = (el_sca_max(j,i) - 
     1        el_sca_min(j,i) ) / float(el_sca_nbins(j,i) - 1) 
              el_sca_step_prod(j) = el_sca_step_prod(j) * 
     1                              el_sca_step(j,i)
      	      if (i .eq. 2) then
	         el_sca_step_prod_d12(j) = el_sca_step_prod(j)
	      endif
	      write(*,200) i,j,
     & el_sca_max(j,i), el_sca_min(j,i), el_sca_nbins(j,i),
     & el_sca_step_prod(j)
           enddo
        enddo

 200	FORMAT(1X,I4,1X,I4,1X,F7.4,1X,F7.4,1X,I5,1X,F7.4)

        end
