C*/
	SUBROUTINE READ_MUON_DESC_FILE(ierror)
	INCLUDE 'km3.inc'
        INCLUDE 'km3-params.inc'
	INCLUDE 'km3-interpol.inc'
c
c This routine reads in the files which contain all the information with
c the hit distributions from muons

c
c  Local variables

        INTEGER*4 part_id, i, ierror, j
        REAL*4    muon_energy, min_hold

c first we open the muon description file which contains global quantities 
c relevant to the muon hit distributions
	ierror = 0
	OPEN(UNIT=IO_UN_MUON_DESC,FILE=IO_MUON_DESC_FILE,
     1       STATUS='OLD', IOSTAT=ierror)
	IF(ierror.NE.0) THEN
	  WRITE(*,*) ' Error opening muon_desc file ',ierror
	  WRITE(*,*) ' file name = ',IO_MUON_DESC_FILE
	  RETURN
	END IF
c
c  read inputs from control file
c  start with global variables
	READ(IO_UN_MUON_DESC,*)            ! skip line
	READ(IO_UN_MUON_DESC,*) part_id    ! should be muon
        IF (part_id .ne. p_id_muon) then
           write(*,*) 'ERROR: non-muon found in muon desc file' 
           ierror = 1
           return
        endif
	READ(IO_UN_MUON_DESC,*) muon_energy
        write(*,*) 'muon energy in desc file = ', muon_energy 
	READ(IO_UN_MUON_DESC,*) h_media_id  ! 1=ice, 2=water, 3=sea

C--- We now take the phase refractive index from libgeasim
 	READ(IO_UN_MUON_DESC,*) h_refindex  ! refractive index of water/ice
        h_refindex = CN
	IF (TNGRP.EQ.0) THEN
          h_groupindex = CN
        ELSE 
          h_groupindex = CN+XLDNDL
        ENDIF
        h_cos_ch = 1.0 / h_refindex
        h_tan_ch = tan( acos( h_cos_ch ) )
	READ(IO_UN_MUON_DESC,*) h_dens_medium ! density of water/ice
	READ(IO_UN_MUON_DESC,*) h_seg_length_hit ! muon segment lengths in HIT
c Now we compute all the numbers for segment ratios.        
	h_seg_length_km3 = h_seg_length_hit
	h_rho_min_27 = h_seg_length_km3 * 54.0 * h_min_seg_ratio
        h_rho_min_9  = h_seg_length_km3 * 18.0  * h_min_seg_ratio
        h_rho_min_3  = h_seg_length_km3 * 6.0  * h_min_seg_ratio
	h_seg_length_ratio = h_seg_length_km3 / h_seg_length_hit
        ELOSS_DZ = h_seg_length_km3*ELOSS_NSEGS
	
	READ(IO_UN_MUON_DESC,*) h_ave_e_loss_hit ! average mu eloss for 
c muon steps with e_loss < h_max e_loss
        h_ave_e_loss_km3 = h_ave_e_loss_hit * h_seg_length_ratio
	READ(IO_UN_MUON_DESC,*) h_max_e_loss ! threshold for `good' muon steps
        h_max_e_loss = h_max_e_loss * h_seg_length_ratio

c now read parameters for the radii dependence of hit distributions
	READ(IO_UN_MUON_DESC,*) mu_dir_nbins(1) ! number of radii bins
	READ(IO_UN_MUON_DESC,*) mu_dir_min(1)   ! minimum radius bin
	READ(IO_UN_MUON_DESC,*) mu_dir_max(1)   ! maximum radius bin
	READ(IO_UN_MUON_DESC,*) mu_dir_power(1) ! exponent for radii bins
c the min and max radii must be adjusted to the correct power

        mu_dir_min(1) = mu_dir_min(1)**mu_dir_power(1)
        mu_dir_max(1) = mu_dir_max(1)**mu_dir_power(1)

c the variables must be copied into the scattered muon distributions

        do i = 1,2  ! loop over low and high bands
           mu_sca_nbins(i,1) = mu_dir_nbins(1)
           mu_sca_min(i,1)   = mu_dir_min(1)
           mu_sca_max(i,1)   = mu_dir_max(1)
           mu_sca_power(i,1) = mu_dir_power(1)
        enddo
c read the OM angle info for direct photons

	READ(IO_UN_MUON_DESC,*) mu_dir_nbins(2)  ! # of cos(theta_OM) bins

c input the hardwired default values for theta_OM direct variables

        mu_dir_power(2) =  1.0
        mu_dir_min(2)   = -1.0     ! minimum cos(theta_OM)
        mu_dir_max(2)   =  1.0     ! maximum cos(theta_OM)

c now read band info for scattered hit distributions starting with
c low bands (i=1) and then doing high bands
        
        do i = 1,2  ! loop over low and high bands
	   READ(IO_UN_MUON_DESC,*) mu_sca_nbins(i,2)  ! # of bands
	   READ(IO_UN_MUON_DESC,*) mu_sca_power(i,2)  ! power for bands
	   READ(IO_UN_MUON_DESC,*) mu_sca_step(i,2)   ! step between bins
	   READ(IO_UN_MUON_DESC,*) mu_sca_min(i,2)    ! minimum band
	   READ(IO_UN_MUON_DESC,*) mu_sca_max(i,2)    ! maximum band
        enddo
c adjust min and max bands by taking the absolute value of the difference
c between the cos angle and cos cherenkov angle and then taking this value
c to the appropriate power. Note that we also switch max and min for the
c lo bands so that min is always less than max

        min_hold         = mu_sca_min(1,2)
        mu_sca_min(1,2) = (h_cos_ch - mu_sca_max(1,2))**
     1                     mu_sca_power(1,2)
        mu_sca_max(1,2) = (h_cos_ch - min_hold)**
     1                     mu_sca_power(1,2)

        mu_sca_min(2,2) = (mu_sca_min(2,2) - h_cos_ch)**
     1                     mu_sca_power(2,2)
        mu_sca_max(2,2) = (mu_sca_max(2,2) - h_cos_ch)**
     1                     mu_sca_power(2,2)

c input the hardwired default values for theta_OM variables
c for the scattered distributions
      READ(IO_UN_MUON_DESC,*) mu_sca_nbins(1,3)
      mu_sca_nbins(2,3)=mu_sca_nbins(1,3)
        do i = 1,2  ! loop over low and high bands
c           mu_sca_nbins(i,3) = 5
           mu_sca_power(i,3) = 1.0  
           mu_sca_min(i,3)   = 0.0     ! minimum theta_OM
           mu_sca_max(i,3)   = c_pi    ! maximum theta_OM
        enddo
c input the hardwired default values for phi_OM variables
c for the scattered distributions
      READ(IO_UN_MUON_DESC,*) mu_sca_nbins(1,4)
      mu_sca_nbins(2,4)=mu_sca_nbins(1,4)
      
        do i = 1,2   ! loop over low and high bands
c           mu_sca_nbins(i,4) = 3
           mu_sca_power(i,4) = 1.0  
           mu_sca_min(i,4)   = 0.0     ! minimum phi_OM
           mu_sca_max(i,4)   = c_pi    ! maximum phi_OM
        enddo

c read in the number of time bins for direct and scattered photons

	READ(IO_UN_MUON_DESC,*) mu_dir_nbins(3)     ! # of time bins
	READ(IO_UN_MUON_DESC,*) mu_sca_nbins(1,5)  ! # of time bins
        READ(IO_UN_MUON_DESC,*) H_CHEB    ! # chebychev interpolation used?
	mu_sca_nbins(2,5) = mu_sca_nbins(1,5)

c reads in the actual direct times into an array
	do i=0, mu_dir_nbins(3)
	    READ(IO_UN_MUON_DESC,*) mu_dir_tx(i)
	enddo

c reads in the actual scattered times into an array
	do i=0, mu_sca_nbins(1,5)
	    READ(IO_UN_MUON_DESC,*) mu_sca_tx(i)
	enddo
	
c generates short-cuts if applicable	
	if (H_CHEB .ge. 2) then
	    write(*,*) 'Using power-law probability scaling'
	    mu_dir_itp=1./float(H_CHEB)
	    mu_sca_itp=1./float(H_CHEB)
c we must accont for the fact that the 'p-value' is multiplied
c by n_bins, and the result must also be from 0-nbins
	    mu_dir_tc=(0.5*mu_dir_nbins(3))**(1.-mu_dir_itp)
	    mu_sca_tc=(0.5*mu_sca_nbins(1,5))**(1.-mu_sca_itp)
	 endif
	    
c calculate the step sizes and step prod factor for direct distributions
        mu_dir_step_prod = 1.0
        do i = 1,2  ! loop over geometrical dimensions
           mu_dir_step(i)  = (mu_dir_max(i) - mu_dir_min(i) ) /
     1                       float(mu_dir_nbins(i) - 1) 
           mu_dir_step_prod = mu_dir_step_prod * mu_dir_step(i)
        enddo
c calculate the step sizes and step prod factors for scattered distributions

	write(*,*) ' ----  scattered muon bins  ------'
	write(*,*) ' 4dim band   max    min   nbins  step'
        mu_sca_step_prod(1) = 1.0
        mu_sca_step_prod(2) = 1.0
        do i = 1,4 ! loop over geoemtrical dimensions
           do j = 1,2 ! loop over low and high bands
              mu_sca_step(j,i)  = (mu_sca_max(j,i) - 
     1        mu_sca_min(j,i) ) / float(mu_sca_nbins(j,i) - 1) 
              mu_sca_step_prod(j) = mu_sca_step_prod(j) * 
     1                              mu_sca_step(j,i)

	      write(*,200) i,j,
     & mu_sca_max(j,i), mu_sca_min(j,i), mu_sca_nbins(j,i),
     & mu_sca_step_prod(j)

           enddo
        enddo
	read (IO_UN_MUON_DESC, *)  watmod ! Water model name
	read (IO_UN_MUON_DESC, *)  labs   ! absorption length
	read (IO_UN_MUON_DESC, *)  lscat  ! scattering length
	read (IO_UN_MUON_DESC, *)  luz    ! at this photon wavelengh
	read (IO_UN_MUON_DESC, *)  alpha  ! Two H-G method: 
	read (IO_UN_MUON_DESC, *)  cosme1 ! alpha*cosme1 + (1-alpha)*cosme2
	read (IO_UN_MUON_DESC, *)  cosme2 ! 
	read (IO_UN_MUON_DESC, *)  eta    ! Rayleigh*eta + Partic*(1-eta)

 200	FORMAT(1X,I4,1X,I4,1X,F7.4,1X,F7.4,1X,I5,1X,F7.4)
	CLOSE(UNIT=IO_UN_MUON_DESC)
        end
