C*/
      SUBROUTINE track_muon( part_num, ier)

*     Created:  27-FEB-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
c     track a given muon by iterating through segments until one of the
c     following occurs:
c     1) muon stopped in detetctor
c     2) muon leaves detector
c     3) muon decays in flight   (not yet implemented!)

*     In/Out Variables:-
*     ==========
c     in        part_num        number of particle in the P array  
 
*     Common Block Access:-
*     ===================
c     /km3/  	in 		holds structures for KM3

*     Assumptions:-
*     ===========
c     Only the muon's continuous energy loss is treated at present, and even
c     this is done very simplisticaly. Muon decay at rest, decay in flight,
c     and showering are not considered yet.
 
*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine

      INCLUDE 'km3.inc'

      INTEGER*4 ier, muon_flag, part_num, nseg, idum
      REAL*4 track_dir(3), eloss_mu, random_dist 
      REAL*4 seg_step_half(3), seg_rad, ran1
      REAL*4 vec_norm, vec_dot, fraction, random_num
      REAL*4 seg_step_full(3), vec_diff, dummy_vec(3)
      REAL*4 dummy_vec2(3), dummy_vec3(3)
      REAL shower_E, hlength_elec
      INTEGER*4 status
      EXTERNAL eloss_mu

c check to see if particle is really a muon

      if ( p_part_id(part_num) .ne. p_id_muon ) then
         print *, 'ERROR: non-muon particle sent to track_muon'
         ier = 1
         return
      endif

      ier = 0

c input muon start conditions into the first segment

      DO idum = 1,3
        dummy_vec(idum) = p_v0(idum,part_num)
      END DO
      call renorm_vec(dummy_vec)    ! just to be sure
      DO idum = 1,3
        p_v0(idum,part_num) = dummy_vec(idum)
        seg_pos_start(idum,1) = p_x0(idum,part_num)
        seg_dir_start(idum,1) = p_v0(idum,part_num)
      END DO

      seg_e_start(1) = p_e0(part_num)
      seg_t_start(1) = p_t0(part_num)
      muon_flag      = 0
      fraction       = 1.0
      seg_length(1)  = h_seg_length_km3
      nseg           = 0

c track muon by iterating over segments until muon stops or leaves detector

      do while (muon_flag .eq. 0)		

         nseg = nseg + 1

c find the muon total energy losses for the current segment
c and find the start position, direction, time, and energy of the NEXT segment
c as well as the position, direction and time at the middle of the
c current segment

         if (h_music .eq. 0) then
c we are using the e_loss tables of D. Lowder
            random_num = ran1(idum)
	    seg_total_e_loss(nseg) = eloss_mu( seg_e_start(nseg), 
     1      random_num ) * h_seg_length_km3	
c Many Kluges are currently used, i.e. no muon scattering and
c the calculation of time will later need to use the AVERAGE
c speed for the segment based on the AVERAGE energy of the muon 

            DO idum=1,3
              seg_dir_start(idum,nseg+1) = seg_dir_start(idum,nseg)
              seg_dir_center(idum,nseg+1) = seg_dir_start(idum,nseg) +
     &                                      seg_dir_start(idum,nseg+1)
            END DO

            DO idum = 1,3
             dummy_vec(idum) = seg_dir_center(idum,nseg)
            END DO
            call renorm_vec(dummy_vec)

            DO idum = 1,3 
              seg_dir_center(idum,nseg) = dummy_vec(idum)
              seg_step_half(idum) = seg_length(nseg) * 
     &                              seg_dir_center(idum,nseg)
              seg_pos_center(idum,nseg) = seg_pos_start(idum,nseg) +
     &                                    seg_step_half(idum)
              seg_step_full(idum) = seg_length(nseg) * 
     &                              seg_dir_center(idum,nseg)    
              seg_pos_start(idum,nseg+1) = seg_pos_start(idum,nseg) + 
     &                                     seg_step_full(idum)
            END DO

            seg_t_center(nseg) = seg_t_start(nseg) + seg_length(nseg) 
     1                         * 0.5 / c_c_mpns
            seg_t_start(nseg+1) = seg_t_start(nseg) + seg_length(nseg)
     1                         / c_c_mpns
            seg_e_start(nseg+1) = seg_e_start(nseg) - 
     1                         seg_total_e_loss(nseg)
            seg_length(nseg+1) = seg_length(nseg)

         else 

c we are using MUSIC which returns the start values for the NEXT segment 

            call step_muon( seg_pos_start(1,nseg),
     1      seg_pos_start(2,nseg), seg_pos_start(3,nseg),
     2      seg_dir_start(1,nseg), seg_dir_start(2,nseg),
     3      seg_dir_start(3,nseg), seg_e_start(nseg), 
     4      seg_t_start(nseg), h_seg_length_km3, 
     5      seg_pos_start(1,nseg+1),
     6      seg_pos_start(2,nseg+1),  seg_pos_start(3,nseg+1),
     7      seg_dir_start(1,nseg+1), seg_dir_start(2,nseg+1),
     8      seg_dir_start(3,nseg+1), seg_e_start(nseg+1),
     9      seg_t_start(nseg+1), seg_length(nseg) )

c first get total energy loss from difference
            seg_total_e_loss(nseg) = seg_e_start(nseg) -
     1      seg_e_start(nseg+1)
	    
c now calculate the middle point values                
 
            DO idum=1,3
              seg_pos_center(idum,nseg) = (seg_pos_start(idum,nseg) + 
     &                                  seg_pos_start(idum,nseg+1))*0.5
              seg_dir_center(idum,nseg) = (seg_dir_start(idum,nseg) +
     &                                  seg_dir_start(idum,nseg+1))*0.5
              dummy_vec(idum) = seg_pos_start(idum,nseg+1)
              dummy_vec2(idum) = seg_pos_start(idum,nseg)
            END DO

            seg_t_center(nseg) = ( seg_t_start(nseg) +
     1      seg_t_start(nseg+1) ) * 0.5

            seg_length(nseg) = vec_diff(dummy_vec,dummy_vec2)
  
         endif

         if ( seg_total_e_loss(nseg) .gt. h_max_e_loss ) then
c this segment is above the threshold considered in HIT
c so we give the average e_loss to the segment (scaled by the
c segment length ratio)

	    seg_ion_e_loss(nseg) = h_ave_e_loss_km3
            shower_E=seg_total_e_loss(nseg) - 
     1                             h_ave_e_loss_km3
c and put the rest into a new shower which is added to the particle stack.
c the shower is assumed to occur at a random location along the length of
c the segment, and is then incremented according to the half-length of an
c electromagnetic cascade of that same energy.

            random_dist = ran1(idum) * seg_length(nseg)
	    random_dist = random_dist+hlength_elec(shower_E)
c MPD Nov 18, 2010
c if we are at the end of the particle array, spit out a warning and 
c ignore other showers... 
            if( gen_npart .ge. max_part ) then
               write(*, *) 'WARNING !!! gen_npart= ', gen_npart
            else
               gen_npart = gen_npart + 1
            endif

            p_part_id(gen_npart)  = p_id_photon
            p_iparent(gen_npart) = p_track_id(part_num)
            p_x0(1,gen_npart)   = seg_pos_start(1,nseg) + 
     1                             seg_dir_start(1,nseg) * random_dist
            p_x0(2,gen_npart)   = seg_pos_start(2,nseg) + 
     1                             seg_dir_start(2,nseg) * random_dist
            p_x0(3,gen_npart)   = seg_pos_start(3,nseg) + 
     1                             seg_dir_start(3,nseg) * random_dist
            p_v0(1,gen_npart)   = seg_dir_start(1,nseg)
            p_v0(2,gen_npart)   = seg_dir_start(2,nseg)
            p_v0(3,gen_npart)   = seg_dir_start(3,nseg)
            p_E0(gen_npart)      = shower_E
            p_t0(gen_npart)      = seg_t_start(nseg) + random_dist /
     1                             c_c_mpns
            p_eff_seg(gen_npart) = nseg

         else
c this segment is below the threshold for making an `independent' shower 
c and all the e_loss is given to minimum ionising

	    seg_ion_e_loss(nseg) = seg_total_e_loss(nseg)
 
         endif

         if ( mod( nseg, 3 ) .eq. 0 ) then
c we calculate the running average ion_e_loss over the last three segments

            seg_ion_e_loss_3(nseg-1) = seg_ion_e_loss(nseg-2) +
     1      seg_ion_e_loss(nseg-1) + seg_ion_e_loss(nseg)

         endif

         if ( mod( nseg, 9 ) .eq. 0 ) then
c we calculate the running average ion_e_loss over the last nine segments

            seg_ion_e_loss_9(nseg-4) = seg_ion_e_loss_3(nseg-7) +
     1      seg_ion_e_loss_3(nseg-4) + seg_ion_e_loss_3(nseg-1)

         endif

         if ( mod( nseg, 27 ) .eq. 0 ) then
c we calculate the running average ion_e_loss over the last 27 segments

            seg_ion_e_loss_27(nseg-13) = seg_ion_e_loss_9(nseg-22) +
     1      seg_ion_e_loss_9(nseg-13) + seg_ion_e_loss_9(nseg-4)

         endif

         if ( seg_ion_e_loss(nseg) .gt. seg_e_start(nseg) ) then 

c the ionising energy loss is greater than the muon energy and the 
c muon stops in this segment

            muon_flag        = 1  ! muon stops
            fraction         = seg_e_start(nseg) / seg_ion_e_loss(nseg)
            seg_length(nseg) = seg_length(nseg) * fraction
            seg_ion_e_loss(nseg) = seg_e_start(nseg)

         endif

c check to see if the next segment is now leaving the detector
c or if the muon has lost all its energy

         DO idum=1,3
           dummy_vec(idum) = seg_pos_start(idum,nseg+1)
           dummy_vec2(idum) = seg_dir_start(idum,nseg+1)
         END DO
 
         seg_rad = vec_norm(dummy_vec)

         if ( ( seg_rad .gt. h_muon_cut_distance + g_rad_sph ) .and. 
     1        ( vec_dot(dummy_vec,dummy_vec2) .gt. 0. ) ) then 

c the muon is moving away from KM3 AND it is more than h_muon_cut_distance
c away from KM3 - so it is LEAVING the detector.

            muon_flag = 2  ! muon leaving detector

         elseif ( seg_e_start(nseg+1) .le. 0.106 ) then
c MUSIC returns zero muon energy for the next step when the muon has stopped
            muon_flag = 1  ! muon stopped in detector

         endif
      enddo

c write outcome of muon into the particle record.

      nseg = nseg + 1

      DO idum=1,3
        p_x_end(idum,part_num) = seg_pos_start(idum,nseg)
        p_v_end(idum,part_num) = seg_dir_start(idum,nseg)
      END DO

      p_e_end(part_num) = seg_e_start(nseg)
      p_t_end(part_num) = seg_t_start(nseg)
      p_outcome(part_num) = muon_flag
      p_nsegs(part_num)   = nseg - 1

      DO idum=1,3
        dummy_vec(idum) = p_x_end(idum,part_num)
        dummy_vec2(idum) = p_x0(idum,part_num)
      END DO

      call sub_vec(dummy_vec, dummy_vec2, track_dir )
      p_length(part_num) = vec_norm( track_dir )
      IF (p_length(part_num).NE.0) THEN 
        call renorm_vec( track_dir )
      ENDIF

      DO idum=1,3
        p_dir(idum,part_num) = track_dir(idum)
      END DO

      end
