C*/
	PROGRAM KM3MC
*************************************************************************
*                                                                       *
*     Name           :  KM3MC                                           *
*     Date           :  04-Feb-1999                                     *
*     Last Modified  :  23-Nov-2000                                     *
*                       09-Mars-2000                                    *
*                       22-Feb-2000                                     *
*                       22-Jul-1999                                     *
*                       Add version number at top, add call to PRESENTA *
*     Task           :                                                  *
*                                                                       *
*             Main program for KM3 Monte Carlo                          *
*                                                                       *
*  Contact people:                                                      *
*     Sergio Navas     navas@cppm.in2p3.fr                              *
*     David Bailey     d.bailey2@physics.ox.ac.uk                       *
*     Lee Thompson     L.Thompson@sheffield.ac.uk                       *
*************************************************************************
*
	INCLUDE 'km3.inc'
	INCLUDE 'km3-mass.inc'
c
c  Local variables
c
	INTEGER*4 STATUS, tot_hits, I
	REAL      TL
	LOGICAL FILEX
        CHARACTER*12  CHVERS
        CHARACTER*255 CHX

* Version Number and Last Date of Change is DEFINED here
        DATA CHVERS / ' 3.06-281009' /

c-------------------------------------------------------------
c  Input Structure constants
c-------------------------------------------------------------
c  Geometry
        do i=1,3
            g_origin(i) = 0.0
        enddo
c Constants
        c_pi         = 3.1415926535
        c_c_mpns     = 0.299792458       ! Speed of light (M/nS)
        c_large_integer = 2147483647
        c_large_real    =  1.0E+20
        c_small_real    =  1.0E-20
c Particle ids
        p_id_laser    = -1
        p_id_photon   =  1
        p_id_electron =  3
        p_id_muon     =  5
	p_id_nu       =  4
        p_id_tau      = 33
c I/0
        io_UNLOG	   = 21	! Unit number for LOG file
	io_UNCNT	   = 22	! Unit number for CNT file
	io_UN_MUON_DESC    = 23	! Unit number for muon desc file
	io_UN_MUON_RZ      = 24	! Unit number for muon rz file
	io_UN_ELEC_DESC    = 28	! Unit number for muon desc file
	io_UN_ELEC_RZ      = 29	! Unit number for muon rz file
	io_UN_OUT	   = 25	! Unit number for OUT file
	io_UNGEO	   = 26	! Unit number for GEO file
	io_UNEVENT	   = 27 ! Unit number for EVENT file
        io_UN_EVT_RZOUT    = 41 ! Unit number for per event ntuple
        io_UN_SEG_RZOUT    = 42 ! Unit number for muon segment ntuple
        io_UN_ERROR_LOG    = 51 ! Unit number for error log          
        io_UN_PHOTON_DESC  = 30 ! Unit number for photon desc file
	io_UN_PHOTON_RZ    = 31 ! Unit number for photon rz file
        io_UN_DISPERSION_RZ = 70 ! Unit number for dispersion file

*  End input constants
*------------------------------------------------------------------
*---- End of Declarations

        CALL PRESENTA (CHVERS)
*
c	CALL TIMEL(TL)
	write(*,*) ' ==> km3 JOB starting ... CPU time available =',TL
c
c Prepare for main processing loop
	STATUS   = 0
        tot_hits = 0
	GEN_EVENT_ID = 1

c read in the user inputs
	CALL READ_USER_INPUTS(status)
*
        WRITE(6,*)'End of READ_USER_INPUTS '
        if( status .ne. 0) stop
* Initialize random number generators (RANLUX and RANMAR).
* For RANLUX, default Luxury level (3).
cc        CALL RLUXGO(3,ISEED(1),0,0)
cc	If a file fort.68 is present take seeds from this instead than from 
cc      data cards
	FILEX = .FALSE.
	INQUIRE(file='fort.68',EXIST=FILEX)
        IF (FILEX) THEN
          READ(68,*) ISEED(1),ISEED(2),ISEED(3),ISEED(4)
          PRINT*,'INITIALIZATION SEEDS',ISEED
          CLOSE(68)
        ENDIF
        CALL RLUXGO(ISEED(1),ISEED(2),ISEED(3),ISEED(4))
cc TM Oct 2003 not used
cc FC Gen 2004 back in use
        CALL RMARIN(ISEED(2),0,0)
c read the input geometry file
        WRITE(CHX,'(A120,I2,I2)') io_geom_file,1,1
	CALL GUGEPM(CHX,STATUS)
	CALL FILL_ANTARES_GEOM(STATUS) ! antares format

c	CALL READ_ANTARES_GEOM(STATUS) ! antares OLD geom format
c if one-particle approximation (H_OPA) is turned on, process showers also
	IF ((EVT_TYPE(1) .EQ. 'EVT_MUON').or.
     &     ((EVT_TYPE(1).EQ.'EVT_SHOW').and.(H_OPA.eq.1))) THEN
c read the .desc file with muon hit distribution global variable values
	  CALL READ_MUON_DESC_FILE(status)
	  if( status .ne. 0) stop
	  
c read the .rz file with the input muon hit distributions
	  CALL READ_MUON_RZ_FILE(status) 
	  if( status .ne. 0) stop
	  
c read the .desc file with muon hit distribution global variable values
	  CALL READ_ELEC_DESC_FILES(status)
	  if( status .ne. 0) stop
	  
c read the .rz file with the input muon hit distributions
	  CALL READ_ELEC_RZ_FILES(status) 
	  if( status .ne. 0) stop

C--- Read the dispersion file if TNGRP = 2
          IF (TNGRP.EQ.2) THEN
	    write(*,*) 'reading dispersion is now disabled'
c            CALL READ_DISPERSION_FILE(IO_UN_DISPERSION_RZ,status)
            if (status .ne. 0) stop
          ENDIF
c initialize the muon tracking   
	  if (h_music .eq. 0) then
c initialise the e_loss tables
	    CALL ELOSS_MU_INIT 
	  else
	    write(*,*) 'initialising music'
	    CALL INITIALIZE_MUSIC
	  endif
          write(*,*) 'Energy-loss initialised'
	ELSE IF (EVT_TYPE(1) .EQ. 'EVT_LASER') THEN
c read the .desc file with the input photon (LASER-flash) hit distributions
	  write(*,*) ' ... Calling read_photon_desc_file ...'
	  CALL READ_PHOTON_DESC_FILE(status) 
	  if( status .ne. 0) stop

c read the .rz file with the input photon (LASER-flash) hit distributions
	  write(*,*) ' ... Calling read_photon_rz_file ...'
	  CALL READ_PHOTON_RZ_FILE(status) 
	  if( status .ne. 0) stop
	ELSE
	  write(*,*) 'WARNING ! Unknown Type of event =',EVT_TYPE(1)
     &              ,' -> return'
	ENDIF
      write(*,*) 'about to open event'
c >> LT, 18-Aug-1998
c if requested, open the RZ file for by-event ntuples and book the ntuple
c I have commented the following out in an attempt to remove all references
c to ntuples and PAW from km3. This is because PAW is the suspected source
c of vast consumption of memory; and because I don't think anybody uses
c these options anymore.
c   ### BEGIN Clancy's destruction of PAW ####
c        if ( h_event_ntuple .eq. 1 ) then
c           CALL OPEN_NTUPLE ( 'EVT' , status )
c           if ( status .ne. 0 ) then
c              CALL REPORT_ERROR ( status , 'OPEN_NTUPLE' )
c              stop
c           endif
c           CALL BOOK_NTUPLE ( 'EVT' , status )
c           if ( status .ne. 0 ) then
c              CALL REPORT_ERROR ( status , 'BOOK_NTUPLE' )
c              stop
c           endif
c        endif

c open the RZ file for by-segment ntuples where requested
c        if ( h_segment_ntuple .eq. 1 ) then
c           CALL OPEN_NTUPLE ( 'SEG' , status )
c           if ( status .ne. 0 ) then
c              CALL REPORT_ERROR ( status , 'OPEN_NTUPLE' )
c              stop
c           endif
c           CALL BOOK_NTUPLE ( 'SEG' , status )
c           if ( status .ne. 0 ) then
c              CALL REPORT_ERROR ( status, 'BOOK_NTUPLE' )
c              stop
c           endif
c        endif
c <<
c   ### END Clancy's destruction of PAW ####

c 8-Feb-2000
c Compute x values for time interpolation
	CALL CHEBYSEV

c open the input file with NEW format events
	CALL OPEN_ANTARES_EVENT_FILE(STATUS,CHVERS) 
	if( status .ne. 0) stop

c open the NEW antares-format output file and write header
	CALL OPEN_ANTARES_OUT_FILE(status)
	if( status .ne. 0) stop
C >> LT 22-Jul-1999
Cc open the OLD antares-format output file and write header
C	CALL OPEN_ANTARES_OUT_FILE2(status)
C	if( status .ne. 0) stop
C << LT

c then read the first ANTARES event
	CALL READ_ANTARES_EVENT(status)
	if( status .ne. 0) stop

c  Main Loop
	write(*,*)'*** Total number of events to process =',gen_nevents
	DO WHILE( ( STATUS .EQ. 0 ) .AND. 
	1    ( GEN_EVENT_ID .LE. GEN_NEVENTS ) )

*    Check CPU-Time.
c	  CALL TIMEL(TL)
c	print*,'timel?!?!?',tl
c	  IF (TL .LT. 10.0) THEN
c            WRITE(*,900) TL,gen_event_id
c            GOTO 888
c	  ENDIF
*
C--- Report progress every 100 events
          if (mod(GEN_EVENT_ID,100).eq.0) 
     &      write(*,400) GEN_EVENT_ID,gen_nevents,TL

	  CALL PROCESS_EVENT

	  tot_hits = tot_hits + gen_nhits

c >> LT, 18-Aug-1998
c            if ( h_event_ntuple .eq. 1 ) then
c              CALL FILL_NTUPLE ( 'EVT' , STATUS , 0 )
c              if ( status .ne. 0 ) then
c                CALL REPORT_ERROR ( STATUS , 'FILL_NTUPLE' )
c                stop
c              endif
c            endif
c <<

	  if ( gen_nhits .gt. 0 ) then
c  ouput current event in ANTARES ouput file (NEW format)
	    CALL WRITE_ANTARES_EVENT
C >> LT, 22-Jul-1999
Cc  ouput current event in ANTARES ouput file (OLD format)
C	       CALL WRITE_ANTARES_EVENT2
C << LT
	  endif

* >> SN  14-Jan-2000 
* JEMPT: flag to write empty events (1= write all events, 0=don't write empty events)
	  IF ( (gen_nhits.gt.0) .OR. (JEMPT.eq.1) ) then
	    CALL EVWRIT(IO_UN_OUT,status)
	    IF (status.NE.0) 
	1	 WRITE(6,'('' write error on event output '')')
	  ENDIF
* <<
*
 777	  CONTINUE

	  gen_event_id = gen_event_id + 1 ! increment current event ID

c read next event from ANTARES format input event file
	  CALL READ_ANTARES_EVENT(status)

	END DO

 888	CONTINUE

c close the event input file
	close( unit = io_unevent ) 
c close the ANTARES event output file
	close( unit = io_un_out ) 

c >> LT, 18-Aug-1998
c   ### BEGIN Clancy's destruction of PAW ####
c        if ( h_event_ntuple .eq. 1 ) then
c           CALL CLOSE_NTUPLE ( 'EVT' , STATUS )
c           if ( status .ne. 0 ) then
c              CALL REPORT_ERROR ( STATUS , 'CLOSE_NTUPLE' )
c              stop
c           endif
c        endif
c        if ( h_segment_ntuple .eq. 1 ) then
c           CALL CLOSE_NTUPLE ( 'SEG' , STATUS )
c           if ( status .ne. 0 ) then
c              CALL REPORT_ERROR ( STATUS , 'CLOSE_NTUPLE' )
c              stop
c           endif
c        endif
c   ### END Clancy's destruction of PAW ####
c <<
c	CALL TIMEL(TL)
	write(*,*)
     &'=> End JOB .. Tot # photoelec =',tot_hits,' CPU time=',TL
	WRITE(*,400) GEN_EVENT_ID,gen_dada_id,TL

*
 900	FORMAT(/,'*** WARNING Km3 info: End of CPU time ',F6.3,'***',
     &I10,/)
 400	FORMAT(' *** Event #',I10,' /',I10,'  CPU time=',F13.3)
	
C TM Oct 2003
        CALL RLUXAT(ISEED(1),ISEED(2),ISEED(3),ISEED(4))
        WRITE(68,*) ISEED(1),ISEED(2),ISEED(3),ISEED(4)
        CLOSE(68)

	END
