

include ${ANTRS_RULES}/compiler.def
include ${ANTRS_RULES}/versions.def
package3 = km3mc
library1 = libkm3
version = ${KM3_V}

# Needed libraries and include file folder
INCIO     = ${ANTRS_IO}/inc

# Local folders
BIN = ${ARCH}
SRC = src
INC = inc

# Get fortran modules
KM3SRC = $(wildcard $(SRC)/*km3*.f)

KM3INC = $(wildcard $(INC)/*km3*.inc)

KM3OBJ = ${subst .f,.o,${subst ${SRC},${BIN},${KM3SRC}}}

# Trap all exceptions
KM3OBJ += ${BIN}/trapfpe.o


all : createdir ${BIN}/${package3}${version}.exe \
                ${BIN}/${library1}${version}.a

km3 : createdir ${BIN}/${package3}${version}.exe

${BIN}/${package3}${version}.exe : ${KM3OBJ}
	${LF77} -o $@ ${KM3OBJ} \
	${IOLIBF77}            \
	${CERNLIBS}
 
${BIN}/${library1}${version}.a : ${KM3OBJ}
	ar -rcv $@ ${KM3OBJ}

info :
	@echo ""
	@echo "--------------------------------------------------------------------------------"
	@echo "* Km3:"
	@echo ${subst ${SRC}/,,${KM3SRC}}
	@echo ${subst ${INC}/,,${KM3INC}}
	@echo "--------------------------------------------------------------------------------"
	@echo ""

${BIN}/%.o : ${SRC}/%.F
	${F77} ${F77OP} -o $@ $< ${PASSCPP}-I${CERN}/pro/include

${BIN}/%.o : ${SRC}/%.f
	${F77} ${F77OP} -o $@ $< -I${INC} -I${INCIO}

${BIN}/trapfpe.o : ${SRC}/trapfpe.c
	${CC} -c -o $@ $<

# General          -----------------------------------------------------------
createdir :
	@test -d "${BIN}" || (echo "Creating ${BIN}"; mkdir ${BIN})

clean :
	@rm -f ${BIN}/*.o
	@rm -f ${BIN}/*.a
	@rm -f ${BIN}/*.exe

tar : clean
	tar -cvf ${ANTRS_SRC}/km3${version}.tar -C ${ANTRS_SRC} km3/${version}

install :
	@test -f "$(BIN)/${package3}${version}.exe" && \
        (echo "Now moving ${package3}${version}.exe to $(ANTRS_BIN)"; \
         mv -f $(BIN)/${package3}${version}.exe $(ANTRS_BIN)/.)
	@test -f "$(BIN)/${library1}${version}.a" && \
        (echo "Now moving ${library1}${version}.a to $(ANTRS_LIB)"; \
         mv -f $(BIN)/${library1}${version}.a $(ANTRS_LIB)/.)
