C* @brief Parameters for generated photon list
C*
C* There are two separate ntuples:
C*
C* - Photon ntuple:
C*   - times = Current time of this photon shell hit relative to start of event
C*   - x_pos, y_pos, z_pos = Location of photon shell hit (m)
C*   - x_dir, y_pos, z_pos = Direction vector of photon (normalized to 1)
C*   - energy = energy of photon in eV
C*   - wlen = Wavelength of photon in nm
C*   - ish = Shell number of this photon shell hit (0 means photon starts here)
C*   - shrad = Radius of this shell (m)
C*   - evnum = Which event this photon was generated in
C*
C*
C* - Diagnostic tracking step ntuple
C*   - evnum = Which event this track segment was generated in
C*   - ipart = GEANT particle type for this segment
C*   - istak, ivert = GEANT variables defining where we are in the secondary
C*     "tree"
C*   - mass, charge = particle mass (GeV), charge (e)
C*   - x,y,z = location of track segment (m)
C*   - vx,vy,vz = direction vector of track segment, normalized to 1
C*   - getot = Total energy of this segment's particle (GeV)
C*   - step = length of this track segment (m)
C*   - delte = energy loss of this track segment (GeV)
C*   - tofg = time of track segment relative to start of event
C*   - nphot = number of photons generated in this segment
C*


	integer ntuplen,ntuplen2,ntuplen3      ! Lengths of the various ntups
	integer nid_initphots		       ! ID for initial photon ntup
	integer nid_eloss		       ! ID for energy loss ntup
	integer nid_tracks		       ! ID for track step ntup
	integer hid_counts		       ! ID for counts vs. radius hist
	integer hid_counts_dir		       ! Counts vs radius for direct
	integer hid_counts_sca		       ! Counts vs radius for scattered
	integer hid_shells_dir		       ! Counts vs shell for direct
	integer hid_shells_sca		       ! Counts vs shell for scattered
        integer reclen	      	               ! record length of this ntuple
	integer reclen2	      	               ! record length of this ntuple
	integer reclen3	      	               ! record length of this ntuple
	integer LUN_NT, LUN_NT2                ! output IDs
	
	parameter(nid_initphots=50)
	parameter(nid_eloss=51)
	parameter(nid_tracks=52)
	parameter(hid_counts=53)
	parameter(hid_counts_dir=54)
	parameter(hid_counts_sca=55)
	parameter(hid_shells_dir=56)
	parameter(hid_shells_sca=57)
      
        PARAMETER (LUN_NT=22)
        PARAMETER (LUN_NT2=23)
	
C
C--- Photon ntuple - 9 real entries, and one integer
C
	parameter(ntuplen=9)
	parameter(reclen=40) !=4*ntuplen+4 for nscat
	real*4 xtup(ntuplen)
	integer*4 xtupscat
	character*5 tags(ntuplen+1)
	integer xtup_id_ish
c	parameter(xtup_id_ish=10)
c In future, remove ish and shrad, since this info is contained in the file group
c Note that
	data tags/'times','x_pos','y_pos','z_pos',
     1			'x_dir','y_dir','z_dir',
     2			'wlen','wgt','nscat'/

c no longer includes event number, and energy/wavelength is redundant!!!!

C
C--- Diagnostic tracking step ntuple
C--- Note that this was originally the thrid ntuple, hence the names "...3"
C
	parameter (ntuplen3=17)
	parameter(reclen3=70) !=4*ntuplen+2
	real xtup3(ntuplen3)
	character*5 tags3(ntuplen3)
	data tags3/'evnum','ipart','istak','ivert','mass',
     1	'charge','x','y','z','vx','vy','vz','etot','step',
     2	'delte','tofg','nphot'/
