C* @brief Defines the data for the hit program
C*/
C Include file for the HIT_DIST program  (generates hit distributions)

C Created 15 June 1996  M.Moorhead  LBNL

c Revision History
C ================
c V1	M. Moorhead	Created include file

*
* Sergio Navas 28-Sep-1998   Printout some user debug information.
* Sergio Navas 30-Oct-1998   Upmdate MAX_R = 25
*
        implicit none

c Parameters
	INTEGER*4 MAX_R, MAX_BAND, MAX_THETA_OM_DIR, MAX_THETA_OM_SCAT
        INTEGER*4 MAX_PHI_OM_DIR, MAX_PHI_OM_SCAT, MAX_T_DIR, MAX_T_SCAT
	INTEGER*4 MAX_HITS,MAX_PER_SHELL
	INTEGER*4 PMT_MAX_A, PMT_NCOS, PMT_MAX_NWLEN, MAX_CH_L, PMT_MAX_EV
	real*4    PMT_MIN_MIN_EFFANG          ! minimum for PMT min eff angle
	PARAMETER (PMT_MIN_MIN_EFFANG = 1e-12)
	PARAMETER (MAX_R             = 25)   ! Max # of shells of diff. radii 
	PARAMETER (MAX_BAND          = 40)   ! Max # of theta bands per shell  
	PARAMETER (MAX_THETA_OM_SCAT = 20)    ! Max # of OM theta's (scat)
	PARAMETER (MAX_THETA_OM_DIR  = 40)   ! Max # of OM theta's (dir)
	PARAMETER (MAX_PHI_OM_SCAT   = 12)    ! Max # of OM phi's   (scat)	
        PARAMETER (MAX_PHI_OM_DIR    = 1)    ! Max # of OM phi's   (dir)
	PARAMETER (MAX_T_SCAT        = 100)  ! Max # of time bins  (scat)
	PARAMETER (MAX_T_DIR         = 100)  ! Max # of time bins  (dir)
	PARAMETER (MAX_HITS       =  10000000)  ! Max # of hits in hit buffer: main memory component!!!
	PARAMETER (PMT_MAX_A  	      = 20) ! max # coefs for pmt qe fit
	PARAMETER (PMT_NCOS   	      = 500) ! # of cosines to calculate pmt effang
	PARAMETER (PMT_MAX_EV  	      = 50)  ! Maximum number of wavelengths to calc effang
	PARAMETER (PMT_MAX_NWLEN      = 100) ! max # of w-lens in pmt desc
	PARAMETER (MAX_CH_L   	    = 120) ! maximum length of characters
c input/output logical units

        integer lun_in_rz, lun_in_desc, lun_in_pmt_desc
        integer lun_out_rz, lun_out_desc, lun_in_pmt_rz

        parameter (lun_in_rz    = 21) ! input rz file from generate-photons
        parameter (lun_in_desc  = 22) ! input desc file from generate-photons
        parameter (lun_in_pmt_desc = 23) ! input PMT desc file from snoman 
        parameter (lun_in_pmt_rz = 24) ! input PMT rz file from snoman
        parameter (lun_out_rz   = 25) ! output rz file with OM distributions
        parameter (lun_out_desc = 26) ! output log file for OM distributions

c Output arrays

        REAL*4    N_DET_SCAT( MAX_R, MAX_BAND, MAX_THETA_OM_SCAT, 
     1            MAX_PHI_OM_SCAT )      ! # of (scattered) photons detected 
        REAL*4    N_DET_DIR ( MAX_R, MAX_BAND, MAX_THETA_OM_DIR,  
     1            MAX_PHI_OM_DIR )       ! # of (direct) photons detected 
        REAL*4    T_DIS_SCAT( MAX_R, MAX_BAND, MAX_THETA_OM_SCAT, 
     1            MAX_PHI_OM_SCAT, 0:MAX_T_SCAT)   
c Inverse cumul. time distribution (for scattered hits)
        REAL*4    T_DIS_DIR ( MAX_R, MAX_BAND, MAX_THETA_OM_DIR, 
     1            MAX_PHI_OM_DIR, 0:MAX_T_DIR)
        
c Inverse cumul. time distribution (for direct hits)

c overall header for global parameters

C        STRUCTURE /HEADER/

      character*120 H_file_in_rz ! input rz file with photon field ntuple
      character*120 H_file_in_desc ! desc file
      character*120 H_file_out_desc ! desc file
      INTEGER*4 H_i_medium   !  1 = ice, 2 = water
      INTEGER*4 H_I_R        !  current shell #
      INTEGER*4 H_I_band     !  current band  #
      INTEGER*4 H_part_id    !  Geant id # for primary part (5=muon 3=elec)
      INTEGER*4 H_nevents    !  # of primary events (muons or showers)
      INTEGER*4 H_good_events!  # of events with e_loss .lt. e_thresh
      INTEGER*4 H_nhits      !  # of hits in the current shell ntuple
      integer*4 H_scat       !  0=direct band, 1=scattered band
      integer*4 H_nbins_om_theta(0:1) ! number of theta_OM bins
      integer*4 H_nbins_om_phi(0:1)   ! number of phi_OM bins
      integer*4 H_nbins_time(0:1)     ! number of time bins 
      integer*4 H_last_dir_r !  last shell (r bin) with enough dir hits
      integer*4 H_dodir  ! do direct hits yes (1) or no (0)
      REAL*4    H_n_ref      ! refractive index of medium
      REAL*4    H_dens_medium! density of medium in g/cm^3
      REAL*4    H_e_thresh   !  (GeV) maximum e_loss for valid muon segmnt 
      REAL*4    H_min_ion_eloss ! average eloss for muons < e_thresh
      REAL*4    H_part_energy ! energy for primary particle 
      REAL*4    H_seg_length !  length of muon track or ave shower devel. 
      REAL*4    H_theta_ch   !  cherenkov angle (radians)
      REAL*4    H_cos_ch     !  cosine of cherenkov angle
      REAL*4    H_c_speed    !  speed of light in m/ns
c      REAL*4    H_dir_ratio  !  minimum ratio between scatterd and direct
c hits to make entries in the direct OM distributions for a given shell 
      real*4    H_min_band_dot ! minimum value for dot product of band
c normal and hit direction (to avoid statistical spikes due to dividing by
c band_dot to correct for the band effective area).

      
      INTEGER*4 ALL_SCAT, MAX_SCAT, EM_SCAT_ID    	 ! code to force scattering or otherwise - and max scat to consider
      COMMON /H/H_file_in_rz,H_i_medium,H_I_R,H_I_band,H_part_id,
     &          H_nevents,H_good_events,H_nhits,H_scat,H_nbins_om_theta,
     &          H_nbins_om_phi,H_nbins_time,H_last_dir_r,
     &          H_n_ref,H_dens_medium,H_e_thresh,H_min_ion_eloss,
     &          H_part_energy,H_seg_length,H_theta_ch,H_cos_ch,
     &          H_c_speed,H_min_band_dot, ALL_SCAT,
     &	        MAX_SCAT, EM_SCAT_ID, H_dodir, H_file_in_desc,
     &	        H_file_out_desc
c    &	        , H_dir_ratio
C	END STRUCTURE

c structure for PMT/OM parameters

      integer*4 PMT_nbins_energy        ! # of energy bins
      integer*4 PMT_nbins_dot           ! # of cos(theta) bins
      integer*4 PMT_nwlen     	        ! # wavelength bins for q.e.
      integer*4 PMT_effang_meth
      integer*4 PMT_nev       	       ! number of photon energies at which aeff is specified
      real*4    PMT_diam      	       ! PMT diameter in inches
      real*4    PMT_eff_col   	       ! PMT effective area fraction (<= 1.0)
      real*4    PMT_area      	       ! PMT area (m^2)
      real*4    PMT_mincos    	       ! min cosine for parameterisation
      real*4    PMT_dcos      	       ! cosine increment for effang param
      real*4    PMT_min_effang	       ! minimum of angular acceptence
      real*4    PMT_max_lam     	       ! max ph wavelength for non-zero acceptance
      real*4    PMT_min_lam     	       ! min ph wavelength for non-zero acceptance
      real*4    PMT_na	      	       ! # of polynoial coefficients
      real*4    PMT_cos(PMT_NCOS)      ! angular cosines
      real*4    PMT_effang_a(PMT_MAX_A) ! polynomial fit coefficients to effang
      real*4    PMT_effang(PMT_NCOS, PMT_MAX_EV)   ! log angular efficiency at PMT_cos
      real*4    PMT_EFF_AREA(PMT_MAX_NWLEN) ! holds PMT quantum efficiencies
      real*4    PMT_QEFF(PMT_MAX_NWLEN) ! holds PMT quantum efficiencies
      real*4    PMT_DLAMB(PMT_MAX_NWLEN) ! holds wavelengths for above
      real*4    PMT_ABSBEN(PMT_MAX_NWLEN) ! holds absorption data for benthos
      real*4    PMT_ABSGEL(PMT_MAX_NWLEN) ! holds absoprtion data for gel
      real*4    PMT_ABSALL(PMT_MAX_NWLEN) ! holds combined absorption data
      real*4    PMT_wlen1     	          ! initial wavelength for qe
      real*4    PMT_dwlen     	          ! wavelength increment for qe
      real*4    PMT_xgel      	          ! cm thickness of gel
      real*4    PMT_xben      	          ! cm thickness of benthos
      real*4    PMT_evmin     	          ! min ev of angular efficiency tables
      real*4    PMT_evmax     	          ! max ev of angular efficiency tables
      real*4    PMT_dev       	          ! bin division in eV
      real*4    PMT_ev(PMT_MAX_EV)     ! contains eV bin centres
      COMMON /PMT/PMT_nbins_energy,PMT_nbins_dot,PMT_nwlen,
c     &	          PMT_energy,PMT_dot,PMT_energy_step,PMT_dot_step,
c     &	          PMT_square,PMT_eff_area
     &	          PMT_effang_meth, PMT_diam,PMT_eff_col,
     &	          PMT_area,PMT_mincos,PMT_dcos,PMT_min_effang,PMT_na,
     &	          PMT_max_lam,PMT_min_lam,PMT_cos,PMT_effang_a,
     &	          PMT_effang,
     &	          PMT_EFF_AREA,PMT_QEFF,PMT_DLAMB,PMT_ABSBEN,
     &	          PMT_ABSGEL,PMT_wlen1,PMT_dwlen,PMT_xgel,PMT_xben,
     &	          PMT_nev, PMT_evmin, PMT_evmax, PMT_dev, PMT_ev
C	END STRUCTURE

c structure for bands

C        STRUCTURE /band/

      integer*4 B_nbins(0:1)        ! # of bins
      integer*4 B_n_low(0:1)        ! # of bins with cos .lt. cos_ch
      integer*4 B_n_high(0:1)       ! # of bins with cos .gt. cos_ch
      integer*4 B_tmeth	      	    ! use chebychev binning?
      real*4    B_cos_min(0:1,max_r,max_band) ! cos_theta value at bin min.
      real*4    B_cos_max(0:1,max_r,max_band) ! cos_theta value at bin max
      real*4    B_cos_ave(0:1,max_r,max_band) ! cos_theta average for bin
      real*4    B_area(0:1,max_r,max_band) ! area of band in m^2
      real*4    B_power_low(0:1)    ! power for `flat' cos theta dist.
      real*4    B_power_high(0:1)   ! power for `flat' cos theta dist.
      real*4    B_step_low(0:1)     ! bin step for low bins.
      real*4    B_step_high(0:1)    ! bin step for high bins.
! These two added by D. Lowder   4/7/97
      real*4    B_om_theta(0:1,max_theta_om_dir)	! values of theta bins
      real*4    B_om_phi(0:1,max_phi_om_scat)       ! values of phi bins
      real*4    B_om_matrix(0:1,max_theta_om_dir,max_phi_om_scat,3) ! rotation matrix for theta and phi

      COMMON /B/B_nbins,B_n_low,B_n_high,B_cos_min,B_cos_max,B_cos_ave,
     &          B_area,B_power_low,B_power_high,B_step_low,B_step_high,
     &          B_om_theta,B_om_phi, B_om_matrix, B_tmeth

C	END STRUCTURE

c structure for shell bins

C        STRUCTURE /shell/

      integer*4 R_nbins              ! number of bins
      real*4    R_rad(0:max_r)       ! radius of each shell
      real*4    R_prescale(0:1,max_r)! pre-scaling factors for each shell
      real*4    R_power              ! power for linear scaling

      COMMON /R/R_nbins,R_rad,R_prescale,R_power

C	END STRUCTURE
c
c  Particle IDs

C	STRUCTURE /PART_IDS/

      INTEGER*4 ID_LASER    
      INTEGER*4 ID_PHOTON   
      INTEGER*4 ID_ELECTRON 
      INTEGER*4 ID_MUON     
      INTEGER*4 ID_TAU      

      COMMON /ID/ID_LASER,ID_PHOTON,ID_ELECTRON,ID_MUON,ID_TAU

C	END STRUCTURE

c  Define constants

C	STRUCTURE /STCON/

      REAL*4 CON_PI
      real*4 CON_root_two
      real*4 CON_wlen_to_energy

      COMMON /CON/CON_PI,CON_root_two,CON_wlen_to_energy

C	END STRUCTURE

c internal photon buffer for all hits on a given band

C	STRUCTURE /PHOTONS/

      INTEGER*4 P_NHITS  ! # of hits in hit buffer
      REAL*4 P_WLEN( MAX_HITS )      ! wavelength for each hit (nm)
      REAL*4 P_TIME( MAX_HITS )      ! time of arrival for each hit
      REAL*4 P_POS( MAX_HITS, 3 )    ! xyz location for each hit
      REAL*4 P_DIR( MAX_HITS, 3 )    ! xyz direction for each hit
      REAL*4 P_WGT( MAX_HITS)     ! contains log weight of the event
      COMMON /P/P_NHITS,P_WLEN,P_TIME,P_POS,P_DIR, P_WGT

C	END STRUCTURE

C        RECORD /      HEADER/ H               ! Header buffer
C        RECORD /     PHOTONS/ P               ! photon field buffer
C        RECORD /       STPMT/ PMT             ! PMT buffer
C        RECORD /        BAND/ B               ! band buffer
C        RECORD /       SHELL/ R               ! shell buffer
C	RECORD /       STCON/ CON             ! Constants
C        RECORD /    PART_IDS/ ID              ! particle IDs
c
c Common block

C	COMMON /HIT/ H, P, PMT, B, R, CON, N_DET_DIR,
C     1              N_DET_SCAT, T_DIS_DIR, T_DIS_SCAT, ID

        COMMON /HITC/ N_DET_DIR,N_DET_SCAT,T_DIS_DIR,T_DIS_SCAT

*
* Printout some user debug information.
*
	INTEGER        IDBG
	LOGICAL             LDEBUG,LDEBUG2,ISCAN
	COMMON /DEBUG/ IDBG,LDEBUG,LDEBUG2,ISCAN
*
* Description:
*
*       IDBG    = Logical unit number to send the print-out.
*       LDEBUG  = Print-out program information during the run (.TRUE.).
*       LDEBUG2 = The same but even more detailed information is printed.
*       ISCAN   = Dump event information (phton by photon)
* ------------------------------------------------------------------

* 30-Nov-1999
* Chebysev numbers between 0 and MAX_T_SCAT
*
        REAL*4 X_CHEBY(0:1,0:MAX_T_SCAT)
        COMMON / CHEBYSEV / X_CHEBY
*
* Water model details ( from "gen.f" )

        REAL          LUZ, LABS, LSCAT, ALPHA, COSME1, COSME2, ETA
        CHARACTER*6   WATMOD
        COMMON /WA_MODEL/LUZ,LABS,LSCAT,ALPHA,COSME1,COSME2,ETA,WATMOD

        INTEGER*4 MAXRBINS
	PARAMETER(MAXRBINS=100)
	INTEGER*4 GENID_BASE, GENIDS(MAXRBINS)
	PARAMETER (GENID_BASE=30)
	CHARACTER GENFILES(MAXRBINS)*120
	INTEGER*4 counts_tot(MAXRBINS),counts_dir(MAXRBINS) ! photons from gen
	INTEGER*4 counts_sca(MAXRBINS)
	INTEGER*4 counts_utot(MAXRBINS),counts_udir(MAXRBINS) ! used photons in hit
	INTEGER*4 counts_usca(MAXRBINS)
	INTEGER*4 total_counts, total_ucounts
	COMMON/COUNTS/counts_tot,counts_dir,counts_sca,total_counts,
     & counts_utot,counts_udir,counts_usca,total_ucounts,GENIDS,
     & GENFILES
      
      INTEGER MAX_DIR_TO_SCAT
      PARAMETER (MAX_DIR_TO_SCAT = 1000000)
      INTEGER DIR_TO_SCAT_IDS(MAX_DIR_TO_SCAT)
      INTEGER N_DIR_TO_SCAT
      INTEGER NEXT_DIR_TO_SCAT
      
      
      
