C* @brief Main include file for KM3
C*/

	IMPLICIT NONE

c  *****************************************
c  ***  Include file for KM3 simulation  ***
c  *****************************************
c
c  Parameters for geometry (may have to be changed to accommodate
c  larger detectors)

	INTEGER*4 MAX_NUM_OMS_DET, MAX_NUM_OMS_CLS
        INTEGER*4 MAX_NUM_CLS, MAX_NUM_STR 
        INTEGER*4 ELOSS_MAXNLS
        INTEGER*4 ELOSS_MAX_LINES
	INTEGER*4 ELOSS_LINE_MAX
c New values able to cope with km3NeT
	PARAMETER (MAX_NUM_OMS_DET = 200000) ! Max # OMs in whole detector
	PARAMETER (MAX_NUM_OMS_CLS =    31) ! Max # OMs in any cluster
	PARAMETER (MAX_NUM_STR     =   512) ! Max # strings in whole detector
	PARAMETER (MAX_NUM_CLS	    =  3000) ! Max # clusters in whole detector

c Testing parameters for a 'sphere' of OMs - need one 'string' per OM
c        PARAMETER (MAX_NUM_OMS_CLS =    1) ! Max # OMs in any cluster
c	PARAMETER (MAX_NUM_STR     =   5120) ! Max # strings in whole detector

c Old values for ANTARES only - only revert to these if having memory problems
c        PARAMETER (MAX_NUM_OMS_DET = 20000) ! Max # OMs in whole detector
c	PARAMETER (MAX_NUM_OMS_CLS =     8) ! Max # OMs in any cluster
c	PARAMETER (MAX_NUM_STR     =   128) ! Max # strings in whole detector
c	PARAMETER (MAX_NUM_CLS     =    64) ! Max # clusters in any string

c energy-loss parameters for ELOSS strings
        PARAMETER (ELOSS_MAXNLS  =    960) ! Max # of energy-loss segments
        PARAMETER (ELOSS_MAX_LINES = 20)  ! Max # of energy-loss lines
	PARAMETER (ELOSS_LINE_MAX = 48)    ! max # eloss entries per line

c  Parameters
	INTEGER*4 MAX_PART, MAX_HITS, MAX_SEGS, MAX_R
        INTEGER*4 MAX_THETA_OM_DIR, MAX_THETA_OM_SCA, MAX_BAND
        INTEGER*4 MAX_PHI_OM, MAX_TIME, MAX_ENERGY
        INTEGER*4 MAX_BAND_PHOT
        REAL*4    MIN_PROB

	PARAMETER (MAX_PART =  20000)	! Max # of particles in an event
	PARAMETER (MAX_HITS =  100000)	! Max # of total hits
	PARAMETER (MAX_SEGS =  10000)	! Max # of segments per muon 
	PARAMETER (MAX_R    =  20)	! Max # of radii in distrbtns. 
	PARAMETER (MAX_THETA_OM_DIR = 40)! Max # theta OMs (direct hits) 
	PARAMETER (MAX_THETA_OM_SCA = 20) ! Max # theta OMs (scatred hits) 
	PARAMETER (MAX_BAND     = 20)  ! Max # of low bands  #set to 2/3+1 of nbands
	PARAMETER (MAX_PHI_OM = 12)      ! Max # phi OMs (scattred photons) 
	PARAMETER (MAX_TIME   = 100)    ! Max # time bins 
	PARAMETER (MAX_ENERGY  = 4)     ! Max # energy bins         
	PARAMETER (MAX_BAND_PHOT = 20)  ! Max # of bands LASER-flash scenario
        PARAMETER (MIN_PROB = -20)      ! Min log for *_dir/sca_prob arrays entries
c
c  Header structure

C	STRUCTURE /HEADER/

            INTEGER*4 H_MEDIA_ID          ! media_id (1=ice, 2=water)
	    INTEGER*4 H_DATE		! YYYYMMDD (E.G. 20021103)
	    INTEGER*4 H_event_format	! format for event file (0=km3,1=dada)
	    INTEGER*4 H_out_format	! format for ouput file (1=ant)
            INTEGER*4 H_music             ! 0=eloss tables, 1=MUSIC on 
            INTEGER*4 H_event_ntuple      ! 1=write event ntuple, 0=don't write
            INTEGER*4 H_segment_ntuple  ! 1=write muon segment ntuple, 0=don't
            INTEGER*4 H_quiet             ! 1=verbose logging, else=quiet
	    INTEGER*4 H_do_dir_ph        ! turns direct calculation of/off
	    INTEGER*4 H_OPA   	          ! one-particle approx on/off
	    INTEGER*4 H_OPA_ID	          ! ID to assign OPA particles
	    INTEGER*4 H_REC_HIT_ORIGIN ! turns hit-origin recording on/off
	    INTEGER*4 H_CHEB  	    ! chebychev time-binning used? 1=yes,0=no
	    REAL*8    H_TSTART		! Start time (sec since 00:00)
            REAL*4    H_DENS_MEDIUM       ! density of medium
            REAL*4    H_RHO_MUON_DIR_CUT ! distance in m for muon dir cut
	    REAL*4    H_RHO_MUON_SCAT_CUT ! distance in m for muon scat cut
	    REAL*4    H_RHO_ELEC_CUT_BASE ! min distance for 100 GeV electrons
	    REAL*4    H_RHO_ELEC_CUT_DEL  ! increase in distance per factor 10 energy
	    REAL*4    H_MUON_CUT_DISTANCE ! distance at which to stop tracking muon
            REAL*4    H_SEG_LENGTH_HIT    ! length in m of muon track segments
c used in the program hit to generate the hit probability distributions
            REAL*4    H_SEG_LENGTH_KM3    ! length in m of muon track segments
c used to track the muon through the detector in the km3 program itself 
            REAL*4    H_SEG_LENGTH_RATIO  ! h.seg_length_km3/h.seg_length_hit
            REAL*4    H_SHOWER_THRESH   ! threshold energy for creating showers
c            REAL*4    H_RHO_MAX         ! range in m to search for nearby OMs 
c	    REAL*4    H_RHO_COEF         ! coefficient to determine h_rho_max 
            REAL*4    H_RHO_MIN_27      ! minimum distance for using the trick
c of averaging over nearby 27 segments to calculate muon scattered hits
            REAL*4    H_RHO_MIN_9       ! minimum distance for using the trick
c of averaging over nearby 27 segments to calculate muon scattered hits
            REAL*4    H_RHO_MIN_3       ! minimum distance for using the trick
c of averaging over nearby 27 segments to calculate muon scattered hits
            REAL*4    H_MAX_E_LOSS        ! Max muon e_loss per segment in
c the input files genrated for muons by the program `hit' (GeV)
            REAL*4    H_AVE_E_LOSS_HIT    ! average muon e_loss per segment
c in the program `hit' for muons with e_loss < h.max_e_loss(GeV)
            REAL*4    H_AVE_E_LOSS_KM3    ! average muon e_loss per segment
c in the input files generated for muons by the prgram `hit' (GeV)
            REAL*4    H_REFINDEX          ! refractive index of water/ice
            REAL*4    H_GROUPINDEX        ! group refractive index
            REAL*4    H_COS_CH            ! cosine of cherenkov angle
            REAL*4    H_TAN_CH            ! tangent of cherenkov angle
            REAL*4    H_MIN_SEG_RATIO  ! scaling of 3/9/27 segment merging
      COMMON /H/H_MEDIA_ID,H_DATE,H_event_format,H_out_format,H_music,
     &          H_event_ntuple,H_segment_ntuple,H_quiet,H_TSTART,
     &          H_DENS_MEDIUM,H_SEG_LENGTH_HIT,
     &          H_SEG_LENGTH_KM3,H_SEG_LENGTH_RATIO,H_SHOWER_THRESH,
     &          H_RHO_MIN_27,H_RHO_MIN_9,H_RHO_MIN_3,
     &          H_MAX_E_LOSS,H_AVE_E_LOSS_HIT,H_AVE_E_LOSS_KM3,
     &          H_REFINDEX,H_COS_CH,H_TAN_CH,H_GROUPINDEX,
     &	        H_do_dir_ph,H_OPA, H_REC_HIT_ORIGIN, H_OPA_ID,
     &	        H_CHEB, H_RHO_MUON_DIR_CUT,
     &	        H_RHO_MUON_SCAT_CUT, H_RHO_ELEC_CUT_BASE,
     &	        H_RHO_ELEC_CUT_DEL, H_MUON_CUT_DISTANCE,
     &          H_MIN_SEG_RATIO
      
c      INTEGER NSPACE
c      PARAMETER NSPACE=100
c      INTEGER SPACE(NSPACE)
c      INTEGER*4 SPACE(200)
c      COMMON /CFREAD/ SPACE(200)
c      COMMON /CFINFO/ NSPACE
C	END STRUCTURE
c event generator structure

C	STRUCTURE /GENERATOR/

	    INTEGER*4 GEN_NEVENTS		! Number events to be generated
            INTEGER*4 GEN_JOB_COUNTER       ! 1% of gen.nevents 
	    INTEGER*4 GEN_EVENT_ID		! current event ID
	    INTEGER*4 GEN_DADA_ID		! current event DADA ID
	    INTEGER*4 GEN_PART_ID	! particle ID (3=electron,5=muon)
	    INTEGER*4 GEN_NPART		! Total # particles in current event
            INTEGER*4 GEN_NPARTIN       ! Number of input particles
	    INTEGER*4 GEN_NHITS		! Total # OM hits in current event
	    INTEGER*4 GEN_OPA_MIN      ! min OPA id - only used with OPA
	    INTEGER*4 GEN_OPA_MAX      ! max OPA id - only used with OPA
	    REAL*4    GEN_ENERGY            ! energy of events
            REAL*4    GEN_POS(3)            ! start position of events
            REAL*4    GEN_DIR(3)            ! start direction of events
            INTEGER*4 GEN_now_s             ! event time information 
            INTEGER*4 GEN_now_ns            ! event time information 

      COMMON /GEN/GEN_NEVENTS,GEN_JOB_COUNTER,GEN_EVENT_ID,GEN_DADA_ID,
     &            GEN_PART_ID,GEN_NPART,GEN_NHITS,GEN_ENERGY,GEN_POS,
     &            GEN_DIR,GEN_NOW_S,GEN_NOW_NS,GEN_NPARTIN,
     &	          GEN_OPA_MIN,GEN_OPA_MAX

C        END STRUCTURE

c structure for muon direct photon distribution

C        STRUCTURE /muon_dir/

c dimensions: 1=radius, 2=cos(theta_om), 3=time
      INTEGER*4 MU_DIR_nbins(3)          ! number of bins in each dimension
      REAL*4    MU_DIR_power(2)          ! power for linear interpolation
      REAL*4    MU_DIR_step(2)           ! step size between bins
      REAL*4    MU_DIR_step_prod         ! product of step sizes
      REAL*4    MU_DIR_min(2)            ! minimum values
      REAL*4    MU_DIR_max(2)            ! maximum values
      REAL*4    MU_DIR_prob(max_r,max_theta_om_dir) ! poisson prob of hit
      REAL*4    MU_DIR_time(max_r,max_theta_om_dir,0:max_time) ! hit time dist.

      COMMON /MUON_DIR/MU_DIR_nbins,MU_DIR_power,MU_DIR_step,
     &                 MU_DIR_step_prod,MU_DIR_min,MU_DIR_max,
     &                 MU_DIR_prob,MU_DIR_time 
     
C        END STRUCTURE

c structure for muon scattered photon distribution

C        STRUCTURE /muon_sca/

c dimensions: 1=radius, 2=band, 3=theta_om, 4=phi_om, 5=time
      INTEGER*4 MU_SCA_nbins(2,5)        ! number of bins in each dimension
      REAL*4    MU_SCA_power(2,4)        ! power for linear interpolation
      REAL*4    MU_SCA_step(2,4)         ! step size between bins
      REAL*4    MU_SCA_step_prod(2)      ! product of step sizes
      REAL*4    MU_SCA_min(2,4)          ! minimum values
      REAL*4    MU_SCA_max(2,4)          ! maximum values
      REAL*4    MU_SCA_prob(2,max_r,max_band,max_theta_om_sca,
     1               max_phi_om)  ! poisson prob of hit
      REAL*4    MU_SCA_time(2,max_r,max_band,max_theta_om_sca,
     1               max_phi_om,0:max_time) ! hit time dist.

      COMMON /MU_SCA/MU_SCA_nbins,MU_SCA_power,MU_SCA_step,
     &               MU_SCA_step_prod,MU_SCA_min,MU_SCA_max,MU_SCA_prob,
     &               MU_SCA_time

C        END STRUCTURE

cc structure for electron direct photon distributions

C        STRUCTURE /elec_dir/

c dimensions: 1=energy, 2=radius, 3=band, 4=cos(theta_om), 5=time
      INTEGER*4 EL_DIR_nbins(2,5)        ! number of bins in each dimension
      REAL*4    EL_DIR_power(2,4)        ! power for linear interpolation
      REAL*4    EL_DIR_step(2,4)         ! step size between bins
      REAL*4    EL_DIR_step_prod(2)      ! product of step sizes
      REAL*4    EL_DIR_min(2,4)          ! minimum values
      REAL*4    EL_DIR_max(2,4)          ! maximum values
      REAL*4    EL_DIR_prob(2,max_energy,max_r,max_band,
     1                      max_theta_om_dir)  ! poisson prob of hit
      REAL*4   EL_DIR_time(2,max_energy,max_r,max_band,max_theta_om_dir,
     1                      0:max_time) ! hit time dist.

      COMMON /EL_DIR/EL_DIR_nbins,EL_DIR_power,EL_DIR_step,
     &               EL_DIR_step_prod,EL_DIR_min,EL_DIR_max,EL_DIR_prob,
     &               EL_DIR_time

C        END STRUCTURE

cc structure for electron shower scattered photon distributions

C        STRUCTURE /elec_sca/

c dimensions: 1=energy, 2=radius, 3=band, 4=theta_om, 5= phi_om, 6=time

      INTEGER*4 EL_SCA_nbins(2,6)        ! number of bins in each dimension
      REAL*4    EL_SCA_power(2,5)        ! power for linear interpolation
      REAL*4    EL_SCA_step(2,5)         ! step size between bins
      REAL*4    EL_SCA_step_prod(2)      ! product of step sizes
      REAL*4    EL_SCA_STEP_PROD_D12(2)  ! product of first two dims only
      REAL*4    EL_SCA_min(2,5)          ! minimum values
      REAL*4    EL_SCA_max(2,5)          ! maximum values
      REAL*4   EL_SCA_prob(2,max_energy,max_r,max_band,max_theta_om_sca,
     1               max_phi_om)       ! poisson prob of hit
      REAL*4   EL_SCA_time(2,max_energy,max_r,max_band,max_theta_om_sca,
     1               max_phi_om,0:max_time) ! hit time dist.

      COMMON /EL_SCA/EL_SCA_nbins,EL_SCA_power,EL_SCA_step,
     &               EL_SCA_step_prod,EL_SCA_min,EL_SCA_max,EL_SCA_prob,
     &               EL_SCA_time,EL_SCA_STEP_PROD_D12

C        END STRUCTURE


cc structure for LASER-flash direct photon distributions

C        STRUCTURE /photon_dir/

c dimensions: 1=radius, 2=band, 3=cos(theta_om), 4=time

      INTEGER*4 PHOT_DIR_nbins(4)        ! number of bins in each dimension
      REAL*4    PHOT_DIR_power(3)        ! power for linear interpolation
      REAL*4    PHOT_DIR_step(3)         ! step size between bins
      REAL*4    PHOT_DIR_step_prod       ! product of step sizes
      REAL*4    PHOT_DIR_min(3)          ! minimum values
      REAL*4    PHOT_DIR_max(3)          ! maximum values
      REAL*4    PHOT_DIR_prob(max_r,max_band_phot,max_theta_om_dir)
c                               ! poisson prob of hit
      REAL*4    PHOT_DIR_time(max_r,max_band_phot,max_theta_om_dir,
     &                        0:max_time)         ! hit time dist.

      COMMON /PHOT_DIR/PHOT_DIR_nbins,PHOT_DIR_power,PHOT_DIR_step,
     &                 PHOT_DIR_step_prod,PHOT_DIR_min,PHOT_DIR_max,
     &                 PHOT_DIR_prob,PHOT_DIR_time

C        END STRUCTURE

cc structure for LASER-flash scattered photon distributions

C        STRUCTURE /photon_sca/

c dimensions: 1=radius, 2=band, 3=theta_om, 4= phi_om, 5=time

      INTEGER*4 PHOT_SCA_nbins(5)        ! number of bins in each dimension
      REAL*4    PHOT_SCA_power(4)        ! power for linear interpolation
      REAL*4    PHOT_SCA_step(4)         ! step size between bins
      REAL*4    PHOT_SCA_step_prod       ! product of step sizes
      REAL*4    PHOT_SCA_min(4)          ! minimum values
      REAL*4    PHOT_SCA_max(4)          ! maximum values
      REAL*4    PHOT_SCA_prob(max_r,max_band_phot,max_theta_om_sca,
     1                        max_phi_om)            ! poisson prob of hit
      REAL*4    PHOT_SCA_time(max_r,max_band_phot,max_theta_om_sca,
     1                        max_phi_om,0:max_time) ! hit time dist.

      COMMON /PHOT_SCA/PHOT_SCA_nbins,PHOT_SCA_power,PHOT_SCA_step,
     &                 PHOT_SCA_step_prod,PHOT_SCA_min,PHOT_SCA_max,
     &                 PHOT_SCA_prob,PHOT_SCA_time

C        END STRUCTURE

c  Geometry structures

C	STRUCTURE /GEOMETRY/		! All geometry information

      REAL*4 G_ORIGIN(3)    	! Center of detector
      REAL*4 G_HHT		! Half-height of detect. encl. cylinder
      REAL*4 G_RAD_CYL		! Radius of detector enclosing cylinder
      REAL*4 G_RAD_SPH		! Radius of detector enclosing sphere
      REAL*4 G_latitude		! latitude in degrees (Pos North)
      REAL*4 G_longitude	! longitude in degrees (Pos west)
      REAL*4 G_z_surface	! z position of sea surface
      REAL*4 G_z_bottom		! z position of sea bottom
      INTEGER*4 G_NUM_OMS	! Number of OMs in detector
      INTEGER*4 G_NUM_CLS	! # of clusters in detector
      INTEGER*4 G_NUM_STR	! # of strings in detector

      COMMON /G/G_ORIGIN,G_HHT,G_RAD_CYL,G_RAD_SPH,G_latitude,
     &          G_longitude,G_z_surface,G_z_bottom,G_NUM_OMS,
     &          G_NUM_CLS,G_NUM_STR

C     RECORD /OM_DETECTOR_MODEL/ OM(MAX_NUM_OMS_DET) ! maximum OMs in detector

      INTEGER*4 G_OM_IPMOD(MAX_NUM_OMS_DET) 	 ! PMT model number
      INTEGER*4 G_OM_ID_ANT_OM(MAX_NUM_OMS_DET)	 ! Antares OM identifier
      INTEGER*4 G_OM_ID_ANT_CLS(MAX_NUM_OMS_DET) ! Antares cluster identifier
      INTEGER*4 G_OM_ID_ANT_STR(MAX_NUM_OMS_DET) ! Antares string identifier
      REAL*4    G_OM_X(3,MAX_NUM_OMS_DET)	 ! Location of OM
      REAL*4    G_OM_DIR(3,MAX_NUM_OMS_DET)	 ! Orientation of OM

      COMMON /G/G_OM_IPMOD,G_OM_ID_ANT_OM,G_OM_ID_ANT_CLS,
     &          G_OM_ID_ANT_STR,G_OM_X,G_OM_DIR
      
      REAL*4 ELOSS_DZ   	      	 ! length of energy-loss segment (m)
      INTEGER*4 ELOSS_NSEGS      	 ! number of segments to combine for eloss
      REAL*4 ELOSS_LOSS(ELOSS_MAXNLS)  	 ! array to contain energy-loss
      COMMON /ELOSS/ELOSS_DZ,ELOSS_NSEGS,ELOSS_LOSS
      
C     RECORD /STRING_MODEL/ STR(MAX_NUM_STR) ! Maximum strings in detector

      REAL*4    G_STR_X(3,MAX_NUM_STR)	! Location of string
      REAL*4    G_STR_HHT(MAX_NUM_STR)	 ! Half-height of string encl. cylinder
      REAL*4    G_STR_RAD_CYL(MAX_NUM_STR) ! Radius of string enclosing cyl.
      REAL*4    G_STR_RAD_SPH(MAX_NUM_STR) ! Radius of string enclosing sphere
      INTEGER*4 G_STR_ID_ANT_STR(MAX_NUM_STR) ! Antares string identifier
      INTEGER*4 G_STR_NUM_CLS(MAX_NUM_STR) ! actual # of cls in this string

      COMMON /G_STR/G_STR_X,G_STR_HHT,G_STR_RAD_CYL,G_STR_RAD_SPH,
     &              G_STR_ID_ANT_STR,G_STR_NUM_CLS

C     RECORD /CLUSTER_MODEL/ CLS(MAX_NUM_CLS) ! Maximum clusters in string

! Location of cluster
      REAL*4    G_STR_CLS_X(3,MAX_NUM_CLS,MAX_NUM_STR)		
! Half-height of clust. encl. cylinder
      REAL*4    G_STR_CLS_HHT(MAX_NUM_CLS,MAX_NUM_STR)		
! Radius of cluster enclosing cylinder
      REAL*4    G_STR_CLS_RAD_CYL(MAX_NUM_CLS,MAX_NUM_STR)		
! Radius of cluster enclosing sphere
      REAL*4    G_STR_CLS_RAD_SPH(MAX_NUM_CLS,MAX_NUM_STR)		
! Antares Cluster identifier
      INTEGER*4 G_STR_CLS_ID_ANT_CLS(MAX_NUM_CLS,MAX_NUM_STR)        
! Antares string identifier
      INTEGER*4 G_STR_CLS_ID_ANT_STR(MAX_NUM_CLS,MAX_NUM_STR)        
! Actual # OMs in this cluster
      INTEGER*4 G_STR_CLS_NUM_OMS(MAX_NUM_CLS,MAX_NUM_STR)		

      COMMON /G_STR_CLS/ G_STR_CLS_X, G_STR_CLS_HHT, G_STR_CLS_RAD_CYL,
     &                   G_STR_CLS_RAD_SPH, G_STR_CLS_ID_ANT_CLS,
     &                   G_STR_CLS_ID_ANT_STR, G_STR_CLS_NUM_OMS

C     RECORD /OM_CLUSTER_MODEL/ OM(MAX_NUM_OMS_CLS) ! Max. # of OMs in cluster

! OM ID # (used by KM3 in g.om array)
      INTEGER*4 G_STR_CLS_OM_ID_KM3(MAX_NUM_OMS_CLS,MAX_NUM_CLS,
     &                              MAX_NUM_STR)
! Location of OM
      REAL*4    G_STR_CLS_OM_X(3,MAX_NUM_OMS_CLS,MAX_NUM_CLS,
     &                         MAX_NUM_STR)

      COMMON /G_STR_CLS_OM/G_STR_CLS_OM_ID_KM3,G_STR_CLS_OM_X

C	END STRUCTURE
c
c  Particle structure

C	STRUCTURE /PARTICLE/

      INTEGER*4 P_PART_ID(MAX_PART)		! Particle type (GEANT)
      INTEGER*4 P_IPARENT(MAX_PART)		! Parent particle number
      INTEGER*4 P_TRACK_ID(MAX_PART)          ! Particle number
      INTEGER*4 P_EFF_SEG(MAX_PART)          ! effective segment number
      REAL*4    P_X0(3,MAX_PART)		! Particle vertex at creation
      REAL*4    P_V0(3,MAX_PART)		! Direction vector at creation
      REAL*4    P_T0(MAX_PART)		! Relative start time (to TSTART)
      REAL*4    P_E0(MAX_PART)		! Initial energy
      REAL*4    P_X_END(3,MAX_PART)		! Particle vertex at end
      REAL*4    P_V_END(3,MAX_PART)		! Direction vector at end
      REAL*4    P_T_END(MAX_PART)		! Relative end time (to TSTART)
      REAL*4    P_E_END(MAX_PART)		! Final energy at end
      REAL*4    P_DIR(3,MAX_PART)          ! direction vector from X0 to X_END
      REAL*4    P_LENGTH(MAX_PART)         ! distance from X0 to X_END
      INTEGER*4 P_NSEGS(MAX_PART)       ! number of segments (for muons only)
      INTEGER*4 P_OUTCOME(MAX_PART)      ! 0 = cut (outside KM3), 
					! 1 = stop   in KM3 (muons)
					! 1 = shower in KM3 (non-muons), 
					! 2 = passed through KM3 (muons only)
					! 3 = decay-in-flight (muons only)

      COMMON /P/P_PART_ID,P_IPARENT,P_TRACK_ID,P_X0,P_V0,P_T0,P_E0,
     &          P_X_END,P_V_END,P_T_END,P_E_END,P_DIR,P_LENGTH,P_NSEGS,
     &          P_OUTCOME, P_EFF_SEG

C	END STRUCTURE
c
c  Segment structure

C	STRUCTURE /SEGMENT/

      REAL*4    SEG_POS_START(3,MAX_SEGS)  ! location of muon at segment start
      REAL*4    SEG_POS_CENTER(3,MAX_SEGS) ! location of muon at segment center
      REAL*4    SEG_DIR_START(3,MAX_SEGS)  ! direction of muon at segment start
      REAL*4    SEG_DIR_CENTER(3,MAX_SEGS) ! direction of muon at segment start
      REAL*4    SEG_E_START(MAX_SEGS)       ! energy of muon at segment start
      REAL*4    SEG_T_START(MAX_SEGS)	   ! time of muon at segment start
      REAL*4    SEG_T_CENTER(MAX_SEGS)	   ! time of muon at segment center
      REAL*4    SEG_LENGTH(MAX_SEGS)        ! step length for this segment
      REAL*4    SEG_TOTAL_E_LOSS(MAX_SEGS)  ! total energy loss in this segment
      REAL*4    SEG_ION_E_LOSS(MAX_SEGS)    ! ion. energy loss in this segment
      REAL*4    SEG_ION_E_LOSS_3(MAX_SEGS)  
C                                        ion. energy loss averaged over 3 segs.
      REAL*4    SEG_ION_E_LOSS_9(MAX_SEGS)  
C                                        ion. energy loss averaged over 9 segs.
      REAL*4    SEG_ION_E_LOSS_27(MAX_SEGS) 
C                                        ion. energy loss averaged ovr 27 segs.

      COMMON /SEG/SEG_POS_START,SEG_POS_CENTER,SEG_DIR_START,
     &            SEG_DIR_CENTER,SEG_E_START,SEG_T_START,SEG_T_CENTER,
     &            SEG_LENGTH,SEG_TOTAL_E_LOSS,SEG_ION_E_LOSS,
     &            SEG_ION_E_LOSS_3,SEG_ION_E_LOSS_9,SEG_ION_E_LOSS_27

C	END STRUCTURE
c
c  Hit structure

C	STRUCTURE /HIT_BUFFER/

	    INTEGER*4 HIT_IPMT(MAX_HITS)	! PMT number of this hit
	    REAL*4    HIT_THIT(MAX_HITS)	! Arrival time of p.e.s
	    REAL*4    HIT_QHIT(MAX_HITS)	! Number of p.e.s
c	    INTEGER*4 HIT_IPARN(MAX_HITS)	! Particle # making this hit
c	    INTEGER*4 HIT_IPHTY(MAX_HITS)   ! Photon type making hit (0=direct,
                                          ! 1 = scattered
c      	    INTEGER*4 HIT_SEG(MAX_HITS)
c      COMMON /HIT/HIT_IPMT,HIT_THIT,HIT_QHIT,HIT_IPARN,HIT_IPHTY,HIT_SEG
      COMMON /HIT/HIT_IPMT,HIT_THIT,HIT_QHIT
C	END STRUCTURE

c
c  Define constants

C	STRUCTURE /CONSTANTS/

	    REAL*4 C_PI     
	    REAL*4 C_C_MPNS 	! Speed of light (M/nS)
	    INTEGER*4 C_LARGE_INTEGER 
	    REAL*4 C_LARGE_REAL 
	    REAL*4 C_SMALL_REAL 

      COMMON /C/C_PI,C_C_MPNS,C_LARGE_INTEGER,C_LARGE_REAL,C_SMALL_REAL

C	END STRUCTURE
c
c  Particle IDs

C	STRUCTURE /PART_IDS/

	    INTEGER*4 P_ID_LASER    
	    INTEGER*4 P_ID_PHOTON    
	    INTEGER*4 P_ID_ELECTRON 
	    INTEGER*4 P_ID_MUON      
	    INTEGER*4 P_ID_NU
	    INTEGER*4 P_ID_TAU      

      COMMON /P_ID/P_ID_LASER,P_ID_PHOTON,P_ID_ELECTRON,P_ID_MUON,
     &             P_ID_NU, P_ID_TAU

C	END STRUCTURE

c
c  I/O Structure

C	STRUCTURE /IO_VARS/		! All I/O variables

c  - unit numbers
      INTEGER*4 IO_UNLOG	   	! Unit number for LOG file
      INTEGER*4 IO_UNCNT	   	! Unit number for CNT file
      INTEGER*4 IO_UN_MUON_DESC 	! Unit number for muon desc file
      INTEGER*4 IO_UN_MUON_RZ   	! Unit number for muon rz file
      INTEGER*4 IO_UN_ELEC_DESC 	! Unit number for muon desc file
      INTEGER*4 IO_UN_ELEC_RZ   	! Unit number for muon rz file
      INTEGER*4 IO_UN_OUT	   	! Unit number for OUT file
      INTEGER*4 IO_UNGEO	   	! Unit number for GEO file
      INTEGER*4 IO_UNEVENT	        ! Unit number for EVENT file
      INTEGER*4 IO_UN_EVT_RZOUT      ! Unit number for per event ntuple
      INTEGER*4 IO_UN_SEG_RZOUT      ! Unit number for muon segment ntuple
      INTEGER*4 IO_UN_ERROR_LOG      ! Unit number for error log          
      INTEGER*4 IO_UN_PHOTON_DESC    ! Unit number for photon desc file
      INTEGER*4 IO_UN_PHOTON_RZ      ! Unit number for photon rz file
      INTEGER*4 IO_UN_DISPERSION_RZ      ! Unit number for dispersion file
      CHARACTER*400 IO_LOGFILE	! Log file name
      CHARACTER*400 IO_CNTFILE	! Control file name
      CHARACTER*400 IO_MUON_DESC_FILE	! Input muon desc file name
      CHARACTER*400 IO_MUON_RZ_FILE	! Input muon RZ (hbook) file name
      CHARACTER*400 IO_ELEC_DESC_FILE(MAX_ENERGY) !Input elec desc filename
      CHARACTER*400 IO_ELEC_RZ_FILE(MAX_ENERGY)   ! Input elec RZ filename
      CHARACTER*400 IO_OUT_FILE	! Output file name
      CHARACTER*400 IO_GEOM_FILE	! Geometry file name
      CHARACTER*400 IO_EVENT_FILE	! EVENT input file name
      CHARACTER*400 IO_NT_EVT_FILE   ! File name for per event ntuple file
      CHARACTER*400 IO_NT_SEG_FILE   ! File name for segment ntuple file
      CHARACTER*400  IO_ERROR_LOG_FILE 
      CHARACTER*400 IO_PHOTON_DESC_FILE ! Input photon desc filename
      CHARACTER*400 IO_PHOTON_RZ_FILE   ! Input photon  RZ  filename
c      CHARACTER*400 IO_DISPERSION_RZ_FILE ! Dispersion histogram file
      
      
      COMMON /IO/IO_UNLOG,IO_UNCNT,IO_UN_MUON_DESC,IO_UN_MUON_RZ,
     &           IO_UN_ELEC_DESC,IO_UN_ELEC_RZ,IO_UN_OUT,
     &           IO_UNGEO,IO_UNEVENT,IO_UN_EVT_RZOUT,IO_UN_SEG_RZOUT,
     &           IO_UN_ERROR_LOG,IO_UN_PHOTON_DESC,IO_UN_PHOTON_RZ,
     &           IO_UN_DISPERSION_RZ

      COMMON /CIO/IO_LOGFILE,IO_CNTFILE,IO_MUON_DESC_FILE,
     &            IO_MUON_RZ_FILE,IO_ELEC_DESC_FILE,IO_ELEC_RZ_FILE,
     &            IO_OUT_FILE,IO_GEOM_FILE,IO_EVENT_FILE,
     &            IO_NT_EVT_FILE,IO_NT_SEG_FILE,IO_ERROR_LOG_FILE,
     &            IO_PHOTON_DESC_FILE,IO_PHOTON_RZ_FILE
c     &            IO_DISPERSION_RZ_FILE

cwj Adding block to contain the files for muon data
      CHARACTER*400 M_eloss_file ! File for muon energy loss
      CHARACTER*400 M_double_diff_file ! File for muon double differential cross-sections
      CHARACTER*400 M_xsection_file ! file for standard cross-sectional information
      COMMON/Mfiles/M_eloss_file, M_double_diff_file, M_xsection_file
      
C	END STRUCTURE

C	RECORD /    HEADER/ H			! Header buffer
C	RECORD / GENERATOR/ GEN			! Generator buffer
C	RECORD /  GEOMETRY/ G			! Geometry buffer
C	RECORD /  PARTICLE/ P   (MAX_PART)	! Particle buffer
C	RECORD /   SEGMENT/ SEG (MAX_SEGS)	! Segment buffer
C	RECORD /HIT_BUFFER/ HIT (MAX_HITS)	! Hit buffer
C	RECORD / CONSTANTS/ C			! Constants
C	RECORD /  PART_IDS/ p_id		! Particle IDs
C	RECORD /   IO_VARS/ IO			! IO variables
C        RECORD /  muon_dir/ mu_dir              ! direct photons from muon
C        RECORD /  muon_sca/ mu_sca              ! scatterd photons from muon
C        RECORD /  elec_dir/ el_dir              ! direct photons from electron
C        RECORD /  elec_sca/ el_sca              ! scatterd photons from elec.
C        RECORD /  photon_dir/ phot_dir ! direct photons from LASER flash.
C        RECORD /  photon_sca/ phot_sca ! scatterd photons from LASER flash.

c  Common block

C	COMMON /KM3/ H, GEN, G, P, SEG, HIT, C, p_ID, IO, mu_dir,
C     1               mu_sca, el_dir, el_sca, phot_dir, phot_sca

        INTEGER       NLINES
	REAL          TMINH, TMAXH
	COMMON /EVT_LINES/ NLINES, TMINH, TMAXH
*
* Description:
*
* NLINES = number of lines in the .ant file (updated for each event)
* TMINH   = for a given event, TMINH is the time of the earliest hit
* TMAXH   =     "              TMAXH      "             lastest  hit
*   (hits comming from K40 are not included in the computation of TMINH,TMAXH !)

        INTEGER*4     IK40(2), JGAIN, JEMPT, ISEED(4), INTPOL
	REAL*4        TMERG
        INTEGER       TRAWH(3), TNGRP, USENEW
        LOGICAL       PHDIR, PHSCA
        CHARACTER*9   EVT_TYPE(3)
        COMMON /PROC/
     &  TMERG, TRAWH, TNGRP,
     &  IK40, JGAIN, JEMPT, ISEED, INTPOL,
     &  USENEW, PHDIR, PHSCA, EVT_TYPE

*
* Water model details ( from "gen.f" )

        REAL          LUZ, LABS, LSCAT, ALPHA, COSME1, COSME2, ETA
        CHARACTER*6   WATMOD
        COMMON /WA_MODEL/LUZ,LABS,LSCAT,ALPHA,COSME1,COSME2,ETA,WATMOD



**************** Includes from only 'phomul.inc' file ***************

      INTEGER NPHOMU       !  actuell number of PMs
      INTEGER IDPM(MAX_NUM_OMS_DET) !  list of PM identifiers
      INTEGER IDCLS(MAX_NUM_OMS_DET)!  list of cluster identifiers
      INTEGER IDSTR(MAX_NUM_OMS_DET)!  list of string identifiers
      INTEGER IDPMTYP(MAX_NUM_OMS_DET)! list of PM types
      REAL VPM(3,MAX_NUM_OMS_DET)   !  list of vertex positions of PM (cm)
      REAL DPM(3,MAX_NUM_OMS_DET)   !  list of unit vectors of PM oriantation
      REAL OFFTIM(MAX_NUM_OMS_DET)  !  list of PM time offsets (ns)
      REAL OFFAMP(MAX_NUM_OMS_DET)  !  list of PM amplitude offsets (pe)
      REAL OFFEFF(MAX_NUM_OMS_DET)  !  list of efficiency factors
      COMMON/PHOMUL/ NPHOMU,IDPM,IDCLS,IDSTR,IDPMTYP,VPM,DPM,
     +               OFFTIM,OFFAMP,OFFEFF
C

      INTEGER NPHCLU       ! actuell number of PMs in cluster
      INTEGER IDCLU(MAX_NUM_OMS_CLS)! list of PM identifiers in cluster
      REAL VCLU(3,MAX_NUM_OMS_CLS)  ! list of PM positions in cluster (cm)
      REAL THETCLU(MAX_NUM_OMS_CLS) ! list of declination angles (rad)
      REAL AZICLU(MAX_NUM_OMS_CLS)  ! list of azimuth angles (rad)
      COMMON/PHOCLU/ NPHCLU,IDCLU,VCLU,THETCLU,AZICLU
C

      INTEGER NSTR         ! actuell number of strings
      INTEGER NCLU         ! actuell number of clusters
      INTEGER ICLU(MAX_NUM_CLS) ! list of cluster identifier
      INTEGER ISTRCL(MAX_NUM_CLS)! list of string idenitfiers in clusters
      REAL VCENCL(3,MAX_NUM_CLS)! list of cluster center positions
      REAL EULECL(3,MAX_NUM_CLS)! list of Euler angles for cluster
      INTEGER IPMCL(MAX_NUM_OMS_CLS,MAX_NUM_CLS)! list of PM ids in the cluster
      COMMON /CLULIS/ NCLU,ICLU,ISTRCL,IPMCL,NSTR,VCENCL,EULECL
C
      INTEGER MAXTYP       ! maximal number of PM-types
      PARAMETER(MAXTYP=4)  ! 
      INTEGER NTYP         ! actuell number of PM-types
      INTEGER IDTYP(MAXTYP)! list of type ids
      REAL AEFTYP(MAXTYP)  ! list of OM effective areas (cm^2)
      REAL TTSTYP(MAXTYP)  ! list of PM tts (sigma/nsec)
      COMMON /PHOTYP/ NTYP,IDTYP,AEFTYP,TTSTYP
      
c      common to hold tau-related parameters
c     arrays are only needed for the decay and restlife variables -
c        the others are calculated on the fly
      INTEGER TAU_DECAY(MAX_PART)	! integer decay identifier
      INTEGER TAU_NSEG	      ! number of track segments
      REAL TAU_RESTLIFE(MAX_PART) ! rest lifetime of the tau
      REAL TAU_SEALIFE  ! lifetime in our frame
      REAL TAU_MASS ! mass of tau in GeV
      REAL TAU_GAMMA ! calculates tau gamma-factor
      REAL TAU_DISTANCE	! real distance tau travels before decay
      REAL TAU_ELOSS ! eloss per m of tau (assumed)
      REAL TAU_RSEG ! remainding segment
      COMMON /TAU/TAU_DECAY, TAU_RESTLIFE, TAU_DISTANCE,
     & TAU_SEALIFE, TAU_GAMMA, TAU_NSEG, TAU_RSEG, TAU_ELOSS
