#! /bin/bash

########## standard options - user should read this! ############
# global options - changes these as appropriate
USER=cjames
PLATFORM=LINUX
KM3_V=v5r0
KM3DIR=/sps/km3net/users/${USER}/km3
HITEXEC=$KM3DIR/$PLATFORM/hit$KM3_V.exe

### PMT FILE ###
# sets the PMT file to that for ANTARES
export PMTFILE=${KM3DIR}/dat/hit-antares_pmt.dat
# sets the PMT file to the latest from km3net/ORCA
# PMTFILE=/sps/km3net/users/cjames/v5r0/dat/hit-km3net_pmt_july13.dat

# use this if you want to tag your hit files
HITTAG=''

# the user can stop reading... now!

######### checking everything is OK #######

if [ ! -d ${KM3DIR} ]
then
	echo "Directory $KM3DIR does not exist - have you specified the correct user (= ${USER} ) and directory ( = ${KM3DIR} )?"
	exit
fi

if [ ! -f "$PMTFILE" ]
then
   echo "Error: pmtfile ${PMTFILE} not readable"
   exit
fi

# hit executable
HITEXE=${KM3DIR}/${PLATFORM}/hit${KM3_V}.exe
if [ ! -f "$HITEXE" ]
then
   echo "Error: hit executable ${HITEXE} not readable"
   exit
fi

# directory containing scripts (i.e. here!)
SCRIPT_DIR=${KM3DIR}/scripts

##### muon table ######

# environment variables specific to this table: set FILEROOT to the name of your gen outputs!
FILEROOT=muon-100gev_${KM3_V}
INPUTDIR=${SCRIPT_DIR}/muon_100gev
export GENDESC=${INPUTDIR}/${FILEROOT}.desc
export HITDESC=${OUTPUTDIR}/km3-${HITTAG}${FILEROOT}.desc
export HITHBOOK=${OUTPUTDIR}/km3-${HITTAG}${FILEROOT}.hit

if [ ! -f "$GENDESC" ]
then
   echo "Error: gen descriptor file ${GENDESC} not readable"
   exit
fi

${HITEXEC} <<EOF
HDIR 0.001      
HETH 0.30       
HMBD 0.05       
BNUM 20    20   
BELO 0.45 0.45 
BEHI 0.45 0.45  
HOMT 40    20    
HOMP 1     12
HNOT 100   100
END
EOF

##### 100 gev electron table ######

# environment variables specific to this table
FILEROOT=elec-100gev_${KM3_V}
INPUTDIR=${SCRIPT_DIR}/elec_100gev
export GENDESC=${INPUTDIR}/${FILEROOT}.desc
export HITDESC=${OUTPUTDIR}/km3-${HITTAG}${FILEROOT}.desc
export HITHBOOK=${OUTPUTDIR}/km3-${HITTAG}${FILEROOT}.hit

if [ ! -f "$GENDESC" ]
then
   echo "Error: gen descriptor file ${GENDESC} not readable"
   exit
fi

${HITEXEC} <<EOF
HDIR 0.001      
HETH 0.30       
HMBD 0.05       
BNUM 20    20   
BELO 0.45 0.45 
BEHI 0.45 0.45  
HOMT 40    20    
HOMP 1     12
HNOT 100   100
END
EOF

##### 10 gev electron table ######

# environment variables specific to this table
FILEROOT=elec-10gev_${KM3_V}
INPUTDIR=${SCRIPT_DIR}/elec_10gev
export GENDESC=${INPUTDIR}/${FILEROOT}.desc
export HITDESC=${OUTPUTDIR}/km3-${HITTAG}${FILEROOT}.desc
export HITHBOOK=${OUTPUTDIR}/km3-${HITTAG}${FILEROOT}.hit

if [ ! -f "$GENDESC" ]
then
   echo "Error: gen descriptor file ${GENDESC} not readable"
   exit
fi

${HITEXEC} <<EOF
HDIR 0.001      
HETH 0.30       
HMBD 0.05       
BNUM 20    20   
BELO 0.45 0.45 
BEHI 0.45 0.45  
HOMT 40    20    
HOMP 1     12
HNOT 100   100
END
EOF

##### 1 gev electron table ######

# environment variables specific to this table
FILEROOT=elec-1gev_${KM3_V}
INPUTDIR=${SCRIPT_DIR}/elec_1gev
export GENDESC=${INPUTDIR}/${FILEROOT}.desc
export HITDESC=${OUTPUTDIR}/km3-${HITTAG}${FILEROOT}.desc
export HITHBOOK=${OUTPUTDIR}/km3-${HITTAG}${FILEROOT}.hit

if [ ! -f "$GENDESC" ]
then
   echo "Error: gen descriptor file ${GENDESC} not readable"
   exit
fi

${HITEXEC} <<EOF
HDIR 0.001      
HETH 0.30       
HMBD 0.05       
BNUM 20    20   
BELO 0.45 0.45 
BEHI 0.45 0.45  
HOMT 40    20    
HOMP 1     12
HNOT 100   100
END
EOF

##### 100 mev electron table ######

# environment variables specific to this table
FILEROOT=elec-100mev_${KM3_V}
INPUTDIR=${SCRIPT_DIR}/elec_100mev
export GENDESC=${INPUTDIR}/${FILEROOT}.desc
export HITDESC=${OUTPUTDIR}/km3-${HITTAG}${FILEROOT}.desc
export HITHBOOK=${OUTPUTDIR}/km3-${HITTAG}${FILEROOT}.hit

if [ ! -f "$GENDESC" ]
then
   echo "Error: gen descriptor file ${GENDESC} not readable"
   exit
fi

${HITEXEC} <<EOF
HDIR 0.001      
HETH 0.30       
HMBD 0.05       
BNUM 20    20   
BELO 0.45 0.45 
BEHI 0.45 0.45  
HOMT 40    20    
HOMP 1     12
HNOT 100   100
END
EOF

echo 'IF THIS FAILED, RUN IT FROM THE SAME DIRECTORY AS THE DESC FILE!'
