C* Original author: Martin Moorhead<BR>
C* Original date: 22 March 1996<BR>
C* Modified date: 18 July 1996<BR>
C*
C* Tracks the photon to the boundary point of a given region.
C* The parameters abs_dist, P_length and scat_dist are updated to reflect 
C* the distance travelled. The timing, location and direction of the photon
C* at the region boundary is recorded onto the photon ntuple. Tracking 
C* is actually done a little beyond the boundary to avoid round-off errors
C* and the photon re-interecting the same boundary.
C* 
C* @param bound_dist Input. Distance to the boundary from the current point
C* @param new_reg Input. Region number on the other side of the boundary
C* @param abs_dist Distance to the point of absorption from the current
C*        point. Updated internally to take account of the distance travelled.
C* @param scat_dist Distance to the next scattering from the current point.
C*        Updated internally to take account of the distance travelled.
C*
C* @warning UNVERIFIED
C*/ 

      SUBROUTINE cross_boundary(bound_dist,new_reg,scat_dist)

      include 'gen-geant.inc'
      include 'gen.inc'
      include 'gen-hit-ntuple.inc'
            
      INTEGER*4 new_reg, i, j
      REAL*8  scat_dist, bound_dist, dist, shell_rad
      REAL*8 ran1
C--- track photon to boundary point (+ little bit extra for safety)

      dist = bound_dist + c_eps 

      do i = 1,3
         P_pos(i) = P_pos(i) + dist * P_dir(i)
      enddo
C
C--- update scat_dist and P_length 

      scat_dist = scat_dist - dist
      P_length  = P_length  + dist
C--- calculate the probability that the photon has not been absorbed
      P_logwgt = -P_length/P_abs_dist 

C--- find the shell number.
C--- It is used to sort out different OM hit distributions.
C
      if (P_reg .gt. new_reg ) then
         hit_shell = new_reg
         shell_rad = r_rad_out(new_reg)
      else
         hit_shell = P_reg
         shell_rad = r_rad_out(P_reg)     
      endif
C
C--- calculate the hit time
C--- time = pathlength/speed + time of track segment that produced this photon
C--- - time from particle starting point to shell center
        hit_time = P_length * dble(gpindex) / c_speed + tofg*1.e9
     *             - track_length/2/c_speed

C--- hit position, direction
C
	do i=1,3
		hit_pos(i)=P_pos(i)
		hit_dir(i)=P_dir(i)
	end do
C
C--- Fill ntuples
C
        xtup(1)=hit_time			! Hit time
        xtupscat=P_nscat			! Number of scatters
        do j=1,3
                xtup(1+j)=hit_pos(j)		! Position, direction
                xtup(4+j)=hit_dir(j)
        end do
	xtup(8)= P_wlen 		        ! Wavelength (nm)
c	xtup(10) = hit_shell			! Shell bin
c	xtup(11) = shell_rad			! Radius of shell (m)
        xtup(9) = P_logwgt     	             	! log of P(still exists)
C
C--- Other histograms
C Just counts the number of scattered vs direct photons
	counts_etot(hit_shell)=counts_etot(hit_shell)+1 !number of photons vs radius
	if(P_nscat.lt.0.5 ) then
		counts_edir(hit_shell) = counts_edir(hit_shell)+1 ! Direct light
	else
		counts_esca(hit_shell) = counts_esca(hit_shell)+1 ! Scattered light
	end if
C
C--- Fill photon ntuple if appropriate
C
	randomnumber=ran1(in_seed)
      if(i_phot_write.ne.0) then
      	 
	 if(P_nscat.eq.0.and.
	1	randomnumber.lt.r_scale_dir(hit_shell)) then
      	    counts_ewrit=counts_ewrit+1
	    counts_ewdir(hit_shell)=counts_ewdir(hit_shell)+1
      	    if (i_part_type.eq.5.or.i_part_type.eq.6) then
c              write to temporary file - also the hit shell id
      	       write(lun_nt,rec=counts_ewrit)
     &	             	 (xtup(i),i=1,ntuplen), xtupscat, hit_shell
      	    else
c              write to radial bin file	
      	       counts_tot(hit_shell)=counts_tot(hit_shell)+1
      	       write(outids(hit_shell),rec=counts_tot(hit_shell))
     &             	 (xtup(i),i=1,ntuplen), xtupscat
	    endif
      	 
	 else if (P_nscat.ne.0.and.
     &	       randomnumber.lt.r_scale_sca(hit_shell)) then
      	    counts_ewrit=counts_ewrit+1
	    counts_ewsca(hit_shell) = counts_ewsca(hit_shell)+1
	    if (i_part_type.eq.5.or.i_part_type.eq.6) then
c              write to temporary file
	       write(lun_nt,rec=counts_ewrit) (xtup(i),i=1,ntuplen),
     &               	xtupscat, hit_shell
	    else
c	       write to radial bin file	
      	       counts_tot(hit_shell)=counts_tot(hit_shell)+1
	       if (hit_shell.lt.1.or.hit_shell.gt.in_nregions) then
	          write(*,*) 'hit shell ',hit_shell,' wrong number'
	       endif
      	       write(outids(hit_shell),rec=counts_tot(hit_shell))
     &             	(xtup(i),i=1,ntuplen), xtupscat
	    endif
	 end if
      end if
C
C--- update the region number
C
	P_reg = new_reg
        
	return
      end
