C* Original author: Martin Moorhead<BR>
C* Original date: 21 March 1996<BR>
C*
C* Find the distance from a specified point in a given direction to the 
C* closest boundary for the current region.
C* The starting point (P_pos) and direction (P_dir) are used to calculate the
C* distance and the identifier of the next region.
C*
C* This routine assumes that the current region is bounded by two concentric
C* spheres. If the photon intersects the inner sphere, then this gives the 
C* closest boundary. Otherwise, the outer sphere gives the closest boundary.
C*
C* @param dist Output. The distance to the boundary of this region
C* @param new_region Output. The number of the region on the other side of the
C*        boundary.
C*
C* @warning UNVERIFIED
C*/

      SUBROUTINE distance_to_boundary( dist, new_region )
 
      include 'gen-geant.inc'
      include 'gen.inc'
      include 'gen-hit-ntuple.inc'

      INTEGER*4 new_region, flag
      REAL*8    dist
C
C--- first test to see if photon intersects the inner sphere (as long as the
C--- inner sphere exists!) 
CWJ - c_eps used to be 0.1 - but perhaps we will want spheres smaller than this???
C
      if ( r_rad_in(P_reg)   .gt.  c_eps ) then

cwj *** Not that P_scaling will be set to 1.0 if it is not used
      	 if (CYLINDER .eq. 1) then
      	    call distance_to_cylinder( P_pos, P_dir, 
     &               r_rad_in(P_reg)*p_scaling, dist, flag )
      	 else
      	    call distance_to_sphere( P_pos, P_dir, 
     &               r_rad_in(P_reg)*p_scaling, dist, flag )
      	 endif

      	 if ( flag .eq. 1 ) then
C--- the photon has intersected the inner sphere/cylinder
      	 new_region = P_reg - 1
            return

      	 endif

      endif
C
C--- now test the outer sphere/cylinder, since the inner one has been missed.
C
      if (CYLINDER .eq. 1) then
      	 call distance_to_cylinder( P_pos, P_dir, 
     &               r_rad_out(P_reg)*pscaling, dist, flag )
      else
      	 call distance_to_sphere( P_pos, P_dir, 
     &               r_rad_out(P_reg)*p_scaling, dist, flag )
      endif
      
      if ( flag .eq. 1 ) then
      	 new_region = P_reg + 1
      else
C
C--- sometimes the photon may also cross the next sphere
C--- this is due to p_scaling, and the photon not being exactly where
C--- we think it is
C	    
      	 p_reg = p_reg + 1
      	 if (CYLINDER .eq. 1) then
      	    call distance_to_cylinder( P_pos, P_dir, 
     &               r_rad_out(P_reg)*pscaling, dist, flag )
      	 else
      	    call distance_to_sphere( P_pos, P_dir, 
     &               r_rad_out(P_reg)*p_scaling, dist, flag )
      	 endif

      	 if ( flag .eq. 1 ) then
      	    new_region = P_reg + 1
      	 else
      	    new_region = P_reg + 2
      	 endif
      
      endif

      end
