C* Original author: Clancy W James
C* Original date: 20 March 2012
C*
C*  In :   xlambda = photon wave-length (in nanometers)                  
C*  Out:   fraction of Rayleigh scattering at this wavelength               
C*
C* Use the Kopelevich model for spectral volume scattering functions     
C* The model separates the contributions by:                             
C* - pure_sea: pure sea water                                            
C* - small_par: 'small' particles (size < 1 micro meter)                 
C* - large_par: 'large' particles (size > 1 micro meter)                 
C* (see C.D.Mobley 'Light and Water' ISBN 0-12-502750-8 pag.119)         
C* C*
C* The two parameters specifying the model are:
C* - Vs is the volume concentration of small particles with units of cm3 of 
C* particles per m3 of water
C* - Vl is the analogous volume concentration of large particles
C*/

      REAL FUNCTION KOPELEVICH_ETA(xlambda)
      
      REAL   Vs, Vl, pure_sea, small_par, large_par
      REAL*8 xlambda
      REAL eta

c     number densities of small and large particles
      Vs= 0.0075
      Vl= 0.0075
      pure_sea  = 0.0017*      (550./xlambda)**4.3
      small_par = 1.340 * Vs * (550./xlambda)**1.7
      large_par = 0.312 * Vl * (550./xlambda)**0.3
      
      
      kopelevich_eta = pure_sea/(pure_sea + small_par + large_par)

 999  CONTINUE
      END
