C*/
        SUBROUTINE MOBLEY
*************************************************************************
*                                                                       *
*     Name           :  Mobley                                          *
*     Date           :  03-Nov-1999                                     *
*     Task           :                                                  *
*                                                                       *
*        Volume scattering function                                     *
*                                                                       *
*  Contact people:                                                      *
*      Juan Zuniga     zuniga@uv.es                                     *
*     Sergio Navas     navas@cppm.in2p3.fr                              *
*************************************************************************
	include 'gen-water.inc'
        include 'gen.inc'
	real*8 pi, water_scat, total_scat, part_beta_1

	write(*,*)
	1    '** MOBLEY routine: compute volume scattering function'

        pi = acos(-1.d0)
*-------------------------------------------------------------------------
*  Scattering by Particles
*-------------------------------------------------------------------------
*
* Convert to radians part_ang and
* normalize part_beta according to 3.8 (Light and Water, Mobley)
* 
c      this value is needed for a later calculation
      part_beta_1=part_beta(1)
      
        do i=1, ndat_beta
         part_rad(i) = part_ang(i)*pi/180.d0     
         part_beta(i) = 2.d0*pi*part_beta(i)*sin(part_rad(i))
        enddo
*
*  We now assume that the for 'small' values of part_rad,
*  beta goes as theta**m for m = -1.346

* The cumulative probability distribution is then expressed as:
* int 2 pi sin theta beta(theta_0) (theta/theta_0)^-1.346 dtheta
* from 0 to theta_0 is ~(2pi * beta(theta_0) * theta_0^2/0.654)
* in the limit that theta_0 is small

* Since the normal integration uses a trapezoidal rule to calculate
* the cumulative probability density function, and this method fails
* utterly at small theta, this result is first inserted by hand:
*
      part_acu(1) = (2.*pi/0.654)*part_beta_1*part_rad(1)**2
      
* From here on, part_rad(0) is only used to calculate a mean value
* of the scattering angle in the first bracket. The correct mean
* angle can be found by using the aforementioned integrand, multiplied by theta:
* int 2 pi sin theta beta(theta_0) (theta/theta_0)^-1.346 theta dtheta
* and dividing by the part_acu(1), giving something like
* theta_bar = 6.9e-4 for the first angular 'bin'
* using a part_rad(0) of 0. gives a high mean of 8.7e-4; nonetheless,
* we do not want to use negative angles! Thus, the part_rad(0) is set
* at 0, and part_beta(0) is left undefined
*
      part_rad(0) = 0.
*
* Integrate rest of angular distribution via trapezoidal rule
* int = h*(f0+f1)/2
      do i=2,ndat_beta
         part_acu(i) = part_acu(i-1) + (part_rad(i)-part_rad(i-1))*
     &              (part_beta(i)+part_beta(i-1))/2. 

      enddo
*
* Normalize
*
      
      do i=1,ndat_beta
        part_acu(i) = part_acu(i)/part_acu(ndat_beta)
      enddo

*  If eta is being derived from data, calculate tabulated values
      if (WL_SCAT_METH .eq. 2) then
      	 write(*,*) 'WLEN    ETA'
      	 do i=1,in_nwavelens
* Fraction of scattering off water molecules is ~'known'
* This computers eta from the remaining amount of scattering
	    water_scat = 0.0017*(550./in_wlen(i))**4.3
      	    total_scat = 1./in_l_scat(i)
	    tab_eta(i) = water_scat/total_scat
	    write(*,*) in_wlen(i), tab_eta(i)
	  enddo
      endif
      
      return
      end

