C* Original author:  M. Moorhead<BR>
C* Original date: 22 March 1996
C*
C* Propagate the photon created by subroutine GENERATE_PHOTON through
C* the volume of embedded regions, recording hit times at the region
C* boundaries, until the photon is either absorbed or escapes the outer
C* region.
C*
C* The maximum number of photon steps is given by MAX_STEPS. This is 
C* just to trap geometry errors where the photon keeps intersecting
C* the SAME boundary (due to round-off errors).
C*
C* The distance to the point of absorption for each photon is sampled once
C* from an exponential distribution with mean lambda_abs. The distance to the
C* first scattering point is sampled from an exponential distrbution with mean
C* lambda_scat. The photon is then tracked through the region boundaries,
C* resampling the scattering length and direction at each scattering until it
C* is absorbed or leaves the last region
C*
C* @param flag 1 if the maximum number of hits has been generated which means
C*        that no more photons should be propagated.
C*
C* @warning UNVERIFIED
C*/

      SUBROUTINE propagate_photon( flag )

	include 'gen-geant.inc'
	include 'gen.inc'
	include 'gen-hit-ntuple.inc'

      INTEGER*4 i, int_type, new_region, flag
      REAL*8    abs_dist, scat_dist, bound_dist
      REAL*4    ran1
      REAL      xlambda

! find the distance to the point of absorption for this particular photon
! (by sampling an exponential distribution with mean labs). This
! absorption distance is only sampled ONCE per photon
C
      call find_labs( P_wlen, abs_dist)
      P_abs_dist=abs_dist
      
! find the distance to the FIRST scattering point for this particular photon
! (by sampling an exponential distribution with mean lscat ). This
! sacttering distance is sampled again, after each scatter.

* Read scat_dist from table (.dat file)  <- Used when DIFFUSION ON
      call find_lscat( P_wlen, scat_dist)  
* -->
      scat_dist = - scat_dist * log( ran1( in_seed ) )
      
! main loop for photon propagation (max_steps is used to trap round-off
! geometry errors):

      do i = 1, c_max_steps

! call find_next_interaction, for each photon step, to see if the photon
! has been absorbed, scattred or hit a boundary.
      	 call find_next_int( scat_dist, bound_dist,
     1                       int_type, new_region )
                             
         if ( int_type .eq. 2 ) then
!--- the photon has hit a boundary

      	    if ( new_region .gt. in_nregions ) then
!--- the boundary is the outer most boundary of the volume. stop propagating
               return
            else

! the boundary is OK and we call cross_boundary, to record the hit time
! and pass the photon into the next boundary

               call cross_boundary( bound_dist, new_region, 
     1                              scat_dist )
            endif

         elseif ( int_type .eq. 3 ) then
! the photon has been scattered and we call scatter_photon to find the
! new direction and position, and the distance to the NEXT scatter  

            call scatter_photon(scat_dist )
         else
	    write(*,*) 'unknown interaction type:', int_type
	 endif
c stop propagating photon if its weight is extremely low (< 3 in 10 million)
	 if (P_logwgt .lt. MIN_LOGWGT) then
      	    return
	 endif
      enddo

! if the photon has not been absorbed, or escaped the volume, in max_steps
! then we probably have a geometrical round-off error

      print *, 'photon did not stop in max_steps !!!!'
      print *, 'probably  a round-off geometrical error'

      end
