C*/
      SUBROUTINE READ_DATACARDS
*************************************************************************
*     Name           :  READ_DATACARDS                                  *
*     Called by      :  GEN                                             *
*     Author         :  David Bailey                                    *
*     Task           :  Read user datacards from stdin via FFREAD       *
*     Date           :  04/01/01                                        *
*************************************************************************
*
      include 'gen.inc'
      include 'gen-geant.inc'
*
*      CHARACTER*6 VWATMOD(2) now in COMMON USERIN
*      INTEGER*4 ISEED        now in COMMON USERIN
      INTEGER IFFSZE, nullpos
      REAL FFWORK
      PARAMETER (IFFSZE = 1000)
      COMMON / CFREAD / FFWORK(IFFSZE)
*
      CALL FFINIT(IFFSZE)
      CALL FFSET('SIZE',10)
*
** Description:
*
*
* ISEED = Initial seed for random simulation (RANLUX)
*         Format:  ISEED=`date "+%m%d%y"`${NJOB}
*                                          ^______ NJOB is a sequential number
* ------------------------------------------------------------------
*

C D. Bailey 04/01/01
C   Define the inputs for all the data cards (GEN and GEANT) based on the 
C   original values in the script file. Mandatory inputs will be set with
C   error codes and checked later in the routine

C Input and output filenames
      OUTFILE  = ""
      LOGFILE  = ""
      WLENFILE = ""
      RADFILE  = ""
 
C Run parameters and defaults
      NTRIGGERS          = 10        
      I_PART_TYPE        = 5
      PART_PLAB          = 100.
      I_MEDIUM           = 3
      TRACK_LENGTH       = 1.
      I_TRACK_LEN_MANUAL = 0
      I_PHOT_PROP        = 1
      I_PHOT_WRITE       = 1
      I_STEPS_WRITE      = 0
      I_MUON_CKS         = 1
      IN_MAX_HITS        = 20000
      REAL_DIR_V      	 = 0
      EM_SCAT_ID     	 = 99
      WL_SCAT_METH   	 = 1
      CYLINDER       	 = 0  ! uses cylinders instead of spheres if set to 1
      IN_e_thresh       = 0.3 ! 0.3 GeV energy-loss threshold per m
C Watermodel parameters
      ISEED              = 1000
      ALPHA              = 0.
      COSME(1)           = 0.
      COSME(2)           = 0.
      ETA0               = 0.17
      MIN_LOGWGT     	 = -25

*
C D. Bailey 03/01/01
C   Read all the characted based input via environment variables and all the 
C   numerical input in through FFREAD cards. There will no longer be an
C   assumption on the order of the input.

      CALL GETENV('HBOOKFILE',outfile)
      CALL GETENV('DESCFILE',logfile)
      CALL GETENV('WLENFILE',wlenfile)
      CALL GETENV('RADFILE',radfile)

      CALL FFKEY('NEVT',NTRIGGERS,1,'INT')
      CALL FFKEY('PTYP',I_PART_TYPE,1,'INT')
      CALL FFKEY('LAMB',PART_PLAB,1,'REAL')
      CALL FFKEY('IMED',I_MEDIUM,1,'INT')
      CALL FFKEY('TLEN',TRACK_LENGTH,1,'REAL')
      CALL FFKEY('TMAN',I_TRACK_LEN_MANUAL,1,'INT')
      CALL FFKEY('PROP',I_PHOT_PROP,1,'INT')
      CALL FFKEY('PWRT',I_PHOT_WRITE,1,'INT')
      CALL FFKEY('SWRT',I_STEPS_WRITE,1,'INT')
      CALL FFKEY('MCKS',I_MUON_CKS,1,'INT')
      CALL FFKEY('SEED',ISEED,1,'INT')
      CALL FFKEY('WMOD',VWATMOD,2,'MIXED') 
      CALL FFKEY('ALPH',ALPHA,1,'REAL') 
      CALL FFKEY('COSM',COSME,2,'REAL') 
      CALL FFKEY('ETA',ETA0,1,'REAL') 
      CALL FFKEY('IHIT',IN_MAX_HITS,1,'INT')
      
c  switch to turn direct photon speed on/off
c  0 = adjust sphere radii by real velocity
c  1 = use real velocity and keep spheres the same
      CALL FFKEY('RVEL', REAL_DIR_V,1,'INT')
      
c   Code for scattered electrons (direct electron photon code)
      CALL FFKEY('ESID', EM_SCAT_ID,1,'INT')
      
c   Code for wavelength-dependence of scattering contributions
c   Used only for the 'partic' model: uses koppelevich scaling
c   of scattering fractions. Over-rides 'eta'
      CALL FFKEY('WLSC', WL_SCAT_METH,1,'INT')
      
c  use cylinders at specified radii instead of spheres
      CALL FFKEY('CYLD', CYLINDER,1,'INT')

c     Now input energy-threshold in gen
      CALL FFKEY('ETHR', IN_e_thresh,1,'REAL')

c     sets minimum logwgt at which point photons are no longer tracked
      CALL FFKEY('MLWT',MIN_LOGWGT,1,'REAL')

C Now read in all the data cards including the GEANT ones
      CALL GFFGO
*
C D. Bailey 04/01/01
C   Check that the given inputs are valid (up to a point anyway)

      WATMOD = VWATMOD(1)
      IF (WATMOD.EQ.'MODEL?') THEN
	WRITE(6,*) '** READ_DATACARDS   ERROR ! no water model !!'
        STOP
      ENDIF
      IF (ISEED.EQ.201170001) THEN
	WRITE(6,*)
	1    '!! WARNING !! Using default SEED for random generation'
      ENDIF
      in_seed = ISEED

C D. Bailey 04/01/01
C   Output the (non-GEANT) input parameters to stdout and initialize the
C   medium properties

      WRITE(6,*) '---------------------------------------------------'
      WRITE(6,*) '   User inputs for GEN'
      WRITE(6,*) '   ==================='
      WRITE(6,*) '   Generating ',NTRIGGERS,' events of particle type',
     &           I_PART_TYPE,' with momentum ',PART_PLAB,' GeV'

      IF (I_MEDIUM.EQ.1) THEN 
        N_PHASE = 1.32
        DENS_MEDIUM = 0.9
        WRITE (6,*) '   Photon propagation in ice with model ',
     &              WATMOD
      ELSEIF (I_MEDIUM.EQ.2) THEN
        N_PHASE = 1.3499
        DENS_MEDIUM = 1.0
        WRITE (6,*) '   Photon propagation in water with model ',
     &              WATMOD
      ELSEIF (I_MEDIUM.EQ.3) THEN
        N_PHASE = 1.3499
        DENS_MEDIUM = 1.039839
        WRITE (6,*) '   Photon propagation in seawater with model ',
     &              WATMOD
      ELSE
        WRITE (6,*) '** READ_DATACARDS   ERROR ! Unknown medium !!'
        STOP
      ENDIF

      WRITE(6,*) '   Absorption length from input table'

      IF (WATMOD.EQ.'medsea') THEN
        WRITE (6,*) '   Average cos(theta) = ',
     &              COSME(1), COSME(2),' with alpha = ',ALPHA
      ELSE IF (WATMOD.EQ.'partic') THEN
        WRITE (6,*) '   Eta = ',ETA0
      ELSE IF (WATMOD.EQ.'nwater') THEN
        WRITE (6,*) '   No photon scattering'
      ELSE
        WRITE (6,*) '** READ_DATACARDS   ERROR ! Unknown water model'
      ENDIF

      WRITE (6,*) '   Medium density = ',DENS_MEDIUM,
     &            ' with refractive index ',N_PHASE 

      IF (I_TRACK_LEN_MANUAL.EQ.0) THEN

        IF(I_PART_TYPE.GE.1.AND.I_PART_TYPE.LE.3) THEN	
	  TRACK_LENGTH=1.8*(1.0+log10(PART_PLAB))/DENS_MEDIUM
        ELSE IF(I_PART_TYPE.EQ.5.OR.I_PART_TYPE.EQ.6) THEN
          TRACK_LENGTH = 1.0
        ELSE
c It is more likely that a miscellaneous particle resembled an
c electromagnetic cascade than a segment of muon track
          TRACK_LENGTH=1.8*(1.0+log10(PART_PLAB))/DENS_MEDIUM
        END IF
        Z_START = -track_length/2

        WRITE (6,*) '   Track length set automatically'
        WRITE (6,*) '   Track length = ',TRACK_LENGTH,
     &              ' m starting at ',Z_START,' m'

      ELSE
        IN_E_THRESH = IN_E_THRESH*TRACK_LENGTH
        Z_START = -TRACK_LENGTH/2.
        WRITE (6,*) '   Track length set manually'
        WRITE (6,*) '   Track length = ',TRACK_LENGTH,
     &              ' m starting at ',Z_START,' m'

      ENDIF
      write(*,*) 'Muon energy-loss threshold set at ',
     &            IN_E_THRESH,' GeV per ', TRACK_LENGTH, ' m'
      
      IF (I_PHOT_PROP.EQ.1) WRITE(6,*) '   Propagating photons'
      IF (I_PHOT_WRITE.EQ.1) WRITE(6,*) '   Writing photon ntuple'
      IF (I_STEPS_WRITE.EQ.1) WRITE(6,*) '   Writing track step ntuple'
      IF (I_PART_TYPE.EQ.5.OR.I_PART_TYPE.EQ.6) THEN 
        IF (I_MUON_CKS.EQ.1) THEN
          WRITE(6,*) '   Including Cherenkov light from primary muon'
        ELSE
          WRITE(6,*) '   Ignoring Cherenkov light from primary muon'
        ENDIF
      ENDIF
      
      WRITE(6,*) '   RANDOM SEED for current job = ', in_seed
      
      WRITE(6,*) '---------------------------------------------------'
      
 999  RETURN
      END
