C*/
      SUBROUTINE scatter_photon( scat_dist )

!     Created:  22-Mar-96
!     Contact:  M. Moorhead, LBNL.
!     Verified:

!     Purpose:-
!     =============
!     Routine borrowed from Lars Bergstrom's fastcal program.
!     finds photon's new direction after scater.
!     also tracks photon to point of scatter.
!     also calculates distance to next point of scatter.   

!     In/Out Variables:-
!     ==========

!     in/out  	scat_dist  distance to point of scatter (from current point)

!     Assumptions:-
!     ===========
!     The direction of the scattered photon is calculated with a random
!     direction, biassed to have an average cosine (in the forward direction)
!     given by in_av_cos. The algortithm has been taken from Lars 
!     Bergstrom's fastcal program.

!     Revision History:-
!     ================
!     V1	M. Moorhead	Created routine

	include 'gen-geant.inc'
	include 'gen.inc'
	include 'gen-hit-ntuple.inc'

      INTEGER*4 I
      REAL*8  scat_dist, g, r1, r2, coscorr, sincorr, phi
      REAL*8  costheta, sintheta, rperp(3), snorm
      REAL*4  ran1
      REAL    eta, kopelevich_eta, eta_from_data

      coscorr = 0.

! correct photon direction and position according to its 
! wavelength if this is the first scattering and it comes
! from a muon (but only if this functionality is turned on)
      if (REAL_DIR_V .eq. 0 .and. (ipart .eq. 5 .or. ipart .eq. 6
     *     .or. EM_SCAT_ID .eq. 0) .and. P_nscat .eq. 0 ) then
         do coord = 1, 3
            P_dir(coord) = P_dir_true(coord)
         enddo
	 
         P_scaling = 1.0

! update region if corrected position outside the current one
         if ( sqrt( p_pos(1)*p_pos(1)
     *            + p_pos(2)*p_pos(2)
     *            + p_pos(3)*p_pos(3) ) .gt. r_rad_out(p_reg)) then

            p_reg = p_reg + 1

         endif

      endif

! track photon to point of scatter
! and update number of scatters

      do i = 1,3
         P_pos(i) = P_pos(i) + scat_dist * P_dir(i)
      enddo

      if (P_nscat .eq. EM_SCAT_ID) then
         P_nscat = 1
      else
         P_nscat = P_nscat + 1
      endif
! update  P_length 
      P_length = P_length + scat_dist
      P_logwgt = -P_length/P_abs_dist

! find new distance to next scatter

      call find_lscat( P_wlen, scat_dist)  
      scat_dist = - scat_dist * log( ran1( in_seed ) ) 
! find photon direction after scatter

      r1 = ran1(in_seed)
      r2 = ran1(in_seed+1)

* ------
      IF (WATMOD.EQ.'medsea') THEN
*
* OLD:      Call find_av_cos( P_wlen, g)  ! g = average of cosine theta
* New:      Find the phase function beta as a linear combination of two functions
*
        IF (r2.LT.ALPHA) THEN
          g = COSME(1)         ! Take the first  value of <cos>
        ELSE
          g = COSME(2)         ! Take the second value of <cos>
        ENDIF
*
        coscorr=(1.d0-g+g*r1)*r1*(1.d0+g)**2/(1.d0-g+2.d0*g*r1)**2
        coscorr=2.d0*coscorr-1.d0
* ------
      ELSEIF (WATMOD.EQ.'partic') THEN
* 
* Simulate a linear combination of Rayleigh and Particles scattering
*     WL... determines how to arrive at the fraction of Rayleigh scattering
      	 IF (WL_SCAT_METH .eq. 1) then
*     	    Use the dependence from kopelevich
	    eta=KOPELEVICH_ETA(P_wlen)
         ELSE IF (WL_SCAT_METH .eq. 2) then
*     	    Use the implied dependence from the data
	    eta=ETA_FROM_DATA(P_wlen)
	 ELSE
	    eta = ETA0
	 ENDIF
	 
	 IF (r2.LT.ETA) THEN
            call rayleigh(r1,coscorr)  ! Rayleigh Scattering
         ELSE
            call particle(r1,coscorr)  ! Scattering by particles
        ENDIF
* ------
      ELSE
        write(6,*) '** ERROR unknown water model ',WATMOD
	return
      ENDIF
* ------
      sincorr=dsqrt(1.d0-coscorr**2)
      phi=2.d0*c_Pi*ran1(in_seed)
      costheta=2.d0*ran1(in_seed)-1.d0
      sintheta=dsqrt(1.d0-costheta**2)

      rperp(1)=-dsin(phi)*sintheta*P_dir(3)+costheta*P_dir(2)
      rperp(2)=dcos(phi)*sintheta*P_dir(3)-costheta*P_dir(1)
      rperp(3)=dsin(phi)*sintheta*P_dir(1)-dcos(phi)*sintheta*P_dir(2)
      
      snorm=rperp(1)**2+rperp(2)**2+rperp(3)**2
      snorm=dsqrt(snorm)
      
      do i=1,3
         rperp(i) =rperp(i)/snorm
         P_dir(i)=coscorr*P_dir(i)+sincorr*rperp(i)

      enddo

      end
