C*/
      subroutine correct_photon()
* -----------------------------------------------------------------------
*
* This function corrects the photon properties to undo the 'forcing' of
* all Cherenkov photons to be output at the same angle. This only ever
* gets called for direct photons from muons, and corrects for
* peculiarities of km3 which are accounted for in gen, and some aspects
* of which must be undone
*
* Inputs:
* -------
* id: integer id of photon in the hit buffer
* 
* Description:
* -----------
* takes a photon in the hit buffer, and modifies its apparent direction
* according to its true phase index compared to the mean phase index
* Created  23-Jul-2013 c.w. james
* -----------------------------------------------------------------------
*
      include 'hit.inc'
      real*4 xlambda, pindex, cos_th_ch, delta_theta_ch
      real*4 sqrt_bit, tmp_phi, tmp_theta, sin_th
      real*4 ph_dir(3), norm_ph_dir
      integer*4 id
      
      id=p_nhits
      xlambda=p_wlen(id)
      call water_index(xlambda, pindex, 0)
      cos_th_ch = 1./pindex
      delta_theta_ch = acos(cos_th_ch) - h_theta_ch

c we can now easily compute ph_dir according to the Cerenkov angle
      sqrt_bit=sqrt(p_dir(id,1)*p_dir(id,1)+p_dir(id,2)*p_dir(id,2))
      if (sqrt_bit .eq. 0) then
      	 tmp_phi=0.      ! we cannot define it
      else if (p_dir(id,2) .gt. 0) then
      	 tmp_phi = acos( p_dir(id,1) / sqrt_bit ) 
      else
      	 tmp_phi = 2*3.14159265359 - acos( p_dir(id,1) / sqrt_bit )
      endif
      tmp_theta = acos(p_dir(id,3))
      sin_th = sin(tmp_theta + delta_theta_ch)
      ph_dir(1) = sin_th * cos(tmp_phi)
      ph_dir(2) = sin_th * sin(tmp_phi)
      ph_dir(3) = cos(tmp_theta + delta_theta_ch)
c let us normalize ph_dir and we are done
      norm_ph_dir = sqrt( ph_dir(1)*ph_dir(1)
     *       + ph_dir(2)*ph_dir(2) + ph_dir(3)*ph_dir(3) )
      ph_dir(1) = ph_dir(1)/norm_ph_dir
      ph_dir(2) = ph_dir(2)/norm_ph_dir
      ph_dir(3) = ph_dir(3)/norm_ph_dir

      p_dir(id,1)=ph_dir(1)
      p_dir(id,2)=ph_dir(2)
      p_dir(id,3)=ph_dir(3)

      end
