C* Find the phase and group indices according to wavelength
C* Formulas and parameters from Wolfgang Schuster's PhD thesis, pp48-49
C*
C* @param wlength Wavelength in nm
C* @param index   Group or phase index
C* @param group   0 = phase index, 1 = group index
C*
C*/

      subroutine water_index(wlen, indx, group)
 
        real*4 n0, n1, n2, n3, n4, n5, n6, n7, n8, n9, n10
        real*4 P, S, T
        real*4 wlen, indx
        real*4 pindx, dpindx
        integer group

        n0  = 1.31405
        n1  = 1.45e-5
        n2  = 1.779e-4
        n3  = 1.05e-6
        n4  = 1.6e-8
        n5  = 2.02e-6
        n6  = 15.868
        n7  = 0.01155
        n8  = 0.00423
        n9  = 4382.
        n10 = 1.1455e6
        P   = 220   ! bar
        S   = 38.44 ! per thousand
        T   = 13.1  ! °C

c       compute the phase index
        pindx = n0 + n1*P + ( n2 - n3*T + n4*T**2 )*S
     *            - n5*T**2 + ( n6 + n7*S - n8*T )/wlen
     *            - n9/wlen**2 + n10/wlen**3
c        write(*,*)wlen,pindx

c       compute the group index if needed
        if ( group .eq. 1 ) then

c       derivative of the phase index
           dpindx = 0.0 - ( n6 + n7*S - n8*T )/wlen**2
     *                  + 2*n9/wlen**3 - 3*n10/wlen**4

c       indx is now the group index
           indx = pindx / (1.0 + wlen/pindx*dpindx)

        else

c       indx is now the phase index
           indx = pindx

        endif

c         indx = 1.346

        return

      end




