C*/

      SUBROUTINE INI_OPTIC(IPRINT)
      
      include 'hit.inc'
      INTEGER*4 MAX_TEMP_COS
      parameter (MAX_TEMP_COS  =  1000)
      INTEGER*4 pmt_unit, ierr, iprint,i,j, k,ncos
      REAL*4 qe, wlen, a(PMT_MAX_EV), agel, aben, xben, xgel,coef
      REAL*4 tempcos(MAX_TEMP_COS), tempa(MAX_TEMP_COS, PMT_MAX_EV)
      character*255 pmtfile
      REAL*4 getaa, relbit, thecos
      CALL GETENV('PMTFILE',pmtfile)
      
      pmt_unit=45
      
      open(unit=pmt_unit,file=pmtfile,status='old',
     1       form='formatted',IOSTAT=ierr)
      if (ierr.ne.0) then
      	 write(*,*) 'WARNING: error opening pmt file ',pmtfile
      endif
c PMT diameter (inches) and area efficiency value
      read(pmt_unit,*) PMT_diam, PMT_eff_col
c thickness of gel and benthos (glass) in front of OM
      read(pmt_unit,*) xgel, xben
      PMT_xgel = xgel
      PMT_xben = xben
      
c PMT effective area (pi r^2)*efficiency (in m^2)
      PMT_area=3.14159265359*PMT_eff_col*(0.0254*PMT_diam/2.0)**2
      read(pmt_unit,*) PMT_nwlen
      
      if (iprint.eq.1) then
      	 write(*,*) '# wlen  qe   algel   alben  total qeff'
      endif
      
c reads the tabulated quantum efficiency as a function of wavelength
      do i=1,PMT_nwlen
c wavelength, quantum efficiency, absorption length gel
c absorption length benthos (glass)
      	 read(pmt_unit,*) wlen, qe, agel, aben
	 
	 if (i .le. PMT_MAX_NWLEN) then
	    PMT_QEFF(i) = qe
	    PMT_EFF_AREA(i) = qe*PMT_area
	    PMT_ABSGEL(i) = agel
	    PMT_ABSBEN(i) = aben
	    PMT_DLAMB(i) = wlen
	    if (iprint.eq.1) then
	       write(*,*) wlen, qe, agel, aben, PMT_QEFF(i)
	    endif
	 endif
      enddo
      PMT_wlen1 = PMT_DLAMB(1)
      PMT_dwlen = PMT_DLAMB(2) - PMT_DLAMB(1)
      
c if there are too many wavelengths specified, print a warning,
c and concatenate  
      if (PMT_nwlen .gt. PMT_MAX_NWLEN) then
      	 write(*,*) 'WARNING: Too many pmt wavelengths specified!'
	 write(*,*) 'Resetting from ',PMT_nwlen, ' to ',PMT_MAX_NWLEN
	 PMT_nwlen = PMT_MAX_NWLEN
      endif
      
c sets cuts on minimum and maximum energy - relies on correct ordering
      PMT_max_lam = PMT_DLAMB(PMT_nwlen)
      PMT_min_lam = PMT_DLAMB(1)
      
c Parameters relating to the PMT angular efficiency
c These are (respectively) the number of polynomial coefficients
c used to model the efficiency, the minimum cosine to which this
c fit applies, and the value of the angular efficiency to apply
c at cosines less than this value

c ####### effang: table of polynomial coefficients ###########
      read(pmt_unit,*) PMT_effang_meth
      if (PMT_effang_meth .eq. 1) then
      	 write(*,*) 'PMT ang. eff. as polyfit coefficients'
      	 read(pmt_unit,*) PMT_na, PMT_mincos, PMT_min_effang
c only works for a single set of data, not per-eV bin
	 PMT_nev=1
c Reads fit coefficients to PMT angular efficiency
      	 do i=1, PMT_na
      	    read(pmt_unit, *) a(1)
	    if (i .le. PMT_MAX_A) PMT_effang_a(i) = a(1)
      	 enddo
      
      	 if (PMT_na .gt. PMT_MAX_A) then
      	    write(*,*) 'WARNING: too many polynomial coefficients ',
     &	    ' in fit to effang!. Maximum is ', PMT_MAX_A
      	    write(*,*) '   Concatenating to a lower order polynomial',
     &	    '...  the resulting fit will likely not be accurate'
      	    PMT_na = PMT_MAX_A
      	 endif
      
c if  the minimum cosine applies, the minimum angular efficiency
c must be greater than 0.
      	 if (PMT_min_effang.le.0.) then
      	    write(*,*) 'WARNING: PMT_min_effang set to ', PMT_min_effang
	    write(*,*) '   Resetting to ', PMT_MIN_MIN_EFFANG
	    PMT_min_effang = PMT_MIN_MIN_EFFANG
      	 endif
      
      	 if (PMT_mincos .lt. -1.) then
      	    write(*,*) 'WARNING: minimum value for mincos = -1.'
	    PMT_mincos = -1.
      	 endif
      
c tabulates the angular efficiency in log-space (to be interpolated)
c if the mincos is less than 1.0
      	 if (PMT_mincos .ge. 1.0) then
      	    write(*,*) 'WARNING: effectively no effang parameterisation'
      	 else
      	    do i=1, PMT_NCOS
      	       PMT_cos(i) = PMT_mincos
     & +((i-1.)*(1.0-PMT_mincos))/(PMT_NCOS-1.)
	       if (PMT_cos(i) .lt. PMT_mincos) then
	          PMT_effang(i,1) = PMT_min_effang
	       else
	          PMT_effang(i,1) = PMT_effang_a(1)
	          coef=1.0
      	          do j=2, PMT_na
	             coef = coef*PMT_cos(i)
	             PMT_effang(i,1)=PMT_effang(i,1)+coef*PMT_effang_a(j)
	          enddo
	       endif
	       PMT_effang(i,1) = log(PMT_effang(i,1))
      	    enddo
	    PMT_dcos = (1.0-PMT_mincos)/(PMT_NCOS-1.)
      	 endif
c ####### effang: table of cosines vs values ###########
c arbitrary cosine spacing is OK
      else if (PMT_effang_meth.eq.2 .or. PMT_effang_meth.eq.3) then
      	 write(*,*) 'PMT ang. eff. as tabulated data'
	 
	 read(pmt_unit,*) ncos, PMT_min_effang
	 if (ncos .gt. MAX_TEMP_COS) then
	    write(*,*) 'Too many cosines input! Please reduce spacing..'
	 endif
	 
	 
c if meth=3, we have seperate tables for each photon energy
	 if (PMT_effang_meth .eq. 3 ) then
	    read(pmt_unit,*) PMT_nev, PMT_evmin,PMT_evmax
	    PMT_dev = (PMT_evmax-PMT_evmin)/(PMT_nev)
c the tables are bins over a finite range, so we use the bin-centres
	    PMT_evmin=PMT_evmin+PMT_dev*0.5;
	    PMT_evmax=PMT_evmax-PMT_dev*0.5;
	    do j=1,PMT_nev
	       PMT_ev(j) = PMT_evmin + PMT_dev*(j-1)
	    enddo
	 else
	    PMT_nev=1
	 endif
	 if (PMT_nev .gt. PMT_MAX_EV) then
	    write(*,*) 'WARNING: Too many photon energies in aeff table!'
	 endif
c reads in the tabulated data
	 do i=1, ncos
      	    read(pmt_unit, *) thecos, (a(j),j=1,PMT_nev)
	    tempcos(i) = thecos
	    do j=1,PMT_nev
	       if (a(j) .lt. PMT_min_effang) a(j) = PMT_min_effang
	       tempa(i,j) = log(a(j))
	    enddo
      	 enddo
c sets minimum cos to the smallest one contained in the table
	 PMT_mincos=thecos
	 
c interpolates between the tabulated points to generate a table
	 j=ncos
	 PMT_dcos = (1.0-PMT_mincos)/(PMT_NCOS-1.)
	 do i=1,PMT_NCOS
	    PMT_cos(i)=PMT_mincos+((i-1)
     & *(1.0-PMT_mincos))/(PMT_NCOS-1.)
110	    if (tempcos(j).lt.PMT_cos(i) .and. j.gt.0) then
	       j = j-1
	       GOTO 110
	    endif
	    if (j .lt. 1) then
	       do k=1,PMT_nev
		  PMT_effang(i,k) = tempa(1,k)
	       enddo
	    elseif (j .ge. ncos) then
	       do k=1,PMT_nev
		  PMT_effang(i,k) = tempa(ncos,k)
	       enddo
	    else
	       relbit=(PMT_cos(i)-tempcos(j+1))/
     &               	   (tempcos(j)-tempcos(j+1))
	       do k=1,PMT_nev
	          PMT_effang(i,k) = relbit*tempa(j,k)
     &               	   + (1.-relbit)*tempa(j+1,k)
	       enddo
	    endif
	 enddo
      else
      	 write(*,*) 'WARNING: Angular acceptance input method not recognised!'
      endif
      
           
      END

c ####### code to use the function 'getaa': testing purposes only ######
c      write(*,*) 'bin, cosine, aa_effang, old_effang'
c      do i=1, PMT_NCOS
c      	 thecos=PMT_effang(i)
c      	 PMT_effang(i) = getaa(PMT_cos(i), -5.0)
c	 if (PMT_effang(i) .le. 0.) then
c	    PMT_effang(i) = log(PMT_min_effang)
c	 else
c     	    PMT_effang(i) = log(PMT_effang(i))
c	 endif
c	 write(*,*) i, PMT_cos(i), PMT_effang(i), thecos
c      enddo
