C*/
      SUBROUTINE make_t_dis( nhits, t, w, w_total, t_dis)

*     Created:  12-June-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
*     convert a randomly ordered set of hit times (t) with weights (w)
*     into an inverse cumulative probability distribution
 
*     In/Out Variables:-
*     ==========
c     in        nhits        number of hits  
c     in        t            array of hit times
c     in        w            array of weights
c     in        w_total      total weight of all hits
c     out       t_dis        inverse cumulative time distribution
 
*     Common Block Access:-
*     ===================
c     /hit/  	in 		holds structures for HIT program

*     Assumptions:-
*     ===========
c     the time zero is given by the first hit minus 1 ns.
c     linear interpolation in the cumulative time disribution is used
c     to find the inverse cumulative distribution

*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine

      include 'hit.inc'
      
      integer*4  i, j, nhits,ndis
      real*4     t(max_hits),w(max_hits)
      real*4     t_dis(0:max_t_scat)
c MUST keep these real*8, to avoid floating point underflow errors      
      real*8     w_sum, w_total, w_tot2

      real*4 x_a,x_b,xm,xd,beta
      real*4 x_cheb(0:max_t_scat)
      
      real*4 power, offset

      ndis=h_nbins_time(h_scat)
      do j = 1, ndis
        t_dis(j) = 0.0
      enddo

      if ( w_total .eq. 0.0 ) then
c there isn't enough total weight to make a realistic time distribution
         return
      endif

c <<<<<<<<<
      call sort( nhits, t, w )

c calculate weight increment between points in t_dis
      w_sum = 0.0000000000000
      w_tot2 = 0.0000000000000
c needs new total weight to ensure that the sum is correct after ordering
c (floating point undeflow is a problem with this sum, and hence the answe
c is order-dependent)
      do i = 1, nhits
         w_tot2 = w_tot2 + w(i)
      enddo
      
c sets the first hit time to the earliest hit, minus a tiny increment
      t_dis(0) = t(1) - 0.001
      j = 1

c loop over hits, to make the weighted cumulative time distribution
      do i = 1, nhits
      
         w_sum = w_sum + w(i)

c check to see if w_sum is large enough to make the jth point(s) in
c the inverse cumulative distribution

         do while ( (w_sum .gt. x_cheby(h_scat,j)*w_tot2) .and. 
     &              (j.lt.ndis)                          )

            if ( i .eq. 1 ) then

               t_dis(j) = t(i) - ( ( w_sum - x_cheby(h_scat,j)
     1               	   *w_tot2) / 
     2                    w(i) ) * ( t(i) - t_dis(0) )
	    else

               t_dis(j) = t(i) - ( ( w_sum - 
     1               	   x_cheby(h_scat,j)*w_tot2 ) / 
     2                    w(i) ) * ( t(i) - t(i-1) )
      	       
            endif

            j = j + 1  ! goto next point in t_dis

         enddo

      enddo
      t_dis(ndis) = t(nhits)
      end

c   fills the time-distribution array - does this ONCE
      SUBROUTINE make_t_values( )

      include 'hit.inc'

      integer*4  i, j, nhits, ndis

      real*4 x_a,x_b,xm,xd,beta
      real*4 x_cheb(0:max_t_scat)
      real*4 power, offset
      
      ndis=h_nbins_time(h_scat)

c sort the time and weight arrays in order of time
      if (B_tmeth .eq. 1) then
c     	 use chebychev binning      
      	 x_a = 0.0
      	 x_b = float(ndis)
      	 xm = (x_a+x_b)/2.
      	 xd = (x_b-x_a)/2.
      	 x_cheb(0) = x_a
      	 x_cheb(ndis) = float(ndis)

      	 do i=1,ndis-1
            beta = -cos(con_pi*(2.*float(i)+1.)/(2.*float(ndis)+2.))
            x_cheb(i) = xm+xd*beta
      	 enddo

      	 do i=0,ndis
            x_cheby(h_scat,i) = x_cheb(i)/x_cheb(ndis)
      	 enddo
      else if (B_tmeth .eq. 0) then
c     standard linear binning
      	 x_cheby(h_scat,0)=0.0
	 do i=1,ndis-1
	    x_cheby(h_scat,i)=i/float(ndis);
	 enddo
	 x_cheby(h_scat,ndis)=1.0
      else if (B_tmeth .ge. 2) then
c midpoint power scaling of bins - and, invertable!
      	 power=float(B_tmeth)
	 offset=ndis/(2. * 0.5**(1./power))
	 do i=0,ndis/2
	    x_cheby(h_scat,i) = (i/offset)**power
	 enddo
	 
	 do i=ndis,ndis/2+1,-1
	    x_cheby(h_scat,i) = 1. - ((ndis-i)/offset)**power
	 enddo
	 
      endif
      
      end
