C*/
      SUBROUTINE read_user_inputs

*     Created:  12-June-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
*     get the user inputs which define the scattered and direct bands
c     and the OM orientation bins. Also the file_in_rz filename and
c     the e_thresh
*     
*     Common Block Access:-
*     ===================
c     /hit/  	in 		holds structures for HIT program

*     Assumptions:-
*     ===========

*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine

      include 'hit.inc'

      integer*4 i, j, k
      real*4    x, cos_width

C D. Bailey 5/1/01
C   Local variables for input via FFREAD as some of the entries in hit.inc
C   are indexed from 0 to 1.

      INTEGER*4 temp_nbins(2), temp_nbins_om_theta(2),temp_nbins_time(2)
      INTEGER*4 temp_nbins_om_phi(2)
      REAL*4 temp_power_low(2), temp_power_high(2), dtheta, dphi
      COMMON /TEMPCARD/ temp_nbins,temp_nbins_om_theta,temp_nbins_time,
     +       temp_power_low,temp_power_high, temp_nbins_om_phi
     
c default values of inputs: now EM_SCAT_ID and ALL_SCAT are passed in the desc file
      MAX_SCAT=100
      B_tmeth=3
      
      CALL FFINIT(0)
c      CALL FFKEY('HDIR',h_dir_ratio,1,'REAL')
      CALL FFKEY('HMBD',h_min_band_dot,1,'REAL')
      CALL FFKEY('BNUM',temp_nbins,2,'INT')
      CALL FFKEY('BELO',temp_power_low,2,'REAL')
      CALL FFKEY('BEHI',temp_power_high,2,'REAL')
      CALL FFKEY('HOMT',temp_nbins_om_theta,2,'INT')
      CALL FFKEY('HOMP',temp_nbins_om_phi,2,'INT')
      CALL FFKEY('HNOT',temp_nbins_time,2,'INT')
      CALL FFKEY('ALSC', ALL_SCAT,1,'INT')
      CALL FFKEY('MXSC', MAX_SCAT,1, 'INT')
      CALL FFKEY('ESID', EM_SCAT_ID,1, 'INT')
      CALL FFKEY('TMTH', B_tmeth,1, 'INT')
      CALL FFGO
      
      if (ALL_SCAT .eq. 1) then
      	 write(*,*) 'treating all photons as scattered'
      endif
      
c      print *, ' minimum direct/scattered ratio for making',
c     1         ' dir distributions?'
C      read  *, h_dir_ratio
c      write(6,*) h_dir_ratio
      print *, ' minimum value for dot prod. of band norm. and hit_dir?'
C      read  *, h_min_band_dot
      write(6,*) h_min_band_dot
      
      write(*,*) 'Chebychev binning in time?',
     &         '(y=1,linear=0, power=2)? ',B_tmeth

C D. Bailey 5/1/01
C   Now copy the direct and scattered inputs to the correct arrays

      do i = 0,1 ! loop over direct then scattered distributions

         print *, 'How many bands?'
         b_nbins(i) = temp_nbins(i+1)
         write(6,*) b_nbins(i)
         print *, 'exponent for low bins?'
         b_power_low(i) = temp_power_low(i+1)
         write(6,*) b_power_low(i)
         print *, 'exponent for high bins?'
         b_power_high(i) = temp_power_high(i+1)
         write(6,*) b_power_high(i)
         print *, 'How many theta_om bins?'
         h_nbins_om_theta(i) = temp_nbins_om_theta(i+1)
         write(6,*) h_nbins_om_theta(i)
	 print *, 'How many phi_om bins?'
	 h_nbins_om_phi(i) = temp_nbins_om_phi(i+1)
	 write(6,*) h_nbins_om_phi(i)
         print *, 'How many bins for the cumulative time distributions?'
         h_nbins_time(i) = temp_nbins_time(i+1)
         write(6,*) h_nbins_time(i)

      enddo
      h_nbins_om_phi(0) = 1
c      h_nbins_om_theta(1) = 5 ! currently hardwired (see find_om_directions)
c      h_nbins_om_phi(1) = 3   ! currently hardwired (see find_om_directions)
c      h_nbins_om_phi(0) = 1   ! currently hardwired (see find_om_directions)

      write(*,*) 'h_n_ref is: ', h_n_ref
      h_cos_ch = 1.0 / h_n_ref
      h_theta_ch = acos( h_cos_ch )
      h_last_dir_r   = r_nbins + 1

c Write values of om_theta and om_phi for reference in ntuples
c D. Lowder   4/7/97
c  Direct hits:  there is only one bin in OM_PHI which is set to OM_PHI = 0. 
c  OM_THETA is sampled uniformly in cos(om_theta) from 1 to -1.
c
c OM theta and phi for direct hits
      write(*,*) 'about to initialise theta and phi for OMs'
	b_om_phi(0,1) = 0.
	b_om_theta(0,1)= 0.
	do i = 2,h_nbins_om_theta(0)-1
		b_om_theta(0,i) = 
	1	acos(1.0 - 2.0 * float(i-1) / float(h_nbins_om_theta(0) - 1) )
	end do
	b_om_theta(0,h_nbins_om_theta(0))=con_pi

c OM theta and phi for scattered hits (no longer currently hardwired)
      dphi=con_pi/(h_nbins_om_phi(1)-1.)
      b_om_phi(1,1) = 0.
c      b_om_phi(1,2) = con_pi * 0.5
      do i=2, h_nbins_om_phi(1)-1
      	 b_om_phi(1,i) = (i-1.)*dphi
      end do
      b_om_phi(1,h_nbins_om_phi(1)) = con_pi
      
      b_om_theta(1,1)=0.
      dtheta=con_pi/(h_nbins_om_theta(1)-1.)
      do i=2,h_nbins_om_theta(1)-1
      	 b_om_theta(1,i) = (i-1.) * dtheta
      end do
      b_om_theta(1,h_nbins_om_theta(1))=con_pi
      
      write(*,*) 'finished initialising OM theta and phi'

c Now calculates the rotation matrix
      do i=0,1
      	 do j=1,h_nbins_om_theta(i)
	    do k=1,h_nbins_om_phi(i)
	       B_om_matrix(i,j,k,1)=cos(b_om_theta(i,j))
	       B_om_matrix(i,j,k,2)=sin(b_om_theta(i,j))
     1	             	      	    *cos(b_om_phi(i,k))
      	       B_om_matrix(i,j,k,3)=sin(b_om_theta(i,j))
     1	             	      	    *sin(b_om_phi(i,k))
      	    enddo
	 enddo
      enddo
      
c set -up the angular extents for each band in both the scattered and
c direct distributions
      
      do i = 0,1                ! loop over direct then scattered distributions
*
* Do not consider 'high' and 'low' bands for photons (LASER-flash).
* Consider just 'low' bands for photons, from (cos = -1) to (cos = 1).
* Consider 20 bands of equal area! <-> bins of uniform step in (cos)
*
        if (h_part_id .eq. id_photon) then
*
          b_n_high(i) = 0
          b_n_low(i)  = int( b_nbins(i) )
*
          b_power_low(i) = 0.
          b_power_high(i)= 0.
*
          write(*,*) ' '
          write(*,*) ' ---> DIVIDE THE SPHERE IN BANDS <---'
          write(*,*) 'scatt/no_scatt=',i,' b_nbins=',b_nbins(i),
     &         ' b_n_high=',b_n_high(i),' b_n_low=',b_n_low(i)
*
          b_cos_min(i,1,1)          = -1.0
          b_cos_max(i,1,b_n_low(i)) =  1.0
*
          b_step_low(i) =
     &  ( b_cos_max(i,1,b_n_low(i)) - b_cos_min(i,1,1) ) / b_n_low(i)
*          
          write(*,*) 'step_low =',b_step_low(i)
          write(*,*)'       cos_min   cos_max   cos_ave angle_min'
          write(*,*)'       -------   -------   ------- ---------'
* First bin:
          b_cos_max(i,1,1) = b_cos_min(i,1,1) + b_step_low(i)
          b_cos_ave(i,1,1) = b_cos_min(i,1,1) + b_step_low(i)/2.0
          
          write(*,600) 1,
     &         b_cos_min(i,1,1),b_cos_max(i,1,1),b_cos_ave(i,1,1),
     &         acos(b_cos_min(i,1,1))*57.29578
          
* Find the bin ranges for the rest of the bins
          do j = 2, b_n_low(i)
            
            b_cos_min(i,1,j) = b_cos_max(i,1,j-1)
            b_cos_max(i,1,j) = b_cos_min(i,1,j) + b_step_low(i)
            b_cos_ave(i,1,j) = b_cos_min(i,1,j) + b_step_low(i)/2.0
            
            write(*,600) j,
     &           b_cos_min(i,1,j),b_cos_max(i,1,j),b_cos_ave(i,1,j),
     &           acos(b_cos_min(i,1,j))*57.29578
            
          enddo
*
* Copy the bin ranges for the first shell into all other shells
* and calculate the area of each band
*
          do j = 1, r_nbins     ! loop over shells
            
            do k = 1, b_nbins(i) ! loop over bands
              
              b_cos_min(i,j,k) = b_cos_min(i,1,k)
              b_cos_max(i,j,k) = b_cos_max(i,1,k)
              b_cos_ave(i,j,k) = b_cos_ave(i,1,k)
              b_area(i,j,k)    = 2.0 * con_pi * ( b_cos_max(i,j,k)
     &             -b_cos_min(i,j,k) ) * r_rad(j)**2.0
            enddo
          enddo
*
        else if ( ( i .eq. 0 ) .and. ( h_part_id .eq. id_muon ) ) then

c direct distributions for muons are special.
c there is only one `cherenkov' band which is defined as the projection of the 
c muon track segment onto each shell with emission at only the true
c cherenkov angle. This band defines the band area in routine process_band.
c A five times wider band is also defined which is used to select events
c in process_shell to lie in the `cherenkov' band. This wider band is used
c so that the scattered distributions are smoother_ It does not affect the
c band area calculation.
c NOTE: in 'hit-process_shell', we do NOT select 'near-Cherenkov'
c scattered hits, due to the requirement nscat .eq. 0
c a possible alternative is to not call something scattered
c if it lies below a certain threshold... but this would be very
c tricky in gen

          b_nbins(0) = 1        ! hardwire to 1 band
          
          do j = 1, r_nbins     ! loop over shells
            
c calculate the limits of the true cherenkov band
            x = asin( h_seg_length * sin( con_pi - 
     1           h_theta_ch ) / ( 2.0 * r_rad(j) ) )
            b_cos_max(i,j,1) = cos ( h_theta_ch - x )
            x = asin( h_seg_length * sin( h_theta_ch ) / 
     1           ( 2.0 * r_rad(j) ) )
            b_cos_min(i,j,1) = cos ( h_theta_ch + x )
            b_cos_ave(i,j,1) = ( b_cos_min(i,j,1) +
     1           b_cos_max(i,j,1) ) * 0.5
c calculate the area of the band from the true cherenkov band limits
               b_area(i,j,1) = 2.0 * con_pi * ( b_cos_max(i,j,1) - 
     1                         b_cos_min(i,j,1) ) * r_rad(j)**2.0
c now calculate the limits of the five times wider cherenkov bin
               cos_width = b_cos_max(i,j,1) -  b_cos_min(i,j,1)  
               b_cos_min(i,j,1) = b_cos_ave(i,j,1) - 2.5 * cos_width
               b_cos_max(i,j,1) = b_cos_ave(i,j,1) + 2.5 * cos_width
   
            enddo
         else

c find the number of bins with cos(theta) .gt. cos(theta_ch) = n_high
c and those with cos(theta) .lt. cos(theta_ch) = n_low
          
          b_n_high(i) = int( b_nbins(i) / 3.0 )
          b_n_low(i)  = b_nbins(i) - b_n_high(i)
          
c find the step between bins for the low bins (from cos = -1 to h_cos_ch)
          
          b_step_low(i) = (1.0 + h_cos_ch)**b_power_low(i) 
     1         / b_n_low(i)
          
          write(*,*) 'step_low =',b_step_low(i)
          write(*,*)'       cos_min   cos_max   cos_ave angle_min'
          write(*,*)'       -------   -------   ------- ---------'
          
c find the bin range for the first low bin (starting at cos_ch = -1) 
          
          b_cos_min(i,1,1) = -1.0
          b_cos_max(i,1,1) = h_cos_ch - ( (b_n_low(i) - 1) 
     1         * b_step_low(i) )**(1.0/b_power_low(i))
          b_cos_ave(i,1,1) = h_cos_ch - ((( h_cos_ch - 
     1         b_cos_min(i,1,1) )**b_power_low(i) + ( h_cos_ch - 
     2         b_cos_max(i,1,1) )**b_power_low(i) ) * 0.5 )**
     3         (1.0/b_power_low(i))
          
          write(*,600) 1,
     &         b_cos_min(i,1,1),b_cos_max(i,1,1),b_cos_ave(i,1,1),
     &         acos(b_cos_min(i,1,1))*57.29578
          
c find the bin ranges for the rest of the low bins
          
          do j = 2, b_n_low(i)
            
            b_cos_min(i,1,j) = b_cos_max(i,1,j-1)
            b_cos_max(i,1,j) = h_cos_ch - ( (b_n_low(i) - j) 
     1           * b_step_low(i) )**(1.0/b_power_low(i))
            b_cos_ave(i,1,j) = h_cos_ch - ((( h_cos_ch - 
     1           b_cos_min(i,1,j) )**b_power_low(i) + ( h_cos_ch - 
     2           b_cos_max(i,1,j) )**b_power_low(i) ) * 0.5 )**
     3           (1.0/b_power_low(i))
            
            write(*,600) j,
     &           b_cos_min(i,1,j),b_cos_max(i,1,j),b_cos_ave(i,1,j),
     &           acos(b_cos_min(i,1,j))*57.29578
            
          enddo
          
c find the step between bins for the high bins (from cos_ch to cos = +1)
c                                    ---------
          b_step_high(i) = (1.0 - h_cos_ch)**b_power_high(i) 
     1         / b_n_high(i)
          
          write(*,*) 'step_high =',b_step_high(i)
          write(*,*)'       cos_min   cos_max   cos_ave angle_min'
          write(*,*)'       -------   -------   ------- ---------'
          
c find the bin ranges for the high bins
          
          do j = 1, b_n_high(i)
            
            b_cos_min(i,1,b_n_low(i)+j) = 
     1           b_cos_max(i,1,b_n_low(i)+j-1)
            b_cos_max(i,1,b_n_low(i)+j) = h_cos_ch + 
     1           (j * b_step_high(i))**(1.0/b_power_high(i))
            b_cos_ave(i,1,b_n_low(i)+j) = h_cos_ch + ((( - h_cos_ch
     &           +b_cos_min(i,1,b_n_low(i)+j) )**b_power_high(i) + (
     &           - h_cos_ch +b_cos_max(i,1,b_n_low(i)+j) )**b
     &           _power_high(i) ) * 0.5 )**(1.0/b_power_high(i))
            
            write(*,600) j, b_cos_min(i,1,b_n_low(i)+j),
     &           b_cos_max(i,1,b_n_low(i)+j),
     &           b_cos_ave(i,1,b_n_low(i)+j),
     &           acos(b_cos_min(i,1,b_n_low(i)+j))*57.29578
            
          enddo
c copy the bin ranges for the first shell into all other shells
c and calculate the area of each band
        
          do j = 1, r_nbins     ! loop over shells
            
            do k = 1, b_nbins(i) ! loop over bands
              
              b_cos_min(i,j,k) = b_cos_min(i,1,k)
              b_cos_max(i,j,k) = b_cos_max(i,1,k)
              b_cos_ave(i,j,k) = b_cos_ave(i,1,k)
              b_area(i,j,k)    = 2.0 * con_pi * ( b_cos_max(i,j,k) -
     &             b_cos_min(i,j,k) ) * r_rad(j)**2.0
              
            enddo
          enddo
        endif
      enddo
*
      
 430  FORMAT(I4,F10.6,2F10.5)
 600  FORMAT(I4,4F10.5)
      
      end
