C*/
      SUBROUTINE distance_to_cylinder( point, cyl_center, 
     1                    cyl_half_height, cyl_rad, closest )	

*     Created:  15-FEB-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
c     find the closest distance between a point and a vertical cylinder. 

*     In/Out Variables:-
*     ==========
c     in	point        	xyz coordinates of the point	
c     in	cyl_center	xyz coordinates of the center of the cylinder	
c     in	cyl_half_height half-height of the cylinder	
c     in	cyl_rad  	radius of the cylinder	
c     out       closest         distance of closest approach_ N.B this is
c                               equal to ZERO if the point is inside the
c                               cylinder                      

*     Common Block Access:-
*     ===================
c     none

*     Assumptions:-
*     ===========
c     All quantities are in the same coordinate system! 
c     the cylinder is VERTICAL, i.e. is parallel to the z-axis
c     N.B. closest = 0 if the point is inside the cylinder
                      
*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine

      IMPLICIT NONE

      REAL*4  cyl_center(3), point(3), closest, cyl_half_height
      REAL*4  cyl_rad, cyl_bot, cyl_top, point_row, squ

c calculate the distance between the point and the vertical axis of the
c cylinder

      point_row = sqrt( squ( cyl_center(1)-point(1) ) + 
     1                  squ( cyl_center(2)-point(2) ) )

c calculate the z-value of the top and bottom of the cylinder

      cyl_top = cyl_center(3) + cyl_half_height
      cyl_bot = cyl_center(3) - cyl_half_height

      if ( point_row .le. cyl_rad ) then
c the point lies inside the volume defined by extending the cylinder to +-
c infinity along the z-axis

         if ( point(3) .gt. cyl_top ) then
            closest = point(3) - cyl_top 
         elseif ( point(3) .lt. cyl_bot ) then
            closest = cyl_bot - point(3) 
         else
            closest = 0.
         endif

      else
c the point lies outiside the `infinite' cylinder

         if ( point(3) .gt. cyl_top ) then
            closest = sqrt( squ(point_row - cyl_rad) +
     1                      squ(point(3) - cyl_top) ) 
         elseif ( point(3) .lt. cyl_bot ) then
            closest = sqrt( squ(point_row - cyl_rad) +
     1                      squ(point(3) - cyl_bot) ) 
         else
            closest = point_row - cyl_rad 
         endif

      endif
      end
