C*/
      SUBROUTINE elec_direct_hits( part_num, om_num, 
     1           rho, cos_band, theta_om)

*     Created:  26-mar-98
*     Contact:  M. Moorhead, OXFORD.
*     Verified:

*     Purpose and Method:-
*     ====================
c     Calculate the number of direct hits for a given OM and 
c     A given electron shower. First, determine if we are in the low or high
c     bands (cos_band below or above h_cos_ch).
c     Then find the average poisson 
c     probability of a hit by sampling the el_dir_prob array by linear 
c     interpolation in the energy, rho, cos_band, theta_om and phi_om
c     dimensions. 
c     The hit time of each hit (if any)
c     is then found by sampling the el_dir_time array. 
c     The OM hits (if any) are then placed into the hit structure record.

*     In/Out Variables:-
*     ==========
c     in        part_num        number of particle (shower)
c     in        rho             magnitude of rho_vec
c     in        cos_band        cos(angle between seg_dir and rho_vec) 
c     in        theta_om        angle between om_dir and rho_vec
 
*     Common Block Access:-
*     ===================
c     /km3/  	in 		holds structures for KM3

*     Assumptions:-
*     ===========
c     the light is defined with repsect to the shower  maximum
 
*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine

      INCLUDE 'km3.inc'
      INCLUDE 'km3-interpol.inc'

      INTEGER*4  num_hits, part_num, ran_poisson, bin(5,2)
      INTEGER*4  idum, i_hit, i, j, k, l, m, om_num, i_b
      REAL*4     rho, theta_om, point(5), weight(5,2)
      REAL*4     avg_num_hits, cos_band
      REAL*4     ran1, hit_time
      integer    itbin,ifather,type_hit
      real       vnhits(40000), vthits(40000), vxhits(40000), tempo
      real       time_min, this_time
      integer*4  i_p, locatr

C--- If this is an input particle, set the parent to this particle number
C      IF (P_IPARENT(PART_NUM).EQ.0) P_IPARENT(PART_NUM) = 
C     &                              P_PART_ID(PART_NUM)
C      PRINT*,P_IPARENT(PART_NUM), PART_NUM, GEN_NPARTIN
*
* -- Ntuple inputs :
c      NSCAT = 0
c      ID_OM    = g_om_id_ant_om(om_num)
      TYPE_HIT = 3
*
c first find out if cos_band is below or above the cherenkov angle
      if ( cos_band .lt. h_cos_ch ) then
c we are in the low bands
          i_b = 1
          point(3) = (h_cos_ch - cos_band)**el_dir_power(i_b,3)
      else 
c we are in the high bands
          i_b = 2
          point(3) = (cos_band - h_cos_ch)**el_dir_power(i_b,3)
      endif

c now set the values of the point in question in the other dimensions,
c which must be adjusted to the correct powers

      point(1) = log10( p_e0(part_num) ) 
      point(2) = rho**el_dir_power(i_b,2)
      point(4) = cos(theta_om)

c now we find the bin values which straddle the current point where we are
c in the mu_dir_prob array.

      do i = 1,4    ! loop over four geometrical dimensions
         if ( point(i).le. el_dir_min(i_b,i) ) then
c we use the first two bins
            bin(i,1) = 1 
            bin(i,2) = 2
         else if ( point(i) .ge. el_dir_max(i_b,i) ) then
c we use the last two bins
            bin(i,1) = el_dir_nbins(i_b,i) - 1 
            bin(i,2) = el_dir_nbins(i_b,i) 
         else
c we are inside the linearly spaced array 
            bin(i,1) = 1 + int( (point(i) - el_dir_min(i_b,i) ) / 
     1                 el_dir_step(i_b,i) ) 
            bin(i,2) = bin(i,1) + 1
         endif
      enddo
*
c
c         Shower energy  |  First band
c   ---------------------|-----------------------
c             E < 1 GeV  | @ 0.8 m   sphere nr.1
c     1 GeV < E < 10 GeV | @ 2   m   sphere nr.2
c    10 GeV < E          | @ 4   m   sphere nr.3
c
c

      if ( el_dir_nbins(1,2).eq.19 .and. el_dir_min(1,2).lt.1.0) then
        if (bin(1,1).eq.2 .and. bin(2,1).eq.1) then
          bin(2,1) = 2
          bin(2,2) = 3
        else if (bin(1,1).eq.3 .and. bin(2,1).le.2) then
          bin(2,1) = 3
          bin(2,2) = 4
        endif
      endif

c now we find the weights for each of these bins, depending on how
c far they are from the point in question. This is the linear 
c interpolation

      do i = 1, 4  ! loop over 4 geometrical dimensions
         weight(i,2) = point(i) - ( el_dir_min(i_b,i) + 
     1                 ( bin(i,1) - 1 ) * el_dir_step(i_b,i) ) 
         weight(i,1) = el_dir_min(i_b,i) + ( bin(i,2) - 1 ) * 
     1                 el_dir_step(i_b,i) - point(i) 
      enddo 

c now we do the weighted sum of all the relevant bins in the el_dir_prob
c array which surround the point. There are a 2**n points to consider
c where n=4 is the number of dimensions

      avg_num_hits = 0.0

      do i = 1, 2  ! loop over straddling bins in the first dimension
         do j = 1,2 ! loop over straddl. bins in the second dimension
            do k = 1,2 ! loop over straddl. bins in the 3rd dimension
               do l = 1,2 ! loop over straddl. bins in the 4th geom. dimension
                  avg_num_hits = avg_num_hits + 
     1            el_dir_prob(i_b,bin(1,i),bin(2,j),bin(3,k),bin(4,l)) 
     2            * weight(1,i) * weight(2,j) * weight(3,k) * 
     3            weight(4,l)  
               enddo 
            enddo
         enddo
      enddo

c normalise the weighted average correctly

      avg_num_hits = avg_num_hits / el_dir_step_prod(i_b)

c remember that el_dir_prob is the log(prob) so we take an exponential
c to get the prob itself

      avg_num_hits = exp( avg_num_hits )

c now get the poisson distributed number of hits by sampling a poisson
c distribution

      num_hits = ran_poisson( avg_num_hits )

      if (num_hits.gt.5000) num_hits = 5000

      if ( num_hits .le. 0) then
c no hits and we return
          return 
      endif

*
* ----------------------------------------------------------------------
*
* Define the time window = 4000.  ns  \__ time_max = time_min + 4000.*10.
* Define the time bin    =    0.1 ns  /
*
      if (num_hits .eq. 1) then
        vnhits(1) = 0.
        vthits(1) = 0.
      else
        do i=1,40000
          vnhits(i) = 0.
          vthits(i) = 0.
        enddo
      endif
* sometimes the hit_time is negative -> safety window of 10ns ... 
      ifather = p_iparent(part_num)
      time_min = p_t0(ifather) - 10. 

* -------------------------------------------------------------------------

c now loop over hits (if any), determining each hit time by sampling the 
c el_dir_time distributions

      do i_hit = 1, num_hits

c find the bins and weights in the time dimension (5) by sampling randomly
c between the el_dir_nbins(i_b,5) time bins

         point(5) =  ran1(idum) * el_dir_nbins(i_b,5)

*  Random intervals in inverse cumulative distribution are not 
*  equally space so we need a different approach to know weights
*  and bins in linear interpolation

         i_p = locatr(x_cheb,el_dir_nbins(i_b,5)+1,point(5))

         bin(5,1) =  abs(i_p)-1
         bin(5,2) =  bin(5,1) + 1
         weight(5,2) = point(5) - x_cheb(bin(5,1)) 
         weight(5,1) = x_cheb(bin(5,2)) - point(5)

*         bin(5,1) =  int( point(5) ) 
*         bin(5,2) =  bin(5,1) + 1
*         weight(5,2) = point(5) - bin(5,1) 
*         weight(5,1) = bin(5,2) - point(5)

c now we do the weighted sum of all the relevant bins in the el_dir_time
c array which surrounds the point. There are a 5**n points to consider
c where n=5 is the number of dimensions

         hit_time = 0.0
         do i = 1, 2  ! loop over straddling bins in the first geom dimension
            do j = 1,2 ! loop over straddling bins in the 2nd  geom  dimension
               do k = 1,2 ! loop over straddl. bins in the 3rd geom. dimension
                  do l = 1,2 ! loop over straddl. bins in 4th geom. dimension
                     do m = 1,2 ! loop over straddling bins in time dimension
                        hit_time = hit_time + el_dir_time(i_b,bin(1,i), 
     1                  bin(2,j),bin(3,k),bin(4,l),bin(5,m)) * 
     2                  weight(1,i) * weight(2,j) * weight(3,k) *
     3                  weight(4,l) * weight(5,m) 
                     enddo
                  enddo 
               enddo
            enddo
         enddo
c normalise the weighted average correctly
         hit_time = hit_time / el_dir_step_prod(i_b)
*
         hit_time = hit_time / (weight(5,2)+weight(5,1))
c place the hit info in the hit buffer
         gen_nhits = gen_nhits + 1
c-         if (gen_nhits .le.100000) then
c-         hit(gen_nhits).ipmt  = g_om_id_ant_om(om_num)
c-         hit(gen_nhits).iparn = part_num
c-         hit(gen_nhits).thit  = hit_time + om_time   
c-         hit(gen_nhits).qhit  = 1.0
c-         hit(gen_nhits).iphty = 0  ! 0=direct cherenkov  
c-         endif
*
* -------------------------------------------------------
*
         this_time = hit_time + p_t0(part_num)
	 
         if (num_hits .eq. 1) then
           vnhits(1) = 1.0
           vthits(1) = this_time
         else
c-           itbin = (nint(this_time*10.) - int(time_min*10.) + 1)
           itbin =
     &     ((nint(this_time*10.) - int(time_min*10.))*1./(tmerg*10.))
     &     + 1

           if (itbin.gt.40000 .or. itbin.le.0) then
* Write the hit parameters inmediatly if the hit time is too large
             nlines = nlines + 1
             write(50,110)
     &            nlines,
     &            g_om_id_ant_om(om_num),
     &            1.0,
     &            this_time,
     &            type_hit,
     &            p_iparent(part_num),
     &            part_num
           else
             vnhits(itbin) = vnhits(itbin) + 1.0
	     vxhits(itbin) = this_time
c-             vthits(itbin) = (int(time_min*10.) + itbin - 1 )*0.1
	    vthits(itbin) = int(time_min) + real(itbin)*tmerg
     &                      - tmerg/2.
           endif
         endif
* find the earliest and latest
         if (this_time.gt.tmaxh) tmaxh = this_time
         if (this_time.lt.tminh) tminh = this_time
*
* -------------------------------------------------------
*
       enddo
*
       if (num_hits .eq. 1) then
         nlines = nlines + 1
         write(50,110)
     &             nlines,
     &             g_om_id_ant_om(om_num),
     &             vnhits(1),
     &             vthits(1),
     &             type_hit,
     &             p_iparent(part_num),
     &             part_num
       else
*
         do i = 1, 40000
           if (vnhits(i) .gt. 0.) then
             nlines = nlines + 1

	     if (vnhits(i).eq.1) tempo = vxhits(i)
	     if (vnhits(i).gt.1) tempo = vthits(i)

             write(50,110)
     &            nlines,
     &            g_om_id_ant_om(om_num),
     &            vnhits(i),
     &            tempo,
     &            type_hit,
     &            p_iparent(part_num),
     &            part_num
           endif
         enddo
       endif
*
c 110  FORMAT('hit:',1X,I7,1X,I5,1X,F6.1,1X,F10.2,3(1X,I6))
 110  FORMAT('hit:',1X,I7,1X,I7,1X,F6.1,1X,F10.2,3(1X,I6))
 100  FORMAT(5X,'* WARNING !! ELEC_DIR_HITS routine, gen_nhits 
     &      out of range')
*
 777   CONTINUE
*
**
*
 999  CONTINUE
      end
