C*/
      subroutine elec_inter_ini(part_num,rho,cos_band,theta_om,phi_om)
*************************************************************************
*     Name           :  elec_inter_ini                                  *
*     Called by      :                                                  *
*     Author         :  Sergio Navas, based on "inter_ini"              *
*     Date           :  14-Dec-1999                                     *
*     Task           :  For a given electromagnetic shower              *
*                       Compute inverse cumulative function values for  *
*                       time interpolation scattered photons, once the  *
*                       optical module coordinates are known.           *
*                                                                       *
*  In/Out Variables:                                                    *
*  -----------------                                                    *
*   in     rho         magnitude of rho_vec                             *
*   in     cos_band    cos(angle between seg_dir and rho_vec)           *
*   in     theta_om    angle between om_dir and rho_vec                 *
*   in     phi_om      phi orientation of optical module                *
*                                                                       *
*************************************************************************
      include 'km3.inc'
      include 'km3-interpol.inc'

      integer*4 part_num
      real*4    rho, cos_band, theta_om, phi_om, point(6), weight(6,2) 
      integer*4 bin(6,2),i_b
      integer*4 i_time,i,j,k,l,m

c------------------------------------------------------------------------
c  Compute f values for interpolation (inverse acumulative function)
c------------------------------------------------------------------------
      if ( cos_band .lt. h_cos_ch ) then
c we are in the low bands
          i_b = 1
          point(3) = (h_cos_ch - cos_band)**el_sca_power(i_b,3)
      else 
c we are in the high bands
          i_b = 2
          point(3) = (cos_band - h_cos_ch)**el_sca_power(i_b,3)
      endif

      point(1) = log10( p_e0(part_num) ) 
      point(2) = rho**el_sca_power(i_b,2)
      point(4) = theta_om
      point(5) = phi_om

c------------------------------------------------------------------------
c  Compute x values for interpolation
c------------------------------------------------------------------------

      do i = 1,  el_sca_nbins(i_b,6)+1
        a_time(i) = x_cheb(i-1)
      enddo

c------------------------------------------------------------------------
c now we find the bin values which straddle the current point where we are
c in the el_sca_prob array.
c------------------------------------------------------------------------
      do i = 1,5    ! loop over 1 energy + four geometrical dimensions
        if ( point(i).le. el_sca_min(i_b,i) ) then
c we use the first two bins
          bin(i,1) = 1 
          bin(i,2) = 2
        else if ( point(i) .ge. el_sca_max(i_b,i) ) then
c we use the last two bins
          bin(i,1) = el_sca_nbins(i_b,i) - 1 
          bin(i,2) = el_sca_nbins(i_b,i) 
        else
c we are inside the linearly spaced array 
          bin(i,1) = 1 + int( (point(i) - el_sca_min(i_b,i) ) / 
     1         el_sca_step(i_b,i) ) 
          bin(i,2) = bin(i,1) + 1
        endif
      enddo

      if ( el_sca_nbins(1,2).eq.19 .and. el_sca_min(1,2).lt.1.0) then
        if (bin(1,1).eq.2 .and. bin(2,1).eq.1) then
          bin(2,1) = 2
          bin(2,2) = 3
        else if (bin(1,1).eq.3 .and. bin(2,1).le.2) then
          bin(2,1) = 3
          bin(2,2) = 4
        endif
      endif
c------------------------------------------------------------------------
c now we find the weights for each of these bins, depending on how
c far they are from the point in question. This is the linear 
c interpolation
c------------------------------------------------------------------------
      do i = 1, 5               ! loop over 1 energy + 4 geometrical dimensions
        weight(i,2) = point(i) - ( el_sca_min(i_b,i) + 
     1       ( bin(i,1) - 1 ) * el_sca_step(i_b,i) ) 
        weight(i,1) = el_sca_min(i_b,i) + ( bin(i,2) - 1 ) * 
     1       el_sca_step(i_b,i) - point(i) 
      enddo 
      
*-------------------------------------------------------------------------
* Build the time distribution for the point in question
*-------------------------------------------------------------------------
      do i_time = 0, el_sca_nbins(i_b,6)
        f_time(i_time+1) = 0.0
        do i = 1,2         ! loop over stradd bins in the 1st geom dimension
          do j = 1,2       ! loop over stradd bins in the 2nd geom dimension
            do k = 1,2     ! loop over stradd bins in the 3rd geom dimension
              do l = 1,2   ! loop over stradd bins in the 4th geom dimension
                do m = 1,2 ! loop over stradd bins in the 4th geom dimension
                  f_time(i_time+1) = f_time(i_time+1)+
     &                 el_sca_time(i_b,bin(1,i),bin(2,j),
     &                 bin(3,k),bin(4,l),bin(5,m),i_time)
     &                 *weight(1,i)*weight(2,j)
     &                 *weight(3,k)*weight(4,l)*weight(5,m)
                enddo
              enddo 
            enddo
          enddo
        enddo
        
c normalise the weighted average correctly
        
        f_time(i_time+1) = f_time(i_time+1) / el_sca_step_prod(i_b)
        
      enddo

      return
      end
