C*/
      real function elec_inter_time(i_b,x,ipol)
*************************************************************************
*     Name           :  elec_inter_time                                 *
*     Called by      :                                                  *
*     Author         :  Sergio Navas, based on "inter_time"             *
*     Date           :  14-Dec-1999                                     *
*     Task           :  For a given electromagnetic shower,             *
*                       Compute time hit, sampling the inverse          *
*                       cumulative function with different              *
*                       interpolation approaches                        *
*                                                                       *
*  In/Out Variables:                                                    *
*  -----------------                                                    *
*   in     x           random variable                                  *
*   in     ipol = 1 : Polynomical interpolation taking thre points      *
*                      (Divided differences, using divdif routine from  *
*                      Cernlib                                          *
*   in     ipol = 2 : Rational interpolation taking thre points         *
*                      ( using ratint routine from Numerical recipes)   *
*************************************************************************
      include 'km3.inc'
      include 'km3-interpol.inc'

      real*4 x
      real*4 divdif,dy,rat_time

      integer*4 ipol,i_p,locatr
      integer*4 j,k,npoints,i_b
      parameter (npoints = 3)

      elec_inter_time = 0.

      if (ipol.eq.1) then 
c-----------------------------------------------------------
c  Polynomical interpolation with three points
c-----------------------------------------------------------
        elec_inter_time = divdif(f_time,a_time, el_sca_nbins(i_b,6),x,2)
      elseif (ipol.eq.2) then
c-----------------------------------------------------------
c  Rational interpolation with three points
c-----------------------------------------------------------

        i_p = locatr(x_cheb, el_sca_nbins(i_b,6),x)
        j  =  abs(i_p)

        k = min( max(j-(npoints-1)/2,1),el_sca_nbins(i_b,6)+1+1-npoints)
        call ratint(a_time(k),f_time(k),npoints,x,rat_time,dy)
        elec_inter_time = rat_time
        
      else

        write(*,*)'**        elec_inter_time error         **'
        write(*,*)'**  No time interpolation pattern given **'
        write(*,*)'**  Check ipol                           =',ipol
        
      endif
      return
      end
