C*/	
	SUBROUTINE FILL_ANTARES_GEOM(i_err)
c
c  Sergio Navas 11-Oct-1999
c
c  Read geometry file with the => NEW <= ANTARES format, and fill the
c  the geometry structures
	
	INCLUDE 'km3.inc'
	INCLUDE 'km3-detgeo.inc'
c	INCLUDE 'km3-phomul.inc'

        INTEGER*4 IFLOOR
        INTEGER*4 I, i_err, om_id_km3, j, k, l, m, jj
        INTEGER*4 n_clusters, n_strings
        REAL*4    squ, dummy_vec(3)

	OPEN(UNIT=34,FILE='pm_data.info',status='UNKNOWN',
     &       IOSTAT=i_err)
c
c--- read the detector global geometry specification
c
        g_num_str = NSTR
        g_num_cls = NCLU
        g_num_oms = NPHOMU
        g_latitude = XLAT
        g_longitude= XLONG
        g_z_surface= ZSEAL
        g_z_bottom = ZELEV
        g_rad_cyl  = RADD
        g_hht      = (ZMAXD - ZMIND)/2. + 2.

	WRITE(34,*) NPHOMU,NSTR,XLAT,XLONG,ZSEAL,ZELEV

c calculate radius of detector enclosing sphere
        g_rad_sph = sqrt( squ(g_rad_cyl) + squ(g_hht) )

c check if # of OMs is too many for the g.om array size
	if ( g_num_oms .gt. max_num_oms_det) then
	  WRITE(*,*) ' Error reading geom file: Too many OMs in det'
	  WRITE(*,*) ' Change max_num_oms_det in file km3.inc to',
	1      g_num_oms   
	  i_err = 1
	  RETURN
        END IF

c check if # of Strings is too many for the nested geometry array size
	if ( g_num_str .gt. max_num_str) then
	  WRITE(*,*) ' Error reading geom file: Too many strings'
	  WRITE(*,*) ' Change max_num_str in file km3.inc to',
	1      g_num_str   
	  i_err = 1
	  RETURN
        END IF
*
	om_id_km3 = 0
        n_strings  = 0
        n_clusters = 0

* -------------------
* Fill number of clusters per string
* -------------------
        do i=1,nstr
         g_str_num_cls(i)=0
	enddo
	
        do i=1,nclu
         g_str_num_cls(istrcl(i))=g_str_num_cls(istrcl(i))+1         
	enddo
 
* -------------------
* Loop over Strings :
* -------------------
c now continue reading the data file, looping over strings

	do i = 1, nstr
	  n_strings = n_strings + 1
	  g_str_id_ant_str(i) = i-1
* center of gravity over full line
          call COGSTRING(i,dummy_vec)
	  g_str_x(1,i) = dummy_vec(1)/100. ! cm to meters
	  g_str_x(2,i) = dummy_vec(2)/100.
	  g_str_x(3,i) = dummy_vec(3)/100.
	  g_str_rad_cyl(i) = 0.8
	  g_str_hht(i)     = g_hht

c calculate radius of string enclosing sphere
	  g_str_rad_sph(i) = sqrt( squ(g_str_rad_cyl(i)) + 
     1                       squ(g_str_hht(i)) )

c check if # of clusters is too many for the nested geometry array size
	  if ( g_str_num_cls(i) .gt. max_num_cls) then
	    WRITE(*,*) ' Error reading geom file: Too many clusters'
	    WRITE(*,*) ' Change max_num_cls in file km3.inc to',
     1        g_str_num_cls(i) 
	    i_err = 1
	    RETURN
	  END IF
	enddo

* --------------------
* Loop over Clusters :
* --------------------

	j = 0
	do jj=1,nclu
	  n_clusters = n_clusters + 1
	  j = IFLOOR(jj)  ! floor ID 1-25
	  i = istrcl(jj)  ! string ID 1-12
	  g_str_cls_id_ant_cls(j,i) = iclu(jj)
	  g_str_cls_id_ant_str(j,i) = istrcl(jj)-1
	  g_str_cls_x(1,j,i) = vcencl(1,jj)/100. ! from cm to meters
	  g_str_cls_x(2,j,i) = vcencl(2,jj)/100.
	  g_str_cls_x(3,j,i) = vcencl(3,jj)/100.
	  g_str_cls_rad_cyl(j,i) = 0.8
	  g_str_cls_hht(j,i) = 0.0
	  g_str_cls_num_oms(j,i) = nphclu

c calculate radius of cluster enclosing sphere
	  g_str_cls_rad_sph(j,i) = sqrt( 
	1      squ(g_str_cls_rad_cyl(j,i)) + 
	2      squ(g_str_cls_hht(j,i)) )
	    
c check if # of OMs is too many for the nested geometry array size
	  if ( g_str_cls_num_oms(j,i) .gt. max_num_oms_cls) then
	    WRITE(*,*) ' Error read geom file: Too many OMs in CLS'
	    WRITE(*,*) ' Change max_num_oms_cls in file km3.inc to',
	1	 g_str_cls_num_oms(j,i)
	    i_err = 1
	    RETURN
	  END IF
	enddo	

* ---------------
* Loop over OMs :
* ---------------

	k = 0
	jj = 1
	do l=1,nphomu
	  om_id_km3 = om_id_km3 + 1
	  i = idstr(l)             ! string id
	  k = k + 1
	  if (k .gt. nphclu) then  ! k loops from 1 to the #PMs per cluster
	    k = 1
	    jj = jj + 1   
	  endif
	  j = IFLOOR(jj)           ! floor ID 1-25
	  g_om_id_ant_om(l) =  idpm(l)
	  g_om_id_ant_cls(l) = idcls(l)
	  g_om_id_ant_str(l) = idstr(l)-1
	  g_str_cls_om_x(1,k,j,i) = vpm(1,l)/100. ! from cm to m
	  g_str_cls_om_x(2,k,j,i) = vpm(2,l)/100. ! OM position
	  g_str_cls_om_x(3,k,j,i) = vpm(3,l)/100.
	  g_om_dir(1,l) =     dpm(1,l)
	  g_om_dir(2,l) =     dpm(2,l)  ! OM orientation
	  g_om_dir(3,l) =     dpm(3,l)

	  WRITE(34,*) 
	1      g_om_id_ant_om(l), 
	2      g_om_id_ant_cls(l), 
	3      g_om_id_ant_str(l),
	4      g_str_cls_om_x(1,k,j,i), 
	5      g_str_cls_om_x(2,k,j,i),
	6      g_str_cls_om_x(3,k,j,i), 
	7      g_om_dir(1,l),
	8      g_om_dir(2,l), 
	9      g_om_dir(3,l)


c renormalise OM direction vector
C D. Bailey: 22/11/00
C Again, a copy in each direction. Not performance limiting in this routine
C but it may be elsewhere...
          DO m=1,3 
            dummy_vec(m) = g_om_dir(m,l)
          END DO
	  call renorm_vec(dummy_vec) 
          DO m=1,3 
            g_om_dir(m,l) = dummy_vec(m)
          END DO
	      
c copy the remaining information into the g.om detector array 
	      
	  g_str_cls_om_id_km3(k,j,i) = l
	  do m = 1, 3
	    g_om_x(m,l) = g_str_cls_om_x(m,k,j,i)
	  enddo

	enddo
	
c check # of OMs read-in is correct
	if ( om_id_km3 .ne. g_num_oms ) then
	  WRITE(*,*) ' Error reading geometry file: # OMs wrong',
     & om_id_km3, g_num_oms
	  i_err = 1
	  RETURN
        END IF

c check # of clusters read-in is correct
	if ( n_clusters .ne. g_num_cls ) then
	  WRITE(*,*) ' Error reading geometry file: # CLs wrong'
	  i_err = 1
	  RETURN
        END IF

c check # of strings read-in is correct
	if ( n_strings .ne. g_num_str ) then
	  WRITE(*,*) ' Error reading geometry file: # STRs wrong'
	  i_err = 1
	  RETURN
        END IF

c Read is successful, write summary to log file
	WRITE(*,*) ' Geometry file read succesfully'
        Write(*,*) ' # strings = ', n_strings, ' # clusters = ',
	1    n_clusters, ' # oms = ', g_num_oms 
*
        END
        INTEGER FUNCTION NTOTCLUSTER(NLINE)
c       ----------------------------------
c--- finds how many clusters (floors) exist on a given line
c
c        INCLUDE 'km3-phomul.inc'
      	 INCLUDE 'km3.inc'
	
        INTEGER TOT, I, NLINE
	TOT = 0

        DO I=1,NCLU
	 IF ( ISTRCL(I) .EQ. NLINE ) THEN
          TOT = TOT + 1
	 ENDIF
	ENDDO
        NTOTCLUSTER = TOT
	RETURN
	END
        SUBROUTINE COGSTRING(NLINE,COG)
c       ----------------------------------
c--- calculates center fo gravity of string
c
c        INCLUDE 'km3-phomul.inc'
        INCLUDE 'km3.inc'
	
	INTEGER NLINE, K, NC, I
        REAL COG(3)
	
	DO K=1,3
	 COG(K) = 0.
	ENDDO
        NC = 0

        DO I=1,NCLU
	 IF ( ISTRCL(I) .EQ. NLINE ) THEN
          NC = NC + 1
	  DO K=1,3
	   COG(K) = COG(K) + VCENCL(K,I)
	  ENDDO
	 ENDIF
	ENDDO
	
	DO K=1,3
	 COG(K) = COG(K)/NC
	ENDDO
	RETURN
	END
        INTEGER FUNCTION IFLOOR(ID)
c       --------------------------
c--- find floor identifier 1-25 for given cluster identifier ID
c--- numbering from top to bottom (for historical reason)
c
c        INCLUDE 'km3-phomul.inc'
        INCLUDE 'km3.inc'
	INTEGER IL,IFL,I,ID
	REAL ZZ
	
        IL = ISTRCL(ID)
	ZZ = VCENCL(3,ID) 
        IFL = 1
        DO I=1,NCLU
	 IF ( I .NE. ID ) THEN
	  IF ( ISTRCL(I) .EQ. IL ) THEN
           IF ( ZZ .LT. VCENCL(3,I) ) THEN
	    IFL = IFL + 1
	   ENDIF
	  ENDIF
	 ENDIF
	ENDDO
        IFLOOR = IFL
	RETURN
	END
