C*/
      SUBROUTINE find_oms_near_track( track_start, track_dir,
     1           track_length, track_end, rho_max, oms_in_range, 
     2           num_oms_in_range)

*     Created:  23-FEB-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
c     find all OMS less than a distance rho_max away from a given track
c     by searching through the nested geometry structure

*     In/Out Variables:-
*     ==========
c     in	track_start	xyz coordinates of the track start	
c     in	track_dir	xyz direction cosines along track (from
c                               track_start to the other end)	
c     in	track_length	length of track 
c     in	track_end	xyz coordinates of the track end	
c     in	rho_max    	 distance in meters to decide if in range 
c     out       oms_in_range     array of OM id's which are in range
c     out       num_oms_in_range number of OMs which are in range (returns 0
c                                if no OMs in range).
 
*     Common Block Access:-
*     ===================
c     /km3/  	in 		holds structures for KM3

*     Assumptions:-
*     ===========

*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine

      INCLUDE 'km3.inc'

      INTEGER*4  num_oms_in_range, oms_in_range(max_num_oms_det)
      INTEGER*4  i, j, k, idum
      REAL*4     track_start(3), track_dir(3), track_length
      REAL*4     track_end(3), rho_max, closest
      REAL*4     dummy_vec1(3)

      num_oms_in_range = 0
      call vzero(oms_in_range,max_num_oms_det)

c check to see that the detector itself is within range of the track

      call distance_to_track( track_start, track_dir, 
     1     track_length, track_end, g_origin, closest )

      if ( closest .lt. rho_max + g_rad_sph) then

c the track is within range of the detector
c now loop over strings, checking to see if any are in range          

        do i=1, g_num_str ! loop over strings

          DO idum=1,3
            dummy_vec1(idum) = g_str_x(idum,i)
          END DO
  
          call distance_to_track( track_start, track_dir, 
     1    track_length, track_end, dummy_vec1, closest )

          if ( closest .lt. rho_max + g_str_rad_sph(i)) then

c this string is within range of the detector
c now loop over clusters in this string, checking to see if any are 
c in range of the track         

            do j=1, g_str_num_cls(i) ! loop over clusters

              DO idum=1,3
                dummy_vec1(idum) = g_str_cls_x(idum,j,i)
              END DO

              call distance_to_track( track_start, track_dir, 
     1        track_length, track_end, dummy_vec1, closest )

              if ( closest .lt. rho_max + 
     1                          g_str_cls_rad_sph(j,i)) then

c this cluster is within range of the detector
c now loop over OMs in this cluster, checking to see if any are 
c in range of the track         

                do k=1, g_str_cls_num_oms(j,i)  ! loop over OMs

                  DO idum=1,3
                    dummy_vec1(idum) = g_str_cls_om_x(idum,k,j,i)
                  END DO

                  call distance_to_track( track_start, track_dir, 
     1            track_length, track_end, 
     2            dummy_vec1, closest )

                  if ( closest .lt. rho_max ) then

c the OM is within range and we update array and number of OMs in range

                    num_oms_in_range = num_oms_in_range + 1
                    oms_in_range(num_oms_in_range) = 
     1              g_str_cls_om_id_km3(k,j,i)

                  endif
                enddo
              endif
            enddo
          endif
        enddo
      endif
      end
