      SUBROUTINE GUGEPM(CHX,IERR)
C     ---------------------------------
C     read detector geometry from dadetector-file
C     store PM arrangement in common PHOMUL
C     global geometry values in common DETGEO
C     error codes: 0 - o.k.
C                  1 - file open failed or read error at LIN
C                  2 - unexpected EoF
C                  3 - wrong file structure
C                  4 - too many data words or tags
C                  5 - stack overflow (for IFLAG = 1)
C                  6 - invalid choice for IFLAG
C                  7 - required tag missing

C
      CHARACTER*255 CHX
      CHARACTER*245 CHGEOFIL
      INTEGER IERR, NL, I, LUNGEO
c
c--- find file name, run number and event number
c
      IERR = 0
      NL = LENOCC(CHX)
      IF (NL.LE.1) THEN
       WRITE(6,'('' GUGEPM: file name empty '')')
       IERR = 1
       GOTO 99
      ENDIF
      DO I=2,NL
       IF (CHX(I:I).EQ.' ') THEN
        CHGEOFIL = CHX(1:I-1)
        READ(CHX(I:NL),*) NRUNDET,NEVEDET
        GOTO 5
       ENDIF
      ENDDO
   5  CONTINUE     
c
c--- open file
c
      LUNGEO = 12
      OPEN(UNIT=LUNGEO,FILE=CHGEOFIL,STATUS='OLD',ERR=90)
      CALL  EVSETSTK(1)    ! add event in stack
c
c--- read run header
c
      CALL READ_GEO_RUN(LUNGEO,NRUNDET,IERR)
      IF (IERR.NE.0) GOTO 88
C
C--- read geometry event
C
      CALL READ_GEO_EVE(LUNGEO,NEVEDET,IERR)
      IF (IERR.NE.0) GOTO 88
C
C---compute OM positions and directions, c.o.g., detector size
C
      CALL COMP_GEO_EVE(IERR)
 88   CONTINUE
      CALL EVDELETE(1)
      CLOSE(LUNGEO)
      GOTO 99
C
 90   CONTINUE
      WRITE(6,*) ' ERROR OPENING GEOMETRY FILE ' 
      IERR = 1
  99  CONTINUE
      RETURN
      END

      SUBROUTINE READ_GEO_RUN(LUNGEO,NRUNDET,IERR)
C     --------------------------------------------
C     read run header from geometry file
C     LUNGEO   - logical unit for reading
C     NRUNDET  - run number
C     IERR     - error code
C                0 - o.k. others see GUGEPM
C    
c      INCLUDE 'km3-phomul.inc'
      INCLUDE 'km3.inc'
      INCLUDE 'km3-detgeo.inc'
      INCLUDE 'km3-params.inc'
      
c
      INTEGER IDU,LUNGEO,NRUNDET,IERR,NRUN,NEVENT,IEV,NDATEV,I,IDX
      INTEGER II,K,L,J,NPM,LOCATI
      REAL XDU
      CHARACTER*255 CHLINE,EVTAGN
      LOGICAL NEW_R,NEW_E
c
      CALL EVFINDRU(LUNGEO,NRUNDET,IERR)
      IF (IERR.NE.0) THEN
        WRITE(6,'('' error from EVFINDRU for GEO-file '',I5)') IERR
        GOTO 99
      ENDIF
C
      CALL EVINFO(NEW_R,NEW_E,NRUN,NEVENT,IEV)
      IF (NEW_R) THEN         ! start-of-run event
c
c--- explore 'environment' tag
c
       IF (NDATEV('environment').GE.1) THEN
          CHLINE = EVTAGN('environment')
          READ(CHLINE,*) XLAT,XLONG,XMAGDEC,ZSEAL,ZELEV
       ELSE
        WRITE(6,'('' no environment tag found in GEO-file '')')
        IERR = 7
        GOTO 99
       ENDIF
c
c--- explore 'OM_position' tag
c
       NPHCLU = NDATEV('OM_position')
       IF (NPHCLU.GT.MAX_NUM_OMS_CLS) THEN
        WRITE(6,'(''  to many PMs in cluster (GEO)'',I5)') NPHCLU
        NPHCLU = MAX_NUM_OMS_CLS
       ELSEIF (NPHCLU.EQ.0) THEN
        WRITE(6,'(''  no PMs in cluster (GEO)'')') 
        IERR = 7
        GOTO 99
       ENDIF
       DO I=1,NPHCLU
        CHLINE = EVTAGN('OM_position')
        READ(CHLINE,*) IDX   ! index
        II = I
        IF (I.GT.1) THEN     ! sort entries in ascending order
         DO K=I-1,1,-1      
          IF (IDCLU(K).LE.IDX) GOTO 10
          II = K
          IDCLU(K+1)   = IDCLU(K)
          THETCLU(K+1) = THETCLU(K)
          AZICLU(K+1)  = AZICLU(K)
          DO L=1,3
           VCLU(L,K+1) = VCLU(L,K)
          ENDDO
         ENDDO
 10      CONTINUE
        ENDIF                ! end sorting
        READ(CHLINE,*) IDCLU(II),(VCLU(J,II),J=1,3),
     +      THETCLU(II),AZICLU(II)
        DO J=1,3
          VCLU(J,II) = VCLU(J,II)*XMETER ! transform in cm
        ENDDO
       ENDDO   
c
c--- explore 'PM_type' tag
c
       NTYP = NDATEV('PM_type')
       IF (NTYP.GT.MAXTYP) THEN
        WRITE(6,'('' WARNING GUGEPM :  too many PM-types '',I5)')
     +    NTYP
        IERR = 7
        GOTO 99
       ELSEIF (NTYP.EQ.0) THEN
        WRITE(6,'('' WARNING GUGEPM :   no PM-types '')')
        IERR = 7
        GOTO 99
       ENDIF
       DO I=1,NTYP
        CHLINE = EVTAGN('PM_type')
        READ(CHLINE,*) IDX   ! index
        II = I
        IF (I.GT.1) THEN     ! sort entries in ascending order
         DO K=I-1,1,-1
          IF (IDTYP(K).LE.IDX) GOTO 20
          II = K
          IDTYP(K+1)   = IDTYP(K)
          AEFTYP(K+1)  = AEFTYP(K)
          TTSTYP(K+1)  = TTSTYP(K)
         ENDDO
 20      CONTINUE
        ENDIF                ! end sorting
        READ(CHLINE,*) IDTYP(II),XDU,AEFTYP(II),TTSTYP(II)
        AEFTYP(II) = AEFTYP(II)*XMETER**2    ! cm^2
       ENDDO
c
c--- explore 'OM' tag
c
       NPHOMU = NDATEV('OM')
       IF (NPHOMU.GT.MAX_NUM_OMS_DET) THEN
        WRITE(6,'('' WARNING GUGEPM :  too many PMS '',I5)')
     +    NPHOMU
        IERR = 7
        GOTO 99
       ELSEIF (NPHOMU.EQ.0) THEN
        WRITE(6,'('' WARNING GUGEPM :   no PMs '')')
        IERR = 7
        GOTO 99
       ENDIF
       DO I=1,NPHOMU
        CHLINE = EVTAGN('OM')
        READ(CHLINE,*) IDX   ! index
        II = I
        IF (I.GT.1) THEN     ! sort entries in ascending order
         DO K=I-1,1,-1
          IF (IDPM(K).LE.IDX) GOTO 30
          II = K
          IDPM(K+1)     = IDPM(K)
          IDPMTYP(K+1)  = IDPMTYP(K)
         ENDDO
 30      CONTINUE
        ENDIF                ! end sorting
        READ(CHLINE,*) IDPM(II),IDPMTYP(II)
       ENDDO
c
c--- explore 'OM_cluster' tag
c
       NCLU = NDATEV('OM_cluster')
       IF (NCLU.GT.MAX_NUM_CLS) THEN
        WRITE(6,'('' WARNING GUGEPM :  too many clusters '',I5)')
     +          NCLU
        IERR = 7
        GOTO 99
       ELSEIF (NCLU.EQ.0) THEN
        WRITE(6,'('' WARNING GUGEPM :   no clusters '')')
        IERR = 7
        GOTO 99
       ENDIF
       NPM  = NCLU*NPHCLU
       IF (NPM.GT.MAX_NUM_OMS_DET) THEN
        WRITE(6,'('' WARNING GUGEPM :  too many PMs '',I5)')
     +    NPM
        IERR = 7
        GOTO 99
       ENDIF
       DO I=1,NCLU
        CHLINE = EVTAGN('OM_cluster')
        READ(CHLINE,*) IDX   ! index
        II = I
        IF (I.GT.1) THEN     ! sort entries in ascending order
         DO K=I-1,1,-1
          IF (ICLU(K).LE.IDX) GOTO 40
          II = K
          ICLU(K+1)     = ICLU(K)
          ISTRCL(K+1)   = ISTRCL(K)
          DO L=1,NPHCLU
           IPMCL(L,K+1) = IPMCL(L,K) 
          ENDDO
         ENDDO           
 40      CONTINUE
        ENDIF                ! end sorting
        READ(CHLINE,*) ICLU(II),ISTRCL(II),XDU,IDU,
     +        (IPMCL(J,II),J=1,NPHCLU)
        DO J=1,NPHCLU   ! fill cluster and string ID in PM list
         IDX = LOCATI(IDPM,NPHOMU,IPMCL(J,II))
         IF (IDX.LE.0) THEN
           WRITE(6,'('' PM/CLS/STR not found in PM list'',3I5)')
     +     IPMCL(J,II),ICLU(II),ISTRCL(II)
           GOTO 99
         ENDIF
         IDCLS(IDX) = ICLU(II)
         IDSTR(IDX) = ISTRCL(II) 
        ENDDO           ! end fill cluster and string ID
       ENDDO
       NSTR = NDATEV('string') ! number of strings
      ELSE      ! no start-of-run found
        WRITE(6,'('' no start-of-run found in GEO-file '')')      
       IERR = 3
       GOTO 99       
      ENDIF
C
 99   CONTINUE
      RETURN
      END
      SUBROUTINE READ_GEO_EVE(LUNGEO,NEVEDET,IERR)
C     -----------------------------------------------------
C     read event from geometry file
C     LUNGEO   - logical unit for reading
C     NEVEDET  - event number
C     IERR     - error code
C                0 - o.k. others see GUGEPM
C    
c      INCLUDE 'km3-phomul.inc'
      INCLUDE 'km3.inc'
      INCLUDE 'km3-params.inc'

c
      REAL V1(3)
      CHARACTER*255 CHLINE,EVTAGN
      LOGICAL NEW_R,NEW_E
      INTEGER LUNGEO,NEVEDET,IERR,NRUN,NEVENT,IEV,NPM,NDATEV,I,IDX
      INTEGER II,LOCATI,NCLX,J
      REAL PHI,THE,PSI
C
      CALL EVFINDEV(LUNGEO,NEVEDET,IERR)
      IF (IERR.NE.0) THEN
        WRITE(6,'('' error from EVFINDEV for GEO-file '',I5)') IERR
        GOTO 99
      ENDIF
C
      CALL EVINFO(NEW_R,NEW_E,NRUN,NEVENT,IEV)
      IF (NEW_R) THEN         ! start-of-run event
       WRITE(6,'('' another start-of-run found in GEO-file'',I5)') NRUN
       IERR = 7
       GOTO 99
      ENDIF
C
c--- explore 'OM_data' tag
c
      NPM  = NDATEV('OM_data')
      IF (NPHOMU.NE.NPM) THEN
       WRITE(6,'('' WARNING GUGEPM :  inconsistent PM numbers '',2I5)')
     +    NPHOMU,NPM
       IERR = 7
       GOTO 99
      ENDIF
      DO I=1,NPHOMU
       CHLINE = EVTAGN('OM_data')
       READ(CHLINE,*) IDX   ! index
       II = LOCATI(IDPM,NPHOMU,IDX)
       IF (II.LE.0) THEN
         WRITE(6,'('' PM-ID not found in PM list'',I5)') II
         GOTO 99
       ENDIF
       READ(CHLINE,*) IDX,OFFTIM(II),OFFAMP(II),OFFEFF(II)
      ENDDO
c
c--- explore 'OM_cluster_data' tag
c
      NCLX = NDATEV('OM_cluster_data')
      IF (NCLX.NE.NCLU) THEN
       WRITE(6,'('' WARNING GUGEPM: inconsistent cluster nr '',2I5)') 
     +    NCLX,NCLU
       IERR = 7
       GOTO 99
      ENDIF
      DO I=1,NCLU  ! loop over clusters
       CHLINE = EVTAGN('OM_cluster_data')
       READ(CHLINE,*) IDX,(V1(J),J=1,3),PHI,THE,PSI
       II = LOCATI(ICLU,NCLU,IDX) ! find cluster id
       IF (II.LE.0) THEN
         WRITE(6,'('' CLS-ID not found in cluster list'',I5)') II
         GOTO 99
       ENDIF
       DO J=1,3
        VCENCL(J,II) = V1(J)*XMETER
       ENDDO
       EULECL(1,II) = PHI
       EULECL(2,II) = THE
       EULECL(3,II) = PSI
      ENDDO
C
 99   CONTINUE
      RETURN
      END
      SUBROUTINE COMP_GEO_EVE(IERR)
C     -----------------------------
C--- calculate global PM coord. VPM(1,IPM )and direction DPM(1,IPM)
C--- from cluster PM coord. VCLU(1,II),THETCLU(II),AZICLU(II)
C--- and from global cluster coord. VCENCL(),EULECL()
C
c      INCLUDE 'km3-phomul.inc'
      INCLUDE 'km3.inc'
      INCLUDE 'km3-detgeo.inc'
      INCLUDE 'km3-params.inc'
C
      REAL V2(3),V1(3)
      CHARACTER*13 CHDIR
      INTEGER II,J,IPM,LOCATI,K,I,IERR
      REAL PHI,THE,PSI,PHI1,THE1,PSI1,R
C
      IF (NCOG.EQ.0) THEN 
       VCOG(1) = 0.
       VCOG(2) = 0.
       VCOG(3) = 0.
      ENDIF
      DO II=1,NCLU  ! loop over clusters
       DO J=1,NPHCLU ! loop over PM in cluster
        IPM = LOCATI(IDPM,NPHOMU,IPMCL(J,II)) ! find PM id
        IF (IPM.LE.0) THEN
          WRITE(6,'('' PM-ID not found in cluster list'',I5)') IPM
          GOTO 99
        ENDIF
        PHI = EULECL(1,II)
        THE = EULECL(2,II)
        PSI = EULECL(3,II)
        CALL ROTAEU(V2,VCLU(1,J),PHI,THE,PSI) 
C            V2 now PM coord. (cm) in intermediate coord. system
C            (0,0,0) at cluster center but axes parallel to global coord.
        DO K=1,3
         VPM(K,IPM) = VCENCL(K,II) + V2(K) ! global PM coord. in cm
        ENDDO
        V1(1) = 0.
        V1(2) = 0.
        V1(3) = 1.
        PHI1 = 0.
        THE1 = THETCLU(J)
        PSI1 = PI/2.+ AZICLU(J)
        CALL ROTAEU(V2,V1,PHI1,THE1,PSI1) 
C            V2 now unit vector of PM direction in cluster coord.
        CALL ROTAEU(DPM(1,IPM),V2,PHI,THE,PSI)
C            DPM unit vector of PM direction in global coord.     
        IF (NCOG.EQ.0) THEN
         DO K=1,3
          VCOG(K) = VCOG(K) + VPM(K,IPM) ! calculate center of gravity (cm)
         ENDDO
        ENDIF
       ENDDO
      ENDDO
C
      IF (NCOG.EQ.0) THEN
       DO K=1,3
        VCOG(K) = VCOG(K)/FLOAT(NPHOMU)/XMETER !  transform into m
       ENDDO
      ENDIF
C
C--- transform into c.o.g. system and calculate detector size 
C                                          (ZMIND,ZMAXD,RADD)
C
      ZMAXD  = 0.
      ZMIND  = 0.
      RADD = 0.
      DO I=1,NPHOMU
       DO K=1,3
        VPM(K,I) = VPM(K,I) - VCOG(K)*XMETER ! transformation into cog system
       ENDDO
       R = SQRT(VPM(1,I)**2 + VPM(2,I)**2)
       IF (R.GT.RADD) RADD = R
       IF (VPM(3,I).GT.ZMAXD) ZMAXD = VPM(3,I)
       IF (VPM(3,I).LT.ZMIND) ZMIND = VPM(3,I)
      ENDDO
      DO I=1,NCLU
       DO K=1,3
        VCENCL(K,I) = VCENCL(K,I) - VCOG(K)*XMETER ! transf. into cog system
       ENDDO
      ENDDO
      ZELEV = ZELEV - VCOG(3)   ! transf. into cog system
      ZSEAL = ZSEAL - VCOG(3)   ! transf. into cog system
      ZMIND = ZMIND/XMETER      ! transform into m
      ZMAXD = ZMAXD/XMETER      ! transform into m
      RADD  = RADD /XMETER      ! transform into m 
C
C--- control printout
C
      WRITE(6,'('' geometry read successfully '')')
      WRITE(6,'('' number of PMs     '',i8)') nphomu
      WRITE(6,'('' number of strings '',i8)') nstr
      CALL CHARANG(XLONG,2,CHDIR)
      WRITE(6,'('' longitude'',A13)') CHDIR
      CALL CHARANG(XLAT,1,CHDIR)
      WRITE(6,'('' lattitude'',A13)') CHDIR
      WRITE(6,'('' elevation, depth '',2f10.3)') zelev,zseal
      WRITE(6,'('' c.o.g. (m) '',3f10.3)') (vcog(k),k=1,3)
C
 99   continue
      RETURN
      END
