      SUBROUTINE MUSIC(Emu,zf,Emu_f,x,y,z,t0,theta,phi,dr,t10)
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

C       V2(200) - ARRAY OF LOG OF RELATIVE ENERGY TRANSFERS (E/EMU) FOR WHICH
C               THE MUON INTERACTION INTEGRAL CROSS-SECTIONS WERE CALCULATED:
C               FROM 0.0 TO -10.0 WITH THE STEP OF -0.05. 
C               THE INTEGRATION STARTS
C               FROM FROM V2=ALOG10(E/EMU)=0.0 AND ENDS AT V2(I).
C       CS1(200,71,4) - ARRAY OF NORMALIZED INTEGRAL CROSS-SECTIONS FOR 
C               V2(200),
C               LOG OF MUON ENERGY (71) (FROM 0.0 (1 GEV) TO 7.0 (10000 TEV)
C               WITH THE STEP OF 0.1) AND 4 PROCESSES TAKING INTO ACCOUNT
C               (BREEMSTRAHLUNG, PAIR PRODUCTION, INELASTIC SCATTERING
C               AND KNOCK-ON ELECTRON PRODUCTION)

      implicit real*8 (a-h,o-z)
      REAL*8 mmu,n_a,n_z,n_rho,n_lambda
      real*4 yfl
      INTEGER*4 err
      INTEGER*4 ms_flag,d_flag
      PARAMETER (mmu=0.105658)
      PARAMETER (ms_flag=1)   !to switch off mult.scatt. set ms_flag=0
      PARAMETER (d_flag=1)    !to switch off scatt. due to other processes
                              ! set d_flag=0

      real*4 v2(201),cs1(201,71,4),cs2(201,71,4)
      integer*4 j0
      real*4 emulo(81,7),emc(81)
      COMMON/sig/v2,cs1,cs2,j0
      COMMON/coenlo/emulo,emc
      COMMON/rock2/n_a,n_z,n_rho,n_lambda
      COMMON/cut/e_cut

*       ema(61) - array of log of muon energies (GeV), 0.0, 0.1,...6.0.
*       va(30) - array of log of relative energy transfers, 0.0,-0.1,...-3.0.
*       anga(50) - array of log of scattering angles (rad), 0.4,0.3,...-4.5.
*       dang(50,30,61) - integral probability for muon scattering at an angle
*       larger than anga(i) for fixed values of ema(k) and va(j).

      real*4 ema(61),va(30),anga(50),dang(50,30,61)
      COMMON/ang/ema,va,anga,dang

      em=emu
      t1=t0
      err=0

    9 em1=EM
      J=DLOG10(em1)*10.+2
      IF(J.GE.71) J=71
      J1=J-1

C       IF THE MUON ENERGY BECOME LESS THAN 1 GEV THERE IS NO
C       SIMULATION OF STOCHASTIC ENERGY LOSSES

      IF(em1.LE.1.) GO TO 7

C       SIMULATION OF THE INTERACTION POINT

      call ranlux(yfl,1)

      FP=1./(CS2(J0,J,1)+CS2(J0,J,2)+CS2(J0,J,3)+CS2(J0,J,4))
      FP1=1./(CS2(J0,J1,1)+CS2(J0,J1,2)+CS2(J0,J1,3)+CS2(J0,J1,4))
      FP=(FP-FP1)/(EMC(J+10)-EMC(J1+10))*(DLOG10(EM1)-EMC(J1+10))+FP1
      T=-FP*ALOG(YFL)
      T3=T1+T
      z1=T*dcos(theta)

   15 IF(z+z1.LE.zf) GO TO 10

*       If the next interaction point is deeper than the level of observation
*       we will calculate the continuous energy losses and multiple scattering
*       up to the level of observation

      IF(t3.GT.t10) THEN
        em1=mmu
        dr=t10
        go to 16
      END IF
      t2=(zf-z)/dabs(dcos(theta))
      dz=t2*dcos(theta)

C       CALCULATION OF THE CONTINUOUS ENERGY LOSSES:
C       DUE TO IONISATION AND OTHER PROCESSES FOR V=E/EMU<V_cut

      CALL vdem(em1,B0,b0tot,BS)
      emf=em1-(em1*BS+B0)*T2
*      print *,'emf',emf
      IF(emf.LE.mmu) emf=mmu
      emi=10.**((DLOG10(emf)+DLOG10(em1))/2.)
      CALL vdem(emi,b0,b0tot,bs)
      CALL vem(em1,b0,b0tot,bs,t2,em3)
      IF(em3.LE.mmu) THEN
         dr=t1-t0+em1/b0
         em3=mmu
         t5=(em1-em3)/b0
         dz=t5/t2*dz
         t2=t5
      END IF

*      print *,'em1,em3',em1,em3

      theta2=0.
      phi2=0.
      deltax=0.
      deltay=0.
      deltar=0.
      dx1=0.
      dy1=0.
      dz1=dz

*       simulation of the multiple scattering
      IF(ms_flag.EQ.1) THEN
        CALL multiple
     *(t2,em1,em3,b0,bs,theta2,phi2,deltax,deltay,deltar,err)
cc      IF (err.ne.0) WRITE (*,3057) err,em1,em3
 3057   FORMAT(1x,'%MUSIC-W, multiple error status ',i1,2(1x,f10.5),
     &    ' (standard call)')
      ENDIF

*       transformation of the coordinates
      CALL coord_transform(dx1,dy1,dz1,deltax,deltay,dz,theta,phi)
*       transformation of the angles
      IF(theta2.NE.0.) THEN
        CALL angle_transform(theta,phi,theta2,phi2)
      END IF

      em1=EM3
      NM=1
      T=T-T2+deltar
      z=z+dz1
      x=x+dx1
      y=y+dy1
      t1=t1+t2+deltar

      IF(em3.LE.mmu) go to 16

      GO TO 11

   10 CONTINUE

*       Calculation of the continuous energy losses of muon up to the next
*       interaction point
      CALL vdem(em1,B0,b0tot,BS)
      emf=em1-(em1*BS+B0)*T
      IF(emf.LE.mmu) emf=mmu
      emi=10.**((DLOG10(emf)+DLOG10(em1))/2.)
      CALL vdem(emi,B0,b0tot,BS)
      CALL vem(em1,B0,b0tot,BS,T,EM2)
      IF(em2.LE.mmu) THEN
         dr=t1-t0+em1/b0
         em2=mmu
         t5=(em1-em2)/b0
         z1=t5/t*z1
         t=t5
      END IF

*      print *,'em1,em2',em1,em2

      theta2=0.
      phi2=0.
      deltax=0.
      deltay=0.
      deltar=0.
      dx1=0.
      dy1=0.
      dz1=z1

      IF(ms_flag.EQ.1) THEN
        CALL multiple           !multiple scattering between 2 interactions
     *(t,em1,em2,b0,bs,theta2,phi2,deltax,deltay,deltar,err)
cc      IF (err.ne.0) WRITE (*,3058) err,em1,em2
 3058   FORMAT(1x,'%MUSIC-W, multiple error status ',i1,2(1x,f10.5),
     &    ' (between two int. call)')
      END IF

*       transformation of the muon deflection to the base reference frame
      CALL coord_transform(dx1,dy1,dz1,deltax,deltay,z1,theta,phi)

      em1=em2
      T1=T3+deltar
      z=z+dz1
      x=x+dx1
      y=y+dy1

      IF(theta2.NE.0.) THEN
*       transformation of the deflection angles to the base reference frame
      CALL angle_transform(theta,phi,theta2,phi2)
      END IF

      IF(em1.LE.mmu) go to 16

      if(z.gt.zf) go to 11
      IF(em1.LE.1.) GO TO 7

      call ranlux(yfl,1)
      J=DLOG10(em1)*10.+2
      J2=DLOG10(em1)*10.+0.5+1
      IF(J.GE.71) J=71
      IF(J2.GE.71) J2=71
      J1=J-1

C       SIMULATION OF THE TYPE OF MUON INTERACTION
      css=cs2(j0,j,1)+cs2(j0,j,2)+cs2(j0,j,3)+cs2(j0,j,4)
      css1=cs2(j0,j1,1)+cs2(j0,j1,2)+cs2(j0,j1,3)+cs2(j0,j1,4)
      css=(css-css1)/(EMC(J+10)-EMC(J1+10))*(DLOG10(EM1)-EMC(J1+10))+
     *     css1
      al1=((cs2(j0,j,1)-cs2(j0,j1,1))/(EMC(J+10)-EMC(J1+10))*
     *     (DLOG10(EM1)-EMC(J1+10))+cs2(j0,j1,1))/css
      al2=((cs2(j0,j,2)-cs2(j0,j1,2))/(EMC(J+10)-EMC(J1+10))*
     *     (DLOG10(EM1)-EMC(J1+10))+cs2(j0,j1,2))/css
      al3=((cs2(j0,j,3)-cs2(j0,j1,3))/(EMC(J+10)-EMC(J1+10))*
     *     (DLOG10(EM1)-EMC(J1+10))+cs2(j0,j1,3))/css
      IF(yfl.GT.AL1) GO TO 20
      ip=1
      GO TO 23
   20 IF(YFL.GT.AL1+AL2) GO TO 21
      IP=2
      GO TO 23
   21 IF(YFL.GT.AL1+AL2+AL3) GO TO 22
      IP=3
      GO TO 23
   22 IP=4
   23 CONTINUE

C       SIMULATION OF THE FRACTION OF MUON ENERGY TRANSFERED
C       TO THE SECONDARY PARTICLE
      call ranlux(yfl,1)
      CALL vcs(j2,yfl,ip,v1)

      em=em1
c       simulation of the deflection angle of muon
      theta1=0.
      phi1=0.
      IF(ip.LE.3.AND.ip.GE.1.AND.d_flag.EQ.1) THEN
        CALL mu_scatt(ip,em,v1,theta1,phi1)
      END IF

      Demf=V1*em1
      EM=EM-Demf
      em1=em

c       transformation of the deflection angles to the base reference frame
      IF(theta1.NE.0.) THEN
        CALL angle_transform(theta,phi,theta1,phi1)
      END IF

      IF(em1.LE.mmu) go to 16
      GO TO 9
    7 CONTINUE

C       IF THE MUON ENERGY IS LESS THAN 1 GEV ONLY THE IONISATION
C       LOSSES ARE CALCULATED
      CALL vdem(em1,b0,b0tot,bs)
      z4=zf-z
      t4=z4/dabs(dcos(theta))
      emf=em1-(em1*bs+b0)*t4
      IF(emf.LE.mmu) emf=mmu
      emi=10.**((DLOG10(emf)+DLOG10(em1))/2.)
      CALL vdem(emi,b0,b0tot,bs)
      CALL vem(em1,b0,b0tot,bs,t4,em3)
c      print *,'z4,t4,em1,em3',z4,t4,em1,em3
      IF(em3.LE.mmu) THEN
         em3=mmu
         dr=t1-t0+em1/b0
         t5=(em1-em3)/b0
         z4=t5/t4*z4
         t4=t5
c      print *,'z4,t4,em1,em3',z4,t4,em1,em3
      END IF
      theta2=0.
      phi2=0.
      deltax=0.
      deltay=0.
      deltar=0.
      dx1=0.
      dy1=0.
      dz1=z4

*       simulation of the multiple scattering up to the level of observation
      IF(ms_flag.EQ.1) THEN
        CALL multiple
     *(t4,em1,em3,b0,bs,theta2,phi2,deltax,deltay,deltar,err)
cc         IF (err.ne.0) WRITE (*,3059) err,em1,em3
 3059   FORMAT(1x,'%MUSIC-W, multiple error status ',i1,2(1x,f10.5),
     &    ' (after int. call)')
      END IF
c      print *,'deltax,deltay,theta2,phi2',deltax,deltay,theta2,phi2

*       transformation of the coordinates
      CALL coord_transform(dx1,dy1,dz1,deltax,deltay,z4,theta,phi)

      em1=em3
      nm=2
      z=z+dz1
      x=x+dx1
      y=y+dy1
c      print *,'x,y,z',x,y,z
      t1=t1+t4+deltar

*       transformation of the angles
      IF(theta2.NE.0.) THEN
        CALL angle_transform(theta,phi,theta2,phi2)
      END IF

      IF(em1.LE.mmu) GO TO 16

   11 CONTINUE

      dr=t1-t0
      emu_f=em1

   16 CONTINUE

      IF(em1.LE.mmu) emu_f=mmu

      RETURN
      END
