c Routine to calculate the effective electron-shower energy using the
c one-particle approximation.
c includes low-energy fits per particle, and high-energy fits for pions
      REAL FUNCTION OPA_EFRAC(IPART,EKIN)
      
      
      IMPLICIT NONE
      REAL EKIN
      INTEGER IPART
      REAL weight_part,efrac, etemp
      REAL weight_pion, weight_klong, weight_kshort, ngamma_elec
      REAL weight_kaon, weight_neutron, weight_proton
      REAL wp40, whe40,whex, opa_weight_high_e
      
c 100% energy to EM showers if electron, positron, pi0, or gamma
      if (ipart .eq. 1 .or. ipart .eq. 2
     &	 .or. ipart .eq. 3 .or. ipart .eq. 7) then
	 opa_efrac = 1.0
	 return
      endif

c low-energy fits went up to 40 GeV      
      if (ekin .le. 40) then
      	 etemp=ekin
      else
      	 etemp=40.
      endif
      
c otherwise, calculate fractions the long way. First we get the
c expected number of photons from the particle:
      if (ipart .eq. 8 .or. ipart .eq. 9) then
      	 weight_part=weight_pion(etemp)
      else if (ipart .eq. 10) then
      	 weight_part=weight_klong(etemp)
      else if (ipart .eq. 16) then
      	 weight_part=weight_kshort(etemp)
      else if (ipart .eq. 11 .or. ipart .eq. 12) then
      	 weight_part=weight_kaon(etemp)
      else if (ipart .eq. 13) then
      	 weight_part=weight_neutron(etemp)
      else if (ipart .eq. 14) then
      	 weight_part=weight_proton(etemp)
      else
c     	 when in doubt, treat it as a pion
      	 weight_part=weight_pion(etemp)
      endif
      	
      if (ekin .le. 40) then
      	 opa_efrac = weight_part
      else if (ekin .ge. 1e7) then
      	 opa_efrac = opa_weight_high_e(ekin)
      else
c smooth transition between low-energy weights and high-energy pion weight
      	 wp40=weight_part
	 whe40=opa_weight_high_e(40.)
	 whex=opa_weight_high_e(ekin)	 
	 opa_efrac = whex - (whe40-wp40)*(7.-log10(ekin))/5.398
      endif
      
      return
      end


c **** calculates the expected number of photons for electrons as a function of energy
      REAL FUNCTION NGAMMA_ELEC(EKIN)
      implicit none
      REAL eleca,elecb,elecc,elecd,elece,ekin
      eleca = 1.33356e5
      elecb = 1.66113e2
      elecc = 16.4949
      elecd = 1.5385e5
      elece = 6.04871e5
      ngamma_elec = (eleca*ekin+elecb) * exp(-ekin/elecc) 
     &	    + (elecd*ekin+elece)* (1.-exp(-ekin/elecc))
      return
      end
	    
	    
c **** calculates the expected number of photons for pions as a function of energy
      REAL FUNCTION WEIGHT_PION(EKIN)
      implicit none
      REAL pia,pib,pic,pid,pie,pif,pig,pih,pix,ekin,lek
      REAL ngamma_elec
      
      pia             = 0.538346
      pib             = 1.32041
      pic             = 0.737415
      pid             = -0.813861
      pie             = -2.22444
      pif             = -2.15795
      pig             = -6.47242
      pih             = -2.7567
      pix             = 8.83498
      
      if (ekin .lt. 0.06) then
      	 weight_pion=1e4*pia/ngamma_elec(ekin)
      elseif (ekin .lt. 0.15) then
      	 weight_pion=pix*1e4*ekin/ngamma_elec(ekin)
      else
      	 lek=log(Ekin)
      	 weight_pion=(pib*1e5*ekin + (ekin**(1.-1./pic)) * 
     &	    (pid*1e4 + 1e4*pie*lek + 1e4*pif*lek**2 +
     &	     1e3*pig*lek**3 + 1e2*pih*lek**4 ))/ngamma_elec(ekin)
      endif
      
      return
      end

c **** calculates the expected number of photons for pions as a function of energy
      REAL FUNCTION WEIGHT_KAON(EKIN)
      implicit none
      REAL ka,kb,kc,kd,ke,kf, ekin,ngamma_elec
      
      ka              = 12.7537
      kb              = -1.052
      kc              = 3.49559
      kd              = 16.7914
      ke              = -0.355066
      kf              = 2.77116

      IF (ekin .gt. 0.26) then
      	 weight_kaon = (1e4*ka*(ekin+kb)*(1.-exp(-ekin/kc))
     &	    + 1e4*(kd*ekin+ke)*exp(-ekin/kc))/ngamma_elec(ekin)
      else
	 weight_kaon=kf*1e4/ngamma_elec(ekin)
      endif
      
      return
      end
      
      
c **** calculates the expected number of photons for K0-short as a function of energy
      REAL FUNCTION WEIGHT_KSHORT(EKIN)
      implicit none
      REAL k0sa,k0sb,k0sc,k0sd,ekin,ngamma_elec
      
      k0sa            = 0.351242
      k0sb            = 0.613076
      k0sc            = 6.24682
      k0sd            = 2.8858

      weight_kshort = (k0sa*1e5 + k0sb*1e5*ekin
     & 	 + ekin*k0sc*1e4*log(k0sd + 1./ekin))/ngamma_elec(ekin)
      
      return
      end

c **** calculates the expected number of photons for K0-short as a function of energy
      REAL FUNCTION WEIGHT_KLONG(EKIN)
      implicit none
      REAL k0la,k0lb,k0lc,k0ld,k0le,k0lf,ekin,ngamma_elec
      
      k0la            = 2.18152
      k0lb            = -0.632798
      k0lc            = 0.999514
      k0ld            = 1.36052
      k0le            = 4.22484
      k0lf            = -0.307859
      
      if (ekin .lt. 1.5) then
      	 weight_klong =  (1e4*k0la + ekin*1e5*k0lb*log(ekin)
     &    + 1e5*k0lc*ekin**1.5)/ngamma_elec(ekin)
      else
      	 weight_klong = (ekin*k0ld*1e5 
     &	    + ekin**(1.-1./k0le)*k0lf*1e5)/ngamma_elec(ekin)
      endif
      
      return
      end

c **** calculates the expected number of photons for protons as a function of energy
      REAL FUNCTION WEIGHT_PROTON(EKIN)
      implicit none
      REAL pa,pb,pc,pd,pe,pf,pg,ekin,ngamma_elec
      
      pa              = 12.1281
      pb              = -17.1528
      pc              = 0.573158
      pd              = 34.1436
      pe              = -0.28944
      pf              = -13.2619
      pg              = 24.1357
      
      weight_proton=1e4*(pa*ekin+pb)*(1.-exp(-ekin/pc))
     &   + 1e4*(pd*ekin +pe+ pf*ekin**2 + pg*ekin**3)*exp(-ekin/pc)
     
      weight_proton=weight_proton/ngamma_elec(ekin)

      return
      end

c **** calculates the expected number of photons for neutrons as a function of energy
      REAL FUNCTION WEIGHT_NEUTRON(EKIN)
      implicit none
      REAL na,nb,nc,nd,ne,nf,ng,nh,ni,nj,lek,ekin
      REAL ngamma_elec
      
      na              = 1.24605
      nb              = 0.63819
      nc              = -0.802822
      nd              = -0.935327
      ne              = -6.1126
      nf              = -1.96894
      ng              = 0.716954
      nh              = 2.68246
      ni              = -9.39464
      nj              = 15.0737
      
      if (ekin .gt. 0.5) then
      	 lek=log(ekin)
	 weight_neutron =  (na*1e5*ekin + 1e3*ekin**(1.-1./nb)
     &	    * (100.*nc+100.*nd*lek + 10.*ne*lek**2
     &	    + 11.*nf*lek**3))/ngamma_elec(ekin)
      else
      	 weight_neutron=(1e3*ng + 1e4*nh*ekin + 1e4*ni*ekin**2
     &     + 1e4*nj*ekin**3)/ngamma_elec(ekin)
      endif
      
      return
      end
   
c *** high-energy fit to weights for a high-energy pion (same as v4r5 version)
      REAL FUNCTION OPA_WEIGHT_HIGH_E(EKIN)
      implicit none
      REAL ETOT
      INTEGER IPART
      REAL Ma, Mb, Mc, Md, Me, Mf, Mg, Mh, Mi, Mkref, Mlc
      REAL num, denom, lognp, Ee, logE, Ekin
      
c     	 implement the energy-fractions according to M. Dentler: ANTARES-SOFT-2012-009. E must be the kinetic energy in GeV. Here, 'everything else' is treated as a pion. Other than charged pions, mostly kaons of all varieties and protons fall into this category. These fits were made mostly at high energies - at low energies, other fits are used.
      	 
      	 IF (Ekin .gt. 0.2) THEN
      	    logE=log10(Ekin)
	 ELSE
	    ! nphotons constant below 0.2 GeV (lowest fit point)
	    opa_weight_high_e=0.292
	    return
	 ENDIF
	 Ma=72.425
	 Mb=-49.417
	 Mc=5.858
	 Md=207.252
	 Me=132.784
	 Mf=-10.277
	 Mg=-19.441
	 Mh=58.598
	 Mi=53.161
	 Mkref=2.698
c	 leading_coef Mlc=(Ma-Mf)/Mkref
      	 Mlc=(Ma-Mf)/Mkref
	 num = Me + Md*logE + Mc*logE**2 + Mb*logE**3
     &               + Ma*logE**4 + Mlc*logE**5
	 denom=Mi + Mh*logE + Mg*logE**2 + Mf*logE**3
     &               + Mlc*logE**4
	 if (denom .le. 0) then
	    opa_weight_high_e = 0.
	    return
	 endif
	 lognp = num/denom
	 Ee=10.**(lognp-Mkref)
	 opa_weight_high_e=Ee/Ekin
      
      return
      END
