C*/
      SUBROUTINE process_event

*     Created:  28-FEB-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
c     Top level routine for processing a single event.
c     Loop through the particles in the
c     p array (this array holds all the particles for the current event).
c     After this routine has been called, all the particles will have been
c     processed into OM hits, and we then output the event so that
c     it can processed by another program which adds PMT noise, tts,
c     and other PMT electronics effects and then gets reconstructed.

*     In/Out Variables:-
*     ==========
 
*     Common Block Access:-
*     ===================
c     /km3/  	in 		holds structures for KM3

*     Assumptions:-
*     ===========
c     As we loop through the particles we may create secondary particles
c     (muons or showers) which are added on to the END of the P array,
c     and the value of gen_npart is increased to reflect the extra particle(s) 
 
*     Revision History:-
*     ================c     V1	M. Moorhead	Created routine

      INCLUDE 'km3.inc'
*
      INTEGER*4 part_num, flag_cut, ier, j, ierr, eff_seg_num
      CHARACTER*255 CHLINE
      REAL      BJ
      REAL     em_cut, mu_cut
      
c `clear' the hit buffer by setting nhits=0
      gen_nhits = 0
      nlines = 0
      tminh =  1.0E+35   ! earliest hit time
      tmaxh = -1.0E+35   ! latest   hit time

c start with the first particle
      part_num = 1

c loop over all particles
      do while (part_num .le. gen_npart) 
	 IF ( p_part_id(part_num) .eq. p_id_muon ) then
c this particle is a muon and so we call cut_muon to see if it gets close 
c enough to the detector to be of interest. The cut distance is chosen
c to be the maximum of all possible cut distances
      	    mu_cut=max(h_rho_muon_dir_cut,
     &	       h_rho_muon_scat_cut)
      	    em_cut=h_rho_elec_cut_base + h_rho_elec_cut_del*
     & 	          max(( log10( p_e0(part_num) ) - 2.0),0.)
	    h_muon_cut_distance=max(mu_cut,em_cut)
	    call cut_muon( part_num, flag_cut )

            if ( flag_cut .eq. 0) then 
c the muon has come close enough to KM3 so that it is worth tracking
c and processing into OM hits

               call track_muon( part_num, ier )
               call process_muon( part_num )  
  
            else
c the muon has been `cut' and so we log the outcome

               p_outcome(part_num) = 0

      	    endif

* Negative track length if track leaves the can:
            BJ = 1.
            IF (p_outcome(part_num) .eq. 2)  BJ = -1.
            IF (p_outcome(part_num) .eq. 0)  BJ =  0.
*
* FORMAT change to separate Energy and Time
*
      	    WRITE(CHLINE,'(I6,3F11.3,3F10.6,E15.6,1x,F10.2,1x,I3,F11.3)')
     &       p_track_id(part_num), (p_x0(j,part_num),j=1,3),
     &      (p_v0(j,part_num),j=1,3),
     &       p_e0(part_num), p_t0(part_num), p_part_id(part_num),
     &       p_length(part_num)*BJ
            CALL EVTAGA('track_in',CHLINE,IERR)
      	    IF (IERR.NE.0) 
     &          WRITE(6,'(''ERROR when writting track_in tag '')')
*
c  writes energy-loss if applicable
      	    IF (ELOSS_NSEGS .gt. 0.5) then
	       CALL make_eloss_string(part_num,ierr)
	       IF (IERR.NE.0)
     & WRITE(6,'(''ERROR when writting eloss tag '')')
	    END IF
c ### checks if it's a tau ####
          ELSE IF ( p_part_id(part_num) .eq. p_id_tau ) then
c this particle is a tau and so we call cut_tau to see if it gets close 
c enough to the detector to be of interest. The cut distance is chosen
c to be the maximum of all possible cut distances
      	    mu_cut=max(h_rho_muon_dir_cut,
     &	       h_rho_muon_scat_cut)
      	    em_cut=h_rho_elec_cut_base + h_rho_elec_cut_del*
     & 	          max(( log10( p_e0(part_num) ) - 2.0),0.)
	    h_muon_cut_distance=max(mu_cut,em_cut)
	    call cut_muon( part_num, flag_cut )

            if ( flag_cut .eq. 0) then 
c the muon has come close enough to KM3 so that it is worth tracking
c and processing into OM hits
               call make_tau_track( part_num, ier )
               call process_muon( part_num )
c Always has tau contained within - full tracking always
               IF (p_outcome(part_num) .eq. 2)  then
	          BJ = -1.
	       else
	          BJ=1.
	       end if
            else
c the tau has been `cut' and so we log the outcome
               p_outcome(part_num) = 0
               BJ=0.
      	    endif
*
* FORMAT change to separate Energy and Time
*
      	    WRITE(CHLINE,'(I6,3F11.3,3F10.6,E15.6,1x,F10.2,1x,I3,F11.3)')
     &       p_track_id(part_num), (p_x0(j,part_num),j=1,3),
     &      (p_v0(j,part_num),j=1,3),
     &       p_e0(part_num), p_t0(part_num), p_part_id(part_num),
     &       p_length(part_num)*BJ
            CALL EVTAGA('track_in',CHLINE,IERR)
      	    IF (IERR.NE.0) 
     &          WRITE(6,'(''ERROR when writting track_in tag '')')
*

      	 ELSE IF ( (p_part_id(part_num) .eq. p_id_electron) .or.
     1             (p_part_id(part_num) .eq. p_id_photon) ) then

c call process_em_shower to process this electromagnetic shower
c into OM hits

      	    IF (PART_NUM.LE.GEN_NPARTIN) THEN

               WRITE(CHLINE,'(I6,3F11.3,3F10.6,2E15.6,I3)')
     &            p_track_id(part_num), (p_x0(j,part_num),j=1,3),
     &            (p_v0(j,part_num),j=1,3),
     &            p_e0(part_num), p_t0(part_num), p_part_id(part_num)
               CALL EVTAGA('track_in',CHLINE,IERR)
               IF (IERR.NE.0) 
     &            WRITE(6,'(''ERROR when writting track_in tag '')' )

            ENDIF

C--- Change to only call for bremsstrahlung EM showers
            IF (PART_NUM.GT.GEN_NPARTIN) THEN
	       call process_em_shower( part_num, ier, eff_seg_num )
            ENDIF
	    
C If the particle number is LE to the number read in, it is part of the 
C neutrino vertex and we echo it back to the output file.
         
	 ELSE IF ( p_part_id(part_num) .EQ. H_OPA_ID .AND.
     & H_OPA .GT. 0) THEN
c always write the output of OPA-generated particles, with appropriate code
	    WRITE(CHLINE,'(I6,3F11.3,3F10.6,2E15.6,I3)')
     &            p_track_id(part_num), (p_x0(j,part_num),j=1,3),
     &            (p_v0(j,part_num),j=1,3),
     &            p_e0(part_num), p_t0(part_num), p_part_id(part_num)
               CALL EVTAGA('track_in',CHLINE,IERR)
               IF (IERR.NE.0) 
     &            WRITE(6,'(''ERROR when writting track_in tag '')' )
	    
c always process OPA cascades as electron cascades
	    call process_em_shower( part_num, ier, eff_seg_num )
      	 ELSE IF ( p_part_id(part_num) .eq. p_id_laser) then
c call process_photon_bomb to process this LASER-flash into OM hits
	       call process_photon_bomb( part_num, ier )
         ELSE

C            print *,'Warning: Particle in process_event was not a muon.'
C            print *,'or electron. ONLY muons/electronss are currently' 
C            print *,'supported ... part_id =',p_part_id(part_num)


      	    WRITE(CHLINE,'(I6,3F11.3,3F10.6,2E15.6,I3)') 
     &       p_track_id(part_num), (p_x0(j,part_num),j=1,3),
     &      (p_v0(j,part_num),j=1,3),
     &       p_e0(part_num), p_t0(part_num), p_part_id(part_num)
      	    CALL EVTAGA('track_in',CHLINE,IERR)
            IF (IERR.NE.0) 
     &          WRITE(6,'(''ERROR when writting track_in tag '')')

      	 ENDIF
*
         part_num = part_num + 1

      enddo
*
* Potassium 40 simulation:
*
      IF(IK40(1).GT.0 .AND. gen_nhits.GT.0)THEN
        call process_k40
      ENDIF
*
      end
