C*/
      SUBROUTINE process_muon( part_num )

*     Created:  26-FEB-96
*     Contact:  M. Moorhead, LBNL.
*     Verified:

*     Purpose:-
*     =============
c     Process a given muon track into OM hits

*     In/Out Variables:-
*     ==========
c     in        part_num       number of particle (muon) in particle stack
 
*     Common Block Access:-
*     ===================
c     /km3/  	in 	        holds structures for KM3

*     Assumptions:-
*     ===========
c     Only the muon's continuous energy loss (+ a small amount of showering
c     below some threshold) is considered by this routine. If the muon has
c     produced a significant shower in any segment (above some threshold)
c     then this shower has been added (as an additional particle) to the 
c     event particle stack and will be treated separately by the routine
c     PROCESS SHOWER.
 
*     Revision History:-
*     ================
c     V1	M. Moorhead	Created routine

      INCLUDE 'km3.inc'

      INTEGER*4  num_oms_in_range, oms_in_range(max_num_oms_det)
      INTEGER*4  part_num, seg_num, i, seg_num_27, seg_num_9
      INTEGER*4  seg_num_3, idum
      REAL*4     rho_vec(3), rho, cos_band, theta_om, phi_om
      REAL*4     vec_diff
      REAL*4     dummy_vec1(3), dummy_vec2(3), dummy_vec3(3)
      REAL*4     dummy_vec4(3)
 
c first deal with direct hits from the muon track.

c find the OMs which are within a distance h_rho_max from the muon track

      DO idum=1,3
        dummy_vec1(idum) = p_x0(idum,part_num)
        dummy_vec2(idum) = p_dir(idum,part_num)
        dummy_vec3(idum) = p_x_end(idum,part_num)
      END DO

      CALL find_oms_near_track(dummy_vec1,dummy_vec2,
     &              p_length(part_num),dummy_vec3,h_rho_muon_dir_cut,
     &              oms_in_range,num_oms_in_range)
      
      if ( num_oms_in_range .eq. 0) return
c there are no OMs in range and we simply return

c loop over the OMs which are in range
      do i = 1, num_oms_in_range

c find the direct hits for this OM

         if (H_do_dir_ph .gt. 0.5) then
	    call muon_direct_hits( part_num, oms_in_range(i) )
	 endif

      enddo
      
c now we deal with the scattered hits.
c first we loop over the segments in big steps of 27 segments,

      do seg_num_27 = 14, p_nsegs(part_num) + 13, 27
 
        if ( seg_num_27 .le. p_nsegs(part_num) - 13 ) then  
c This group of 27 segments is complete (the muon track ends outside this 
c group). So we next find the OMs which are within a distance h_rho_max from 
c the central segment of this complete section of 27 segments

          DO idum=1,3
            dummy_vec1(idum) = seg_pos_center(idum,seg_num_27)
          END DO
          call find_oms_near_point(dummy_vec1, h_rho_muon_scat_cut,
     1         0.0, oms_in_range, num_oms_in_range )
        else
c The muon track ends within this group of 27 segments. 
c So we find the OMs which are within a distance h_rho_max from the last
c segment of the track.

          DO idum=1,3
            dummy_vec1(idum) = seg_pos_center(idum,p_nsegs(part_num))
          END DO
          
          call find_oms_near_point(dummy_vec1, h_rho_muon_scat_cut,
     1         0.0,oms_in_range, num_oms_in_range )
        endif
c loop over the OMs which are in range (if any)
        do i = 1, num_oms_in_range

c calculate the separation between this OM and the current segment

          DO idum=1,3
            dummy_vec1(idum) = seg_pos_center(idum,seg_num_27)
            dummy_vec2(idum) = g_om_x(idum,oms_in_range(i))
          END DO

          rho = vec_diff(dummy_vec1,dummy_vec2)
          
          if ( (rho .gt. h_rho_min_27) .and. 
     1         ( seg_num_27 .le. p_nsegs(part_num) - 13 ) ) then
c the OM is not too close to the 27 segments and so we can approximate the
c effect of the 27 segments by assuming they are all located at the central 
c segment (of the group of 27). (.AND. the group is complete)

c So, we find the values of the 4 geometrical parameters which describe the 
c geometrical relationship between this central segment and the OM 
c (rho,cos_band,theta_om,phi_om)
      	    
            DO idum=1,3
              dummy_vec1(idum) = seg_pos_center(idum,seg_num_27)
              dummy_vec2(idum) = seg_dir_center(idum,seg_num_27)
              dummy_vec3(idum) = g_om_x(idum,oms_in_range(i))
              dummy_vec4(idum) = g_om_dir(idum,oms_in_range(i))
            END DO
      	    
            call find_point_params(dummy_vec1,dummy_vec2,dummy_vec3,
     2      dummy_vec4, rho_vec,  rho, cos_band, 
     3      theta_om, phi_om )	

c Now find the scattered hits for this OM (from these 27 segments), including
c the hit times for each hit
            call muon_scattered_hits( part_num, seg_num_27,
     1      seg_ion_e_loss_27(seg_num_27),
     2      oms_in_range(i), rho, cos_band, theta_om, phi_om )

          else
c the OM is too close to average over 27 (or the group of 27 is incomplete)
c and so we loop over the three enclosed groupings of 9 segments

            do seg_num_9 = seg_num_27 - 9, seg_num_27 + 9, 9  

c calculate the separation between this OM and the current segment

              DO idum=1,3
                dummy_vec1(idum) = seg_pos_center(idum,seg_num_9)
                dummy_vec2(idum) = g_om_x(idum,oms_in_range(i))
              END DO

              rho = vec_diff(dummy_vec1,dummy_vec2)

              if ( ( rho .gt. h_rho_min_9 ) .and.
     1        ( seg_num_9 .le. p_nsegs(part_num) - 4 ) ) then
c the OM is not too close to these 9 segments and so we can approximate the
c effect of the 9 segments by assuming they are all located at the central 
c segment (of the 9). (AND the group is complete).

c So, we find the values of the 4 geometrical parameters which describe the 
c geometrical relationship between this central segment and the OM 
c (rho,cos_band,theta_om,phi_om)

                DO idum=1,3
                  dummy_vec1(idum) = seg_pos_center(idum,seg_num_9)
                  dummy_vec2(idum) = seg_dir_center(idum,seg_num_9)
                  dummy_vec3(idum) = g_om_x(idum,oms_in_range(i))
                  dummy_vec4(idum) = g_om_dir(idum,oms_in_range(i))
                END DO
                call find_point_params(dummy_vec1,dummy_vec2,dummy_vec3,
     &               dummy_vec4, rho_vec,  rho, cos_band, 
     3               theta_om, phi_om )	

c find the scattered hits for this OM (from these 9 segments), including
c the hit times for each hit
                call muon_scattered_hits( part_num, seg_num_9,
     1          seg_ion_e_loss_9(seg_num_9),
     2          oms_in_range(i), rho, cos_band, theta_om, phi_om )

              else
c the OM is too close to average over 9 segments (or the group of 9 is 
c incomplete)and so we loop over the three enclosed groupings of 3 segments 

                do seg_num_3 = seg_num_9 - 3, seg_num_9 + 3, 3  

c calculate the separation between this OM and the current segment

                  DO idum=1,3
                    dummy_vec1(idum) = seg_pos_center(idum,seg_num_3)
                    dummy_vec2(idum) = g_om_x(idum,oms_in_range(i))
                  END DO

                  rho = vec_diff(dummy_vec1,dummy_vec2)

                  if ( ( rho .gt. h_rho_min_3 ) .and.
     1            ( seg_num_3 .le. p_nsegs(part_num) - 1 ) ) then
c the OM is not too close to thes 3 segment and so we can approximate the
c effect of the 3 segments by assuming they are all located at the central 
c segment (of the 3). (AND the group of 3 is complete)

c So, we find the values of the 4 geometrical parameters which describe the 
c geometrical relationship between this central segment and the OM 
c (rho,cos_band,theta_om,phi_om)

                    DO idum=1,3
                      dummy_vec1(idum) = seg_pos_center(idum,seg_num_3)
                      dummy_vec2(idum) = seg_dir_center(idum,seg_num_3)
                      dummy_vec3(idum) = g_om_x(idum,oms_in_range(i))
                      dummy_vec4(idum) = g_om_dir(idum,oms_in_range(i))
                    END DO

                    call find_point_params(dummy_vec1,dummy_vec2,
     &              dummy_vec3,dummy_vec4, rho_vec,  rho, cos_band, 
     3              theta_om, phi_om )	

c find the scattered hits for this OM (from these 3 segments), including
c the hit times for each hitw
                    call muon_scattered_hits( part_num, seg_num_3,
     1              seg_ion_e_loss_3(seg_num_3),
     2              oms_in_range(i), rho, cos_band, theta_om, phi_om )

                  else
c the OM is too close to average over 3 segments (or the group is incomplete)
c and so we loop over the three enclosed segments 

                    do seg_num = seg_num_3 - 1, seg_num_3 + 1, 1  

c First check to make sure the segment number is not greater than the 
c total # of segments for this track
                      if ( seg_num .le. p_nsegs(part_num) ) then  
c we find the values of the 4 geometrical parameters which describe the 
c geometrical relationship between this segment and the OM 
c (rho,cos_band,theta_om,phi_om)

                    DO idum=1,3
                      dummy_vec1(idum) = seg_pos_center(idum,seg_num)
                      dummy_vec2(idum) = seg_dir_center(idum,seg_num)
                      dummy_vec3(idum) = g_om_x(idum,oms_in_range(i))
                      dummy_vec4(idum) = g_om_dir(idum,oms_in_range(i))
                    END DO
      	             	
                        call find_point_params(dummy_vec1,dummy_vec2,
     &                  dummy_vec3,dummy_vec4, rho_vec,  rho, 
     3                  cos_band, theta_om, phi_om )
c find the scattered hits for this OM (from this segment), including
c the hit times for each hit
                        call muon_scattered_hits( part_num, seg_num,
     1                  seg_ion_e_loss(seg_num), oms_in_range(i), 
     2                  rho, cos_band, theta_om, phi_om )

                      endif
                    enddo
                  endif   
                enddo 
              endif  
            enddo
          endif
        enddo
      enddo
      end
