C*/
      SUBROUTINE READ_MUON_RZ_FILE( ierror )
c
c This routine reads in the .rz (hbook) file which contains the hit
c distribution from muons

      INCLUDE 'km3.inc'
c
c  Local variables

      INTEGER*4 ierror, num_entries, ir,ib,iomt,iomp,it,count
      INTEGER*4 rec_length
      character*60 chrout

C Reset ERROR condition

      IERROR = 0
      
c the record length is the total number of time bins (el_sca_nbins(2,6)+1), plus
c the detection probability (1), in units of 4-byte reals
      rec_length=(mu_sca_nbins(1,5)+2)*4
      
      OPEN(UNIT=io_un_muon_rz, FILE=io_muon_rz_file,
     &      ACCESS='DIRECT', STATUS='OLD', FORM='UNFORMATTED',
     & 	    RECL=rec_length, IOSTAT=ierror)
      if (ierror.ne.0) then
         write (*,*) ' Error opening muon_rz file',ierror
         write (*,*) ' file name= ',IO_MUON_RZ_FILE
         return
      end if

c loop over entries. The only indices are radii and OM theta (variation in
c angle is small, so is governed by the time axis; and the OM phi thus
c has no effect, since the incident direct flux is cylindrically symmetric
c NOTE however: the om theta axis is reversed, since for direct muon hits
c only, the parameterisation is in cos theta, not theta itself, while hit
c writes the o/p from theta=0 to pi (min to max), cos theta needs to be
c from -1 to 1, i.e. theta=pi to 0.
      count=1
      
      do ir = 1, mu_dir_nbins(1)  ! loop over shells
      	 do iomt = mu_dir_nbins(2),1,-1
      	    READ(io_un_muon_rz,rec=count) mu_dir_prob(ir,iomt),
     & (mu_dir_time(ir,iomt,it),it=0,mu_dir_nbins(3))
      	    count = count+1
	    if (mu_dir_prob(ir,iomt) .eq. 0) then
	       mu_dir_prob(ir,iomt) = -40.
	    else
	       mu_dir_prob(ir,iomt) = log(mu_dir_prob(ir,iomt))
	    endif
      	 enddo
      enddo
c loop over entries. Note the outer-to-inner indices are radii, band,
c OM theta, and OM phi. km3 splits the bands into two groups in two 
c separate arrays, which is physically nice, and computationally idiotic.
      do ir = 1, mu_sca_nbins(1,1)  ! loop over shells
      	 do ib = mu_sca_nbins(1,2),1,-1   ! loop over low bands (theta_track), and reverse direction of ib
      	    do iomt = 1, mu_sca_nbins(1,3)
      	       do iomp = 1, mu_sca_nbins(1,4)  ! loop over phi_OM orientations
      	          READ(io_un_muon_rz,rec=count)
     &               mu_sca_prob(1,ir,ib,iomt,iomp),
     & (mu_sca_time(1,ir,ib,iomt,iomp,it),it=0,mu_sca_nbins(1,5))
      	          count = count+1
		  if (mu_sca_prob(1,ir,ib,iomt,iomp) .eq. 0) then
		     mu_sca_prob(1,ir,ib,iomt,iomp) = -40.
		  else
		     mu_sca_prob(1,ir,ib,iomt,iomp) = 
     & log(mu_sca_prob(1,ir,ib,iomt,iomp))
      	          endif
               enddo
            enddo
         enddo
	 do ib = 1, mu_sca_nbins(2,2)   ! loop over high bands (theta_track)
      	    do iomt = 1, mu_sca_nbins(2,3)
      	       do iomp = 1, mu_sca_nbins(2,4)  ! loop over phi_OM orientations
      	          READ(io_un_muon_rz,rec=count)
     &               mu_sca_prob(2,ir,ib,iomt,iomp),
     & (mu_sca_time(2,ir,ib,iomt,iomp,it),it=0,mu_sca_nbins(2,5))
      	          count = count+1
		  if (mu_sca_prob(2,ir,ib,iomt,iomp) .eq. 0.) then
		     mu_sca_prob(2,ir,ib,iomt,iomp) = -40.
		  else
		     mu_sca_prob(2,ir,ib,iomt,iomp) = 
     & log(mu_sca_prob(2,ir,ib,iomt,iomp))
      	          endif
               enddo
            enddo
         enddo
      enddo
      
c close the input muon .rz file and clear the ntuples from local paw memory
      close(io_un_muon_rz)
      end
