C*/
	SUBROUTINE READ_PHOTON_DESC_FILE(ierror)
*************************************************************************
*     Name           :  READ_PHOTON_DESC_FILE                           *
*     Called by      :                                                  *
*     Author         :  Sergio Navas                                    *
*     Date           :  18/09/1998                                      *
*     Task           :                                                  *
*                                                                       *
* This routine reads in the decscritpion files which contain all the    *
* relevant information with respect to                                  *
* the hit distributions from photons (LASER flash)                      *
*                                                                       *
*  In/Out Variables:                                                    *
*  -----------------                                                    *
*                                                                       *
*************************************************************************
	INCLUDE 'km3.inc'
        INCLUDE 'km3-params.inc'
c
c  Local variables

        INTEGER*4 part_id, i, ierror
        REAL*4    phot_energy, r_dum

c first we open the first photon description file which contains gloabl 
c quantities relevant to all the photon (LASER flash) hit distributions
	ierror = 0
	ierror = 0

	OPEN(UNIT=IO_UN_PHOTON_DESC,FILE=IO_PHOTON_DESC_FILE,
     1       STATUS='OLD', IOSTAT=ierror)
	IF(ierror.NE.0) THEN
	  WRITE(*,*) ' Error opening muon_desc file',ierror
	  RETURN
	END IF

        write(*,*) 'Open file ',IO_PHOTON_DESC_FILE,
     & ' Unit=',IO_UN_PHOTON_DESC
c
c  read inputs from control file
c  start with global variables

	READ(IO_UN_PHOTON_DESC,*)            ! skip line
	READ(IO_UN_PHOTON_DESC,*) part_id    ! should be photon (LASER flash)
        IF (part_id .ne. p_id_laser) then
           write(*,*) 'ERROR: non-photon found in photon (LASER flash)
     & desc file' 
           ierror = 1
           return
        endif

	READ(IO_UN_PHOTON_DESC,*) phot_energy  ! photon minimum energy
        write(*,*) 'first elec energy in desc file = ', phot_energy
      	READ(IO_UN_PHOTON_DESC,*) h_media_id ! 1=ice, 2=water

 	READ(IO_UN_PHOTON_DESC,*) h_refindex ! refractive index of water/ice
        h_groupindex = h_refindex

        h_cos_ch = 1.0 / h_refindex
        h_tan_ch = tan( acos( h_cos_ch ) )

	READ(IO_UN_PHOTON_DESC,*) h_dens_medium ! density of water/ice
	READ(IO_UN_PHOTON_DESC,*) r_dum ! segment lengths
	READ(IO_UN_PHOTON_DESC,*) r_dum ! average mu eloss <e_thresh
	READ(IO_UN_PHOTON_DESC,*) r_dum ! threshold for muon showers

c now read parameters for the radii dependence of hit distributions

	READ(IO_UN_PHOTON_DESC,*) phot_dir_nbins(1) ! number of radii bins
	READ(IO_UN_PHOTON_DESC,*) phot_dir_min(1)   ! minimum radius bin
	READ(IO_UN_PHOTON_DESC,*) phot_dir_max(1)   ! maximum radius bin
	READ(IO_UN_PHOTON_DESC,*) phot_dir_power(1) ! exponent for radii bins

* Check to see if there are too many shells in the input file
	if ( phot_dir_nbins(1) .gt. max_r ) then
* there are too many shells and the MAX_R parameter in the file
* hit.inc needs to be changed. Abort run until change is made and
* code re-compiled with new array sizes
	  write (*,*) 'FATAL ERROR: too many shells in input file'
	  write (*,*) 'Change value of MAX_R in km3.inc and recompile'
	  return
	endif
c the min and max radii must be adjusted to the correct power

        phot_dir_min(1) = phot_dir_min(1)**phot_dir_power(1)
        phot_dir_max(1) = phot_dir_max(1)**phot_dir_power(1)
 
c the variables must be copied into the scattered muon distributions

	phot_sca_nbins(1) = phot_dir_nbins(1)
	phot_sca_min(1)   = phot_dir_min(1)
	phot_sca_max(1)   = phot_dir_max(1)
	phot_sca_power(1) = phot_dir_power(1)

c now read band info for direct hit distributions.
        
	READ(IO_UN_PHOTON_DESC,*) phot_dir_nbins(2) ! # of bands
	READ(IO_UN_PHOTON_DESC,*) phot_dir_power(2) ! power for bands
	READ(IO_UN_PHOTON_DESC,*) phot_dir_step(2)  ! step between bins
	READ(IO_UN_PHOTON_DESC,*) phot_dir_min(2)   ! minimum band
	READ(IO_UN_PHOTON_DESC,*) phot_dir_max(2)   ! maximum band

c read the OM-theta angle info for direct photons

	READ(IO_UN_PHOTON_DESC,*) phot_dir_nbins(3)  ! # of cos(theta_OM) bins

c input the hardwired default values for theta_OM direct variables

        phot_dir_power(3) =  1.0
        phot_dir_min(3)   = -1.0     ! minimum cos(theta_OM)
        phot_dir_max(3)   =  1.0     ! maximum cos(theta_OM)

c now read band info for scattered hit distributions.
        
	READ(IO_UN_PHOTON_DESC,*) phot_sca_nbins(2) ! # of bands
	READ(IO_UN_PHOTON_DESC,*) phot_sca_power(2) ! power for bands
	READ(IO_UN_PHOTON_DESC,*) phot_sca_step(2)  ! step between bins
	READ(IO_UN_PHOTON_DESC,*) phot_sca_min(2)   ! minimum band
	READ(IO_UN_PHOTON_DESC,*) phot_sca_max(2)   ! maximum band

c input the hardwired default values for theta_OM variables
c for the scattered distributions

	phot_sca_nbins(3) = 5
	phot_sca_power(3) = 1.0  
	phot_sca_min(3)   = 0.0  ! minimum theta_OM
	phot_sca_max(3)   = c_pi ! maximum theta_OM

c input the hardwired default values for phi_OM variables
c for the scattered distributions

	phot_sca_nbins(4) = 3
	phot_sca_power(4) = 1.0  
	phot_sca_min(4)   = 0.0  ! minimum phi_OM
	phot_sca_max(4)   = c_pi ! maximum phi_OM

c read in the number of time bins for direct and scattered photons

	READ(IO_UN_PHOTON_DESC,*) phot_dir_nbins(4)  ! # of time bins
	READ(IO_UN_PHOTON_DESC,*) phot_sca_nbins(5)  ! # of time bins

C Close the first photon (LASER flash) desc file
	CLOSE(UNIT=IO_UN_PHOTON_DESC)

c calculate the step sizes and step prod factor for direct distributions

	write(*,*) ' -------  direct LASER bins   -------'
	write(*,*) ' 3dim    max    min   nbins   step'
        phot_dir_step_prod = 1.0
        do i = 1,3  ! loop over 3 geometrical dimensions
              phot_dir_step(i)  = (phot_dir_max(i) - 
     1        phot_dir_min(i) ) / float(phot_dir_nbins(i) - 1) 
              phot_dir_step_prod = phot_dir_step_prod * 
     1        phot_dir_step(i)

	      write(*,200) i,
     & phot_dir_max(i), phot_dir_min(i), phot_dir_nbins(i),
     & phot_dir_step_prod
        enddo

c calculate the step sizes and step prod factors for scattered distributions

	write(*,*) ' -----  scattered LASER bins   -------'
	write(*,*) ' 4dim    max    min   nbins   step'
        phot_sca_step_prod = 1.0
        do i = 1,4 ! loop over 4 geometrical dimensions
              phot_sca_step(i)  = (phot_sca_max(i) - 
     1        phot_sca_min(i) ) / float(phot_sca_nbins(i) - 1) 
              phot_sca_step_prod = phot_sca_step_prod * 
     1                              phot_sca_step(i)

	      write(*,200) i,
     & phot_sca_max(i), phot_sca_min(i), phot_sca_nbins(i),
     & phot_sca_step_prod
        enddo

 200	FORMAT(1X,I4,1X,F7.4,1X,F7.4,1X,I5,1X,F7.4)

        end
