#!/bin/bash
set -e
#cd /opt/exp_soft/km3net.org
pwd

home_folder=`pwd`
cd $home_folder

#wget http://www.inp.demokritos.gr/web2/cvfms_node.tar.gz
eTuser=km3filippidis
export port=$((61949 + $sn))

mkdir node-v0.10.31-linux-x64_$eTuser/
cp -r /opt/exp_soft/km3net.org/node-v0.10.31-linux-x64/* node-v0.10.31-linux-x64_$eTuser/



 #This is an example script to run a km3 job locally with the km3net detector. Please modify it according to your needs. If something goes wrong with running km3, contact Clancy James, at clancy.james@physik.uni-erlangen.de .
export CERN=/opt/exp_soft/km3net.org/cern
export CERN_ROOT=/opt/exp_soft/km3net.org/cern
export CERNLIB=$CERN/pro/lib
export CERNBIN=$CERN/pro/bin
export PATH=$PATH:$CERNBIN

# pointers to common directories and files
KM3_THRONG=afs/in2p3.fr/home/throng/km3net
KM3_V=v5r1
KM3_DAT=$KM3_THRONG/dat/km3/${KM3_V}
#KM3_EXEC=$KM3_THRONG/bin/km3mc${KM3_V}.exe
KM3_EXEC=km3_io/km3/Linux/km3mcv5r1.exe
DET_DIR=$KM3_THRONG/dat/det

# Does not abort on floating-point errors
export TRAPKM3FPE=0

# choose which test you'd like - the electron or muon test. Each contains 100 events near the centre of the detector
#export EVIFIL=${KM3_DAT}/elec_100_by_10tev_test.evt
export EVIFIL=${KM3_DAT}/muon_100_by_1tev_test.evt

# geometry file
export GEOFIL=${DET_DIR}/hex115_3inch31pm90_1836.det

# output event file
export EVOFIL=$home_folder/node-v0.10.31-linux-x64_$eTuser/node_modules/elastic-transfer/eTshare/test_event.km3.evt

# points to data files generated by 'hit'
TAG=km3net_800m_
LABEL=$KM3_V

export hbmuon=${KM3_DAT}/km3-${TAG}muon-100gev_${LABEL}.hit
export hbele1=${KM3_DAT}/km3-${TAG}elec-100mev_${LABEL}.hit
export hbele2=${KM3_DAT}/km3-${TAG}elec-3gev_${LABEL}.hit
export hbele3=${KM3_DAT}/km3-${TAG}elec-100gev_${LABEL}.hit
export hbele4=${KM3_DAT}/km3-${TAG}elec-3tev_${LABEL}.hit

export demuon=${KM3_DAT}/km3-${TAG}muon-100gev_${LABEL}.desc
export deele1=${KM3_DAT}/km3-${TAG}elec-100mev_${LABEL}.desc
export deele2=${KM3_DAT}/km3-${TAG}elec-3gev_${LABEL}.desc
export deele3=${KM3_DAT}/km3-${TAG}elec-100gev_${LABEL}.desc
export deele4=${KM3_DAT}/km3-${TAG}elec-3tev_${LABEL}.desc

# music files. NOTE: no dispersion file is needed
export Meloss=${KM3_DAT}/km3-music-eloss.dat
export Mddxsections=${KM3_DAT}/km3-music-double-diff.dat
export Mxsections=${KM3_DAT}/km3-music-cross-sections.dat


# Run KM3 with all other user options
$KM3_EXEC << EOF
# random number initialisation
IRAND 3 1000 0 0
# max number of events to process - this number should be large
INEVT 1
# merge events on a 0.5 ns level
XMERG 0.5
# do NOT apply any gain randomisation!
IGAIN 0
END
EOF

### default parameters, used by default in the above
# Uses the multi-particle approximation - setting it to '1' *should* be OK for high-energy, non-tau events
# INOPA 2
# testing options to record hit origins - off by default
# RECHO 0
# ELREC 0
# uses standard group velocity
# INGRP 2
# Write empty events - set to 0 to ignore empty events [why not do this?]
# IEMPT 1
# does not smear raw events
# XRAWH 0 25 250
# controls handling of 40k rate - the first zero turns it off
# IPT40 0 500
cd $home_folder

node-v0.10.31-linux-x64_$eTuser/bin/node  node-v0.10.31-linux-x64_$eTuser/node_modules/elastic-transfer/eT_v1.js $eTuser $port  &

sleep 5m
